/****************************************************
	TORNADO-E2/6713 Demo Utility.
	On-board I/O peripherals and Control Registers test. rev.1A
	(C) MicroLAB Systems, 2007


	Description:
	------------
	This demo scans continuously control registers within
	the DSP environment.


	TORNADO platform:
	-----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

	Copyright:
	----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


	Demo and Signal Parameters:
	---------------------------
	1. On-board BOOTMODE configuration switch: HPI
	2. Variable r contains possible error codes:
		(Note, that error codes
			from -1 to -9 are applied to common errors,
			from -10 to -19 are applied to C6xxx on-chip registers errors,
			from -20 to -29 are applied to DSP initialization errors,
			from -30 to -39 are applied to DSP ports configuration errors,
			from -100 to -109 are applied to FLASH PROGRAMMING CONTROL errors,
			from -50 to -99 are applied to user defined errors)
		 0	- no errors;
		-2	- invalid H/W error (not E2/6713 board);
		-3	- H/W error (error writing to the DSP external control registers, etc);
		-4	- incompatible H/W error (the setting is not allowed on this board);
		-10	- error writing to C6713B DSP regs;
		-20	- error during PLL configuration;
*****************************************************/

#define __T2E6XXX_SELECT_E6713__			1

#include "t2e6xxx_dsp.h"

unsigned pass_counter = 0;

void main()
{
	int i, j, n, r;
	
	// configure DSP PLL with SPREAD_SPECTRUM_CLK not used and initialize DSP
	if ((r = T2E6XXX_init_dsp(0)) != T2E6XXX_OK)
		goto error;

	// enter infinite test loop
	while (1)
	{
		// use uP WDT RESET strobe as synchro-pulse if oscilloscope is being used
		T2E6XXX_SET_WDT_RESET;

		// test WDT enable
		T2E6XXX_SET_WDT_EN_ON;
		if (!T2E6XXX_WDT_EN_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}
		T2E6XXX_SET_WDT_EN_OFF;
		if (T2E6XXX_WDT_EN_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		// test RTC enable
		T2E6XXX_SET_RTC_EN_ON;
		if (!T2E6XXX_RTC_EN_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}
		T2E6XXX_SET_RTC_EN_OFF;
		if (T2E6XXX_RTC_EN_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		// test PIOX2, SIOX rev.B and ASIOX rev.D reset control register
		T2E6XXX_SET_PIOX_DCM_RESET_OFF;
		if (T2E6XXX_PIOX_DCM_RESET_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}
		T2E6XXX_SET_PIOX_DCM_RESET_ON;
		if (!T2E6XXX_PIOX_DCM_RESET_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		T2E6XXX_SET_SIOX_DCM_RESET_OFF;
		if (T2E6XXX_SIOX_DCM_RESET_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}
		T2E6XXX_SET_SIOX_DCM_RESET_ON;
		if (!T2E6XXX_SIOX_DCM_RESET_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		T2E6XXX_set_dcm_reset_rg(3);
		if (T2E6XXX_get_dcm_reset_rg()!=3)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}
		T2E6XXX_set_dcm_reset_rg(0);
		if (T2E6XXX_get_dcm_reset_rg()!=0)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		// verify device ID register read-back data
		if (!T2E6713_BOARD)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		// verify device revision ID register read-back data
		if (!T2E6713_REV_ID_IS_REV1A)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		// verify DSP clock frequency ID register read-back data
		if (!T2E6713_DSP_CLK_FREQ_IS_300MHZ)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		// verify read-back bootmode data
		if (!T2E6XXX_BMODE_IS_HPI)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		// test EXT_INT/NMI source selectors
		// !!!note!!!: NMI source selector must not be tested since
		//			   no NMI interrupt handler is provided in this demo

		// ensure that NMI selector is OFF
		T2E6XXX_SET_EXT_INT_SEL_OFF(T2E6XXX_NMI_SEL);
		if (!T2E6XXX_EXT_INT_SEL_IS_OFF(T2E6XXX_NMI_SEL))
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		for (i=0;i <= 15; i++)
		{
			T2E6XXX_set_ext_int6_sel(i);
			T2E6XXX_set_ext_int7_sel(~i);
			T2E6XXX_set_ext_int4_sel(i+8);
			T2E6XXX_set_ext_int5_sel(i+5);

			if (	T2E6XXX_get_ext_int6_sel()!=i
				 || T2E6XXX_get_ext_int7_sel()!=((~i) &0xf)
				 || T2E6XXX_get_ext_int4_sel()!=((i+8) &0xf)
				 || T2E6XXX_get_ext_int5_sel()!=((i+5) &0xf)
				)
			{
				r = T2E6XXX_HW_ERR;
				goto error;
			}
		}

		T2E6XXX_SET_EXT_INT_SEL_OFF(T2E6XXX_EXT_INT4_SEL);
		T2E6XXX_SET_EXT_INT_SEL_OFF(T2E6XXX_EXT_INT5_SEL);
		T2E6XXX_SET_EXT_INT_SEL_OFF(T2E6XXX_EXT_INT6_SEL);
		T2E6XXX_SET_EXT_INT_SEL_OFF(T2E6XXX_EXT_INT7_SEL);
		
		// test FPGA FLASH control register register outputs
		if (T2E6XXX_FLASH_LEN_IS_8MX8 || T2E6XXX_FLASH_LEN_IS_64MX8)
		{
		// this is E2/6713 board with either 8Mx8 or 64Mx8 FLASH memory, i.e. with FPAGE register.
		// Number of bits in FPAGE register depends upon the FLASH length.
			if (T2E6XXX_FLASH_LEN_IS_8MX8)
				j = 3;
			else
				j = 6;

			// test FPAGE to the '0' state
			T2E6XXX_set_flash_page(0);
			T2E6XXX_SET_EXT_INT_SEL_OFF(T2E6XXX_EXT_INT4_SEL);
			if (T2E6XXX_get_flash_page() != 0)
			{
				r = T2E6XXX_HW_ERR;
				goto error;
			}

			// run '1' thru all FPAGE bits
			for (i = 0, n = 1; i < j; i++)
			{
				T2E6XXX_set_flash_page(n);
				// quad-wide the time for bit '0' for easier oscilloscope synch
				if (i == 0)
				{
					T2E6XXX_set_flash_page(n);
					T2E6XXX_set_flash_page(n);
					T2E6XXX_set_flash_page(n);
				}
				// write false bus data
				T2E6XXX_set_ext_int4_sel(~n);
				// verify FPAGE register contents
				if (T2E6XXX_get_flash_page() != n)
				{
					r = T2E6XXX_HW_ERR;
					goto error;
				}
				// shift '1' to the upper bit
				n <<= 1;
			}
			// clear FPAGE register at the end of the test
			T2E6XXX_set_flash_page(0);
		}
		pass_counter++;
	}

	// get here on any error condition
	// variable 'r' contains returned error code
error:
	while (1);
}

