/****************************************************
	TORNADO-E2/6713 Demo Utility.
	SDRAM memory test for E2/6713 f/w rev.1A boards
	(C) MicroLAB Systems, 2007

	Notes:
	1. E2/6713 boards are assumed to be configured with HPI boot.
	2. Variable r contains possible error codes:
		(Note, that error codes
			from -1 to -9 are applied to common errors,
			from -10 to -19 are applied to C6xxx on-chip registers errors,
			from -20 to -29 are applied to DSP initialization errors,
			from -30 to -39 are applied to DSP ports configuration errors,
			from -100 to -109 are applied to FLASH PROGRAMMING CONTROL errors,
			from -50 to -99 are applied to user defined errors)
		 0	- no errors;
		-2	- invalid H/W error (not E2/6713 board);
		-3	- H/W error (error writing to the DSP external control registers, etc);
		-4	- incompatible H/W error (the setting is not allowed on this board);
		-10	- error writing to C6713B DSP regs;
		-20	- error during PLL configuration;
		-50	- error during memory verification;
*****************************************************/

#define __T2E6XXX_SELECT_E6713__			1

#include "t2e6xxx_dsp.h"

#define T2E6XXX_SDRAM_ERR					-50		// error during memory verification

unsigned *ptr;

unsigned *DMEM_START_PTR, *DMEM_END_PTR;

unsigned start_data = 0xa596e73b,
         start_data_block;
unsigned mem_inc_data = 0x97b5f3be;
unsigned mem_wr_data;
unsigned pass_counter=0;


void main()
{
	int r;
	
	// configure DSP PLL with SPREAD_SPECTRUM_CLK not used and initialize DSP
	if ((r = T2E6XXX_init_dsp(0)) != T2E6XXX_OK)
		goto error;

	DMEM_START_PTR = ((unsigned *) T2E6XXX_SDRAM_AREA_SADDR);
	DMEM_END_PTR   = ((unsigned *) T2E6XXX_SDRAM_AREA_EADDR);

	while (1)
	{
		start_data_block= start_data;

		for (mem_wr_data=start_data, ptr=DMEM_START_PTR;
			ptr<=DMEM_END_PTR ; *ptr++ = mem_wr_data++);

		start_data=start_data_block;

		for (mem_wr_data=start_data, ptr=DMEM_START_PTR;
			ptr<=DMEM_END_PTR ;	)
		{
			if (*ptr++ != mem_wr_data++)
			{
				r = T2E6XXX_SDRAM_ERR;
				goto error;
			}
		}
		start_data += mem_inc_data ;

		pass_counter++;
	}

error:
	// variable 'r' contains returned error code
	while (1);
}

