/****************************************************
	TORNADO-E2/6713 Demo Utility.
	PIOX2 Synchronous 32-bit section
	Scan Data test for E2/6713 board. rev.1A
	(C) MicroLAB Systems, 2007

	Notes:
	1. In order to use this demo on E2/6713 board
		PX_DCM_INSTALLED signal (pin A5) and PX_DCM_SX_EN signal (pin A6)
		must be connected to GND!
	2. On-board BOOTMODE configuration switch: HPI boot
	3. Variable r contains possible error codes:
		(Note, that error codes
			from -1 to -9 are applied to common errors,
			from -10 to -19 are applied to C6xxx on-chip registers errors,
			from -20 to -29 are applied to DSP initialization errors,
			from -30 to -39 are applied to DSP ports configuration errors,
			from -100 to -109 are applied to FLASH PROGRAMMING CONTROL errors,
			from -50 to -99 are applied to user defined errors)
		 0	- no errors;
		-2	- invalid H/W error (not E2/6713 board);
		-3	- H/W error (error writing to the DSP external control registers, etc);
		-4	- incompatible H/W error (the setting is not allowed on this board);
		-10	- error writing to C6713B DSP regs;
		-20	- error during PLL configuration;
		-50	- PIOX DCM is not installed;
		-51	- Synchronous section of PIOX2 I/F is not enabled;
*****************************************************/

#define __T2E6XXX_SELECT_E6713__			1

#include "t2e6xxx_dsp.h"

#define T2E6XXX_PIOX_DCM_INSTALLED_ERR		-50		// PIOX DCM is not installed
#define T2E6XXX_PIOX_SYNC_EN_ERR			-51		// Synchronous section of PIOX2 I/F is not enabled

void main()
{
	unsigned d, i;
	int r;

	// configure DSP PLL with SPREAD_SPECTRUM_CLK not used and initialize DSP
	if ((r = T2E6XXX_init_dsp(0)) != T2E6XXX_OK)
		goto error;

	// check if PIOX DCM is installed
	// It's needed to connect PX_DCM_INSTALLED signal (pin A5) to GND to enable PIOX address and
	// data transceivers and to exclude manual short circuit during test!
	if (!T2E6XXX_PIOX_DCM_IS_INSTALLED)
	{
		r = T2E6XXX_PIOX_DCM_INSTALLED_ERR;
		goto error;
	}
	// check if PIOX2 DCM with Synchronous section support is installed
	// It's needed to connect PX_DCM_SX_EN signal (pin A6) to GND to enable 
	// synchronous PIOX address and data transceivers!
	if (!T2E6XXX_PIOX_DCM_TYPE_IS_ASYNC_SYNC)
	{
		r = T2E6XXX_PIOX_SYNC_EN_ERR;
		goto error;
	}

	while(1)
	{
		for (d = 0x1, i = 0; i < 32 ; i++)
		{
			T2E6XXX_write_piox_sync0_w32(0,d);
			if (i == 0)
				T2E6XXX_write_piox_sync0_w32(0,d);	/* perform double width for D0 synchronization */
			d = (d << 1);
		}
	}

	// get here on any error condition
	// variable 'r' contains returned error code
error:
	while (1);
}

