/****************************************************
	TORNADO-E2/6713 Demo Utility.
	ASIOX rev.D 16-bit parallel bus
	Scan Address test for E2/6713 board. rev.1A
	(C) MicroLAB Systems, 2007

		Note!!!:
		--------
		1. In order to run this demo on E2/6713 board
		 ASIOX rev.D I/F header must be installed, ASX_DCM_INSTALLED signal (pin 115),
		 ASX_DCM_PB_EN signal (pin 116) and ASX_READY signal (pin 73) must be connected to GND!

	TORNADO platform:
	-----------------
	This demo does not utilize any host resources.
	TI CCS6000 tools are required to recompile this demo.
	MIRAGE JTAG emulator are required to 
	upload code to the on-board DSP environment.

	Copyright:
	----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.

	Demo and Signal Parameters:
	---------------------------
	1. In order to use this demo on E2/6713 board
		ASX_DCM_INSTALLED signal (pin 115), ASX_DCM_PB_EN signal (pin 116)
		and ASX_READY signal (pin 73) must be connected to GND!
	2. On-board BOOTMODE configuration switch: HPI boot
	3. Variable r contains possible error codes:
		(Note, that error codes
			from -1 to -9 are applied to common errors,
			from -10 to -19 are applied to C6xxx on-chip registers errors,
			from -20 to -29 are applied to DSP initialization errors,
			from -30 to -39 are applied to DSP ports configuration errors,
			from -100 to -109 are applied to FLASH PROGRAMMING CONTROL errors,
			from -50 to -99 are applied to user defined errors)
		 0	- no errors;
		-2	- invalid H/W error (not E2/6713 board);
		-3	- H/W error (error writing to the DSP external control registers, etc);
		-4	- incompatible H/W error (the setting is not allowed on this board);
		-10	- error writing to C6713B DSP regs;
		-20	- error during PLL configuration;
		-50	- ASIOX rev.D I/F is not installed;
		-51	- Parallel bus for ASIOX rev.D DCM is not supported;
*****************************************************/

#define __T2E6XXX_SELECT_E6713__			1

#include "t2e6xxx_dsp.h"

#define T2E6XXX_ASIOX_DCM_IS_NOT_INSTALLED_ERR	-50		// ASIOX rev.D I/F is not installed
#define T2E6XXX_ASIOX_DCM_PIO_ERR				-51		// Parallel bus for ASIOX rev.D DCM is not supported

void main()
{
	unsigned d;
	int r;

	// configure DSP PLL with SPREAD_SPECTRUM_CLK not used and initialize DSP
	if ((r = T2E6XXX_init_dsp(0)) != T2E6XXX_OK)
		goto error;

	// check if ASIOX rev.D DCM (or adapter boards) is installed
	// It's needed to connect ASX_DCM_INSTALLED signal (pin 115) to GND
	if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
	{
		r = T2E6XXX_ASIOX_DCM_IS_NOT_INSTALLED_ERR;
		goto error;
	}
	// check if Parallel bus for ASIOX rev.D DCM is supported
	// It's needed to connect ASX_DCM_PB_EN signal (pin 116) to GND
	// to enable ASIOX address and data transceivers
	if (!T2E6XXX_ASIOX_DCM_TYPE_IS_SIO_PIO)
	{
		r = T2E6XXX_ASIOX_DCM_PIO_ERR;
		goto error;
	}

	while(1)
	{
		d = T2E6XXX_read_asiox_w16(1);			// provide A0 SYNCHRO as triple-width
		d = T2E6XXX_read_asiox_w16(1);			// provide A0 SYNCHRO as triple-width
		d = T2E6XXX_read_asiox_w16(1);			// provide A0 SYNCHRO as triple-width

		d = T2E6XXX_read_asiox_w16(2);			// A1
		d = T2E6XXX_read_asiox_w16(4);			// A2
		d = T2E6XXX_read_asiox_w16(8);			// A3
		d = T2E6XXX_read_asiox_w16(0x10);		// A4
		d = T2E6XXX_read_asiox_w16(0x20);		// A5
		d = T2E6XXX_read_asiox_w16(0x40);		// A6
		d = T2E6XXX_read_asiox_w16(0x80);		// A7
		d = T2E6XXX_read_asiox_w16(0x100);		// A8
		d = T2E6XXX_read_asiox_w16(0x200);		// A9
		d = T2E6XXX_read_asiox_w16(0x400);		// A10
		d = T2E6XXX_read_asiox_w16(0x800);		// A11
		d = T2E6XXX_read_asiox_w16(0x1000);		// A12
		d = T2E6XXX_read_asiox_w16(0x2000);		// A13
		d = T2E6XXX_read_asiox_w16(0x4000);		// A14
		d = T2E6XXX_read_asiox_w16(0x8000);		// A15
	}

error:
	// get here on error condition
	// variable 'r' contains returned error code
	while(1);
}

