/****************************************************
	TORNADO-E2/6713 Demo Utility.
	McASP-0/1 ports demo. rev.1A
	(C) MicroLAB Systems, 2007


	Description:
	------------
	This demo tests DSP McASP-0/1 ports. 

	This test configures all McASP pins as GPIO OUTPUT pins and continuously generates 
	'running '1'' over AXR[n], AFSX, AFSR, ACLKX, ACLKR, AHCLKX and AHCLKR pins
	for each McASP port. Oscilloscope can be used to view pulses at ASIOX rev.D I/F
	pins of McASP-0/1 ports.


	TORNADO platform:
	-----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

	Copyright:
	----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.

		Note!!!:
		--------
		1. In order to run this demo on E2/6713 board
		 ASIOX rev.D I/F header must be installed, ASX_DCM_INSTALLED signal (pin 115) and
		 ASX_DCM_PB_EN signal (pin 116) must be connected to GND!

	Board configuration and demo parameters:
	----------------------------------------
	1. On-board bootmode configuration switch: HPI
	2. Variable r contains possible error codes:
		(Note, that error codes
			from -1 to -9 are applied to common errors,
			from -10 to -19 are applied to C6xxx on-chip registers errors,
			from -20 to -29 are applied to DSP initialization errors,
			from -30 to -39 are applied to DSP ports configuration errors,
			from -100 to -109 are applied to FLASH PROGRAMMING CONTROL errors,
			from -50 to -99 are applied to user defined errors)
		 0	- no errors;
		-2	- invalid H/W error (not E2/6713 board);
		-3	- H/W error (error writing to the DSP external control registers, etc);
		-4	- incompatible H/W error (the setting is not allowed on this board);
		-10	- error writing to C6713B DSP regs;
		-20	- error during PLL configuration;
		-30	- ASIOX rev.D DCM is not installed;
		-31	- incompatible DSP ports configuration;
*****************************************************/

#define __T2E6XXX_SELECT_E6713__			1

#include "t2e6xxx_dsp.h"


int mcasp0_gpio_init()
{
	// configure McASP0 pins as GPIO output pins
	// and clear output data
	*C6713_MCASP0_GBLCTL_RG = 0;
	if (*C6713_MCASP0_GBLCTL_RG != 0)
		return(C6XXX_HW_ERR);
	*C6713_MCASP0_PWRDEMU_RG = 0;
	if (*C6713_MCASP0_PWRDEMU_RG != 0)
		return(C6XXX_HW_ERR);
	*C6713_MCASP0_PDIR_RG = 0;
	if (*C6713_MCASP0_PDIR_RG != 0)
		return(C6XXX_HW_ERR);
	*C6713_MCASP0_PFUNC_RG = 0xfe0000ff;
	if (*C6713_MCASP0_PFUNC_RG != 0xfe0000ff)
		return(C6XXX_HW_ERR);
	*C6713_MCASP0_PDOUT_RG = 0;
	if (*C6713_MCASP0_PDOUT_RG != 0)
		return(C6XXX_HW_ERR);
	*C6713_MCASP0_PDIR_RG = 0xfe0000ff;
	if (*C6713_MCASP0_PDIR_RG != 0xfe0000ff)
		return(C6XXX_HW_ERR);
	return(T2E6XXX_OK);
}

int mcasp1_gpio_init()
{
	// configure McASP1 pins as GPIO output pins
	// and clear output data
	*C6713_MCASP1_GBLCTL_RG = 0;
	if (*C6713_MCASP1_GBLCTL_RG != 0)
		return(C6XXX_HW_ERR);
	*C6713_MCASP1_PWRDEMU_RG = 0;
	if (*C6713_MCASP1_PWRDEMU_RG != 0)
		return(C6XXX_HW_ERR);
	*C6713_MCASP1_PDIR_RG = 0;
	if (*C6713_MCASP1_PDIR_RG != 0)
		return(C6XXX_HW_ERR);
	*C6713_MCASP1_PFUNC_RG = 0xfe0000ff;
	if (*C6713_MCASP1_PFUNC_RG != 0xfe0000ff)
		return(C6XXX_HW_ERR);
	*C6713_MCASP1_PDOUT_RG = 0;
	if (*C6713_MCASP1_PDOUT_RG != 0)
		return(C6XXX_HW_ERR);
	*C6713_MCASP1_PDIR_RG = 0xfe0000ff;
	if (*C6713_MCASP1_PDIR_RG != 0xfe0000ff)
		return(C6XXX_HW_ERR);
	return(T2E6XXX_OK);
}

void main()
{
	int r;
	unsigned d, i;
	
	// configure DSP PLL with SPREAD_SPECTRUM_CLK not used and initialize DSP
	if ((r = T2E6XXX_init_dsp(0)) != T2E6XXX_OK)
		goto error;

	// enable McASP0 and McASP1 ports via DSP ports configuration function
	if ((r = T2E6XXX_set_dsp_ports_cnf(T2E6713_DSP_PORTS_CNF_MCASP0_MCASP1)) != T2E6XXX_OK)
		goto error;

	// configure McASP0 and McASP1 pins as GPIO output pins
	// and clear output data
	if ((r = mcasp0_gpio_init()) != T2E6XXX_OK)
		goto error;
	if ((r = mcasp1_gpio_init()) != T2E6XXX_OK)
		goto error;

	while (1)
	{
		// set McASP0 AXR[i] pins to Logic HIGH
		for (d = 0x1, i = 0; i < 8 ; i++)
		{
			*C6713_MCASP0_PDSET_RG = d;
			d = (d << 1);
		}
		// clear McASP0 AXR[i] pins
		for (d = 0x1, i = 0; i < 8 ; i++)
		{
			*C6713_MCASP0_PDCLR_RG = d;
			d = (d << 1);
		}
		// set McASP0 AFSX, AFSR, ACLKX, ACLKR, AHCLKX and AHCLKR pins to Logic HIGH
		for (d = 0x2000000, i = 0; i < 7 ; i++)
		{
			*C6713_MCASP0_PDSET_RG = d;
			d = (d << 1);
		}
		// clear McASP0 AFSX, AFSR, ACLKX, ACLKR, AHCLKX and AHCLKR pins
		for (d = 0x2000000, i = 0; i < 7 ; i++)
		{
			*C6713_MCASP0_PDCLR_RG = d;
			d = (d << 1);
		}

		// set McASP1 AXR[i] pins to Logic HIGH
		for (d = 0x1, i = 0; i < 8 ; i++)
		{
			*C6713_MCASP1_PDSET_RG = d;
			d = (d << 1);
		}
		// clear McASP1 AXR[i] pins
		for (d = 0x1, i = 0; i < 8 ; i++)
		{
			*C6713_MCASP1_PDCLR_RG = d;
			d = (d << 1);
		}
		// set McASP1 AFSX, AFSR, ACLKX, ACLKR, AHCLKX and AHCLKR pins to Logic HIGH
		for (d = 0x2000000, i = 0; i < 7 ; i++)
		{
			*C6713_MCASP1_PDSET_RG = d;
			d = (d << 1);
		}
		// clear McASP1 AFSX, AFSR, ACLKX, ACLKR, AHCLKX and AHCLKR pins
		for (d = 0x2000000, i = 0; i < 7 ; i++)
		{
			*C6713_MCASP1_PDCLR_RG = d;
			d = (d << 1);
		}
	}

	// get here on any error condition
	// variable 'r' contains returned error code
error:
	while(1);
}

