/****************************************************
	TORNADO-E2/6713 Demo Utility.
	McBSP-0/1 ports demo. rev.1A
	(C) MicroLAB Systems, 2007


	Description:
	------------
	This demo tests DSP McBSP-0/1 ports. 

	External DX-to-DR shorting jumpers are required for each of the
	McBSP-0/1 ports in order to run this demo. These shorting 
	jumpers shall be connected to SIOX rev.B site (McBSP-0/1 ports).
	Refer to TORNADO-E2/6713 User's Guide for more details about SIOX site 
	headers.

	This test configures all McBSP pins as OUTPUT pins except for
	DR pin, which is configured as INPUT, and continuously generates 
	'running '1'' over DX/DR, FSX, FSR, CLKX and CLKR pins
	for each McBSP port. Oscilloscope can be used to view pulses at
	pins of McBSP-0/1 ports.


	TORNADO platform:
	-----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

	Copyright:
	----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


	Board configuration and demo parameters:
	----------------------------------------
	1. On-board bootmode configuration switch: HPI
	2. Demo-specific jumpers for McBSP ports:
	  - DX-to-DR shorting jumpers are equired for each of the McBSP-0/1 ports,
	    which shall be connected to SIOX rev.B site (McBSP-0/1 ports).
	3. Variable r contains possible error codes:
		(Note, that error codes
			from -1 to -9 are applied to common errors,
			from -10 to -19 are applied to C6xxx on-chip registers errors,
			from -20 to -29 are applied to DSP initialization errors,
			from -30 to -39 are applied to DSP ports configuration errors,
			from -100 to -109 are applied to FLASH PROGRAMMING CONTROL errors,
			from -50 to -99 are applied to user defined errors)
		 0	- no errors;
		-2	- invalid H/W error (not E2/6713 board);
		-3	- H/W error (error writing to the DSP external control registers, etc);
		-4	- incompatible H/W error (the setting is not allowed on this board);
		-10	- error writing to C6713B DSP regs;
		-20	- error during PLL configuration;
		-30	- ASIOX rev.D DCM is not installed;
		-31	- incompatible DSP ports configuration;
*****************************************************/

#define __T2E6XXX_SELECT_E6713__			1

#include "t2e6xxx_dsp.h"


#define DX_OUT_0		0x3f00
#define DX_OUT_1		0x3f20
#define FSX_OUT_0		0x3f00
#define FSX_OUT_1		0x3f08
#define FSR_OUT_0		0x3f00
#define FSR_OUT_1		0x3f04
#define CLKX_OUT_0		0x3f00
#define CLKX_OUT_1		0x3f02
#define CLKR_OUT_0		0x3f00
#define CLKR_OUT_1		0x3f01

#define DR_BIT_MASK		0x10

unsigned pass_counter = 0;

void main()
{
	int r;

	// configure DSP PLL with SPREAD_SPECTRUM_CLK not used and initialize DSP
	if ((r = T2E6XXX_init_dsp(0)) != T2E6XXX_OK)
		goto error;

	// enable McBSP0 and McBSP1 ports via DSP ports configuration function
	if ((r = T2E6XXX_set_dsp_ports_cnf(T2E6713_DSP_PORTS_CNF_MCBSP0_MCBSP1)) != T2E6XXX_OK)
		goto error;
	
	*C6XXX_MCBSP0_SPCR_RG = 0;		/* configure McBSP-0 for I/O pins */
	*C6XXX_MCBSP1_SPCR_RG = 0;		/* configure McBSP-1 for I/O pins */

	while(1)
	{
		// verify for McBSP-0
		// set DX=1 
		*C6XXX_MCBSP0_PCR_RG = DX_OUT_1;
		if ((*C6XXX_MCBSP0_PCR_RG & DR_BIT_MASK) == 0)
		{
			r = C6XXX_HW_ERR;
			goto error;
		}

		// set DX=0
		*C6XXX_MCBSP0_PCR_RG = DX_OUT_0;
		if ((*C6XXX_MCBSP0_PCR_RG & DR_BIT_MASK) != 0)
		{
			r = C6XXX_HW_ERR;
			goto error;
		}

		*C6XXX_MCBSP0_PCR_RG = FSX_OUT_1;
		*C6XXX_MCBSP0_PCR_RG = FSX_OUT_0;

		*C6XXX_MCBSP0_PCR_RG = FSR_OUT_1;
		*C6XXX_MCBSP0_PCR_RG = FSR_OUT_0;

		*C6XXX_MCBSP0_PCR_RG = CLKX_OUT_1;
		*C6XXX_MCBSP0_PCR_RG = CLKX_OUT_0;

		*C6XXX_MCBSP0_PCR_RG = CLKR_OUT_1;
		*C6XXX_MCBSP0_PCR_RG = CLKR_OUT_0;


		// verify for McBSP-1
		// set DX=1
		*C6XXX_MCBSP1_PCR_RG = DX_OUT_1;
		if ((*C6XXX_MCBSP1_PCR_RG & DR_BIT_MASK) == 0)
		{
			r = C6XXX_HW_ERR;
			goto error;
		}

		// set DX=0
		*C6XXX_MCBSP1_PCR_RG = DX_OUT_0;
		if ((*C6XXX_MCBSP1_PCR_RG & DR_BIT_MASK) != 0)
		{
			r = C6XXX_HW_ERR;
			goto error;
		}

		*C6XXX_MCBSP1_PCR_RG = FSX_OUT_1;
		*C6XXX_MCBSP1_PCR_RG = FSX_OUT_0;

		*C6XXX_MCBSP1_PCR_RG = FSR_OUT_1;
		*C6XXX_MCBSP1_PCR_RG = FSR_OUT_0;

		*C6XXX_MCBSP1_PCR_RG = CLKX_OUT_1;
		*C6XXX_MCBSP1_PCR_RG = CLKX_OUT_0;

		*C6XXX_MCBSP1_PCR_RG = CLKR_OUT_1;
		*C6XXX_MCBSP1_PCR_RG = CLKR_OUT_0;

		pass_counter++;
	}

	// get here on any error condition
	// variable 'r' contains returned error code
error:
	while(1);
}

