/****************************************************
	TORNADO-E2/6713 Demo Utility.
	TIMERs demo. rev.1A
	(C) MicroLAB Systems, 2007
	
	Description:
	------------
	This demo tests DSP Timer-0/1 outputs and internal XIO signals. 
	SIOX rev.B DCM site I/F provides two legacy signals named as TM/XIO-0/1.
	In E2/6713 board, these signals can be routed to the timer outputs, or behave as GPIOs signals.
	These signals do not support timer inputs.

	This test requires an external TM/XIO-0-to-TM/XIO-1
	shorting jumpers to be installed. This shorting 
	jumper shall be connected to SIOX rev.B site (13-to-14 pins).

	Board configuration and demo parameters:
	----------------------------------------
	1. On-board bootmode configuration switch: HPI
	2. Variable r contains possible error codes:
		(Note, that error codes
			from -1 to -9 are applied to common errors,
			from -10 to -19 are applied to C6xxx on-chip registers errors,
			from -20 to -29 are applied to DSP initialization errors,
			from -30 to -39 are applied to DSP ports configuration errors,
			from -100 to -109 are applied to FLASH PROGRAMMING CONTROL errors,
			from -50 to -99 are applied to user defined errors)
		 0	- no errors;
		-2	- invalid H/W error (not E2/6713 board);
		-3	- H/W error (error writing to the DSP external control registers, etc);
		-4	- incompatible H/W error (the setting is not allowed on this board);
		-10	- error writing to C6713B DSP regs;
		-20	- error during PLL configuration;
		-30	- ASIOX rev.D DCM is not installed;
		-31	- incompatible DSP ports configuration;
*****************************************************/

#define __T2E6XXX_SELECT_E6713__			1

#include "t2e6xxx_dsp.h"


#define TM_OUT_0		0
#define TM_OUT_1		4

unsigned pass_counter = 0;

void main()
{
	int r;

	// configure DSP PLL with SPREAD_SPECTRUM_CLK not used and initialize DSP
	if ((r = T2E6XXX_init_dsp(0)) != T2E6XXX_OK)
		goto error;

	// enable Timers outputs through Serial ports configuration function
	if ((r = T2E6XXX_set_dsp_ports_cnf(T2E6713_DSP_PORTS_CNF_TOUT0_TOUT1)) != T2E6XXX_OK)
		goto error;

	*C6XXX_TIMER0_CTL_RG = 0;
	*C6XXX_TIMER1_CTL_RG = 0;

	while(1)
	{
		/*
		 * enable SX_TM/XIO-0 output as Timer 0 output and
		 * SX_TM/XIO-1 as I/O port input via DSP_SIOX_XIO_CNF_RG and
		 * DSP_SIOX_XIO_DATA_RG DSP external control registers
		 */
		T2E6XXX_SET_SIOX_XIO0_CNF_TOUT0;
		if (!T2E6XXX_SIOX_XIO0_CNF_IS_TOUT0)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}
		T2E6XXX_SET_SIOX_XIO1_CNF_INPUT;
		if (!T2E6XXX_SIOX_XIO1_CNF_IS_INPUT)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		/* verify for XIO1 = TOUT0 for TIMER-0 */
		/* set TOUT0 = 0 */
		*C6XXX_TIMER0_CTL_RG = TM_OUT_0;
		/* check for XIO1 = TOUT0 */
		if (T2E6XXX_SIOX_XIO1_DATA_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}
		/* set TOUT0 = 1 */
		*C6XXX_TIMER0_CTL_RG = TM_OUT_1;
		/* check for XIO1 = TOUT0 */
		if (!T2E6XXX_SIOX_XIO1_DATA_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		/*
		 * enable SX_TM/XIO-0 output as I/O port output and
		 * SX_TM/XIO-1 as I/O port input via DSP_SIOX_XIO_CNF_RG and
		 * DSP_SIOX_XIO_DATA_RG DSP external control registers
		 */
		T2E6XXX_SET_SIOX_XIO0_CNF_OUTPUT;
		if (!T2E6XXX_SIOX_XIO0_CNF_IS_OUTPUT)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		/* verify for XIO1 = XIO0 */
		/* set XIO0 = 0 */
		T2E6XXX_SET_SIOX_XIO0_DATA_OFF;
		/* check for XIO1 = XIO0 */
		if (T2E6XXX_SIOX_XIO1_DATA_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}
		/* set XIO0 = 1 */
		T2E6XXX_SET_SIOX_XIO0_DATA_ON;
		/* check for XIO1 = XIO0 */
		if (!T2E6XXX_SIOX_XIO1_DATA_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		/*
		 * enable SX_TM/XIO-1 output as Timer 1 output and
		 * SX_TM/XIO-0 as I/O port input via DSP_SIOX_XIO_CNF_RG and
		 * DSP_SIOX_XIO_DATA_RG DSP external control registers
		 */
		T2E6XXX_SET_SIOX_XIO1_CNF_TOUT1;
		if (!T2E6XXX_SIOX_XIO1_CNF_IS_TOUT1)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}
		T2E6XXX_SET_SIOX_XIO0_CNF_INPUT;
		if (!T2E6XXX_SIOX_XIO0_CNF_IS_INPUT)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		/* verify for XIO0 = TOUT1 for TIMER-1 */
		/* set TOUT1 = 0 */
		*C6XXX_TIMER1_CTL_RG = TM_OUT_0;
		/* check for XIO0 = TOUT1 */
		if (T2E6XXX_SIOX_XIO0_DATA_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}
		/* set TOUT1 = 1 */
		*C6XXX_TIMER1_CTL_RG = TM_OUT_1;
		/* check for XIO0 = TOUT1 */
		if (!T2E6XXX_SIOX_XIO0_DATA_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		/*
		 * enable SX_TM/XIO-1 output as I/O port output and
		 * SX_TM/XIO-0 as I/O port input via DSP_SIOX_XIO_CNF_RG and
		 * DSP_SIOX_XIO_DATA_RG DSP external control registers
		 */
		T2E6XXX_SET_SIOX_XIO1_CNF_OUTPUT;
		if (!T2E6XXX_SIOX_XIO1_CNF_IS_OUTPUT)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		/* verify for XIO0 = XIO1 */
		/* set XIO1 = 0 */
		T2E6XXX_SET_SIOX_XIO1_DATA_OFF;
		/* check for XIO0 = XIO1 */
		if (T2E6XXX_SIOX_XIO0_DATA_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}
		/* set XIO1 = 1 */
		T2E6XXX_SET_SIOX_XIO1_DATA_ON;
		/* check for XIO0 = XIO1 */
		if (!T2E6XXX_SIOX_XIO0_DATA_IS_ON)
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}

		pass_counter++;
	}

	// get here on any error condition
	// variable 'r' contains returned error code
error:
	while(1);
}

