/********************************************************************
	TORNADO-E2/6713 Demo Utility.
	GPIO Test. rev.1A
	(C) MicroLAB Systems, 2007


	Description:
	------------
	This demo continuously runs '1' thru 8-bit GPIO, 
	which is available via JP13 connector of TORNADO-E2/6713 board.


	TORNADO platform:
	-----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

	Copyright:
	----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


	board configuration and demo parameters:
	----------------------------------------
	1. On-board BOOTMODE configuration switch: HPI boot
	2. Variable r contains possible error codes:
		(Note, that error codes
			from -1 to -9 are applied to common errors,
			from -10 to -19 are applied to C6xxx on-chip registers errors,
			from -20 to -29 are applied to DSP initialization errors,
			from -30 to -39 are applied to DSP ports configuration errors,
			from -100 to -109 are applied to FLASH PROGRAMMING CONTROL errors,
			from -50 to -99 are applied to user defined errors)
		 0	- no errors;
		-2	- invalid H/W error (not E2/6713 board);
		-3	- H/W error (error writing to the DSP external control registers, etc);
		-4	- incompatible H/W error (the setting is not allowed on this board);
		-10	- error writing to C6713B DSP regs;
		-20	- error during PLL configuration;
*****************************************************/

#define __T2E6XXX_SELECT_E6713__			1

#include "t2e6xxx_dsp.h"

void main()
{
	int i, d, r;

	// configure DSP PLL with SPREAD_SPECTRUM_CLK not used and initialize DSP
	if ((r = T2E6XXX_init_dsp(0)) != T2E6XXX_OK)
		goto error;

	// configure GPIO pins as outputs and clear output data
	T2E6XXX_set_gpio_dir_rg(0xff);
	if (T2E6XXX_get_gpio_dir_rg() != 0xff)
	{
		r = T2E6XXX_HW_ERR;
		goto error;
	}
	T2E6XXX_set_gpio_data_rg(0);
	if (T2E6XXX_get_gpio_data_rg() != 0)
	{
		r = T2E6XXX_HW_ERR;
		goto error;
	}

	while(1)
	{
		// issue WDT reset for external oscilloscope synchronization
		T2E6XXX_SET_WDT_RESET;

		// now run '1' thru GPIO pins
		for (i = 0, d = 1; i <= 7; i++, d <<= 1)
			T2E6XXX_set_gpio_data_rg(d);
	}

	// get here on any error condition
	// variable 'r' contains returned error code
error:
	while (1);
}

