/********************************************************************************
	TORNADO-E2/6xxx (E2/6713) Second Generation E6xxx controllers DSP Utilities. Rev.1A1-6
	(C) MicroLAB Systems, 2007-2008


	Revision history:
	-----------------
	rev.1A1		- 2007, initial release for E2/6713 rev.1A board.
	rev.1A1-5	- 2008, fixed minor bugs.
	rev.1A1-6	- April 2008
					- fixed error in T2E6XXX_DCM_RESET_RG definition: '0' value corresponds to active RESET signal;
					- fixed PLL configuration routine in T2E6XXX_init_dsp().

	Notes:
	------
	1.	This C-header file is include file for TI C6000 compile tools. C6XXX_DEF.H
		header file for general C6xxx DSP definitions must also be available for
		inclusion if required.
	2.	This header file is externally controlled from user C-code by run-time
		compiler keys definitions in order to select correct DSP controller type
		and to include/exclude extended T2E6XXX API functions.

			__T2E6XXX_SELECT_E6713__
				- if defined in user code prior inclusion of this header file,
				  then E2/6713 DSP controller definitions are enabled.
				  Correspondingly, __C6XXX_SELECT_C6713_DSP__ definition is
				  defined for correct processing of C6XXX_DEF.H general C6xxx DSP
				  header file.

			__T2E6XXX_EXCLUDE_AUX_FUNCTIONS__
				- if defined in user code prior inclusion of this header file,
				  then the DSP initialization and DSP on-chip peripherals (McBSPs, McASPs, I2C-1)
				  configuration functions are excluded from the user source code.
				  Default is INCLUDED. Note, that in case user application
				  comprises of several .C linked together modules, then this run-time
				  compiler key must be included in all modules except for the one module in
				  order to exclude multiple function body appearance.

			__T2E6XXX_INCLUDE_FLASH_CONTROL__
				- if defined in user code prior inclusion of this header file,
				  then the FLASH PROGRAMMING CONTROL function are included
				  into the user source code. Default is EXCLUDED.

********************************************************************************/

// check for this file has been already included
#ifndef	__T2E6XXX_DEF__
#define	__T2E6XXX_DEF__						1


// general defs
#define T2E6XXX_ON							1
#define T2E6XXX_OFF							0


//===== DSP-type specific run-time compiler keys processing ==================
// (this is required in order to exclude key confusions)


#ifdef	__T2E6XXX_SELECT_E6416__
#undef	__T2E6XXX_SELECT_E6713__
#undef	__C6XXX_SELECT_C6713_DSP__
#undef	__C6XXX_SELECT_C6416_DSP__
#define	__C6XXX_SELECT_C6416_DSP__			1	// use C6416 defs in C6XXX_DEF.H file
#endif

#ifdef	__T2E6XXX_SELECT_E6713__
#undef	__C6XXX_SELECT_C6416_DSP__
#undef	__T2E6XXX_SELECT_E6416__
#undef	__C6XXX_SELECT_C6713_DSP__
#define	__C6XXX_SELECT_C6713_DSP__			1	// use C6713 defs in C6XXX_DEF.H file
#endif

// Default setting is E2/6713 definitions
#ifndef	__T2E6XXX_SELECT_E6416__
#ifndef	__T2E6XXX_SELECT_E6713__
#define	__T2E6XXX_SELECT_E6713__			1
#endif
#endif

//============================================================================

// include C6xxx DSP defs
#include "c6xxx_def.h"

// include E2/6xxx DSP controllers defs, macros and aux functions
#include "t2e6xxx_dsp_def.hxx"
#include "t2e6xxx_dsp_macros.hxx"
#include "t2e6xxx_dsp_aux.hxx"

//======================================================================
#endif
