/********************************************************************************
	TORNADO-E2/6xxx (E2/6713) 2nd Generation E6xxx controllers DSP Utilities. Rev.1A1-6
	(C) MicroLAB Systems, 2007-2008

	File:	Definitions
	-----

	Notes:
	------
	1.	This C-header file is include file for TI C6000 compile tools,
		which is used with T2E6XXX_DSP.H C-header file.
********************************************************************************/

// check for this file has been already included
#ifndef	__T2E6XXX_DSP_DEF__
#define	__T2E6XXX_DSP_DEF__						1




#ifdef	__T2E6XXX_SELECT_E6713__
//====================== E2/6713 Memory/IO Areas =============================
// DSP memory areas for E2/6713 DSP controllers

//------------ SBSRAM area (x32) @ EMIF CE-0 area ----------------
	// different SBSRAM length defs (in x32 words)
	// available options are 0K, 128Kx32 (512KByte) and 512Kx32 (2MByte)
#define T2E6713_SBSRAM_LEN_0K					0
#define T2E6713_SBSRAM_LEN_128KX32				0x00080000
#define T2E6713_SBSRAM_LEN_512KX32				0x00200000
#define T2E6713_SBSRAM_LEN_MAX					T2E6713_SBSRAM_LEN_512KX32	// max available SBSRAM length for E2/6713
#define T2E6713_SBSRAM_DATA_BITMASK				0xffffffff					// SBSRAM data width for E2/6713
	// SBSRAM length aliases in bytes
#define T2E6713_SBSRAM_LEN_512KX8				T2E6713_SBSRAM_LEN_128KX32
#define T2E6713_SBSRAM_LEN_2MX8					T2E6713_SBSRAM_LEN_512KX32
	// aliases for compatibility with T2E6XXX API
#define T2E6XXX_SBSRAM_LEN_0K					T2E6713_SBSRAM_LEN_0K
#define T2E6XXX_SBSRAM_LEN_128KX32				T2E6713_SBSRAM_LEN_128KX32
#define T2E6XXX_SBSRAM_LEN_512KX32				T2E6713_SBSRAM_LEN_512KX32
#define T2E6XXX_SBSRAM_LEN_MAX					T2E6713_SBSRAM_LEN_MAX
#define T2E6XXX_SBSRAM_DATA_BITMASK				T2E6713_SBSRAM_DATA_BITMASK
	// SBSRAM length aliases in bytes
#define T2E6XXX_SBSRAM_LEN_512KX8				T2E6713_SBSRAM_LEN_512KX8
#define T2E6XXX_SBSRAM_LEN_2MX8					T2E6713_SBSRAM_LEN_2MX8

	// SBSRAM area mapping
#define T2E6713_SBSRAM_AREA_SADDR				0x80000000	// SBSRAM start address
#define T2E6713_SBSRAM_AREA_EADDR				(T2E6713_SBSRAM_AREA_SADDR + T2E6XXX_get_sbsram_len() -1)	// last SBSRAM address
#define T2E6713_SBSRAM_AREA_EADDR_MAX			(T2E6713_SBSRAM_AREA_SADDR + T2E6713_SBSRAM_LEN_MAX -1)		// maximum SBSRAM last address
#define T2E6713_SBSRAM_AREA_LEN					T2E6XXX_get_sbsram_len()

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_SBSRAM_AREA_SADDR				T2E6713_SBSRAM_AREA_SADDR
#define T2E6XXX_SBSRAM_AREA_EADDR				T2E6713_SBSRAM_AREA_EADDR
#define T2E6XXX_SBSRAM_AREA_LEN					T2E6713_SBSRAM_AREA_LEN



//------------ SDRAM area (x32) @ EMIF CE-2 area -----------------
	// different SDRAM lengths (in x32 words)
	// available options are 0M, 4Mx32 (16MB) and 16Mx32 (64MB)
#define T2E6713_SDRAM_LEN_0M					0
#define T2E6713_SDRAM_LEN_4MX32					0x01000000
#define T2E6713_SDRAM_LEN_16MX32				0x04000000
#define T2E6713_SDRAM_LEN_MAX					T2E6713_SDRAM_LEN_16MX32	// max available SDRAM length for E2/6713
	// SDRAM length aliases (in bytes)
#define T2E6713_SDRAM_LEN_16MX8					T2E6713_SDRAM_LEN_4MX32
#define T2E6713_SDRAM_LEN_64MX8					T2E6713_SDRAM_LEN_16MX32
	// aliases for compatibility with T2E6XXX API
#define T2E6XXX_SDRAM_LEN_0M					T2E6713_SDRAM_LEN_0M
#define T2E6XXX_SDRAM_LEN_4MX32					T2E6713_SDRAM_LEN_4MX32
#define T2E6XXX_SDRAM_LEN_16MX32				T2E6713_SDRAM_LEN_16MX32
#define T2E6XXX_SDRAM_LEN_MAX					T2E6713_SDRAM_LEN_MAX
	// SDRAM length aliases (in bytes)
#define T2E6XXX_SDRAM_LEN_16MX8					T2E6713_SDRAM_LEN_16MX8
#define T2E6XXX_SDRAM_LEN_64MX8					T2E6713_SDRAM_LEN_64MX8

	// SDRAM area mapping
#define T2E6713_SDRAM_AREA_SADDR				0xa0000000	// SDRAM start address
#define T2E6713_SDRAM_AREA_EADDR				(T2E6713_SDRAM_AREA_SADDR + T2E6XXX_get_sdram_len()-1)	// last SDRAM address
#define T2E6713_SDRAM_AREA_EADDR_MAX			(T2E6713_SDRAM_AREA_SADDR + T2E6XXX_SDRAM_LEN_MAX-1)	// maximum SDRAM last address
#define T2E6713_SDRAM_AREA_LEN					T2E6XXX_get_sdram_len()
	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_SDRAM_AREA_SADDR				T2E6713_SDRAM_AREA_SADDR
#define T2E6XXX_SDRAM_AREA_EADDR				T2E6713_SDRAM_AREA_EADDR
#define T2E6XXX_SDRAM_AREA_LEN					T2E6713_SDRAM_AREA_LEN



//------------ FLASH area @ EMIF CE-1 area -----------------------
#define T2E6713_FLASH_AREA_SADDR				0x90000000
#define T2E6713_FLASH_AREA_EADDR				0x900fffff
#define T2E6713_FLASH_AREA_LEN					0x00100000
#define T2E6713_FLASH_AREA_ADDR_STEP			1

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_FLASH_AREA_SADDR				T2E6713_FLASH_AREA_SADDR
#define T2E6XXX_FLASH_AREA_EADDR				T2E6713_FLASH_AREA_EADDR
#define T2E6XXX_FLASH_AREA_LEN					T2E6713_FLASH_AREA_LEN
#define T2E6XXX_FLASH_AREA_ADDR_STEP			T2E6713_FLASH_AREA_ADDR_STEP

	// FLASH page defs for E2/6713 rev.1A
#define T2E6713_FLASH_PAGE_LEN					T2E6713_FLASH_AREA_LEN

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_FLASH_PAGE_LEN					T2E6713_FLASH_PAGE_LEN


	// FLASH length defs for E2/6713 rev.1A
#define T2E6713_FLASH_LEN_0K					0x00000000	// FLASH not installed
#define T2E6713_FLASH_LEN_512KX8				0x00080000	// no FLASH memory paging, direct access to full FLASH memory
#define T2E6713_FLASH_LEN_1MX8					0x00100000	// no FLASH memory paging, direct access to full FLASH memory
#define T2E6713_FLASH_LEN_8MX8					0x00800000	// 8x FLASH memory pages
#define T2E6713_FLASH_LEN_64MX8					0x04000000	// 64x FLASH memory pages

	// FLASH address range for FLASH API functions (WINDEX is dataword index in linear addressing)
	// FLASH area can be addressed by byte(8-bit) data words only (8-bit async area)
#define T2E6713_FLASH_WINDEX_MIN				0x0
#define T2E6713_FLASH_WINDEX_MAX_BYTE_512KX8	(T2E6713_FLASH_LEN_512KX8-1)
#define T2E6713_FLASH_WINDEX_MAX_BYTE_1MX8		(T2E6713_FLASH_LEN_1MX8-1)
#define T2E6713_FLASH_WINDEX_MAX_BYTE_8MX8		(T2E6713_FLASH_LEN_8MX8-1)
#define T2E6713_FLASH_WINDEX_MAX_BYTE_64MX8		(T2E6713_FLASH_LEN_64MX8-1)

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_FLASH_LEN_0K					T2E6713_FLASH_LEN_0K
#define T2E6XXX_FLASH_LEN_512KX8				T2E6713_FLASH_LEN_512KX8
#define T2E6XXX_FLASH_LEN_1MX8					T2E6713_FLASH_LEN_1MX8
#define T2E6XXX_FLASH_LEN_8MX8					T2E6713_FLASH_LEN_8MX8
#define T2E6XXX_FLASH_LEN_64MX8					T2E6713_FLASH_LEN_64MX8

#define T2E6XXX_FLASH_WINDEX_MIN				T2E6713_FLASH_WINDEX_MIN
#define T2E6XXX_FLASH_WINDEX_MAX_BYTE_512KX8	T2E6713_FLASH_WINDEX_MAX_BYTE_512KX8
#define T2E6XXX_FLASH_WINDEX_MAX_BYTE_1MX8		T2E6713_FLASH_WINDEX_MAX_BYTE_1MX8
#define T2E6XXX_FLASH_WINDEX_MAX_BYTE_8MX8		T2E6713_FLASH_WINDEX_MAX_BYTE_8MX8
#define T2E6XXX_FLASH_WINDEX_MAX_BYTE_64MX8		T2E6713_FLASH_WINDEX_MAX_BYTE_64MX8



//------------ I/O sync peripherals (PIOX_SYNC, HCX_SYNC) area @ EMIF CE-0

//------------ r/w: synchronous PIOX area #0 256KB (64Kx32) ------

#define T2E6713_PIOX_SYNC0_AREA_SADDR			0x80200000
#define T2E6713_PIOX_SYNC0_AREA_EADDR			0x8023ffff
#define T2E6713_PIOX_SYNC0_AREA_LEN				(T2E6713_PIOX_SYNC0_AREA_EADDR - T2E6713_PIOX_SYNC0_AREA_SADDR + 1)	// PIOX-SYNC0 length in bytes
#define T2E6713_PIOX_SYNC0_AREA_DATA_BITMASK	0xffffffff	// PIOX-SYNC0 data width (32 bits)

	// PIOX-SYNC0 area length in datawords
#define T2E6713_PIOX_SYNC0_AREA_LEN_W32			(T2E6713_PIOX_SYNC0_AREA_LEN/4)	// PIOX-SYNC0 area length in 32-bit datawords
#define T2E6713_PIOX_SYNC0_AREA_LEN_W16			(T2E6713_PIOX_SYNC0_AREA_LEN/2)	// PIOX-SYNC0 area length in 16-bit datawords
#define T2E6713_PIOX_SYNC0_AREA_LEN_BYTE		(T2E6713_PIOX_SYNC0_AREA_LEN)	// PIOX-SYNC0 area length in 8-bit datawords

	// PIOX-SYNC0 address range for API macros (WINDEX is dataword index in linear addressing)
	// PIOX-SYNC0 area can be addressed by 32-bit, 16-bit and byte (8-bit) datawords
#define T2E6713_PIOX_SYNC0_WINDEX_MIN			0x0
#define T2E6713_PIOX_SYNC0_WINDEX_MAX_W32		(T2E6713_PIOX_SYNC0_AREA_LEN_W32-1)
#define T2E6713_PIOX_SYNC0_WINDEX_MAX_W16		(T2E6713_PIOX_SYNC0_AREA_LEN_W16-1)
#define T2E6713_PIOX_SYNC0_WINDEX_MAX_BYTE		(T2E6713_PIOX_SYNC0_AREA_LEN_BYTE-1)

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_PIOX_SYNC0_AREA_SADDR			T2E6713_PIOX_SYNC0_AREA_SADDR
#define T2E6XXX_PIOX_SYNC0_AREA_EADDR			T2E6713_PIOX_SYNC0_AREA_EADDR
#define T2E6XXX_PIOX_SYNC0_AREA_LEN				T2E6713_PIOX_SYNC0_AREA_LEN
#define T2E6XXX_PIOX_SYNC0_AREA_DATA_BITMASK	T2E6713_PIOX_SYNC0_AREA_DATA_BITMASK

#define T2E6XXX_PIOX_SYNC0_AREA_LEN_W32			T2E6713_PIOX_SYNC0_AREA_LEN_W32
#define T2E6XXX_PIOX_SYNC0_AREA_LEN_W16			T2E6713_PIOX_SYNC0_AREA_LEN_W16
#define T2E6XXX_PIOX_SYNC0_AREA_LEN_BYTE		T2E6713_PIOX_SYNC0_AREA_LEN_BYTE

#define T2E6XXX_PIOX_SYNC0_WINDEX_MIN			T2E6713_PIOX_SYNC0_WINDEX_MIN
#define T2E6XXX_PIOX_SYNC0_WINDEX_MAX_W32		T2E6713_PIOX_SYNC0_WINDEX_MAX_W32
#define T2E6XXX_PIOX_SYNC0_WINDEX_MAX_W16		T2E6713_PIOX_SYNC0_WINDEX_MAX_W16
#define T2E6XXX_PIOX_SYNC0_WINDEX_MAX_BYTE		T2E6713_PIOX_SYNC0_WINDEX_MAX_BYTE


//------------ r/w: synchronous PIOX area #1 256KB (64Kx32) ------
#define T2E6713_PIOX_SYNC1_AREA_SADDR			0x80240000
#define T2E6713_PIOX_SYNC1_AREA_EADDR			0x8027ffff
#define T2E6713_PIOX_SYNC1_AREA_LEN				(T2E6713_PIOX_SYNC1_AREA_EADDR - T2E6713_PIOX_SYNC1_AREA_SADDR + 1)	// PIOX-SYNC1 length in bytes
#define T2E6713_PIOX_SYNC1_AREA_DATA_BITMASK	0xffffffff	// PIOX-SYNC1 data width (32 bits)

	// PIOX-SYNC1 area length in datawords
#define T2E6713_PIOX_SYNC1_AREA_LEN_W32			(T2E6713_PIOX_SYNC1_AREA_LEN/4)	// PIOX-SYNC1 area length in 32-bit datawords
#define T2E6713_PIOX_SYNC1_AREA_LEN_W16			(T2E6713_PIOX_SYNC1_AREA_LEN/2)	// PIOX-SYNC1 area length in 16-bit datawords
#define T2E6713_PIOX_SYNC1_AREA_LEN_BYTE		(T2E6713_PIOX_SYNC1_AREA_LEN)	// PIOX-SYNC1 area length in 8-bit datawords

	// PIOX-SYNC1 address range for API macros (WINDEX is dataword index in linear addressing)
	// PIOX-SYNC1 area can be addressed by 32-bit, 16-bit and byte (8-bit) datawords
#define T2E6713_PIOX_SYNC1_WINDEX_MIN			0x0
#define T2E6713_PIOX_SYNC1_WINDEX_MAX_W32		(T2E6713_PIOX_SYNC1_AREA_LEN_W32-1)
#define T2E6713_PIOX_SYNC1_WINDEX_MAX_W16		(T2E6713_PIOX_SYNC1_AREA_LEN_W16-1)
#define T2E6713_PIOX_SYNC1_WINDEX_MAX_BYTE		(T2E6713_PIOX_SYNC1_AREA_LEN_BYTE-1)

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_PIOX_SYNC1_AREA_SADDR			T2E6713_PIOX_SYNC1_AREA_SADDR
#define T2E6XXX_PIOX_SYNC1_AREA_EADDR			T2E6713_PIOX_SYNC1_AREA_EADDR
#define T2E6XXX_PIOX_SYNC1_AREA_LEN				T2E6713_PIOX_SYNC1_AREA_LEN
#define T2E6XXX_PIOX_SYNC1_AREA_DATA_BITMASK	T2E6713_PIOX_SYNC1_AREA_DATA_BITMASK

#define T2E6XXX_PIOX_SYNC1_AREA_LEN_W32			T2E6713_PIOX_SYNC1_AREA_LEN_W32
#define T2E6XXX_PIOX_SYNC1_AREA_LEN_W16			T2E6713_PIOX_SYNC1_AREA_LEN_W16
#define T2E6XXX_PIOX_SYNC1_AREA_LEN_BYTE		T2E6713_PIOX_SYNC1_AREA_LEN_BYTE

#define T2E6XXX_PIOX_SYNC1_WINDEX_MIN			T2E6713_PIOX_SYNC1_WINDEX_MIN
#define T2E6XXX_PIOX_SYNC1_WINDEX_MAX_W32		T2E6713_PIOX_SYNC1_WINDEX_MAX_W32
#define T2E6XXX_PIOX_SYNC1_WINDEX_MAX_W16		T2E6713_PIOX_SYNC1_WINDEX_MAX_W16
#define T2E6XXX_PIOX_SYNC1_WINDEX_MAX_BYTE		T2E6713_PIOX_SYNC1_WINDEX_MAX_BYTE


//------------ r/w: synchronous HCX area (occupies 1Mbyte for direct access to 256Kx32 DPRAM)
#define T2E6713_HCX_SYNC_AREA_SADDR				0x80300000
#define T2E6713_HCX_SYNC_AREA_EADDR				0x803fffff
#define T2E6713_HCX_SYNC_AREA_LEN				(T2E6713_HCX_SYNC_AREA_EADDR - T2E6713_HCX_SYNC_AREA_SADDR + 1)	// HCX-SYNC length in bytes
#define T2E6713_HCX_SYNC_AREA_DATA_BITMASK		0xffffffff	// HCX-SYNC data width (32 bits)
	// HCX-SYNC page defs for E2/6713 rev.1A
#define T2E6713_HCX_SYNC_PAGE_LEN				T2E6713_HCX_SYNC_AREA_LEN

	// HCX-SYNC area length in datawords
#define T2E6713_HCX_SYNC_AREA_LEN_W32			(T2E6713_HCX_SYNC_AREA_LEN/4)	// HCX-SYNC area length in 32-bit datawords
#define T2E6713_HCX_SYNC_AREA_LEN_W16			(T2E6713_HCX_SYNC_AREA_LEN/2)	// HCX-SYNC area length in 16-bit datawords
#define T2E6713_HCX_SYNC_AREA_LEN_BYTE			(T2E6713_HCX_SYNC_AREA_LEN)		// HCX-SYNC area length in 8-bit datawords

	// HCX-SYNC address range for API macros (WINDEX is dataword index in linear addressing)
	// HCX-SYNC area can be addressed by 32-bit, 16-bit and byte (8-bit) datawords
	// These defs are used for addressing within HCX-SYNC area only
	// For addressing HCX-SYNC DCM over HCX_SYNC_AREA_LEN use universal HCX-SYNC macros
#define T2E6713_HCX_SYNC_AREA_WINDEX_MIN		0x0
#define T2E6713_HCX_SYNC_AREA_WINDEX_MAX_W32	(T2E6713_HCX_SYNC_AREA_LEN_W32-1)
#define T2E6713_HCX_SYNC_AREA_WINDEX_MAX_W16	(T2E6713_HCX_SYNC_AREA_LEN_W16-1)
#define T2E6713_HCX_SYNC_AREA_WINDEX_MAX_BYTE	(T2E6713_HCX_SYNC_AREA_LEN_BYTE-1)

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_HCX_SYNC_AREA_SADDR				T2E6713_HCX_SYNC_AREA_SADDR
#define T2E6XXX_HCX_SYNC_AREA_EADDR				T2E6713_HCX_SYNC_AREA_EADDR
#define T2E6XXX_HCX_SYNC_AREA_LEN				T2E6713_HCX_SYNC_AREA_LEN
#define T2E6XXX_HCX_SYNC_AREA_DATA_BITMASK		T2E6713_HCX_SYNC_AREA_DATA_BITMASK
#define T2E6XXX_HCX_SYNC_PAGE_LEN				T2E6713_HCX_SYNC_PAGE_LEN

#define T2E6XXX_HCX_SYNC_AREA_LEN_W32			T2E6713_HCX_SYNC_AREA_LEN_W32
#define T2E6XXX_HCX_SYNC_AREA_LEN_W16			T2E6713_HCX_SYNC_AREA_LEN_W16
#define T2E6XXX_HCX_SYNC_AREA_LEN_BYTE			T2E6713_HCX_SYNC_AREA_LEN_BYTE

#define T2E6XXX_HCX_SYNC_AREA_WINDEX_MIN		T2E6713_HCX_SYNC_AREA_WINDEX_MIN
#define T2E6XXX_HCX_SYNC_AREA_WINDEX_MAX_W32	T2E6713_HCX_SYNC_AREA_WINDEX_MAX_W32
#define T2E6XXX_HCX_SYNC_AREA_WINDEX_MAX_W16	T2E6713_HCX_SYNC_AREA_WINDEX_MAX_W16
#define T2E6XXX_HCX_SYNC_AREA_WINDEX_MAX_BYTE	T2E6713_HCX_SYNC_AREA_WINDEX_MAX_BYTE



//------------ I/O async peripherals area @ EMIF CE-3 ------------
#define T2E6713_UARTA_AREA_SADDR				0xb0040040	// r/w: DUART channel A (Exar ST16C2550) via D0..D7
#define T2E6713_UARTB_AREA_SADDR				0xb0040000	// r/w: DUART channel B (Exar ST16C2550) via D0..D7
#define T2E6713_RTC_AREA_SADDR					0xb0080000	// r/w: DallasSemi DS1501 RTC via D0..D7
#define T2E6713_USB_AREA_SADDR					0xb00c0000	// r/w: USB controller via D0..D7
#define T2E6713_USB3_DC_DACK_ADDR				0xb0100000	// r/w: ISP1761 USB controller only: device controller DMA port
#define T2E6713_USB3_HC_DACK_ADDR				0xb0140000	// r/w: ISP1761 USB controller only: host controller DMA port

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_UARTA_AREA_SADDR				T2E6713_UARTA_AREA_SADDR
#define T2E6XXX_UARTB_AREA_SADDR				T2E6713_UARTB_AREA_SADDR
#define T2E6XXX_RTC_AREA_SADDR					T2E6713_RTC_AREA_SADDR
#define T2E6XXX_USB_AREA_SADDR					T2E6713_USB_AREA_SADDR
#define T2E6XXX_USB3_DC_DACK_ADDR				T2E6713_USB3_DC_DACK_ADDR
#define T2E6XXX_USB3_HC_DACK_ADDR				T2E6713_USB3_HC_DACK_ADDR


//------------ r/w: asynchronous PIOX area (64Kx32, only 32-bit words access)
#define T2E6713_PIOX_ASYNC_AREA_SADDR			0xb03c0000
#define T2E6713_PIOX_ASYNC_AREA_EADDR			0xb03fffff
#define T2E6713_PIOX_ASYNC_AREA_LEN				(T2E6713_PIOX_ASYNC_AREA_EADDR - T2E6713_PIOX_ASYNC_AREA_SADDR + 1)	// PIOX-ASYNC length in bytes
#define T2E6713_PIOX_ASYNC_AREA_DATA_BITMASK	0xffffffff	// PIOX-ASYNC data width (32 bits)

	// PIOX-ASYNC area length in datawords (32-bit datawords only)
#define T2E6713_PIOX_ASYNC_AREA_LEN_W32			(T2E6713_PIOX_ASYNC_AREA_LEN/4)	// PIOX-ASYNC area length in 32-bit datawords

	// PIOX-ASYNC address range for API macros (WINDEX is dataword index in linear addressing)
	// PIOX-ASYNC area can be addressed by 32-bit datawords only
#define T2E6713_PIOX_ASYNC_WINDEX_MIN			0x0
#define T2E6713_PIOX_ASYNC_WINDEX_MAX_W32		(T2E6713_PIOX_ASYNC_AREA_LEN_W32-1)

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_PIOX_ASYNC_AREA_SADDR			T2E6713_PIOX_ASYNC_AREA_SADDR
#define T2E6XXX_PIOX_ASYNC_AREA_EADDR			T2E6713_PIOX_ASYNC_AREA_EADDR
#define T2E6XXX_PIOX_ASYNC_AREA_LEN				T2E6713_PIOX_ASYNC_AREA_LEN
#define T2E6XXX_PIOX_ASYNC_AREA_DATA_BITMASK	T2E6713_PIOX_ASYNC_AREA_DATA_BITMASK

#define T2E6XXX_PIOX_ASYNC_AREA_LEN_W32			T2E6713_PIOX_ASYNC_AREA_LEN_W32

#define T2E6XXX_PIOX_ASYNC_WINDEX_MIN			T2E6713_PIOX_ASYNC_WINDEX_MIN
#define T2E6XXX_PIOX_ASYNC_WINDEX_MAX_W32		T2E6713_PIOX_ASYNC_WINDEX_MAX_W32


//------------ r/w: asynchronous ASIOX rev.D area (64Kx32, only 16-bit LSWs are valid)
#define T2E6713_ASIOX_AREA_SADDR				0xb02c0000
#define T2E6713_ASIOX_AREA_EADDR				0xb02fffff
#define T2E6713_ASIOX_AREA_LEN					(T2E6713_ASIOX_AREA_EADDR - T2E6713_ASIOX_AREA_SADDR + 1)	// ASIOX rev.D length in bytes
#define T2E6713_ASIOX_AREA_DATA_BITMASK			0xffff	// ASIOX data width (16 bits)

	// ASIOX area length in datawords (16-bit datawords only)
	// ASIOX area 16-bit datawords are aligned at 32-bit boundaries,
	// so only 16-bit LSW of 32-bit dataword are valid!!!
#define T2E6713_ASIOX_AREA_LEN_W16				(T2E6713_ASIOX_AREA_LEN/4)	// ASIOX rev.D length in 16-bit data words

	// ASIOX address range for API macros (WINDEX is dataword index in linear addressing)
	// ASIOX area can be addressed by 16-bit datawords only
#define T2E6713_ASIOX_WINDEX_MIN				0x0
#define T2E6713_ASIOX_WINDEX_MAX_W16			(T2E6713_ASIOX_AREA_LEN_W16-1)

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_ASIOX_AREA_SADDR				T2E6713_ASIOX_AREA_SADDR
#define T2E6XXX_ASIOX_AREA_EADDR				T2E6713_ASIOX_AREA_EADDR
#define T2E6XXX_ASIOX_AREA_LEN					T2E6713_ASIOX_AREA_LEN
#define T2E6XXX_ASIOX_AREA_DATA_BITMASK			T2E6713_ASIOX_AREA_DATA_BITMASK

#define T2E6XXX_ASIOX_AREA_LEN_W16				T2E6713_ASIOX_AREA_LEN_W16

#define T2E6XXX_ASIOX_WINDEX_MIN				T2E6713_ASIOX_WINDEX_MIN
#define T2E6XXX_ASIOX_WINDEX_MAX_W16			T2E6713_ASIOX_WINDEX_MAX_W16



//------------ DSP external control registers --------------------------------
#define T2E6713_SYS_CNF1_RG_ADDR				0xb0000000	// r-only: device ID register
#define T2E6713_SYS_CNF2_RG_ADDR				0xb0000004	// r-only: revision ID, clock ID register
#define T2E6713_SYS_CNF3_RG_ADDR				0xb0000008	// r-only: external memory length IDs (SBSRAM/SDRAM/FLASH)
#define T2E6713_SYS_CNF4_RG_ADDR				0xb000000c	// r-only: extrenal parallel peripherals IDs (USB, RTC controllers)
#define T2E6713_DSP_CNF_RG_ADDR					0xb0000018	// r-only: DSP op-mode, DSP bootmode, HPI enable, etc
#define T2E6713_DCM_CNF_RG_ADDR					0xb000001c	// r-only: DCM installation status: PIOX DCM, ASIOX DCM, HCX status

#define T2E6713_FLASH_PAGE_RG_ADDR				0xb0000020	// r/w: FLASH page (8M/64M only) selector
#define T2E6713_FLASH_CNTR_RG_ADDR				0xb0000024	// r/w: FLASH WE/WP status

#define T2E6713_HCX_SYNC_PAGE_RG_ADDR			0xb000002c	// r/w: HCX-SYNC I/F extended address register

#define T2E6713_EXT_INT4_SEL_RG_ADDR			0xb0000030	// r/w: DSP EXT INT4 selector
#define T2E6713_EXT_INT5_SEL_RG_ADDR			0xb0000034	// r/w: DSP EXT INT5 selector
#define T2E6713_EXT_INT6_SEL_RG_ADDR			0xb0000038	// r/w: DSP EXT INT6 selector
#define T2E6713_EXT_INT7_SEL_RG_ADDR			0xb000003c	// r/w: DSP EXT INT7 selector
#define T2E6713_NMI_SEL_RG_ADDR					0xb0000040	// r/w: DSP NMI selector

#define T2E6713_DCM_RESET_RG_ADDR				0xb0000060	// r/w: DCM sites (PIOX2/SIOX/ASIOX) reset control: [D0]=PIOX2, [D1]=SIOX/ASIOX
#define T2E6713_WDT_RTC_CNTR_RG_ADDR			0xb0000064	// r/w: uP WDT/RTC enable RG (uP WDT ENABLE is for SA-mode only)

#define T2E6713_GPIO_DATA_RG_ADDR				0xb0000068	// r/w: GPIO data
#define T2E6713_GPIO_DIR_RG_ADDR				0xb000006c	// r/w: GPIO direction control

#define T2E6713_SIOX_XIO_DATA_RG_ADDR			0xb0000070	// r/w: TM/XIO-0/1 data for SIOX rev.B site
#define T2E6713_SIOX_XIO_CNF_RG_ADDR			0xb0000074	// r/w: TM/XIO-0/1 mode/direction control for SIOX rev.B site

#define T2E6713_DSP_PORTS_CNTR_RG_ADDR			0xb000007c	// r/w: DSP on-chip serial I/F control (McASP-0/1 enable, McBSP-0/1 enable, I2C-1 enable)

#define T2E6713_WDT_RESET_RG_ADDR				0xb01c0000	// w-only: uP WDT RESET strobe (requires WS generation)

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_SYS_CNF1_RG_ADDR				T2E6713_SYS_CNF1_RG_ADDR
#define T2E6XXX_SYS_CNF2_RG_ADDR				T2E6713_SYS_CNF2_RG_ADDR
#define T2E6XXX_SYS_CNF3_RG_ADDR				T2E6713_SYS_CNF3_RG_ADDR
#define T2E6XXX_SYS_CNF4_RG_ADDR				T2E6713_SYS_CNF4_RG_ADDR
#define T2E6XXX_DSP_CNF_RG_ADDR					T2E6713_DSP_CNF_RG_ADDR
#define T2E6XXX_DCM_CNF_RG_ADDR					T2E6713_DCM_CNF_RG_ADDR
#define T2E6XXX_FLASH_PAGE_RG_ADDR				T2E6713_FLASH_PAGE_RG_ADDR
#define T2E6XXX_FLASH_CNTR_RG_ADDR				T2E6713_FLASH_CNTR_RG_ADDR
#define T2E6XXX_HCX_SYNC_PAGE_RG_ADDR			T2E6713_HCX_SYNC_PAGE_RG_ADDR
#define T2E6XXX_EXT_INT4_SEL_RG_ADDR			T2E6713_EXT_INT4_SEL_RG_ADDR
#define T2E6XXX_EXT_INT5_SEL_RG_ADDR			T2E6713_EXT_INT5_SEL_RG_ADDR
#define T2E6XXX_EXT_INT6_SEL_RG_ADDR			T2E6713_EXT_INT6_SEL_RG_ADDR
#define T2E6XXX_EXT_INT7_SEL_RG_ADDR			T2E6713_EXT_INT7_SEL_RG_ADDR
#define T2E6XXX_NMI_SEL_RG_ADDR					T2E6713_NMI_SEL_RG_ADDR
#define T2E6XXX_DCM_RESET_RG_ADDR				T2E6713_DCM_RESET_RG_ADDR
#define T2E6XXX_WDT_RTC_CNTR_RG_ADDR			T2E6713_WDT_RTC_CNTR_RG_ADDR
#define T2E6XXX_GPIO_DATA_RG_ADDR				T2E6713_GPIO_DATA_RG_ADDR
#define T2E6XXX_GPIO_DIR_RG_ADDR				T2E6713_GPIO_DIR_RG_ADDR
#define T2E6XXX_SIOX_XIO_DATA_RG_ADDR			T2E6713_SIOX_XIO_DATA_RG_ADDR
#define T2E6XXX_SIOX_XIO_CNF_RG_ADDR			T2E6713_SIOX_XIO_CNF_RG_ADDR
#define T2E6XXX_DSP_PORTS_CNTR_RG_ADDR			T2E6713_DSP_PORTS_CNTR_RG_ADDR
#define T2E6XXX_WDT_RESET_RG_ADDR				T2E6713_WDT_RESET_RG_ADDR
//----------------------------------------------------------------------------



//------------ recommended EMIF configurations -------------------------------
	// recommended EMIF settings for E2/6713 (DSP_clk=300MHz @ 3.3ns)
	// maximum EMIF speed is 100 MHz @ 10 ns
#define T2E6713_EMIF_GCR_DATA					0x3068		// default GCR setting
#define T2E6713_EMIF_CE0_SBSRAM_DATA			0x40		// enable CE-0 as SBSRAM (32-bit-wide)
#define T2E6713_EMIF_CE1_DATA					0x23124c01	// FLASH area (8-bit,120ns access, stb=12, setup=2,hold=1, TA=1)
#define T2E6713_EMIF_CE2_SDRAM_DATA				0x30		// enable CE-2 as SDRAM (32-bit-wide)
#define T2E6713_EMIF_CE3_DATA					0x20d24321	// PIOX/SIOX and UTIL area (32-bit ASYNC, stb=3, setup=2,hold=1, TA=1)
#define T2E6713_EMIF_SDRAM16M_DATA				0x63115000	// 16Mx32: Trc=60ns, Trp=15ns, Trcd=15ns for Micron 133MHz SDRAM
#define T2E6713_EMIF_SDRAM4M_DATA				0x57115000	// 4Mx32: Trc=60ns, Trp=15ns, Trcd=15ns for Micron 133MHz SDRAM
#define T2E6713_EMIF_SDRAM16M_TIMER_DATA		781			// REFR period = 64mS@8192rows => 7.81us (10ns)
#define T2E6713_EMIF_SDRAM4M_TIMER_DATA			1562		// REFR period = 64mS@4096rows => 15.62us (10ns)
#define T2E6713_EMIF_SDRAM_EXT_DATA				0x00054529	// SDRAM extension register (CL=3, TRAS=4, TRRD=0, RD2DEAC=1, WR2DEAC=1)


//------------ DSP clock def upon the DSP type -------------------
// This data is not available for direct read-back via T2E6XXX registers. These defs are provided
// for user reference.
#define T2E6713_DSP_CLK_FREQ_300MHZ				3.0e+8		// E2/6713 DSP clock frequency (Hz)
//----------------------------------------------------------------------------

#endif



//----------------------------------------------------------------------------
//------------ Peripherals defs ----------------------------------------------
#ifdef	__T2E6XXX_SELECT_E6713__

// read-back data bitmask for FPGA registers (8-bit-wide)
#define T2E6XXX_CNTR_DATA_BITMASK				0xff



//------------ C6xxx DSP EXT_INT4..7/NMI interrupt source selectors
	// For E2/6xxx DSP controllers these registers are called T2E6XXX_EXT_INT4..7/NMI_SEL_RG.
	// E2/6713 EXT_INT/NMI settings:
	// Default state - external interrupts are OFF (0x0)
#define T2E6713_EXT_INT_SEL_OFF					0	// selector is OFF (no IRQ source is selected) - default state
#define T2E6713_EXT_INT_SEL_WDT					1	// selects WDT interrupt (uP Supervisory circuit)
#define T2E6713_EXT_INT_SEL_RTC					2	// selects RTC ALARM/WDT interrupt
#define T2E6713_EXT_INT_SEL_GPIO0				3	// selects GPIO-0 interrupt
#define T2E6713_EXT_INT_SEL_UARTA				4	// selects UART-A IRQ
#define T2E6713_EXT_INT_SEL_UARTB				5	// selects UART-B IRQ
#define T2E6713_EXT_INT_SEL_USB					6	// USB IRQ selector (valid only for USS820 and NET2272 USB controllers)
#define T2E6713_EXT_INT_SEL_USB_DC				6	// USB-DC IRQ  (EXT_INT4 only) (valid only for ISP1761 USB controller)
#define T2E6713_EXT_INT_SEL_USB_HC				6	// USB-HC IRQ  (EXT_INT5 only) (valid only for ISP1761 USB controller)
#define T2E6713_EXT_INT_SEL_USB_DC_DREQ			6	// USB-DC DREQ (EXT_INT6 only) (valid only for ISP1761 USB controller)
#define T2E6713_EXT_INT_SEL_USB_HC_DREQ			6	// USB-HC DREQ (EXT_INT7 only) (valid only for ISP1761 USB controller)
#define T2E6713_EXT_INT_SEL_PIOX_ASYNC_IRQ0		7	// selects PIOX2 Async IRQ0
#define T2E6713_EXT_INT_SEL_PIOX_ASYNC_IRQ1		8	// selects PIOX2 Async IRQ1
#define T2E6713_EXT_INT_SEL_PIOX_SYNC_IRQ0		9	// selects PIOX2 Sync IRQ0
#define T2E6713_EXT_INT_SEL_PIOX_SYNC_IRQ1		0xa	// selects PIOX2 Sync IRQ1
#define T2E6713_EXT_INT_SEL_SIOX_IRQ0			0xb	// selects SIOX IRQ0
#define T2E6713_EXT_INT_SEL_SIOX_IRQ1			0xc	// selects SIOX IRQ1
#define T2E6713_EXT_INT_SEL_HCX_SYNC_IRQ0		0xd	// selects HCX_SYNC I/F IRQ0
#define T2E6713_EXT_INT_SEL_ASIOX_AMUTEIN0		0xe	// selects ASIOX AMUTEIN0 input interrupt
#define T2E6713_EXT_INT_SEL_ASIOX_AMUTEIN1		0xf	// selects ASIOX AMUTEIN1 input interrupt

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_EXT_INT_SEL_OFF					T2E6713_EXT_INT_SEL_OFF
#define T2E6XXX_EXT_INT_SEL_WDT					T2E6713_EXT_INT_SEL_WDT
#define T2E6XXX_EXT_INT_SEL_RTC					T2E6713_EXT_INT_SEL_RTC
#define T2E6XXX_EXT_INT_SEL_GPIO0				T2E6713_EXT_INT_SEL_GPIO0
#define T2E6XXX_EXT_INT_SEL_UARTA				T2E6713_EXT_INT_SEL_UARTA
#define T2E6XXX_EXT_INT_SEL_UARTB				T2E6713_EXT_INT_SEL_UARTB
#define T2E6XXX_EXT_INT_SEL_USB					T2E6713_EXT_INT_SEL_USB
#define T2E6XXX_EXT_INT_SEL_USB_DC				T2E6713_EXT_INT_SEL_USB_DC
#define T2E6XXX_EXT_INT_SEL_USB_HC				T2E6713_EXT_INT_SEL_USB_HC
#define T2E6XXX_EXT_INT_SEL_USB_DC_DREQ			T2E6713_EXT_INT_SEL_USB_DC_DREQ
#define T2E6XXX_EXT_INT_SEL_USB_HC_DREQ			T2E6713_EXT_INT_SEL_USB_HC_DREQ
#define T2E6XXX_EXT_INT_SEL_PIOX_ASYNC_IRQ0		T2E6713_EXT_INT_SEL_PIOX_ASYNC_IRQ0
#define T2E6XXX_EXT_INT_SEL_PIOX_ASYNC_IRQ1		T2E6713_EXT_INT_SEL_PIOX_ASYNC_IRQ1
#define T2E6XXX_EXT_INT_SEL_PIOX_SYNC_IRQ0		T2E6713_EXT_INT_SEL_PIOX_SYNC_IRQ0
#define T2E6XXX_EXT_INT_SEL_PIOX_SYNC_IRQ1		T2E6713_EXT_INT_SEL_PIOX_SYNC_IRQ1
#define T2E6XXX_EXT_INT_SEL_SIOX_IRQ0			T2E6713_EXT_INT_SEL_SIOX_IRQ0
#define T2E6XXX_EXT_INT_SEL_SIOX_IRQ1			T2E6713_EXT_INT_SEL_SIOX_IRQ1
#define T2E6XXX_EXT_INT_SEL_HCX_SYNC_IRQ0		T2E6713_EXT_INT_SEL_HCX_SYNC_IRQ0
#define T2E6XXX_EXT_INT_SEL_ASIOX_AMUTEIN0		T2E6713_EXT_INT_SEL_ASIOX_AMUTEIN0
#define T2E6XXX_EXT_INT_SEL_ASIOX_AMUTEIN1		T2E6713_EXT_INT_SEL_ASIOX_AMUTEIN1

#endif



//------------ DCM (PIOX2/SIOX/ASIOX) Reset Control --------------
// For E2/6xxx DSP controllers this register is called T2E6XXX_DCM_RESET_RG.
// Default state - PIOX2/SIOX/ASIOX resets are ON (0x0)
	// PIOX2 DCM site reset control.
#define T2E6XXX_PIOX_DCM_RESET_BITMASK			1
#define T2E6XXX_PIOX_DCM_RESET_ON				0
#define T2E6XXX_PIOX_DCM_RESET_OFF				1

	// SIOX rev.B and ASIOX rev.D DCM sites common reset control
#define T2E6XXX_SIOX_DCM_RESET_BITMASK			2
#define T2E6XXX_SIOX_DCM_RESET_ON				0
#define T2E6XXX_SIOX_DCM_RESET_OFF				2

	// aliases for ASIOX rev.D DCM site
#define T2E6XXX_ASIOX_DCM_RESET_BITMASK			T2E6XXX_SIOX_DCM_RESET_BITMASK
#define T2E6XXX_ASIOX_DCM_RESET_ON				T2E6XXX_SIOX_DCM_RESET_ON
#define T2E6XXX_ASIOX_DCM_RESET_OFF				T2E6XXX_SIOX_DCM_RESET_OFF



//------------ uP Supervisory WDT/RTC control register defs ------
// For E2/6xxx DSP controllers this register is called T2E6XXX_WDT_RTC_CNTR_RG.
// Contain uP Supervisory WDT enable bit (D0), RTC enable bit (D2) and RTC Power status bit (D3)
// for E2/6713 controller.
// uP Supervisory WDT enable bit (D0) is used to enable Watchdog Timer option of uP Supervisory circuit
// and is applicable only if BOOTMODE for E2/6713 controller is FLASH8.
// RTC enable bit (D2) is used to enable access to RTC controller.
// This minimizes risk to corrupt contents of RTC registers and NvRAM
// on accidental access to RTC due to DSP hangs on.
// RTC Power status bit (D3) reflects state of RTC_PWR~ which is used in Kickstart or Wakeup features
// to activate auxillary power supply in case main power supply is failed

	// Default state - all bits are OFF except bit D1 (0x02)
#define T2E6XXX_WDT_EN_BITMASK					0x1
#define T2E6XXX_WDT_EN_OFF						0x0
#define T2E6XXX_WDT_EN_ON						0x1

#define T2E6XXX_RTC_EN_BITMASK					0x4
#define T2E6XXX_RTC_EN_OFF						0x0
#define T2E6XXX_RTC_EN_ON						0x4

#define T2E6XXX_RTC_XPS_EN_BITMASK				0x8
#define T2E6XXX_RTC_XPS_EN_OFF					0x0
#define T2E6XXX_RTC_XPS_EN_ON					0x8



#ifdef	__T2E6XXX_SELECT_E6713__
//------------ Device ID register defs ---------------------------
// This register is used for recogintion of the Device ID
// For E2/6xxx DSP controllers this register is called T2E6XXX_SYS_CNF1_RG.
#define T2E6713_DEV_ID_BITMASK					0xff
#define T2E6713_DEV_ID							1	// E2/6713 device ID
	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_DEV_ID_BITMASK					T2E6713_DEV_ID_BITMASK



//------------ Board Revision ID, DSP speed ID, Spread spectrum clock presence ID register defs
// For E2/6xxx DSP controllers this register is called T2E6XXX_SYS_CNF2_RG.
// This register is used for recogintion of the board revision ID, DSP speed ID
// and EMIF spread spectrum clock presence ID.
#define T2E6713_REV_ID_BITMASK					0xf		// E2/6713 revision ID code bitmask
#define T2E6713_DSP_CLK_FREQ_ID_BITMASK			0x30	// E2/6713 DSP clock frequency ID code bitmask
#define T2E6713_SSCLK_ID_BITMASK				0x40	// E2/6713 EMIF spread spectrum clock presence ID bitmask

#define T2E6713_REV_ID_REV1A					0x1		// f/w rev.1A (initial) for E2/6713 board rev.1A
#define T2E6713_DSP_CLK_FREQ_ID_300MHZ			0x10	// C6713B DSP with 300MHz clock
#define T2E6713_SSCLK_ID_NOT_INSTALLED			0x0		// E2/6713 EMIF spread spectrum clock oscillator is not installed
#define T2E6713_SSCLK_ID_INSTALLED				0x40	// E2/6713 EMIF spread spectrum clock oscillator is installed

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_REV_ID_BITMASK					T2E6713_REV_ID_BITMASK

#define T2E6XXX_DSP_CLK_FREQ_ID_BITMASK			T2E6713_DSP_CLK_FREQ_ID_BITMASK
#define T2E6XXX_DSP_CLK_FREQ_ID_300MHZ			T2E6713_DSP_CLK_FREQ_ID_300MHZ

#define T2E6XXX_SSCLK_ID_BITMASK				T2E6713_SSCLK_ID_BITMASK
#define T2E6XXX_SSCLK_ID_NOT_INSTALLED			T2E6713_SSCLK_ID_NOT_INSTALLED
#define T2E6XXX_SSCLK_ID_INSTALLED				T2E6713_SSCLK_ID_INSTALLED



//------------ External memory capacity (length) ID register -----
// For E2/6xxx DSP controllers this register is called T2E6XXX_SYS_CNF3_RG.
// This register is used for identification of the on-board SBSRAM/SDRAM/FLASH memories capacity.
#define T2E6713_SBSRAM_LEN_ID_BITMASK			0x03	// SBSRAM capacity ID bitmask
#define T2E6713_SDRAM_LEN_ID_BITMASK			0x0c	// SDRAM capacity ID bitmask
#define T2E6713_FLASH_LEN_ID_BITMASK			0xf0	// FLASH capacity ID bitmask
	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_SBSRAM_LEN_ID_BITMASK			T2E6713_SBSRAM_LEN_ID_BITMASK
#define T2E6XXX_SDRAM_LEN_ID_BITMASK			T2E6713_SDRAM_LEN_ID_BITMASK
#define T2E6XXX_FLASH_LEN_ID_BITMASK			T2E6713_FLASH_LEN_ID_BITMASK

	// SBSRAM length ID
#define T2E6713_SBSRAM_LEN_ID_0K				0	// SBSRAM is not installed
#define T2E6713_SBSRAM_LEN_ID_128KX32			1	// SBSRAM capacity is 128Kx32
#define T2E6713_SBSRAM_LEN_ID_512KX32			2	// SBSRAM capacity is 512Kx32
	// aliases (for length in bytes)
#define T2E6713_SBSRAM_LEN_ID_512KX8			T2E6713_SBSRAM_LEN_ID_128KX32
#define T2E6713_SBSRAM_LEN_ID_2MX8				T2E6713_SBSRAM_LEN_ID_512KX32
	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_SBSRAM_LEN_ID_0K				T2E6713_SBSRAM_LEN_ID_0K
#define T2E6XXX_SBSRAM_LEN_ID_128KX32			T2E6713_SBSRAM_LEN_ID_128KX32
#define T2E6XXX_SBSRAM_LEN_ID_512KX32			T2E6713_SBSRAM_LEN_ID_512KX32
	// aliases (for length in bytes)
#define T2E6XXX_SBSRAM_LEN_ID_512KX8			T2E6713_SBSRAM_LEN_ID_512KX8
#define T2E6XXX_SBSRAM_LEN_ID_2MX8				T2E6713_SBSRAM_LEN_ID_2MX8

	// SDRAM length ID
#define T2E6713_SDRAM_LEN_ID_0M					0	// SDRAM is not installed
#define T2E6713_SDRAM_LEN_ID_4MX32				4	// SDRAM capacity is 4Mx32
#define T2E6713_SDRAM_LEN_ID_16MX32				8	// SDRAM capacity is 16Mx32
	// aliases (for length in bytes)
#define T2E6713_SDRAM_LEN_ID_16MX8				T2E6713_SDRAM_LEN_ID_4MX32
#define T2E6713_SDRAM_LEN_ID_64MX8				T2E6713_SDRAM_LEN_ID_16MX32
	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_SDRAM_LEN_ID_0M					T2E6713_SDRAM_LEN_ID_0M
#define T2E6XXX_SDRAM_LEN_ID_4MX32				T2E6713_SDRAM_LEN_ID_4MX32
#define T2E6XXX_SDRAM_LEN_ID_16MX32				T2E6713_SDRAM_LEN_ID_16MX32
	// aliases (for length in bytes)
#define T2E6XXX_SDRAM_LEN_ID_16MX8				T2E6713_SDRAM_LEN_ID_16MX8
#define T2E6XXX_SDRAM_LEN_ID_64MX8				T2E6713_SDRAM_LEN_ID_64MX8

	// FLASH length ID
#define T2E6713_FLASH_LEN_ID_0K					0		// FLASH is not installed
#define T2E6713_FLASH_LEN_ID_512KX8				0x10	// FLASH capacity is 512Kx8
#define T2E6713_FLASH_LEN_ID_1MX8				0x20	// FLASH capacity is 1Mx8
#define T2E6713_FLASH_LEN_ID_8MX8				0x30	// FLASH capacity is 8Mx8
#define T2E6713_FLASH_LEN_ID_64MX8				0x40	// FLASH capacity is 64Mx8
	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_FLASH_LEN_ID_0K					T2E6713_FLASH_LEN_ID_0K
#define T2E6XXX_FLASH_LEN_ID_512KX8				T2E6713_FLASH_LEN_ID_512KX8
#define T2E6XXX_FLASH_LEN_ID_1MX8				T2E6713_FLASH_LEN_ID_1MX8
#define T2E6XXX_FLASH_LEN_ID_8MX8				T2E6713_FLASH_LEN_ID_8MX8
#define T2E6XXX_FLASH_LEN_ID_64MX8				T2E6713_FLASH_LEN_ID_64MX8



//------------ Peripherals ID register defs ----------------------
// This register is used for recogintion of installed peripherals (USB controller and RTC)
// For E2/6xxx DSP controllers this register is called T2E6XXX_SYS_CNF4_RG.
#define T2E6713_USB_ID_BITMASK					0x03
#define T2E6713_RTC_ID_BITMASK					0x0c

	// IDs for supported USB controllers (only one is installed)
#define T2E6713_USB_ID_NOT_INSTALLED			0
#define T2E6713_USB_ID_USB1						1		// Agere USS820 1-channel USB 1.1 device controller
#define T2E6713_USB_ID_USB2						2		// Netchip/PLX NET2272 1-channel USB 2.0 device controller
#define T2E6713_USB_ID_USB3						3		// Philips ISP1761 3-channel USB 2.0 host/device controller
	// aliases with USB chip p/n (not recommended for use in application)
#define T2E6713_USB_ID_USS820					T2E6713_USB_ID_USB1
#define T2E6713_USB_ID_NET2272					T2E6713_USB_ID_USB2
#define T2E6713_USB_ID_ISP1761					T2E6713_USB_ID_USB3

	// IDs for supported RTC controllers
#define T2E6713_RTC_ID_NOT_INSTALLED			0
#define T2E6713_RTC_ID_RTC1						0x4		// Dallas DS1501 RTC chip
	// aliases with RTC chip p/n (not recommended for use in application)
#define T2E6713_RTC_ID_DS1501					T2E6713_RTC_ID_RTC1

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_USB_ID_BITMASK					T2E6713_USB_ID_BITMASK
#define T2E6XXX_RTC_ID_BITMASK					T2E6713_RTC_ID_BITMASK

#define T2E6XXX_USB_ID_NOT_INSTALLED			T2E6713_USB_ID_NOT_INSTALLED
#define T2E6XXX_USB_ID_USB1						T2E6713_USB_ID_USB1
#define T2E6XXX_USB_ID_USB2						T2E6713_USB_ID_USB2
#define T2E6XXX_USB_ID_USB3						T2E6713_USB_ID_USB3
#define T2E6XXX_USB_ID_USS820					T2E6713_USB_ID_USS820
#define T2E6XXX_USB_ID_NET2272					T2E6713_USB_ID_NET2272
#define T2E6XXX_USB_ID_ISP1761					T2E6713_USB_ID_ISP1761

#define T2E6XXX_RTC_ID_NOT_INSTALLED			T2E6713_RTC_ID_NOT_INSTALLED
#define T2E6XXX_RTC_ID_RTC1						T2E6713_RTC_ID_RTC1
#define T2E6XXX_RTC_ID_DS1501					T2E6713_RTC_ID_DS1501



//------------ DSP environment configuration register defs -------
// This read-only register is used to return DSP op-mode, DSP bootmode, HPI enable status.
// For E2/6xxx DSP controllers this register is called T2E6XXX_DSP_CNF_RG.
#define T2E6713_BMODE_BITMASK					0x01
#define T2E6713_HPI_EN_BITMASK					0x40
#define T2E6713_OPMODE_BITMASK					0x80

#define T2E6713_BMODE_HPI						0
#define T2E6713_BMODE_FLASH8					1
#define T2E6713_HPI_EN_OFF						0
#define T2E6713_HPI_EN_ON						0x40
#define T2E6713_OPMODE_SA						0
#define T2E6713_OPMODE_HOST						0x80

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_BMODE_BITMASK					T2E6713_BMODE_BITMASK
#define T2E6XXX_HPI_EN_BITMASK					T2E6713_HPI_EN_BITMASK
#define T2E6XXX_OPMODE_BITMASK					T2E6713_OPMODE_BITMASK

#define T2E6XXX_BMODE_HPI						T2E6713_BMODE_HPI
#define T2E6XXX_BMODE_FLASH8					T2E6713_BMODE_FLASH8
#define T2E6XXX_HPI_EN_OFF						T2E6713_HPI_EN_OFF
#define T2E6XXX_HPI_EN_ON						T2E6713_HPI_EN_ON
#define T2E6XXX_OPMODE_SA						T2E6713_OPMODE_SA
#define T2E6XXX_OPMODE_HOST						T2E6713_OPMODE_HOST



//------------ DCM installation status register defs -------------
// This read-only register is used to return DCM installation status: PIOX DCM, ASIOX DCM, HCX status
// For E2/6xxx DSP controllers this register is called T2E6XXX_DCM_CNF_RG.
#define T2E6713_PIOX_DCM_TYPE_BITMASK			0x03
#define T2E6713_ASIOX_DCM_TYPE_BITMASK			0x0c
#define T2E6713_HCX_DCM_TYPE_BITMASK			0xc0

#define T2E6713_PIOX_DCM_TYPE_NOT_INSTALLED		0x00
#define T2E6713_PIOX_DCM_TYPE_ASYNC				0x01
#define T2E6713_PIOX_DCM_TYPE_ASYNC_SYNC		0x03
#define T2E6713_PIOX_DCM_TYPE_RESERVED			0x02

#define T2E6713_ASIOX_DCM_TYPE_NOT_INSTALLED	0x00
#define T2E6713_ASIOX_DCM_TYPE_SIO				0x04
#define T2E6713_ASIOX_DCM_TYPE_SIO_PIO			0x0c
#define T2E6713_ASIOX_DCM_TYPE_RESERVED			0x08

#define T2E6713_HCX_DCM_TYPE_NOT_INSTALLED		0x00
#define T2E6713_HCX_DCM_TYPE_ASYNC				0x40
#define T2E6713_HCX_DCM_TYPE_ASYNC_SYNC			0xc0
#define T2E6713_HCX_DCM_TYPE_RESERVED			0x80

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_PIOX_DCM_TYPE_BITMASK			T2E6713_PIOX_DCM_TYPE_BITMASK
#define T2E6XXX_ASIOX_DCM_TYPE_BITMASK			T2E6713_ASIOX_DCM_TYPE_BITMASK
#define T2E6XXX_HCX_DCM_TYPE_BITMASK			T2E6713_HCX_DCM_TYPE_BITMASK

#define T2E6XXX_PIOX_DCM_TYPE_NOT_INSTALLED		T2E6713_PIOX_DCM_TYPE_NOT_INSTALLED
#define T2E6XXX_PIOX_DCM_TYPE_ASYNC				T2E6713_PIOX_DCM_TYPE_ASYNC
#define T2E6XXX_PIOX_DCM_TYPE_ASYNC_SYNC		T2E6713_PIOX_DCM_TYPE_ASYNC_SYNC
#define T2E6XXX_PIOX_DCM_TYPE_RESERVED			T2E6713_PIOX_DCM_TYPE_RESERVED

#define T2E6XXX_ASIOX_DCM_TYPE_NOT_INSTALLED	T2E6713_ASIOX_DCM_TYPE_NOT_INSTALLED
#define T2E6XXX_ASIOX_DCM_TYPE_SIO				T2E6713_ASIOX_DCM_TYPE_SIO
#define T2E6XXX_ASIOX_DCM_TYPE_SIO_PIO			T2E6713_ASIOX_DCM_TYPE_SIO_PIO
#define T2E6XXX_ASIOX_DCM_TYPE_RESERVED			T2E6713_ASIOX_DCM_TYPE_RESERVED

#define T2E6XXX_HCX_DCM_TYPE_NOT_INSTALLED		T2E6713_HCX_DCM_TYPE_NOT_INSTALLED
#define T2E6XXX_HCX_DCM_TYPE_ASYNC				T2E6713_HCX_DCM_TYPE_ASYNC
#define T2E6XXX_HCX_DCM_TYPE_ASYNC_SYNC			T2E6713_HCX_DCM_TYPE_ASYNC_SYNC
#define T2E6XXX_HCX_DCM_TYPE_RESERVED			T2E6713_HCX_DCM_TYPE_RESERVED



//------------ GPIO data register defs ---------------------------
// For E2/6713 board this register is called T2E6XXX_GPIO_DATA_RG.
	// Default state - all pins are OFF (0x0)
#define T2E6713_GPIO0_DATA_BITMASK				0x01
#define T2E6713_GPIO1_DATA_BITMASK				0x02
#define T2E6713_GPIO2_DATA_BITMASK				0x04
#define T2E6713_GPIO3_DATA_BITMASK				0x08
#define T2E6713_GPIO4_DATA_BITMASK				0x10
#define T2E6713_GPIO5_DATA_BITMASK				0x20
#define T2E6713_GPIO6_DATA_BITMASK				0x40
#define T2E6713_GPIO7_DATA_BITMASK				0x80

#define T2E6713_GPIO0_DATA_ON					0x01
#define T2E6713_GPIO0_DATA_OFF					0x0
#define T2E6713_GPIO1_DATA_ON					0x02
#define T2E6713_GPIO1_DATA_OFF					0x0
#define T2E6713_GPIO2_DATA_ON					0x04
#define T2E6713_GPIO2_DATA_OFF					0x0
#define T2E6713_GPIO3_DATA_ON					0x08
#define T2E6713_GPIO3_DATA_OFF					0x0
#define T2E6713_GPIO4_DATA_ON					0x10
#define T2E6713_GPIO4_DATA_OFF					0x0
#define T2E6713_GPIO5_DATA_ON					0x20
#define T2E6713_GPIO5_DATA_OFF					0x0
#define T2E6713_GPIO6_DATA_ON					0x40
#define T2E6713_GPIO6_DATA_OFF					0x0
#define T2E6713_GPIO7_DATA_ON					0x80
#define T2E6713_GPIO7_DATA_OFF					0x0

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_GPIO0_DATA_BITMASK				T2E6713_GPIO0_DATA_BITMASK
#define T2E6XXX_GPIO1_DATA_BITMASK				T2E6713_GPIO1_DATA_BITMASK
#define T2E6XXX_GPIO2_DATA_BITMASK				T2E6713_GPIO2_DATA_BITMASK
#define T2E6XXX_GPIO3_DATA_BITMASK				T2E6713_GPIO3_DATA_BITMASK
#define T2E6XXX_GPIO4_DATA_BITMASK				T2E6713_GPIO4_DATA_BITMASK
#define T2E6XXX_GPIO5_DATA_BITMASK				T2E6713_GPIO5_DATA_BITMASK
#define T2E6XXX_GPIO6_DATA_BITMASK				T2E6713_GPIO6_DATA_BITMASK
#define T2E6XXX_GPIO7_DATA_BITMASK				T2E6713_GPIO7_DATA_BITMASK

#define T2E6XXX_GPIO0_DATA_ON					T2E6713_GPIO0_DATA_ON
#define T2E6XXX_GPIO0_DATA_OFF					T2E6713_GPIO0_DATA_OFF
#define T2E6XXX_GPIO1_DATA_ON					T2E6713_GPIO1_DATA_ON
#define T2E6XXX_GPIO1_DATA_OFF					T2E6713_GPIO1_DATA_OFF
#define T2E6XXX_GPIO2_DATA_ON					T2E6713_GPIO2_DATA_ON
#define T2E6XXX_GPIO2_DATA_OFF					T2E6713_GPIO2_DATA_OFF
#define T2E6XXX_GPIO3_DATA_ON					T2E6713_GPIO3_DATA_ON
#define T2E6XXX_GPIO3_DATA_OFF					T2E6713_GPIO3_DATA_OFF
#define T2E6XXX_GPIO4_DATA_ON					T2E6713_GPIO4_DATA_ON
#define T2E6XXX_GPIO4_DATA_OFF					T2E6713_GPIO4_DATA_OFF
#define T2E6XXX_GPIO5_DATA_ON					T2E6713_GPIO5_DATA_ON
#define T2E6XXX_GPIO5_DATA_OFF					T2E6713_GPIO5_DATA_OFF
#define T2E6XXX_GPIO6_DATA_ON					T2E6713_GPIO6_DATA_ON
#define T2E6XXX_GPIO6_DATA_OFF					T2E6713_GPIO6_DATA_OFF
#define T2E6XXX_GPIO7_DATA_ON					T2E6713_GPIO7_DATA_ON
#define T2E6XXX_GPIO7_DATA_OFF					T2E6713_GPIO7_DATA_OFF



//------------ GPIO control register defs ------------------------
// For E2/6713 board this register is called T2E6XXX_GPIO_DIR_RG.
	// Default state - all pins are INPUTS (0x0)
#define T2E6713_GPIO0_DIR_BITMASK				0x01
#define T2E6713_GPIO1_DIR_BITMASK				0x02
#define T2E6713_GPIO2_DIR_BITMASK				0x04
#define T2E6713_GPIO3_DIR_BITMASK				0x08
#define T2E6713_GPIO4_DIR_BITMASK				0x10
#define T2E6713_GPIO5_DIR_BITMASK				0x20
#define T2E6713_GPIO6_DIR_BITMASK				0x40
#define T2E6713_GPIO7_DIR_BITMASK				0x80

#define T2E6713_GPIO0_DIR_OUTPUT				0x01
#define T2E6713_GPIO0_DIR_INPUT					0x0
#define T2E6713_GPIO1_DIR_OUTPUT				0x02
#define T2E6713_GPIO1_DIR_INPUT					0x0
#define T2E6713_GPIO2_DIR_OUTPUT				0x04
#define T2E6713_GPIO2_DIR_INPUT					0x0
#define T2E6713_GPIO3_DIR_OUTPUT				0x08
#define T2E6713_GPIO3_DIR_INPUT					0x0
#define T2E6713_GPIO4_DIR_OUTPUT				0x10
#define T2E6713_GPIO4_DIR_INPUT					0x0
#define T2E6713_GPIO5_DIR_OUTPUT				0x20
#define T2E6713_GPIO5_DIR_INPUT					0x0
#define T2E6713_GPIO6_DIR_OUTPUT				0x40
#define T2E6713_GPIO6_DIR_INPUT					0x0
#define T2E6713_GPIO7_DIR_OUTPUT				0x80
#define T2E6713_GPIO7_DIR_INPUT					0x0

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_GPIO0_DIR_BITMASK				T2E6713_GPIO0_DIR_BITMASK
#define T2E6XXX_GPIO1_DIR_BITMASK				T2E6713_GPIO1_DIR_BITMASK
#define T2E6XXX_GPIO2_DIR_BITMASK				T2E6713_GPIO2_DIR_BITMASK
#define T2E6XXX_GPIO3_DIR_BITMASK				T2E6713_GPIO3_DIR_BITMASK
#define T2E6XXX_GPIO4_DIR_BITMASK				T2E6713_GPIO4_DIR_BITMASK
#define T2E6XXX_GPIO5_DIR_BITMASK				T2E6713_GPIO5_DIR_BITMASK
#define T2E6XXX_GPIO6_DIR_BITMASK				T2E6713_GPIO6_DIR_BITMASK
#define T2E6XXX_GPIO7_DIR_BITMASK				T2E6713_GPIO7_DIR_BITMASK

#define T2E6XXX_GPIO0_DIR_OUTPUT				T2E6713_GPIO0_DIR_OUTPUT
#define T2E6XXX_GPIO0_DIR_INPUT					T2E6713_GPIO0_DIR_INPUT
#define T2E6XXX_GPIO1_DIR_OUTPUT				T2E6713_GPIO1_DIR_OUTPUT
#define T2E6XXX_GPIO1_DIR_INPUT					T2E6713_GPIO1_DIR_INPUT
#define T2E6XXX_GPIO2_DIR_OUTPUT				T2E6713_GPIO2_DIR_OUTPUT
#define T2E6XXX_GPIO2_DIR_INPUT					T2E6713_GPIO2_DIR_INPUT
#define T2E6XXX_GPIO3_DIR_OUTPUT				T2E6713_GPIO3_DIR_OUTPUT
#define T2E6XXX_GPIO3_DIR_INPUT					T2E6713_GPIO3_DIR_INPUT
#define T2E6XXX_GPIO4_DIR_OUTPUT				T2E6713_GPIO4_DIR_OUTPUT
#define T2E6XXX_GPIO4_DIR_INPUT					T2E6713_GPIO4_DIR_INPUT
#define T2E6XXX_GPIO5_DIR_OUTPUT				T2E6713_GPIO5_DIR_OUTPUT
#define T2E6XXX_GPIO5_DIR_INPUT					T2E6713_GPIO5_DIR_INPUT
#define T2E6XXX_GPIO6_DIR_OUTPUT				T2E6713_GPIO6_DIR_OUTPUT
#define T2E6XXX_GPIO6_DIR_INPUT					T2E6713_GPIO6_DIR_INPUT
#define T2E6XXX_GPIO7_DIR_OUTPUT				T2E6713_GPIO7_DIR_OUTPUT
#define T2E6XXX_GPIO7_DIR_INPUT					T2E6713_GPIO7_DIR_INPUT



//------------ DSP McBSP/McASP/I2C serial port configuration register defs
// For E2/6713 board this register is called T2E6XXX_DSP_PORTS_CNTR_RG.
	// Default state - all buffers are DISABLED (0x0)
#define T2E6713_MCASP0_BUF_EN1_BITMASK			0x01
#define T2E6713_MCASP0_BUF_EN2_BITMASK			0x02
#define T2E6713_MCASP0_BUF_EN3_BITMASK			0x04
#define T2E6713_MCASP0_BUF_EN4_BITMASK			0x08
#define T2E6713_MCASP1_BUF_EN_BITMASK			0x10
#define T2E6713_MCBSP0_BUF_EN_BITMASK			0x20
#define T2E6713_MCBSP1_BUF_EN_BITMASK			0x40
#define T2E6713_I2C1_BUF_EN_BITMASK				0x80
#define T2E6713_MCASP0_BUF_EN_BITMASK			0x6f

#define T2E6713_MCASP0_BUF_EN1_ON				0x01
#define T2E6713_MCASP0_BUF_EN1_OFF				0x0
#define T2E6713_MCASP0_BUF_EN2_ON				0x02
#define T2E6713_MCASP0_BUF_EN2_OFF				0x0
#define T2E6713_MCASP0_BUF_EN3_ON				0x04
#define T2E6713_MCASP0_BUF_EN3_OFF				0x0
#define T2E6713_MCASP0_BUF_EN4_ON				0x08
#define T2E6713_MCASP0_BUF_EN4_OFF				0x0
#define T2E6713_MCASP1_BUF_EN_ON				0x10
#define T2E6713_MCASP1_BUF_EN_OFF				0x0
#define T2E6713_MCBSP0_BUF_EN_ON				0x20
#define T2E6713_MCBSP0_BUF_EN_OFF				0x0
#define T2E6713_MCBSP1_BUF_EN_ON				0x40
#define T2E6713_MCBSP1_BUF_EN_OFF				0x0
#define T2E6713_I2C1_BUF_EN_ON					0x80
#define T2E6713_I2C1_BUF_EN_OFF					0x0
#define T2E6713_MCASP0_BUF_EN_ON				0x0f
#define T2E6713_MCASP0_BUF_EN_OFF				0x0

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_MCASP0_BUF_EN1_BITMASK			T2E6713_MCASP0_BUF_EN1_BITMASK
#define T2E6XXX_MCASP0_BUF_EN2_BITMASK			T2E6713_MCASP0_BUF_EN2_BITMASK
#define T2E6XXX_MCASP0_BUF_EN3_BITMASK			T2E6713_MCASP0_BUF_EN3_BITMASK
#define T2E6XXX_MCASP0_BUF_EN4_BITMASK			T2E6713_MCASP0_BUF_EN4_BITMASK
#define T2E6XXX_MCASP1_BUF_EN_BITMASK			T2E6713_MCASP1_BUF_EN_BITMASK
#define T2E6XXX_MCBSP0_BUF_EN_BITMASK			T2E6713_MCBSP0_BUF_EN_BITMASK
#define T2E6XXX_MCBSP1_BUF_EN_BITMASK			T2E6713_MCBSP1_BUF_EN_BITMASK
#define T2E6XXX_I2C1_BUF_EN_BITMASK				T2E6713_I2C1_BUF_EN_BITMASK
#define T2E6XXX_MCASP0_BUF_EN_BITMASK			T2E6713_MCASP0_BUF_EN_BITMASK

#define T2E6XXX_MCASP0_BUF_EN1_ON				T2E6713_MCASP0_BUF_EN1_ON
#define T2E6XXX_MCASP0_BUF_EN1_OFF				T2E6713_MCASP0_BUF_EN1_OFF
#define T2E6XXX_MCASP0_BUF_EN2_ON				T2E6713_MCASP0_BUF_EN2_ON
#define T2E6XXX_MCASP0_BUF_EN2_OFF				T2E6713_MCASP0_BUF_EN2_OFF
#define T2E6XXX_MCASP0_BUF_EN3_ON				T2E6713_MCASP0_BUF_EN3_ON
#define T2E6XXX_MCASP0_BUF_EN3_OFF				T2E6713_MCASP0_BUF_EN3_OFF
#define T2E6XXX_MCASP0_BUF_EN4_ON				T2E6713_MCASP0_BUF_EN4_ON
#define T2E6XXX_MCASP0_BUF_EN4_OFF				T2E6713_MCASP0_BUF_EN4_OFF
#define T2E6XXX_MCASP1_BUF_EN_ON				T2E6713_MCASP1_BUF_EN_ON
#define T2E6XXX_MCASP1_BUF_EN_OFF				T2E6713_MCASP1_BUF_EN_OFF
#define T2E6XXX_MCBSP0_BUF_EN_ON				T2E6713_MCBSP0_BUF_EN_ON
#define T2E6XXX_MCBSP0_BUF_EN_OFF				T2E6713_MCBSP0_BUF_EN_OFF
#define T2E6XXX_MCBSP1_BUF_EN_ON				T2E6713_MCBSP1_BUF_EN_ON
#define T2E6XXX_MCBSP1_BUF_EN_OFF				T2E6713_MCBSP1_BUF_EN_OFF
#define T2E6XXX_I2C1_BUF_EN_ON					T2E6713_I2C1_BUF_EN_ON
#define T2E6XXX_I2C1_BUF_EN_OFF					T2E6713_I2C1_BUF_EN_OFF
#define T2E6XXX_MCASP0_BUF_EN_ON				T2E6713_MCASP0_BUF_EN_ON
#define T2E6XXX_MCASP0_BUF_EN_OFF				T2E6713_MCASP0_BUF_EN_OFF



//------------ FLASH control register defs -----------------------
// For E2/6713 board this register is called T2E6XXX_FLASH_CNTR_RG.
	// Default state - write DISABLED (0x0)
#define T2E6713_FLASH64M_BOOT_SECTOR_WR_EN_BITMASK			0x40
#define T2E6713_FLASH_WR_EN_BITMASK							0x80

#define T2E6713_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_BITMASK	0x10
#define T2E6713_FLASH_XWRPROT_STAT_BITMASK					0x20

#define T2E6713_FLASH64M_BOOT_SECTOR_WR_EN_OFF				0
#define T2E6713_FLASH64M_BOOT_SECTOR_WR_EN_ON				0x40
#define T2E6713_FLASH_WR_EN_OFF								0
#define T2E6713_FLASH_WR_EN_ON								0x80
#define T2E6713_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_OFF		0
#define T2E6713_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_ON		0x40
#define T2E6713_FLASH_XWRPROT_STAT_OFF						0
#define T2E6713_FLASH_XWRPROT_STAT_ON						0x80

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_FLASH64M_BOOT_SECTOR_WR_EN_BITMASK			T2E6713_FLASH64M_BOOT_SECTOR_WR_EN_BITMASK
#define T2E6XXX_FLASH_WR_EN_BITMASK							T2E6713_FLASH_WR_EN_BITMASK
#define T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_BITMASK	T2E6713_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_BITMASK
#define T2E6XXX_FLASH_XWRPROT_STAT_BITMASK					T2E6713_FLASH_XWRPROT_STAT_BITMASK

#define T2E6XXX_FLASH64M_BOOT_SECTOR_WR_EN_OFF				T2E6713_FLASH64M_BOOT_SECTOR_WR_EN_OFF
#define T2E6XXX_FLASH64M_BOOT_SECTOR_WR_EN_ON				T2E6713_FLASH64M_BOOT_SECTOR_WR_EN_ON
#define T2E6XXX_FLASH_WR_EN_OFF								T2E6713_FLASH_WR_EN_OFF
#define T2E6XXX_FLASH_WR_EN_ON								T2E6713_FLASH_WR_EN_ON

#define T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_OFF		T2E6713_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_OFF
#define T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_ON		T2E6713_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_ON
#define T2E6XXX_FLASH_XWRPROT_STAT_OFF						T2E6713_FLASH_XWRPROT_STAT_OFF
#define T2E6XXX_FLASH_XWRPROT_STAT_ON						T2E6713_FLASH_XWRPROT_STAT_ON



//------------ FLASH page register defs --------------------------
// For E2/6713 board this register is called T2E6XXX_FLASH_PAGE_RG.
	// Default state - write DISABLED (0x0)
#define T2E6713_FLASH_PAGE_RG_BITMASK			0x3f
	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_FLASH_PAGE_RG_BITMASK			T2E6713_FLASH_PAGE_RG_BITMASK



//------------ SIOX rev.B SX_TM/XIO-0/1 pins control register defs
// For E2/6713 board this register is called T2E6XXX_SIOX_XIO_CNF_RG.
	// Default state - all pins are IO and INPUTS (0x0)
#define T2E6713_SIOX_XIO0_CNF_BITMASK			0x03
#define T2E6713_SIOX_XIO1_CNF_BITMASK			0x30

#define T2E6713_SIOX_XIO0_CNF_INPUT				0x00
#define T2E6713_SIOX_XIO0_CNF_OUTPUT			0x01
#define T2E6713_SIOX_XIO0_CNF_TOUT0				0x02

#define T2E6713_SIOX_XIO1_CNF_INPUT				0x00
#define T2E6713_SIOX_XIO1_CNF_OUTPUT			0x10
#define T2E6713_SIOX_XIO1_CNF_TOUT1				0x20

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_SIOX_XIO0_CNF_BITMASK			T2E6713_SIOX_XIO0_CNF_BITMASK
#define T2E6XXX_SIOX_XIO1_CNF_BITMASK			T2E6713_SIOX_XIO1_CNF_BITMASK

#define T2E6XXX_SIOX_XIO0_CNF_INPUT				T2E6713_SIOX_XIO0_CNF_INPUT
#define T2E6XXX_SIOX_XIO0_CNF_OUTPUT			T2E6713_SIOX_XIO0_CNF_OUTPUT
#define T2E6XXX_SIOX_XIO0_CNF_TOUT0				T2E6713_SIOX_XIO0_CNF_TOUT0

#define T2E6XXX_SIOX_XIO1_CNF_INPUT				T2E6713_SIOX_XIO1_CNF_INPUT
#define T2E6XXX_SIOX_XIO1_CNF_OUTPUT			T2E6713_SIOX_XIO1_CNF_OUTPUT
#define T2E6XXX_SIOX_XIO1_CNF_TOUT1				T2E6713_SIOX_XIO1_CNF_TOUT1



//------------ SIOX rev.B SX_TM/XIO-0/1 output data register defs
// For E2/6713 board this register is called T2E6XXX_SIOX_XIO_DATA_RG.
	// Default state - all pins are OFF (0x0)
#define T2E6713_SIOX_XIO0_DATA_BITMASK			0x01
#define T2E6713_SIOX_XIO1_DATA_BITMASK			0x02

#define T2E6713_SIOX_XIO0_DATA_ON				0x01
#define T2E6713_SIOX_XIO0_DATA_OFF				0x0
#define T2E6713_SIOX_XIO1_DATA_ON				0x02
#define T2E6713_SIOX_XIO1_DATA_OFF				0x0

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_SIOX_XIO0_DATA_BITMASK			T2E6713_SIOX_XIO0_DATA_BITMASK
#define T2E6XXX_SIOX_XIO1_DATA_BITMASK			T2E6713_SIOX_XIO1_DATA_BITMASK

#define T2E6XXX_SIOX_XIO0_DATA_ON				T2E6713_SIOX_XIO0_DATA_ON
#define T2E6XXX_SIOX_XIO0_DATA_OFF				T2E6713_SIOX_XIO0_DATA_OFF
#define T2E6XXX_SIOX_XIO1_DATA_ON				T2E6713_SIOX_XIO1_DATA_ON
#define T2E6XXX_SIOX_XIO1_DATA_OFF				T2E6713_SIOX_XIO1_DATA_OFF



//------------ HCX_SYNC Address Extension register defs ----------
// For E2/6713 board this register is called T2E6XXX_HCX_SYNC_PAGE_RG.
#define T2E6713_HCX_SYNC_PAGE_RG_BITMASK		0x3f

	// aliases for compatibilty with T2E6XXX API
#define T2E6XXX_HCX_SYNC_PAGE_RG_BITMASK		T2E6713_HCX_SYNC_PAGE_RG_BITMASK
//----------------------------------------------------------------

#endif



#ifdef	__T2E6XXX_SELECT_E6713__

//------------ Exar ST16C2550 DUART defs -------------------------
	// UART refrence clock (Hz)
#define T2E6XXX_UART_REF_CLK_FREQ				18.432e+6	// UART ref clock value (Hz)
	// UART data registers read-back bitmask
#define T2E6XXX_UART_DATA_BITMASK				0xff
	// UART register offset bitmask/bitshift
#define T2E6XXX_UART_RG_OFFSET_BITMASK			0x1c
#define T2E6XXX_UART_RG_OFFSET_BITSHIFT			2

	// UART registers offsets, which shall be '<<2' and added to the
	// corresponding UART-A/B base address in order to get UART-A/B register address
#define T2E6XXX_UART_RDATA_RG					0x00	// r: receiver data register if DLAB=0
#define T2E6XXX_UART_TDATA_RG					0x00	// w: tramitter data register if DLAB=0
#define T2E6XXX_UART_DIVL_RG					0x00	// r/w: divisor low register if DLAB=1
#define T2E6XXX_UART_IE_RG						0x01	// r/w: interrupt enable register if DLAB=0
#define T2E6XXX_UART_DIVH_RG					0x01	// r/w: divisor high register if DLAB=1
#define T2E6XXX_UART_IID_RG						0x02	// r: interrupt status/ID register
#define T2E6XXX_UART_FCNTR_RG					0x02	// w: FIFO control register (specific to ST16C2550)
#define T2E6XXX_UART_LCNTR_RG					0x03	// r/w: line control register
#define T2E6XXX_UART_MCNTR_RG					0x04	// r/w: modem control register
#define T2E6XXX_UART_LSTAT_RG					0x05	// r: line status register
#define T2E6XXX_UART_MSTAT_RG					0x06	// r: modem control register
#define T2E6XXX_UART_SCRPAD_RG					0x07	// r/w: general 8-bit scratch-pad register (specific to ST16C2550)

	// UART DIVL/DIVH registers setting for most popular bit rates
	// UART_baud_rate = UART_REF_CLK_FREQ/(16*(DIVL+(256*DIVH)))
#define T2E6XXX_UART_DIVL_384000				0x03
#define T2E6XXX_UART_DIVH_384000				0x00
#define T2E6XXX_UART_DIVL_230400				0x05
#define T2E6XXX_UART_DIVH_230400				0x00
#define T2E6XXX_UART_DIVL_128000				0x09
#define T2E6XXX_UART_DIVH_128000				0x00
#define T2E6XXX_UART_DIVL_115200				0x0a
#define T2E6XXX_UART_DIVH_115200				0x00
#define T2E6XXX_UART_DIVL_57600					0x14
#define T2E6XXX_UART_DIVH_57600					0x00
#define T2E6XXX_UART_DIVL_38400					0x1e
#define T2E6XXX_UART_DIVH_38400					0x00
#define T2E6XXX_UART_DIVL_19200					0x3c
#define T2E6XXX_UART_DIVH_19200					0x00
#define T2E6XXX_UART_DIVL_9600					0x78
#define T2E6XXX_UART_DIVH_9600					0x00
#define T2E6XXX_UART_DIVL_4800					0xf0
#define T2E6XXX_UART_DIVH_4800					0x00
#define T2E6XXX_UART_DIVL_2400					0xe0
#define T2E6XXX_UART_DIVH_2400					0x01
#define T2E6XXX_UART_DIVL_1200					0xc0
#define T2E6XXX_UART_DIVH_1200					0x03
#define T2E6XXX_UART_DIVL_600					0x80
#define T2E6XXX_UART_DIVH_600					0x07

	// UART IE register bits
#define T2E6XXX_UART_IE_DR						0x01
#define T2E6XXX_UART_IE_RRDY					0x01	// alias
#define T2E6XXX_UART_IE_TEMPTY					0x02
#define T2E6XXX_UART_IE_RLINESTAT				0x04
#define T2E6XXX_UART_IE_MSTAT					0x08

	// UART LCNTR register bits
#define T2E6XXX_UART_LCNTR_DLAB					0x80
#define T2E6XXX_UART_LCNTR_WLEN5				0x00
#define T2E6XXX_UART_LCNTR_WLEN6				0x01
#define T2E6XXX_UART_LCNTR_WLEN7				0x02
#define T2E6XXX_UART_LCNTR_WLEN8				0x03
#define T2E6XXX_UART_LCNTR_STOP1				0x00
#define T2E6XXX_UART_LCNTR_STOP2				0x04
#define T2E6XXX_UART_LCNTR_NOPAR				0x00
#define T2E6XXX_UART_LCNTR_ODDPAR				0x08
#define T2E6XXX_UART_LCNTR_EVENPAR				0x18

	// UART IID register bits (read-only)
#define T2E6XXX_UART_IID_INT_BITMASK			0x0f
#define T2E6XXX_UART_IID_INT_NONE				0x01
#define T2E6XXX_UART_IID_INT_MSTAT				0x00
#define T2E6XXX_UART_IID_INT_TEMPTY				0x02
#define T2E6XXX_UART_IID_INT_RRDY				0x04
#define T2E6XXX_UART_IID_INT_RTMOUT				0x0c
#define T2E6XXX_UART_IID_INT_RLINESTAT			0x06

#define T2E6XXX_UART_IID_FIFO_EN_STAT_BITMASK	0xc0
#define T2E6XXX_UART_IID_FIFO_EN_STAT_OFF		0x00
#define T2E6XXX_UART_IID_FIFO_EN_STAT_ON		0xc0

	// UART FCNTR register bits (write-only)
#define T2E6XXX_UART_FCNTR_FIFO_EN_OFF			0x00
#define T2E6XXX_UART_FCNTR_FIFO_EN_ON			0x01
#define T2E6XXX_UART_FCNTR_RFIFO_RESET			0x02
#define T2E6XXX_UART_FCNTR_TFIFO_RESET			0x04
#define T2E6XXX_UART_FCNTR_DMA_MODE0			0x00
#define T2E6XXX_UART_FCNTR_DMA_MODE1			0x08
#define T2E6XXX_UART_FCNTR_RFIFO_TRIG_LEVEL_1	0x00
#define T2E6XXX_UART_FCNTR_RFIFO_TRIG_LEVEL_4	0x40
#define T2E6XXX_UART_FCNTR_RFIFO_TRIG_LEVEL_8	0x80
#define T2E6XXX_UART_FCNTR_RFIFO_TRIG_LEVEL_14	0xc0

	// UART MCNTR register bits
#define T2E6XXX_UART_MCNTR_DTR					0x01
#define T2E6XXX_UART_MCNTR_RTS					0x02
#define T2E6XXX_UART_MCNTR_INT_OE_OFF			0x00	// INT OE and OUT2 feature shared control bit in MCNTR
#define T2E6XXX_UART_MCNTR_INT_OE_ON			0x08
#define T2E6XXX_UART_MCNTR_OUT2_OFF				0x00
#define T2E6XXX_UART_MCNTR_OUT2_ON				0x08
#define T2E6XXX_UART_MCNTR_LOOPBACK_EN			0x10

	// UART LSTAT register bits (read-only)
#define T2E6XXX_UART_LSTAT_DR					0x01
#define T2E6XXX_UART_LSTAT_RRDY					0x01	// alias
#define T2E6XXX_UART_LSTAT_OE					0x02
#define T2E6XXX_UART_LSTAT_ROVR_ERR				0x02	// alias
#define T2E6XXX_UART_LSTAT_PE					0x04
#define T2E6XXX_UART_LSTAT_PARITY_ERR			0x04	// alias
#define T2E6XXX_UART_LSTAT_FE					0x08
#define T2E6XXX_UART_LSTAT_FRAMING_ERR			0x08	// alias
#define T2E6XXX_UART_LSTAT_BI					0x10
#define T2E6XXX_UART_LSTAT_BREAK_INT			0x10	// alias
#define T2E6XXX_UART_LSTAT_THEMPTY				0x20
#define T2E6XXX_UART_LSTAT_TEMPTY				0x40
#define T2E6XXX_UART_LSTAT_FIFO_ERR				0x80

	// UART MSTAT register bits (read-only)
#define T2E6XXX_UART_MSTAT_DCTS					0x01
#define T2E6XXX_UART_MSTAT_DDSR					0x02
#define T2E6XXX_UART_MSTAT_TERI					0x04
#define T2E6XXX_UART_MSTAT_DDCD					0x08
#define T2E6XXX_UART_MSTAT_CTS					0x10
#define T2E6XXX_UART_MSTAT_DSR					0x20
#define T2E6XXX_UART_MSTAT_RI					0x40
#define T2E6XXX_UART_MSTAT_DCD					0x80



//------------ USB defs ------------------------------------------
//------------ USB1: Lucent USS820 1-channel USB 1.1 Device controller registers defs
// USB 1.1 controller is Agere' USS-820 USB 1.1.
// Maximum bulk data transfer rate is 12 Mbit/s.
// For more details refer to USS-820 Datasheet
//
// This controller has alias USB1 in this file.
//
// Note!!!:
//	1.	No bit defs are provided for USB1 controller registers.
//		This info is available via USS820.H header file.
//		User must do it himself upon particular application.

	// USB1 controller data registers read-back bitmask
#define T2E6XXX_USB1_DATA_BITMASK				0xff
	// USB1 register offset bitmask/bitshift
#define T2E6XXX_USB1_RG_OFFSET_BITMASK			0x7c
#define T2E6XXX_USB1_RG_OFFSET_BITSHIFT			2

	// USB1 controller register offsets, which shall be '<<2' and added to the USB1
	// controller base address in order to get USB1 controller register address
#define T2E6XXX_USB1_TXDAT_RG					0x0
#define T2E6XXX_USB1_TXCNTL_RG					0x1
#define T2E6XXX_USB1_TXCNTH_RG					0x2
#define T2E6XXX_USB1_TXCON_RG					0x3
#define T2E6XXX_USB1_TXFLG_RG					0x4
#define T2E6XXX_USB1_RXDAT_RG					0x5
#define T2E6XXX_USB1_RXCNTL_RG					0x6
#define T2E6XXX_USB1_RXCNTH_RG					0x7
#define T2E6XXX_USB1_RXCON_RG					0x8
#define T2E6XXX_USB1_RXFLG_RG					0x9
#define T2E6XXX_USB1_EPINDEX_RG					0xa
#define T2E6XXX_USB1_EPCON_RG					0xb
#define T2E6XXX_USB1_TXSTAT_RG					0xc
#define T2E6XXX_USB1_RXSTAT_RG					0xd
#define T2E6XXX_USB1_SOFL_RG					0xe
#define T2E6XXX_USB1_SOFH_RG					0xf
#define T2E6XXX_USB1_FADDR_RG					0x10
#define T2E6XXX_USB1_SCR_RG						0x11
#define T2E6XXX_USB1_SSR_RG						0x12
#define T2E6XXX_USB1_SBI_RG						0x14
#define T2E6XXX_USB1_SBI1_RG					0x15
#define T2E6XXX_USB1_SBIE_RG					0x16
#define T2E6XXX_USB1_SBIE1_RG					0x17
#define T2E6XXX_USB1_REV_RG						0x18
#define T2E6XXX_USB1_LOCK_RG					0x19
#define T2E6XXX_USB1_PEND_RG					0x1a
#define T2E6XXX_USB1_SCRATCH_RG					0x1b
#define T2E6XXX_USB1_MCSR_RG					0x1c



//------------ USB2: PLX/NetChip NET2272 USB 2.0 1-channel Device controller registers defs
// USB 2.0 1-channel Device only controller is PLX-NetChip NET2272.
// Data transfer speed is high-speed 480 Mbit/s and full-speed 12 Mbit/s (low speed is not supported).
// Data register format is s/w configured either 8-bit or 16-bit, however these utilities use 16-bit for
// highest performance. All control registers have 8-bit data format, whereas endpoint data register has
// 16-bit data format.
// For more details refer to the NET2272 Datasheet.
//
// This controller has alias USB2 in this file.
//
// Note!!!:
//	1.	No bit defs are provided for USB2 controller registers.
//		This info is available via NET2272.H header file.

	// USB2 controller data registers read-back bitmask
#define T2E6XXX_USB2_DATA_BITMASK				0xffff
	// USB2 register offset bitmask/bitshift
#define T2E6XXX_USB2_RG_OFFSET_BITMASK			0x7c
#define T2E6XXX_USB2_RG_OFFSET_BITSHIFT			2

	// USB2 controller register offsets, which shall be '<<2' and added to the USB2
	// controller base address in order to get USB2 controller register address
	// directly addressed registers
#define T2E6XXX_USB2_REGADDRPTR_RG				0x0
#define T2E6XXX_USB2_REGDATA_RG					0x1		// 8-bit r/w data for indirectly addressed registers
#define T2E6XXX_USB2_IRQSTAT0_RG				0x2
#define T2E6XXX_USB2_IRQSTAT1_RG				0x3
#define T2E6XXX_USB2_PAGESEL_RG					0x4
#define T2E6XXX_USB2_EPDATA_RG					0x5		// 16-bit end-point data
#define T2E6XXX_USB2_EPSTAT0_RG					0x6
#define T2E6XXX_USB2_EPSTAT1_RG					0x7
#define T2E6XXX_USB2_EPTRANSFER0_RG				0x8
#define T2E6XXX_USB2_EPTRANSFER1_RG				0x9
#define T2E6XXX_USB2_EPTRANSFER2_RG				0xa
#define T2E6XXX_USB2_EPIRQENB_RG				0xb
#define T2E6XXX_USB2_EPAVAIL0_RG				0xc
#define T2E6XXX_USB2_EPAVAIL1_RG				0xd
#define T2E6XXX_USB2_RSPCLR_RG					0xe
#define T2E6XXX_USB2_RSPSET_RG					0xf
#define T2E6XXX_USB2_USBCTL0_RG					0x18
#define T2E6XXX_USB2_USBCTL1_RG					0x19
#define T2E6XXX_USB2_FRAME0_RG					0x1a
#define T2E6XXX_USB2_FRAME1_RG					0x1b
#define T2E6XXX_USB2_DMAREQ_RG					0x1c
#define T2E6XXX_USB2_SCRATCH_RG					0x1d

	// indirectly addressed registers (8-bit data)
	// These registers cannot be accessed directly. In order to access these registers,
	// the register address must be first loaded into the T2E6XXX_USB2_REGADDRPTR_RG register and
	// then the data can be accessed via the T2E6XXX_USB2_REGDATA_RG register.
#define T2E6XXX_USB2_IRQENB0_RG					0x20
#define T2E6XXX_USB2_IRQENB1_RG					0x21
#define T2E6XXX_USB2_LOCCTL_RG					0x22
#define T2E6XXX_USB2_CHIPREVLEGACY_RG			0x23
#define T2E6XXX_USB2_LOCCTL1_RG					0x24
#define T2E6XXX_USB2_CHIPREV2272_RG				0x25
#define T2E6XXX_USB2_EPMAXPKT0_RG				0x28
#define T2E6XXX_USB2_EPMAXPKT1_RG				0x29
#define T2E6XXX_USB2_EPCFG_RG					0x2a
#define T2E6XXX_USB2_EPHBW_RG					0x2b
#define T2E6XXX_USB2_EBBUFFSTATES_RG			0x2c
#define T2E6XXX_USB2_OURADDR_RG					0x30
#define T2E6XXX_USB2_USBDIAG_RG					0x31
#define T2E6XXX_USB2_USBTEST_RG					0x32
#define T2E6XXX_USB2_XCVRDIAG_RG				0x33
#define T2E6XXX_USB2_VIRTOUT0_RG				0x34
#define T2E6XXX_USB2_VIRTOUT1_RG				0x35
#define T2E6XXX_USB2_VIRTIN0_RG					0x36
#define T2E6XXX_USB2_VIRTIN1_RG					0x37
#define T2E6XXX_USB2_SETUP0_RG					0x40
#define T2E6XXX_USB2_SETUP1_RG					0x41
#define T2E6XXX_USB2_SETUP2_RG					0x42
#define T2E6XXX_USB2_SETUP3_RG					0x43
#define T2E6XXX_USB2_SETUP4_RG					0x44
#define T2E6XXX_USB2_SETUP5_RG					0x45
#define T2E6XXX_USB2_SETUP6_RG					0x46
#define T2E6XXX_USB2_SETUP7_RG					0x47



//------------ USB3: Philips ISP1761 USB 2.0 3-channel Host/Device controller registers defs
// USB 2.0 3-channel Host/Device controller is Philips ISP1761 USB 2.0 compliant controller.
// Data transfer speeds are high-speed 480 Mbit/s, full-speed 12 Mbit/s and low speed 1.5 Mbit/s.
// The ISP1761 has three USB ports. Port 1 can be configured as an OTG Controller port, as a Host
// Controller port or as a Peripheral Controller port. Ports 2 and 3 are always configured as
// Host Controller ports.
// Data register format is s/w configured either 16-bit or 32-bit, however these utilities use 32-bit
// access for highest performance (This selection is allowed by HW Mode Control register - default
// setting is 32-bit data bus width).
// For more details refer to the ISP1761 Datasheet.
//
// This controller has alias USB3 in this file.
//
// Note!!!:
//	1.	No bit defs are provided for USB3 controller registers.

	// USB3 controller data registers read-back bitmask
#define T2E6XXX_USB3_DATA_BITMASK				0xffffffff
	// USB3 register offset bitmask/bitshift
#define T2E6XXX_USB3_RG_OFFSET_BITMASK			0x3fffc
#define T2E6XXX_USB3_RG_OFFSET_BITSHIFT			2

//!!!! reserved for ISP1761 register defs here



//------------ RTC defs ------------------------------------------
//------------ RTC1: DallasSemi DS1501 RTC (real-time clock) controller defs
// This controller has alias RTC1 in this file.

	// RTC1 controller data registers read-back bitmask
#define T2E6XXX_RTC1_DATA_BITMASK				0xff
	// RTC1 register offset bitmask/bitshift
#define T2E6XXX_RTC1_RG_OFFSET_BITMASK			0x7c
#define T2E6XXX_RTC1_RG_OFFSET_BITSHIFT			2

	// RTC1 registers offset definitions
#define T2E6XXX_RTC1_CLK_SECONDS_RG				0x0		// x1sec/x10sec clock settings
#define T2E6XXX_RTC1_CLK_MINUTES_RG				0x1		// x1min/x10min clock settings
#define T2E6XXX_RTC1_CLK_HOURS_RG				0x2		// x1hour/x10hour clock settings
#define T2E6XXX_RTC1_CLK_DAY_OF_WEEK_RG			0x3		// day of week clock settings
#define T2E6XXX_RTC1_CLK_DATE_RG				0x4		// date clock settings
#define T2E6XXX_RTC1_CLK_MONTH_RG				0x5		// month clock settings
#define T2E6XXX_RTC1_CLK_YEAR_RG				0x6		// year clock settings
#define T2E6XXX_RTC1_CLK_CENTURY_RG				0x7		// century clock settings
#define T2E6XXX_RTC1_ALARM_SECONDS_RG			0x8		// x1sec/x10sec alarm settings
#define T2E6XXX_RTC1_ALARM_MINUTES_RG			0x9		// x1min/x10min alarm settings
#define T2E6XXX_RTC1_ALARM_HOURS_RG				0xa		// x1hour/x10hour alarm settings
#define T2E6XXX_RTC1_ALARM_DAY_DATE_RG			0xb		// day of week/date alarm settings
#define T2E6XXX_RTC1_WDT_SECONDS_FRACTION_RG	0xc		// x0.01sec/x0.1sec WDT settings
#define T2E6XXX_RTC1_WDT_SECONDS_RG				0xd		// x1sec/x10sec WDT settings
#define T2E6XXX_RTC1_CNTRA_RG					0xe		// control A register
#define T2E6XXX_RTC1_CNTRB_RG					0xf		// control B register
	// Extended user RAM area (256x8)
	// This RAM cannot be accessed directly. In order to access this area,
	// an address must be first loaded into the T2E6XXX_RTC1_USER_RAM_ADDR_RG register and
	// then the data can be accessed via the T2E6XXX_RTC1_USER_RAM_DATA_RG register.
#define T2E6XXX_RTC1_USER_RAM_ADDR_RG			0x10	// address register for user RAM area accesses
#define T2E6XXX_RTC1_USER_RAM_DATA_RG			0x13	// data register for user RAM area accesses
#define T2E6XXX_RTC1_USER_RAM_LEN				0xff	// length of user registers area (RAM)

	// RTC1 Control A register bits definitions
#define T2E6XXX_RTC1_CNTRA_BLF1_BITMASK			0x80
#define T2E6XXX_RTC1_CNTRA_BLF2_BITMASK			0x40
#define T2E6XXX_RTC1_CNTRA_PRS_BITMASK			0x20
#define T2E6XXX_RTC1_CNTRA_PAB_BITMASK			0x10
#define T2E6XXX_RTC1_CNTRA_TDF_BITMASK			0x08
#define T2E6XXX_RTC1_CNTRA_KSF_BITMASK			0x04
#define T2E6XXX_RTC1_CNTRA_WDF_BITMASK			0x02
#define T2E6XXX_RTC1_CNTRA_IRQF_BITMASK			0x01

#define T2E6XXX_RTC1_CNTRA_BLF1_ON				0x80
#define T2E6XXX_RTC1_CNTRA_BLF1_OFF				0x0
#define T2E6XXX_RTC1_CNTRA_BLF2_ON				0x40
#define T2E6XXX_RTC1_CNTRA_BLF2_OFF				0x0
#define T2E6XXX_RTC1_CNTRA_PRS_ON				0x20
#define T2E6XXX_RTC1_CNTRA_PRS_OFF				0x0
#define T2E6XXX_RTC1_CNTRA_PAB_ON				0x10
#define T2E6XXX_RTC1_CNTRA_PAB_OFF				0x0
#define T2E6XXX_RTC1_CNTRA_TDF_ON				0x08
#define T2E6XXX_RTC1_CNTRA_TDF_OFF				0x0
#define T2E6XXX_RTC1_CNTRA_KSF_ON				0x04
#define T2E6XXX_RTC1_CNTRA_KSF_OFF				0x0
#define T2E6XXX_RTC1_CNTRA_WDF_ON				0x02
#define T2E6XXX_RTC1_CNTRA_WDF_OFF				0x0
#define T2E6XXX_RTC1_CNTRA_IRQF_ON				0x01
#define T2E6XXX_RTC1_CNTRA_IRQF_OFF				0x0

	// RTC1 Control B register bits definitions
#define T2E6XXX_RTC1_CNTRB_TE_BITMASK			0x80
#define T2E6XXX_RTC1_CNTRB_CS_BITMASK			0x40
#define T2E6XXX_RTC1_CNTRB_BME_BITMASK			0x20
#define T2E6XXX_RTC1_CNTRB_TPE_BITMASK			0x10
#define T2E6XXX_RTC1_CNTRB_TIE_BITMASK			0x08
#define T2E6XXX_RTC1_CNTRB_KIE_BITMASK			0x04
#define T2E6XXX_RTC1_CNTRB_WDE_BITMASK			0x02
#define T2E6XXX_RTC1_CNTRB_WDS_BITMASK			0x01

#define T2E6XXX_RTC1_CNTRB_TE_ON				0x80
#define T2E6XXX_RTC1_CNTRB_TE_OFF				0x0
#define T2E6XXX_RTC1_CNTRB_CS_ON				0x40
#define T2E6XXX_RTC1_CNTRB_CS_OFF				0x0
#define T2E6XXX_RTC1_CNTRB_BME_ON				0x20
#define T2E6XXX_RTC1_CNTRB_BME_OFF				0x0
#define T2E6XXX_RTC1_CNTRB_TPE_ON				0x10
#define T2E6XXX_RTC1_CNTRB_TPE_OFF				0x0
#define T2E6XXX_RTC1_CNTRB_TIE_ON				0x08
#define T2E6XXX_RTC1_CNTRB_TIE_OFF				0x0
#define T2E6XXX_RTC1_CNTRB_KIE_ON				0x04
#define T2E6XXX_RTC1_CNTRB_KIE_OFF				0x0
#define T2E6XXX_RTC1_CNTRB_WDE_ON				0x02
#define T2E6XXX_RTC1_CNTRB_WDE_OFF				0x0
#define T2E6XXX_RTC1_CNTRB_WDS_ON				0x01
#define T2E6XXX_RTC1_CNTRB_WDS_OFF				0x0

#endif
//============================================================================
#endif
