/********************************************************************
	TORNADO-E2/6713 Demo Utility.
	RTC (real-time clock) controller KICKSTART WRITE demo. rev.1A
	(C) MicroLAB Systems, 2007


	Description:
	------------
	This demo initializes RTC and writes control registers to enable KICKSTART and WAKEUP features.
	This demo must be used in conjunction with further run of the RTC_KICKSTART_RD demo,
	which will read back and verify that KICKSTART or WAKEUP procedure have been occurred.
	User must connect E2/6713 KICKSTART test board to JP16 connector, switch on MANUAL SWITCH (yellow LED must be ON),
	run this demo, close Code Composer Studio, then switch off MANUAL SWITCH (yellow LED must be OFF),
	the power of E2/6713 board will switched off (Target Power LED (green) must be OFF),
	press KICKSTART button to start KICKSTART procedure or wait until WAKEUP will occurred (about 2 minutes).
	Red LED must be ON if RTC Remote Power Supply Control Circuit is functioned correctly!
	After power supply will be stabilized at its normal level user will have to run RTC_KICKSTART_RD demo.

	TORNADO platform:
	-----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

	Copyright:
	----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.

	Board configuration and demo parameters:
	----------------------------------------
	1. On-board bootmode configuration switch: HPI
	2. Variable r contains possible error codes:
		(Note, that error codes
			from -1 to -9 are applied to common errors,
			from -10 to -19 are applied to C6xxx on-chip registers errors,
			from -20 to -29 are applied to DSP initialization errors,
			from -30 to -39 are applied to DSP ports configuration errors,
			from -100 to -109 are applied to FLASH PROGRAMMING CONTROL errors,
			from -50 to -99 are applied to user defined errors)
		 0	- no errors;
		-2	- invalid H/W error (not E2/6713 board);
		-3	- H/W error (error writing to the DSP external control registers, etc);
		-4	- incompatible H/W error (the setting is not allowed on this board);
		-10	- error writing to C6713B DSP regs;
		-20	- error during PLL configuration;
		-50..-54	- errors occurred during this test;
***********************************************************************/

#define __T2E6XXX_SELECT_E6713__			1

#include "t2e6xxx_dsp.h"

#define T2E6XXX_PWR_STAT_ERR				-50		// error when switching power supply OFF
#define T2E6XXX_RTC1_CNTRA_RG_ERR			-51		// error setting RTC Control A register
#define T2E6XXX_RTC1_CNTRB_RG_ERR			-52		// error setting RTC Control B register
#define T2E6XXX_RTC1_CLK_RG_ERR				-53		// error setting RTC clock registers
#define T2E6XXX_RTC1_ALARM_RG_ERR			-54		// error setting RTC alarm registers


void main()
{
	int r, i, d;

	// configure DSP PLL with SPREAD_SPECTRUM_CLK not used and initialize DSP
	if ((r = T2E6XXX_init_dsp(0)) != T2E6XXX_OK)
		goto error;

	// enable access to RTC controller
	T2E6XXX_SET_RTC_EN_ON;
	if (!T2E6XXX_RTC_EN_IS_ON)
	{
		r = T2E6XXX_HW_ERR;
		goto error;
	}

	//-- initialize RTC registers

	// clear TE bit of RTC ontrol B register
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CNTRB_RG, 0x0);
	if ((T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CNTRB_RG)) != 0x0)
	{
		r = T2E6XXX_RTC1_CNTRB_RG_ERR;
		goto error;
	}

	// set all RTC clock to predefined values (00:00:00 Mon 01.01.2000)
	// and clear RTC WDT registers
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_SECONDS_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_MINUTES_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_HOURS_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_DAY_OF_WEEK_RG, 0x01);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_DATE_RG, 0x01);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_MONTH_RG, 0x01);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_YEAR_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_CENTURY_RG, 0x20);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_WDT_SECONDS_FRACTION_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_WDT_SECONDS_RG, 0x00);
	if (	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_SECONDS_RG) != 0x00
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_MINUTES_RG) != 0x00
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_HOURS_RG) != 0x00
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_DAY_OF_WEEK_RG) != 0x01
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_DATE_RG) != 0x01
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_MONTH_RG) != 0x01
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_YEAR_RG) != 0x00
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_CENTURY_RG) != 0x20
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_WDT_SECONDS_FRACTION_RG) != 0x00
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_WDT_SECONDS_RG) != 0x00
		)
	{
		r = T2E6XXX_RTC1_CLK_RG_ERR;
		goto error;
	}

	// set RTC ALARM registers value to 2 minutes
	// WAKEUP must be occurred at the end of 2 minutes after system power-down
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_ALARM_SECONDS_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_ALARM_MINUTES_RG, 0x02);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_ALARM_HOURS_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_ALARM_DAY_DATE_RG, 0x01);
	if (	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_ALARM_SECONDS_RG) != 0x00
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_ALARM_MINUTES_RG) != 0x02
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_ALARM_HOURS_RG) != 0x00
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_ALARM_DAY_DATE_RG) != 0x01
		)
	{
		r = T2E6XXX_RTC1_ALARM_RG_ERR;
		goto error;
	}

	// enable KICKSTART and WAKEUP features in RTC ontrol B register
	T2E6XXX_SET_RTC1_CNTRB_TPE_ON;
	T2E6XXX_SET_RTC1_CNTRB_TIE_ON;
	T2E6XXX_SET_RTC1_CNTRB_KIE_ON;
	if (	!T2E6XXX_RTC1_CNTRB_TPE_IS_ON
		||	!T2E6XXX_RTC1_CNTRB_TIE_IS_ON
		||	!T2E6XXX_RTC1_CNTRB_KIE_IS_ON
		)
	{
		r = T2E6XXX_RTC1_CNTRB_RG_ERR;
		goto error;
	}

	// clear FLAG bits of RTC ontrol A register and set RTC_PWR pin
	// in the high-impendance state
	d = T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CNTRA_RG);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CNTRA_RG, 0x10);
	if(T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CNTRA_RG) != 0x10)
	{
		r = T2E6XXX_RTC1_CNTRA_RG_ERR;
		goto error;
	}

	// set TE bit of RTC ontrol B register and unfreeze RTC clock registers
	T2E6XXX_SET_RTC1_CNTRB_TE_ON;
	if (!T2E6XXX_RTC1_CNTRB_TE_IS_ON)
	{
		r = T2E6XXX_RTC1_CNTRB_RG_ERR;
		goto error;
	}

	// finally, disable access to RTC controller
	T2E6XXX_SET_RTC_EN_OFF;
	if (T2E6XXX_RTC_EN_IS_ON)
	{
		r = T2E6XXX_HW_ERR;
		goto error;
	}
	// wait a little in order to RTC_PWR signal will switched off
	for (i = 0; i < 1000000; i++);

	// check if power supply has been really switched off (RTC_PWR must be HIGH)
	if (T2E6XXX_RTC_XPS_EN_IS_ON)
	{
		r = T2E6XXX_PWR_STAT_ERR;
		goto error;
	}

	// get here on successfull program execution
	// Red LED must be switched OFF!
	while(1);

error:
	// trap here on any error condition
	// variable 'r' contains returned error code
	while (1);
}

