/********************************************************************
	TORNADO-E2/6713 Demo Utility.
	RTC (real-time clock) controller CLOCK OFF demo. rev.1A
	(C) MicroLAB Systems, 2007


	Description:
	------------
	This demo sets RTC clock OFF in order to save backup battery energy.
	This demo should be the last running RTC demo.

	TORNADO platform:
	-----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

	Copyright:
	----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


	Board configuration and demo parameters:
	----------------------------------------
	1. On-board bootmode configuration switch: HPI
	2. Variable r contains possible error codes:
		(Note, that error codes
			from -1 to -9 are applied to common errors,
			from -10 to -19 are applied to C6xxx on-chip registers errors,
			from -20 to -29 are applied to DSP initialization errors,
			from -30 to -39 are applied to DSP ports configuration errors,
			from -100 to -109 are applied to FLASH PROGRAMMING CONTROL errors,
			from -50 to -99 are applied to user defined errors)
		 0	- no errors;
		-2	- invalid H/W error (not E2/6713 board);
		-3	- H/W error (error writing to the DSP external control registers, etc);
		-4	- incompatible H/W error (the setting is not allowed on this board);
		-10	- error writing to C6713B DSP regs;
		-20	- error during PLL configuration;
		-50..-51	- errors occurred during this test;
***********************************************************************/

#define __T2E6XXX_SELECT_E6713__			1

#include "t2e6xxx_dsp.h"

#define T2E6XXX_RTC1_CNTRA_RG_ERR			-50		// error setting RTC Control A register
#define T2E6XXX_RTC1_CNTRB_RG_ERR			-51		// error setting RTC Control B register

void main()
{
	int r, i, d;

	// configure DSP PLL with SPREAD_SPECTRUM_CLK not used and initialize DSP
	if ((r = T2E6XXX_init_dsp(0)) != T2E6XXX_OK)
		goto error;

	// enable access to RTC controller
	T2E6XXX_SET_RTC_EN_ON;
	if (!T2E6XXX_RTC_EN_IS_ON)
	{
		r = T2E6XXX_HW_ERR;
		goto error;
	}

	// clear TE bit of RTC ontrol B register and freeze RTC clock registers
	// Also set BURST mode to write consecutive RAM locations
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CNTRB_RG, 0x20);
	if ((T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CNTRB_RG)) != 0x20)
	{
		r = T2E6XXX_RTC1_CNTRB_RG_ERR;
		goto error;
	}

	// clear all RTC registers and disable clock via EOSC 
	// and E32K bits of RTC CLK MONTH register
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_SECONDS_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_MINUTES_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_HOURS_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_DAY_OF_WEEK_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_DATE_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_MONTH_RG, 0xc0);	// disable clock oscillator
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_YEAR_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_CENTURY_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_ALARM_SECONDS_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_ALARM_MINUTES_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_ALARM_HOURS_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_ALARM_DAY_DATE_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_WDT_SECONDS_FRACTION_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_WDT_SECONDS_RG, 0x00);

	// now clear RTC USER RAM
	// BURST mode is used to write consecutive RAM locations
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_ADDR_RG, 0);
	for (i = 0; i < T2E6XXX_RTC1_USER_RAM_LEN; i++)
		T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x00);

	// clear FLAG bits of RTC ontrol A register and set RTC_PWR pin
	// in the high-impendance state
	d = T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CNTRA_RG);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CNTRA_RG, 0x10);
	if(T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CNTRA_RG) != 0x10)
	{
		r = T2E6XXX_RTC1_CNTRA_RG_ERR;
		goto error;
	}

	// set TE bit of RTC ontrol B register and unfreeze RTC clock registers
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CNTRB_RG, 0x80);
	if ((T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CNTRB_RG)) != 0x80)
	{
		r = T2E6XXX_RTC1_CNTRB_RG_ERR;
		goto error;
	}
	// finally, disable access to RTC controller
	T2E6XXX_SET_RTC_EN_OFF;
	if (T2E6XXX_RTC_EN_IS_ON)
	{
		r = T2E6XXX_HW_ERR;
		goto error;
	}

	// end here
	while(1);

error:
	// trap here on any error condition
	// variable 'r' contains returned error code
	while (1);
}

