/********************************************************************
	TORNADO-E2/6713 Demo Utility.
	RTC (real-time clock) controller USER RAM demo. rev.1A
	(C) MicroLAB Systems, 2007


	Description:
	------------
	This demo scans RTC data bus and RTC USER RAM registers.


	TORNADO platform:
	-----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

	Copyright:
	----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.

	Board configuration and demo parameters:
	----------------------------------------
	1. On-board bootmode configuration switch: HPI
	2. Variable r contains possible error codes:
		(Note, that error codes
			from -1 to -9 are applied to common errors,
			from -10 to -19 are applied to C6xxx on-chip registers errors,
			from -20 to -29 are applied to DSP initialization errors,
			from -30 to -39 are applied to DSP ports configuration errors,
			from -100 to -109 are applied to FLASH PROGRAMMING CONTROL errors,
			from -50 to -99 are applied to user defined errors)
		 0	- no errors;
		-2	- invalid H/W error (not E2/6713 board);
		-3	- H/W error (error writing to the DSP external control registers, etc);
		-4	- incompatible H/W error (the setting is not allowed on this board);
		-10	- error writing to C6713B DSP regs;
		-20	- error during PLL configuration;
		-50	- error during user RAM verification;
***********************************************************************/

#define __T2E6XXX_SELECT_E6713__			1

#include "t2e6xxx_dsp.h"

#define T2E6XXX_RTC1_RAM_ERR			-50		// error during user RAM verification

unsigned start_data = 0x3b,
			start_data_block;
unsigned mem_inc_data = 0x97;
unsigned mem_wr_data;
unsigned pass_counter=0;


void main()
{
	int i, r;
	unsigned char d;

	// configure DSP PLL with SPREAD_SPECTRUM_CLK not used and initialize DSP
	if ((r = T2E6XXX_init_dsp(0)) != T2E6XXX_OK)
		goto error;

	// enable access to RTC controller
	T2E6XXX_SET_RTC_EN_ON;
	if (!T2E6XXX_RTC_EN_IS_ON)
	{
		r = T2E6XXX_HW_ERR;
		goto error;
	}

	//-- check RTC data bus via running 1<< to the USER_RAM #0 reg
	for (i = 0,d = 1; i <= 8; i++)
	{
		T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_ADDR_RG, 0);
		T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, i==0 ? 0: d);
		T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_SECONDS_RG, 0);		// perform false bus data

		T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_ADDR_RG, 0);
		if (T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != (i == 0 ? 0 : d))
		{
			r = T2E6XXX_HW_ERR;
			goto error;
		}
		if (i > 0)
			d <<= 1;
	}

	// continuously test RTC on-chip USER RAM registers
	while(1)
	{
		start_data_block = start_data;
		for (mem_wr_data = start_data_block, i = 0; i < T2E6XXX_RTC1_USER_RAM_LEN;)
		{
			T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_ADDR_RG, i++);
			T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, mem_wr_data++);
		}

		start_data = start_data_block;
		for (mem_wr_data = start_data, i = 0; i < T2E6XXX_RTC1_USER_RAM_LEN;)
		{
			T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_ADDR_RG, i++);
			if (T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != ((mem_wr_data++) & 0xff))
			{
				r = T2E6XXX_RTC1_RAM_ERR;
				goto error;
			}
		}
		start_data += mem_inc_data ;
		start_data &= 0xff;

		pass_counter++;
	}

error:
	// trap here on any error condition
	// variable 'r' contains returned error code
	while (1);
}

