/********************************************************************
	TORNADO-E2/6713 Demo Utility.
	RTC (real-time clock) controller CLOCK WRITE demo. rev.1A
	(C) MicroLAB Systems, 2007


	Description:
	------------
	This demo initializes RTC and writes clock registers. This demo must 
	be used in conjunction with further run of the RTC CLOCK READ demo,
	which will read back and verify RTC clock data and ensure that clock is
	running. User can switch off the power of E2/6713 board after running 
	RTC CLOCK WRITE demo and before running RTC CLOCK READ demo.

	Note, that this demo does not test operation of RTC ALARM and WDT features,
	which are tested in the T2E6713_RGIRQ.out demo in the E2/6713 IRQ demo folder.

	TORNADO platform:
	-----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

	Copyright:
	----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.

	Board configuration and demo parameters:
	----------------------------------------
	1. On-board bootmode configuration switch: HPI
	2. Variable r contains possible error codes:
		(Note, that error codes
			from -1 to -9 are applied to common errors,
			from -10 to -19 are applied to C6xxx on-chip registers errors,
			from -20 to -29 are applied to DSP initialization errors,
			from -30 to -39 are applied to DSP ports configuration errors,
			from -100 to -109 are applied to FLASH PROGRAMMING CONTROL errors,
			from -50 to -99 are applied to user defined errors)
		 0	- no errors;
		-2	- invalid H/W error (not E2/6713 board);
		-3	- H/W error (error writing to the DSP external control registers, etc);
		-4	- incompatible H/W error (the setting is not allowed on this board);
		-10	- error writing to C6713B DSP regs;
		-20	- error during PLL configuration;
		-50..-55	- errors occurred during this test;
***********************************************************************/

#define __T2E6XXX_SELECT_E6713__			1

#include "t2e6xxx_dsp.h"

#define T2E6XXX_RTC1_CNTRA_RG_ERR			-50		// error setting RTC Control A register
#define T2E6XXX_RTC1_CNTRB_RG_ERR			-51		// error setting RTC Control B register
#define T2E6XXX_RTC1_CLK_RG_ERR				-52		// error setting RTC clock registers
#define T2E6XXX_RTC1_ALARM_RG_ERR			-53		// error setting RTC alarm registers
#define T2E6XXX_RTC1_WDT_RG_ERR				-54		// error setting RTC WDT registers
#define T2E6XXX_RTC1_RAM_ERR				-55		// error setting RTC RAM

void main()
{
	int r, d;

	// configure DSP PLL with SPREAD_SPECTRUM_CLK not used and initialize DSP
	if ((r = T2E6XXX_init_dsp(0)) != T2E6XXX_OK)
		goto error;

	// enable access to RTC controller
	T2E6XXX_SET_RTC_EN_ON;
	if (!T2E6XXX_RTC_EN_IS_ON)
	{
		r = T2E6XXX_HW_ERR;
		goto error;
	}

	//-- initialize RTC clock registers

	// clear TE bit of RTC ontrol B register and freeze RTC clock registers
	// Also set BURST mode to write consecutive RAM locations
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CNTRB_RG, 0x20);
	if ((T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CNTRB_RG)) != 0x20)
	{
		r = T2E6XXX_RTC1_CNTRB_RG_ERR;
		goto error;
	}
	// clear FLAG bits of RTC ontrol A register
	d = T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CNTRA_RG);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CNTRA_RG, 0x0);
	if((T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CNTRA_RG)) != 0x0)
	{
		r = T2E6XXX_RTC1_CNTRA_RG_ERR;
		goto error;
	}

	// set RTC seconds register
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_SECONDS_RG, 0x15);
	if (T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_SECONDS_RG) != 0x15)
	{
		r = T2E6XXX_RTC1_CLK_RG_ERR;
		goto error;
	}

	// set RTC minutes register (10min)
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_MINUTES_RG, 0x10);
	if (T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_MINUTES_RG) != 0x10)
	{
		r = T2E6XXX_RTC1_CLK_RG_ERR;
		goto error;
	}

	// set RTC hours register (21 hour)
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_HOURS_RG, 0x21);
	if (T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_HOURS_RG) != 0x21)
	{
		r = T2E6XXX_RTC1_CLK_RG_ERR;
		goto error;
	}

	// set RTC day of week register (=4 (THURSDAY))
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_DAY_OF_WEEK_RG, 0x04);
	if (T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_DAY_OF_WEEK_RG) != 0x04)
	{
		r = T2E6XXX_RTC1_CLK_RG_ERR;
		goto error;
	}

	// set RTC date register (14-th)
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_DATE_RG, 0x14);
	if (T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_DATE_RG) != 0x14)
	{
		r = T2E6XXX_RTC1_CLK_RG_ERR;
		goto error;
	}

	// enable clock oscillator (EOSC=0) and set MONTH=MARCH
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_MONTH_RG, 0x03);
	if (T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_MONTH_RG) != 0x03)
	{
		r = T2E6XXX_RTC1_CLK_RG_ERR;
		goto error;
	}

	// set RTC YEAR register ('2002)
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_YEAR_RG, 0x02);
	if (T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_YEAR_RG) != 0x02)
	{
		r = T2E6XXX_RTC1_CLK_RG_ERR;
		goto error;
	}

	// set RTC CENTURY register (20 century)
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CLK_CENTURY_RG, 0x20);
	if (T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CLK_CENTURY_RG) != 0x20)
	{
		r = T2E6XXX_RTC1_CLK_RG_ERR;
		goto error;
	}

	// clear RTC ALARM registers
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_ALARM_SECONDS_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_ALARM_MINUTES_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_ALARM_HOURS_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_ALARM_DAY_DATE_RG, 0x00);
	if (	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_ALARM_SECONDS_RG) != 0x00
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_ALARM_MINUTES_RG) != 0x00
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_ALARM_HOURS_RG) != 0x00
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_ALARM_DAY_DATE_RG) != 0x00
		)
	{
		r = T2E6XXX_RTC1_ALARM_RG_ERR;
		goto error;
	}

	// clear RTC WDT registers
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_WDT_SECONDS_FRACTION_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_WDT_SECONDS_RG, 0x00);
	if (	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_WDT_SECONDS_FRACTION_RG) != 0x00
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_WDT_SECONDS_RG) != 0x00
		)
	{
		r = T2E6XXX_RTC1_WDT_RG_ERR;
		goto error;
	}

	// now write test pattern to RTC USER RAM in order further running
	// RTC CLOCK READ test could verify that CLOCK written data
	// are valid
	// BURST mode is used to write consecutive RAM locations
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_ADDR_RG, 0);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x00);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x11);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x22);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x33);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x44);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x55);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x66);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x77);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x88);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x99);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0xaa);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0xbb);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0xcc);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0xdd);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0xee);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0xff);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x5a);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0xa5);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x96);
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG, 0x69);
	
	T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_USER_RAM_ADDR_RG, 0);
	if(		T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x00
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x11
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x22
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x33
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x44
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x55
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x66
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x77
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x88
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x99
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0xaa
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0xbb
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0xcc
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0xdd
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0xee
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0xff
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x5a
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0xa5
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x96
		||	T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_USER_RAM_DATA_RG) != 0x69
		)
	{
		r = T2E6XXX_RTC1_RAM_ERR;
		goto error;
	}

	// set TE bit of RTC ontrol B register and unfreeze RTC clock registers
	T2E6XXX_SET_RTC1_CNTRB_TE_ON;
	if (!T2E6XXX_RTC1_CNTRB_TE_IS_ON)
	{
		r = T2E6XXX_RTC1_CNTRB_RG_ERR;
		goto error;
	}

	// finally, disable access to RTC controller
	T2E6XXX_SET_RTC_EN_OFF;
	if (T2E6XXX_RTC_EN_IS_ON)
	{
		r = T2E6XXX_HW_ERR;
		goto error;
	}

	// get here on successfull program execution
	while(1);

error:
	// trap here on any error condition
	// variable 'r' contains returned error code
	while (1);
}

