/******************************************************************************
	TMS320C6XXX (C671x/C6416) DSP General Definitions. rev.1A1-6
	(C) MicroLAB Systems Ltd, 2007-2008

	Revision history:
	-----------------
	rev.1A1		- 2007, initial release.
	rev.1A1-5	- 2008, fixed minor bugs.
	rev.1A1-6	- April 2008, fixed error in Cache control macros: L1P and L1D cannot be disabled.

	Notes:
	------
	1.	This C-header file contains general C6XXX DSP definitions and is include 
		file for TI C6XXX compile tools. 
	2.	This header file is externally controlled from user C-code by run-time 
		compiler keys definitions in order to apply DSP-type specific difinitions
		to refer to particular definitions included for different DSP type:
			__C6XXX_SELECT_C6416_DSP__
				- if defined in user code prior inclusion of this header file,
				  then DSP-type specific definitions are applied to C6416 DSP

			__C6XXX_SELECT_C671X_DSP__
				- if defined in user code prior inclusion of this header file,
				  then DSP-type specific definitions are applied to C671x DSP

			__C6XXX_SELECT_C6713_DSP__
				- if defined in user code prior inclusion of this header file,
				  then DSP-type specific definitions are applied to C6713 DSP

*******************************************************************************/

#ifndef __C6XXX_DEF__						// check for this file has been already included
#define __C6XXX_DEF__						1

// general defs
#define ON									1
#define OFF									0

//------------ DSP-type specific run-time compiler keys processing
// (this is required in order to exclude key confusions)

#ifdef	__C6XXX_SELECT_C6416_DSP__
#undef	__C6XXX_SELECT_C671X_DSP__
#undef	__C6XXX_SELECT_C6713_DSP__
#endif

#ifdef	__C6XXX_SELECT_C671X_DSP__
#undef	__C6XXX_SELECT_C6416_DSP__
#endif

#ifdef	__C6XXX_SELECT_C6713_DSP__
#undef	__C6XXX_SELECT_C6416_DSP__
#undef	__C6XXX_SELECT_C671X_DSP__
#define	__C6XXX_SELECT_C671X_DSP__			1
#endif

// Default setting is C6713 definitions
#ifndef	__C6XXX_SELECT_C6416_DSP__
#ifndef	__C6XXX_SELECT_C671X_DSP__
#ifndef	__C6XXX_SELECT_C6713_DSP__
#define	__C6XXX_SELECT_C671X_DSP__			1
#define	__C6XXX_SELECT_C6713_DSP__			1
#endif
#endif
#endif

//----------------------------------------------------------------


//----------------------------------------------------------------
//============ C6XXX peripheral regs definitions =================
// DSP on-chip register allocated defs for all C6XXX DSP without
// pointers allocation in the .BSS section

//------------ Memory mapped peripheral registers ----------------

//------------ EMIF control RGs ----------------------------------
#define C6XXX_EMIF_GBLCTL_RG		((unsigned *) 0x01800000)
#define C6XXX_EMIF_CECTL0_RG		((unsigned *) 0x01800008)
#define C6XXX_EMIF_CECTL1_RG		((unsigned *) 0x01800004)
#define C6XXX_EMIF_CECTL2_RG		((unsigned *) 0x01800010)
#define C6XXX_EMIF_CECTL3_RG		((unsigned *) 0x01800014)
#define C6XXX_EMIF_SDCTL_RG			((unsigned *) 0x01800018)
#define C6XXX_EMIF_SDTIM_RG			((unsigned *) 0x0180001c)

	// C621x/C671x/C6416 specific SDRAM extension register
#define C6XXX_EMIF_SDEXT_RG			((unsigned *) 0x01800020)

	// C6416 specific extension regs
#define C6XXX_EMIF_CESEC0_RG		((unsigned *) 0x01800048)
#define C6XXX_EMIF_CESEC1_RG		((unsigned *) 0x01800044)
#define C6XXX_EMIF_CESEC2_RG		((unsigned *) 0x01800050)
#define C6XXX_EMIF_CESEC3_RG		((unsigned *) 0x01800054)

	// aliases for C6416 DSP EMIF-A
#define C6XXX_EMIFA_GBLCTL_RG		C6XXX_EMIF_GBLCTL_RG
#define C6XXX_EMIFA_CECTL0_RG		C6XXX_EMIF_CECTL0_RG
#define C6XXX_EMIFA_CECTL1_RG		C6XXX_EMIF_CECTL1_RG
#define C6XXX_EMIFA_CECTL2_RG		C6XXX_EMIF_CECTL2_RG
#define C6XXX_EMIFA_CECTL3_RG		C6XXX_EMIF_CECTL3_RG
#define C6XXX_EMIFA_SDCTL_RG		C6XXX_EMIF_SDCTL_RG
#define C6XXX_EMIFA_SDTIM_RG		C6XXX_EMIF_SDTIM_RG

#define C6XXX_EMIFA_SDEXT_RG		C6XXX_EMIF_SDEXT_RG
#define C6XXX_EMIFA_CESEC0_RG		C6XXX_EMIF_CESEC0_RG
#define C6XXX_EMIFA_CESEC1_RG		C6XXX_EMIF_CESEC1_RG
#define C6XXX_EMIFA_CESEC2_RG		C6XXX_EMIF_CESEC2_RG
#define C6XXX_EMIFA_CESEC3_RG		C6XXX_EMIF_CESEC3_RG

#define C6416_EMIFA_GBLCTL_RG		C6XXX_EMIF_GBLCTL_RG
#define C6416_EMIFA_CECTL0_RG		C6XXX_EMIF_CECTL0_RG
#define C6416_EMIFA_CECTL1_RG		C6XXX_EMIF_CECTL1_RG
#define C6416_EMIFA_CECTL2_RG		C6XXX_EMIF_CECTL2_RG
#define C6416_EMIFA_CECTL3_RG		C6XXX_EMIF_CECTL3_RG
#define C6416_EMIFA_SDCTL_RG		C6XXX_EMIF_SDCTL_RG
#define C6416_EMIFA_SDTIM_RG		C6XXX_EMIF_SDTIM_RG

#define C6416_EMIFA_SDEXT_RG		C6XXX_EMIF_SDEXT_RG
#define C6416_EMIFA_CESEC0_RG		C6XXX_EMIF_CESEC0_RG
#define C6416_EMIFA_CESEC1_RG		C6XXX_EMIF_CESEC1_RG
#define C6416_EMIFA_CESEC2_RG		C6XXX_EMIF_CESEC2_RG
#define C6416_EMIFA_CESEC3_RG		C6XXX_EMIF_CESEC3_RG

	// C6416 EMIF-B defs
#define C6XXX_EMIFB_GBLCTL_RG		((unsigned *) 0x01A80000)
#define C6XXX_EMIFB_CECTL0_RG		((unsigned *) 0x01A80008)
#define C6XXX_EMIFB_CECTL1_RG		((unsigned *) 0x01A80004)
#define C6XXX_EMIFB_CECTL2_RG		((unsigned *) 0x01A80010)
#define C6XXX_EMIFB_CECTL3_RG		((unsigned *) 0x01A80014)
#define C6XXX_EMIFB_SDCTL_RG		((unsigned *) 0x01A80018)
#define C6XXX_EMIFB_SDTIM_RG		((unsigned *) 0x01A8001c)

#define C6XXX_EMIFB_SDEXT_RG		((unsigned *) 0x01A80020)
#define C6XXX_EMIFB_CESEC0_RG		((unsigned *) 0x01A80048)
#define C6XXX_EMIFB_CESEC1_RG		((unsigned *) 0x01A80044)
#define C6XXX_EMIFB_CESEC2_RG		((unsigned *) 0x01A80050)
#define C6XXX_EMIFB_CESEC3_RG		((unsigned *) 0x01A80054)

#define C6416_EMIFB_GBLCTL_RG		C6XXX_EMIFB_GBLCTL_RG
#define C6416_EMIFB_CECTL0_RG		C6XXX_EMIFB_CECTL0_RG
#define C6416_EMIFB_CECTL1_RG		C6XXX_EMIFB_CECTL1_RG
#define C6416_EMIFB_CECTL2_RG		C6XXX_EMIFB_CECTL2_RG
#define C6416_EMIFB_CECTL3_RG		C6XXX_EMIFB_CECTL3_RG
#define C6416_EMIFB_SDCTL_RG		C6XXX_EMIFB_SDCTL_RG
#define C6416_EMIFB_SDTIM_RG		C6XXX_EMIFB_SDTIM_RG

#define C6416_EMIFB_SDEXT_RG		C6XXX_EMIFB_SDEXT_RG
#define C6416_EMIFB_CESEC0_RG		C6XXX_EMIFB_CESEC0_RG
#define C6416_EMIFB_CESEC1_RG		C6XXX_EMIFB_CESEC1_RG
#define C6416_EMIFB_CESEC2_RG		C6XXX_EMIFB_CESEC2_RG
#define C6416_EMIFB_CESEC3_RG		C6XXX_EMIFB_CESEC3_RG



//------------ TIMER Control RGs ---------------------------------
#define C6XXX_TIMER0_CTL_RG			((unsigned *) 0x01940000)
#define C6XXX_TIMER0_PRD_RG			((unsigned *) 0x01940004)
#define C6XXX_TIMER0_CNT_RG			((unsigned *) 0x01940008)
#define C6XXX_TIMER1_CTL_RG			((unsigned *) 0x01980000)
#define C6XXX_TIMER1_PRD_RG			((unsigned *) 0x01980004)
#define C6XXX_TIMER1_CNT_RG			((unsigned *) 0x01980008)

	// C6416 specific TIMER-2
#define C6XXX_TIMER2_CTL_RG			((unsigned *) 0x01AC0000)
#define C6XXX_TIMER2_PRD_RG			((unsigned *) 0x01AC0004)
#define C6XXX_TIMER2_CNT_RG			((unsigned *) 0x01AC0008)



//------------ McBSP Registers -----------------------------------
#define C6XXX_MCBSP0_DRR_RG			((unsigned *) 0x018C0000)
#define C6XXX_MCBSP0_DXR_RG			((unsigned *) 0x018C0004)
#define C6XXX_MCBSP0_SPCR_RG		((unsigned *) 0x018C0008)
#define C6XXX_MCBSP0_RCR_RG			((unsigned *) 0x018C000C)
#define C6XXX_MCBSP0_XCR_RG			((unsigned *) 0x018C0010)
#define C6XXX_MCBSP0_SRGR_RG		((unsigned *) 0x018C0014)
#define C6XXX_MCBSP0_MCR_RG			((unsigned *) 0x018C0018)
#define C6XXX_MCBSP0_RCER_RG		((unsigned *) 0x018C001C)
#define C6XXX_MCBSP0_XCER_RG		((unsigned *) 0x018C0020)
#define C6XXX_MCBSP0_PCR_RG			((unsigned *) 0x018C0024)

#define C6XXX_MCBSP1_DRR_RG			((unsigned *) 0x01900000)
#define C6XXX_MCBSP1_DXR_RG			((unsigned *) 0x01900004)
#define C6XXX_MCBSP1_SPCR_RG		((unsigned *) 0x01900008)
#define C6XXX_MCBSP1_RCR_RG			((unsigned *) 0x0190000C)
#define C6XXX_MCBSP1_XCR_RG			((unsigned *) 0x01900010)
#define C6XXX_MCBSP1_SRGR_RG		((unsigned *) 0x01900014)
#define C6XXX_MCBSP1_MCR_RG			((unsigned *) 0x01900018)
#define C6XXX_MCBSP1_RCER_RG		((unsigned *) 0x0190001C)
#define C6XXX_MCBSP1_XCER_RG		((unsigned *) 0x01900020)
#define C6XXX_MCBSP1_PCR_RG			((unsigned *) 0x01900024)

	// available in C6416
#define C6XXX_MCBSP2_DRR_RG			((unsigned *) 0x01a40000)
#define C6XXX_MCBSP2_DXR_RG			((unsigned *) 0x01a40004)
#define C6XXX_MCBSP2_SPCR_RG		((unsigned *) 0x01a40008)
#define C6XXX_MCBSP2_RCR_RG			((unsigned *) 0x01a4000C)
#define C6XXX_MCBSP2_XCR_RG			((unsigned *) 0x01a40010)
#define C6XXX_MCBSP2_SRGR_RG		((unsigned *) 0x01a40014)
#define C6XXX_MCBSP2_MCR_RG			((unsigned *) 0x01a40018)
#define C6XXX_MCBSP2_RCER_RG		((unsigned *) 0x01a4001C)
#define C6XXX_MCBSP2_XCER_RG		((unsigned *) 0x01a40020)
#define C6XXX_MCBSP2_PCR_RG			((unsigned *) 0x01a40024)

	// C6416 specific McBSP regs
#define C6XXX_MCBSP0_RCERE1_RG		((unsigned *) 0x018C0028)
#define C6XXX_MCBSP0_XCERE1_RG		((unsigned *) 0x018C002C)
#define C6XXX_MCBSP0_RCERE2_RG		((unsigned *) 0x018C0030)
#define C6XXX_MCBSP0_XCERE2_RG		((unsigned *) 0x018C0034)
#define C6XXX_MCBSP0_RCERE3_RG		((unsigned *) 0x018C0038)
#define C6XXX_MCBSP0_XCERE3_RG		((unsigned *) 0x018C003C)

#define C6XXX_MCBSP1_RCERE1_RG		((unsigned *) 0x01900028)
#define C6XXX_MCBSP1_XCERE1_RG		((unsigned *) 0x0190002C)
#define C6XXX_MCBSP1_RCERE2_RG		((unsigned *) 0x01900030)
#define C6XXX_MCBSP1_XCERE2_RG		((unsigned *) 0x01900034)
#define C6XXX_MCBSP1_RCERE3_RG		((unsigned *) 0x01900038)
#define C6XXX_MCBSP1_XCERE3_RG		((unsigned *) 0x0190003C)

#define C6XXX_MCBSP2_RCERE1_RG		((unsigned *) 0x01a40028)
#define C6XXX_MCBSP2_XCERE1_RG		((unsigned *) 0x01a4002C)
#define C6XXX_MCBSP2_RCERE2_RG		((unsigned *) 0x01a40030)
#define C6XXX_MCBSP2_XCERE2_RG		((unsigned *) 0x01a40034)
#define C6XXX_MCBSP2_RCERE3_RG		((unsigned *) 0x01a40038)
#define C6XXX_MCBSP2_XCERE3_RG		((unsigned *) 0x01a4003C)

	// aliases for C6416 specific McBSP regs
#define C6XXX_MCBSP0_RCERE0_RG		C6XXX_MCBSP0_RCER_RG
#define C6XXX_MCBSP0_XCERE0_RG		C6XXX_MCBSP0_XCER_RG
#define C6XXX_MCBSP1_RCERE0_RG		C6XXX_MCBSP1_RCER_RG
#define C6XXX_MCBSP1_XCERE0_RG		C6XXX_MCBSP1_XCER_RG
#define C6XXX_MCBSP2_RCERE0_RG		C6XXX_MCBSP2_RCER_RG
#define C6XXX_MCBSP2_XCERE0_RG		C6XXX_MCBSP2_XCER_RG



//------------ HPI registers -------------------------------------
#define C6XXX_HPIC_RG				((unsigned *) 0x01880000)

	// C6416 extension regs for HPI (HPIA splitted into READ/WRITE)
#define C6XXX_HPIAW_RG				((unsigned *) 0x01880004)
#define C6XXX_HPIAR_RG				((unsigned *) 0x01880008)



//------------ INT specific registers ----------------------------
#define C6XXX_INT_MUXH_RG			((unsigned *) 0x019C0000)
#define C6XXX_INT_MUXL_RG			((unsigned *) 0x019C0004)
#define C6XXX_INT_EXTPOL_RG			((unsigned *) 0x019C0008)



//------------ EDMA control registers ----------------------------
	// event LOW/HIGH registers (HIGH part for C6416 only)
#define C6XXX_EDMA_ER_RG			((unsigned *) 0x01A0fff0)
#define C6XXX_EDMA_ERL_RG			((unsigned *) 0x01A0fff0)
#define C6XXX_EDMA_ERH_RG			((unsigned *) 0x01A0ffb0)
	
	// event enable LOW/HIGH (HIGH part for C6416 only)
#define C6XXX_EDMA_EER_RG			((unsigned *) 0x01A0fff4)
#define C6XXX_EDMA_EERL_RG			((unsigned *) 0x01A0fff4)
#define C6XXX_EDMA_EERH_RG			((unsigned *) 0x01A0ffb4)

	// event clear LOW/HIGH (HIGH part for C6416 only)
#define C6XXX_EDMA_ECR_RG			((unsigned *) 0x01A0fff8)
#define C6XXX_EDMA_ECRL_RG			((unsigned *) 0x01A0fff8)
#define C6XXX_EDMA_ECRH_RG			((unsigned *) 0x01A0ffb8)

	// event set LOW/HIGH (HIGH part for C6416 only)
#define C6XXX_EDMA_ESR_RG			((unsigned *) 0x01A0fffc)
#define C6XXX_EDMA_ESRL_RG			((unsigned *) 0x01A0fffc)
#define C6XXX_EDMA_ESRH_RG			((unsigned *) 0x01A0ffbc)

	// event polarity LOW/HIGH (HIGH part for C6416 only)
#define C6XXX_EDMA_EPR_RG			((unsigned *) 0x01A0ffdc)
#define C6XXX_EDMA_EPRL_RG			((unsigned *) 0x01A0ffdc)
#define C6XXX_EDMA_EPRH_RG			((unsigned *) 0x01A0ff9c)

	// channel interrupt enable LOW/HIGH (HIGH part for C6416 only)
#define C6XXX_EDMA_CIER_RG			((unsigned *) 0x01A0ffe8)
#define C6XXX_EDMA_CIERL_RG			((unsigned *) 0x01A0ffe8)
#define C6XXX_EDMA_CIERH_RG			((unsigned *) 0x01A0ffa8)

	// channel interrupt pending LOW/HIGH (HIGH part for C6416 only)
#define C6XXX_EDMA_CIPR_RG			((unsigned *) 0x01A0ffe4)
#define C6XXX_EDMA_CIPRL_RG			((unsigned *) 0x01A0ffe4)
#define C6XXX_EDMA_CIPRH_RG			((unsigned *) 0x01A0ffa4)

	// channel chain enable LOW/HIGH (HIGH part for C6416 only)
#define C6XXX_EDMA_CCER_RG			((unsigned *) 0x01A0ffec)
#define C6XXX_EDMA_CCERL_RG			((unsigned *) 0x01A0ffec)
#define C6XXX_EDMA_CCERH_RG			((unsigned *) 0x01A0ffac)

	// priority queue status
#define C6XXX_EDMA_PQSR_RG			((unsigned *) 0x01A0ffe0)

	// C6416 only: priority queue allocation regs
#define C6XXX_EDMA_PQAR0_RG			((unsigned *) 0x01A0ffc0)
#define C6XXX_EDMA_PQAR1_RG			((unsigned *) 0x01A0ffc4)
#define C6XXX_EDMA_PQAR2_RG			((unsigned *) 0x01A0ffc8)
#define C6XXX_EDMA_PQAR3_RG			((unsigned *) 0x01A0ffcc)

	// C671x only: EDMA event selector regs
#define C6XXX_EDMA_ESEL0_RG			((unsigned *) 0x01A0ff00)
#define C6XXX_EDMA_ESEL1_RG			((unsigned *) 0x01A0ff04)
#define C6XXX_EDMA_ESEL3_RG			((unsigned *) 0x01A0ff0c)

	// EDMA channel descriptors (located in PaRAM)
	// EDMA parameter RAM channel and reload-link channel descriptor def
typedef struct
{
	unsigned		opt;
	unsigned		src_addr;
	unsigned short	element_count;
	unsigned short	array_frame_count;
	unsigned		dst_addr;
	unsigned short	element_index;
	unsigned short	array_frame_index;
	unsigned short	link_addr;
	unsigned short	element_count_reload;
}
C6XXX_EDMA_CH_DD;


#define C6XXX_EDMA_PRAM_BADDR		0x01A00000	// base address for EDMA parameter RAM

#define C6416_EDMA_MAX_CH_COUNT		64			// C6416: max number of EDMA channels
#define C6416_EDMA_MAX_RLCH_COUNT	21			// C6416: max number of EDMA reload-link channel descriptors

#define C671X_EDMA_MAX_CH_COUNT		16			// C671x: max number of EDMA channels
#define C671X_EDMA_MAX_RLCHD_COUNT	69			// C671x: max number of EDMA reload-link channel descriptors

			// macros for getting pointer for EDMA channel and reload-link channel descriptors
			// user must use the follow syntax to access channel descitor:
			//		C6XXX_EDMA_CH_DPTR(ch)->opt =	...;
			//			etc...
#define C6XXX_EDMA_CH_DPTR(ch)		((C6XXX_EDMA_CH_DD *)	(C6XXX_EDMA_PRAM_BADDR + (ch%85)*24))

			// direct access to channel and reload-link cannel descriptor regs
#define C6XXX_EDMA_OPT_RG(ch)		((unsigned *) (C6XXX_EDMA_PRAM_BADDR + (ch%85)*24))
#define C6XXX_EDMA_SRC_RG(ch)		((unsigned *) (C6XXX_EDMA_PRAM_BADDR + (ch%85)*24) + 0x4))
#define C6XXX_EDMA_CNT_RG(ch)		((unsigned *) (C6XXX_EDMA_PRAM_BADDR + (ch%85)*24) + 0x8))
#define C6XXX_EDMA_DST_RG(ch)		((unsigned *) (C6XXX_EDMA_PRAM_BADDR + (ch%85)*24) + 0xc))
#define C6XXX_EDMA_IDX_RG(ch)		((unsigned *) (C6XXX_EDMA_PRAM_BADDR + (ch%85)*24) + 0x10))
#define C6XXX_EDMA_RLD_RG(ch)		((unsigned *) (C6XXX_EDMA_PRAM_BADDR + (ch%85)*24) + 0x14))

#define C6XXX_EDMA_PARAM_SCRPAD0_RG	((unsigned *) (C6XXX_EDMA_PRAM_BADDR + 85*24))
#define C6XXX_EDMA_PARAM_SCRPAD1_RG	((unsigned *) (C6XXX_EDMA_PRAM_BADDR + 85*24 + 4))



//------------ QDMA and Pseudo registers -------------------------
#define C6XXX_QDMA_OPT_RG			((unsigned *) 0x02000000)
#define C6XXX_QDMA_SRC_RG			((unsigned *) 0x02000004)
#define C6XXX_QDMA_CNT_RG			((unsigned *) 0x02000008)
#define C6XXX_QDMA_DST_RG			((unsigned *) 0x0200000c)
#define C6XXX_QDMA_IDX_RG			((unsigned *) 0x02000010)
#define C6XXX_QDMA_S_OPT_RG			((unsigned *) 0x02000020)
#define C6XXX_QDMA_S_SRC_RG			((unsigned *) 0x02000024)
#define C6XXX_QDMA_S_CNT_RG			((unsigned *) 0x02000028)
#define C6XXX_QDMA_S_DST_RG			((unsigned *) 0x0200002c)
#define C6XXX_QDMA_S_IDX_RG			((unsigned *) 0x02000030)



//------------ Cache control registers ---------------------------
#define C6XXX_CCFG_RG				((unsigned *) 0x01840000)
#define C6XXX_L2ALLOC0_RG			((unsigned *) 0x01842000)	//C6416 only
#define C6XXX_L2ALLOC1_RG			((unsigned *) 0x01842004)	//C6416 only
#define C6XXX_L2ALLOC2_RG			((unsigned *) 0x01842008)	//C6416 only
#define C6XXX_L2ALLOC3_RG			((unsigned *) 0x0184200c)	//C6416 only
#define C6XXX_L2FBAR_RG				((unsigned *) 0x01844000)
#define C6XXX_L2FWC_RG				((unsigned *) 0x01844004)
#define C6XXX_L2CBAR_RG				((unsigned *) 0x01844010)
#define C6XXX_L2CWC_RG				((unsigned *) 0x01844014)
#define C6XXX_L1PFBAR_RG			((unsigned *) 0x01844020)
#define C6XXX_L1PFWC_RG				((unsigned *) 0x01844024)
#define C6XXX_L1DFBAR_RG			((unsigned *) 0x01844030)
#define C6XXX_L1DFWC_RG				((unsigned *) 0x01844034)
#define C6XXX_L2FLUSH_RG			((unsigned *) 0x01845000)
#define C6XXX_L2CLEAN_RG			((unsigned *) 0x01845004)



//------------ On-chip GPIO control registers --------------------
#define C6XXX_GPEN_RG				((unsigned *) 0x01B00000)
#define C6XXX_GPDIR_RG				((unsigned *) 0x01B00004)
#define C6XXX_GPVAL_RG				((unsigned *) 0x01B00008)
#define C6XXX_GPDH_RG				((unsigned *) 0x01B00010)
#define C6XXX_GPHM_RG				((unsigned *) 0x01B00014)
#define C6XXX_GPDL_RG				((unsigned *) 0x01B00018)
#define C6XXX_GPLM_RG				((unsigned *) 0x01B0001c)
#define C6XXX_GPGC_RG				((unsigned *) 0x01B00020)
#define C6XXX_GPPOL_RG				((unsigned *) 0x01B00024)
//----------------------------------------------------------------



#ifdef	__C6XXX_SELECT_C6416_DSP__
//----------------------------------------------------------------
//------------ C6416 DEVICE_REV register -------------------------
#define C6XXX_DEVICE_REV_RG			((unsigned *) 0x01B00200)

//------------ C6416 MAR0..255 registers -------------------------
	// Note, that C64x has MAR96..111 and MAR128..191 valid regs only.
#define C6XXX_MAR_RG(n)				((unsigned *) (0x01848000+n*4))
//----------------------------------------------------------------
#endif



#ifdef	__C6XXX_SELECT_C671X_DSP__
//----------------------------------------------------------------
//------------ C671x MAR0..15 registers --------------------------
#define C6XXX_MAR_RG(n)				((unsigned *) (0x01848200+n*4))
//----------------------------------------------------------------
#endif



#ifdef	__C6XXX_SELECT_C6713_DSP__
//----------------------------------------------------------------
//------------ C6713 DEVCFG device configuration register --------
#define C6713_DEVCFG_RG				((unsigned *) 0x019C0200)



//------------ C6713 PLL Control registers -----------------------
#define C6713_PLL_PID_RG			((unsigned *) 0x01B7c000)
#define C6713_PLL_CSR_RG			((unsigned *) 0x01B7c100)
#define C6713_PLL_M_RG				((unsigned *) 0x01B7c110)
#define C6713_PLL_DIV0_RG			((unsigned *) 0x01B7c114)
#define C6713_PLL_DIV1_RG			((unsigned *) 0x01B7c118)
#define C6713_PLL_DIV2_RG			((unsigned *) 0x01B7c11c)
#define C6713_PLL_DIV3_RG			((unsigned *) 0x01B7c120)
#define C6713_PLL_OSCDIV1_RG		((unsigned *) 0x01B7c124)



//------------ C6713 McASP registers -----------------------------
#define C6713_MCASP0_PID_RG			((unsigned *) 0x01B4c000)
#define C6713_MCASP0_PWRDEMU_RG		((unsigned *) 0x01B4c004)
#define C6713_MCASP0_PFUNC_RG		((unsigned *) 0x01B4c010)
#define C6713_MCASP0_PDIR_RG		((unsigned *) 0x01B4c014)
#define C6713_MCASP0_PDOUT_RG		((unsigned *) 0x01B4c018)
#define C6713_MCASP0_PDIN_RG		((unsigned *) 0x01B4c01c)	//use only for reads
#define C6713_MCASP0_PDSET_RG		((unsigned *) 0x01B4c01c)	//use only for writes
#define C6713_MCASP0_PDCLR_RG		((unsigned *) 0x01B4c020)
#define C6713_MCASP0_GBLCTL_RG		((unsigned *) 0x01B4c044)
#define C6713_MCASP0_AMUTE_RG		((unsigned *) 0x01B4c048)
#define C6713_MCASP0_DLBCTL_RG		((unsigned *) 0x01B4c04c)
#define C6713_MCASP0_DITCTL_RG		((unsigned *) 0x01B4c050)
#define C6713_MCASP0_RGBLCTL_RG		((unsigned *) 0x01B4c060)
#define C6713_MCASP0_RMASK_RG		((unsigned *) 0x01B4c064)
#define C6713_MCASP0_RFMT_RG		((unsigned *) 0x01B4c068)
#define C6713_MCASP0_AFSRCTL_RG		((unsigned *) 0x01B4c06c)
#define C6713_MCASP0_ACLKRCTL_RG	((unsigned *) 0x01B4c070)
#define C6713_MCASP0_AHCLKRCTL_RG	((unsigned *) 0x01B4c074)
#define C6713_MCASP0_RTDM_RG		((unsigned *) 0x01B4c078)
#define C6713_MCASP0_RINTCTL_RG		((unsigned *) 0x01B4c07c)
#define C6713_MCASP0_RSTAT_RG		((unsigned *) 0x01B4c080)
#define C6713_MCASP0_RSLOT_RG		((unsigned *) 0x01B4c084)
#define C6713_MCASP0_RCLKCHK_RG		((unsigned *) 0x01B4c088)
#define C6713_MCASP0_XGBLCTL_RG		((unsigned *) 0x01B4c0a0)
#define C6713_MCASP0_XMASK_RG		((unsigned *) 0x01B4c0a4)
#define C6713_MCASP0_XFMT_RG		((unsigned *) 0x01B4c0a8)
#define C6713_MCASP0_AFSXCTL_RG		((unsigned *) 0x01B4c0ac)
#define C6713_MCASP0_ACLKXCTL_RG	((unsigned *) 0x01B4c0b0)
#define C6713_MCASP0_AHCLKXCTL_RG	((unsigned *) 0x01B4c0b4)
#define C6713_MCASP0_XTDM_RG		((unsigned *) 0x01B4c0b8)
#define C6713_MCASP0_XINTCTL_RG		((unsigned *) 0x01B4c0bc)
#define C6713_MCASP0_XSTAT_RG		((unsigned *) 0x01B4c0c0)
#define C6713_MCASP0_XSLOT_RG		((unsigned *) 0x01B4c0c4)
#define C6713_MCASP0_XCLKCHK_RG		((unsigned *) 0x01B4c0c8)

#define C6713_MCASP0_DITCSRA0_RG	((unsigned *) 0x01B4c100)
#define C6713_MCASP0_DITCSRA1_RG	((unsigned *) 0x01B4c104)
#define C6713_MCASP0_DITCSRA2_RG	((unsigned *) 0x01B4c108)
#define C6713_MCASP0_DITCSRA3_RG	((unsigned *) 0x01B4c10c)
#define C6713_MCASP0_DITCSRA4_RG	((unsigned *) 0x01B4c110)
#define C6713_MCASP0_DITCSRA5_RG	((unsigned *) 0x01B4c114)
#define C6713_MCASP0_DITCSRB0_RG	((unsigned *) 0x01B4c118)
#define C6713_MCASP0_DITCSRB1_RG	((unsigned *) 0x01B4c11c)
#define C6713_MCASP0_DITCSRB2_RG	((unsigned *) 0x01B4c120)
#define C6713_MCASP0_DITCSRB3_RG	((unsigned *) 0x01B4c124)
#define C6713_MCASP0_DITCSRB4_RG	((unsigned *) 0x01B4c128)
#define C6713_MCASP0_DITCSRB5_RG	((unsigned *) 0x01B4c12c)
#define C6713_MCASP0_DITUDRA0_RG	((unsigned *) 0x01B4c130)
#define C6713_MCASP0_DITUDRA1_RG	((unsigned *) 0x01B4c134)
#define C6713_MCASP0_DITUDRA2_RG	((unsigned *) 0x01B4c138)
#define C6713_MCASP0_DITUDRA3_RG	((unsigned *) 0x01B4c13c)
#define C6713_MCASP0_DITUDRA4_RG	((unsigned *) 0x01B4c140)
#define C6713_MCASP0_DITUDRA5_RG	((unsigned *) 0x01B4c144)
#define C6713_MCASP0_DITUDRB0_RG	((unsigned *) 0x01B4c148)
#define C6713_MCASP0_DITUDRB1_RG	((unsigned *) 0x01B4c14c)
#define C6713_MCASP0_DITUDRB2_RG	((unsigned *) 0x01B4c150)
#define C6713_MCASP0_DITUDRB3_RG	((unsigned *) 0x01B4c154)
#define C6713_MCASP0_DITUDRB4_RG	((unsigned *) 0x01B4c158)
#define C6713_MCASP0_DITUDRB5_RG	((unsigned *) 0x01B4c15c)

#define C6713_MCASP0_SRCTL0_RG		((unsigned *) 0x01B4c180)
#define C6713_MCASP0_SRCTL1_RG		((unsigned *) 0x01B4c184)
#define C6713_MCASP0_SRCTL2_RG		((unsigned *) 0x01B4c188)
#define C6713_MCASP0_SRCTL3_RG		((unsigned *) 0x01B4c18c)
#define C6713_MCASP0_SRCTL4_RG		((unsigned *) 0x01B4c190)
#define C6713_MCASP0_SRCTL5_RG		((unsigned *) 0x01B4c194)
#define C6713_MCASP0_SRCTL6_RG		((unsigned *) 0x01B4c198)
#define C6713_MCASP0_SRCTL7_RG		((unsigned *) 0x01B4c19c)

#define C6713_MCASP0_XBUF0_RG		((unsigned *) 0x01B4c200)
#define C6713_MCASP0_XBUF1_RG		((unsigned *) 0x01B4c204)
#define C6713_MCASP0_XBUF2_RG		((unsigned *) 0x01B4c208)
#define C6713_MCASP0_XBUF3_RG		((unsigned *) 0x01B4c20c)
#define C6713_MCASP0_XBUF4_RG		((unsigned *) 0x01B4c210)
#define C6713_MCASP0_XBUF5_RG		((unsigned *) 0x01B4c214)
#define C6713_MCASP0_XBUF6_RG		((unsigned *) 0x01B4c218)
#define C6713_MCASP0_XBUF7_RG		((unsigned *) 0x01B4c21c)
#define C6713_MCASP0_RBUF0_RG		((unsigned *) 0x01B4c280)
#define C6713_MCASP0_RBUF1_RG		((unsigned *) 0x01B4c284)
#define C6713_MCASP0_RBUF2_RG		((unsigned *) 0x01B4c288)
#define C6713_MCASP0_RBUF3_RG		((unsigned *) 0x01B4c28c)
#define C6713_MCASP0_RBUF4_RG		((unsigned *) 0x01B4c290)
#define C6713_MCASP0_RBUF5_RG		((unsigned *) 0x01B4c294)
#define C6713_MCASP0_RBUF6_RG		((unsigned *) 0x01B4c298)
#define C6713_MCASP0_RBUF7_RG		((unsigned *) 0x01B4c29c)

#define C6713_MCASP1_PID_RG			((unsigned *) 0x01B50000)
#define C6713_MCASP1_PWRDEMU_RG		((unsigned *) 0x01B50004)
#define C6713_MCASP1_PFUNC_RG		((unsigned *) 0x01B50010)
#define C6713_MCASP1_PDIR_RG		((unsigned *) 0x01B50014)
#define C6713_MCASP1_PDOUT_RG		((unsigned *) 0x01B50018)
#define C6713_MCASP1_PDIN_RG		((unsigned *) 0x01B5001c)	//use only for reads
#define C6713_MCASP1_PDSET_RG		((unsigned *) 0x01B5001c)	//use only for writes
#define C6713_MCASP1_PDCLR_RG		((unsigned *) 0x01B50020)
#define C6713_MCASP1_GBLCTL_RG		((unsigned *) 0x01B50044)
#define C6713_MCASP1_AMUTE_RG		((unsigned *) 0x01B50048)
#define C6713_MCASP1_DLBCTL_RG		((unsigned *) 0x01B5004c)
#define C6713_MCASP1_DITCTL_RG		((unsigned *) 0x01B50050)
#define C6713_MCASP1_RGBLCTL_RG		((unsigned *) 0x01B50060)
#define C6713_MCASP1_RMASK_RG		((unsigned *) 0x01B50064)
#define C6713_MCASP1_RFMT_RG		((unsigned *) 0x01B50068)
#define C6713_MCASP1_AFSRCTL_RG		((unsigned *) 0x01B5006c)
#define C6713_MCASP1_ACLKRCTL_RG	((unsigned *) 0x01B50070)
#define C6713_MCASP1_AHCLKRCTL_RG	((unsigned *) 0x01B50074)
#define C6713_MCASP1_RTDM_RG		((unsigned *) 0x01B50078)
#define C6713_MCASP1_RINTCTL_RG		((unsigned *) 0x01B5007c)
#define C6713_MCASP1_RSTAT_RG		((unsigned *) 0x01B50080)
#define C6713_MCASP1_RSLOT_RG		((unsigned *) 0x01B50084)
#define C6713_MCASP1_RCLKCHK_RG		((unsigned *) 0x01B50088)
#define C6713_MCASP1_XGBLCTL_RG		((unsigned *) 0x01B500a0)
#define C6713_MCASP1_XMASK_RG		((unsigned *) 0x01B500a4)
#define C6713_MCASP1_XFMT_RG		((unsigned *) 0x01B500a8)
#define C6713_MCASP1_AFSXCTL_RG		((unsigned *) 0x01B500ac)
#define C6713_MCASP1_ACLKXCTL_RG	((unsigned *) 0x01B500b0)
#define C6713_MCASP1_AHCLKXCTL_RG	((unsigned *) 0x01B500b4)
#define C6713_MCASP1_XTDM_RG		((unsigned *) 0x01B500b8)
#define C6713_MCASP1_XINTCTL_RG		((unsigned *) 0x01B500bc)
#define C6713_MCASP1_XSTAT_RG		((unsigned *) 0x01B500c0)
#define C6713_MCASP1_XSLOT_RG		((unsigned *) 0x01B500c4)
#define C6713_MCASP1_XCLKCHK_RG		((unsigned *) 0x01B500c8)

#define C6713_MCASP1_DITCSRA0_RG	((unsigned *) 0x01B50100)
#define C6713_MCASP1_DITCSRA1_RG	((unsigned *) 0x01B50104)
#define C6713_MCASP1_DITCSRA2_RG	((unsigned *) 0x01B50108)
#define C6713_MCASP1_DITCSRA3_RG	((unsigned *) 0x01B5010c)
#define C6713_MCASP1_DITCSRA4_RG	((unsigned *) 0x01B50110)
#define C6713_MCASP1_DITCSRA5_RG	((unsigned *) 0x01B50114)
#define C6713_MCASP1_DITCSRB0_RG	((unsigned *) 0x01B50118)
#define C6713_MCASP1_DITCSRB1_RG	((unsigned *) 0x01B5011c)
#define C6713_MCASP1_DITCSRB2_RG	((unsigned *) 0x01B50120)
#define C6713_MCASP1_DITCSRB3_RG	((unsigned *) 0x01B50124)
#define C6713_MCASP1_DITCSRB4_RG	((unsigned *) 0x01B50128)
#define C6713_MCASP1_DITCSRB5_RG	((unsigned *) 0x01B5012c)
#define C6713_MCASP1_DITUDRA0_RG	((unsigned *) 0x01B50130)
#define C6713_MCASP1_DITUDRA1_RG	((unsigned *) 0x01B50134)
#define C6713_MCASP1_DITUDRA2_RG	((unsigned *) 0x01B50138)
#define C6713_MCASP1_DITUDRA3_RG	((unsigned *) 0x01B5013c)
#define C6713_MCASP1_DITUDRA4_RG	((unsigned *) 0x01B50140)
#define C6713_MCASP1_DITUDRA5_RG	((unsigned *) 0x01B50144)
#define C6713_MCASP1_DITUDRB0_RG	((unsigned *) 0x01B50148)
#define C6713_MCASP1_DITUDRB1_RG	((unsigned *) 0x01B5014c)
#define C6713_MCASP1_DITUDRB2_RG	((unsigned *) 0x01B50150)
#define C6713_MCASP1_DITUDRB3_RG	((unsigned *) 0x01B50154)
#define C6713_MCASP1_DITUDRB4_RG	((unsigned *) 0x01B50158)
#define C6713_MCASP1_DITUDRB5_RG	((unsigned *) 0x01B5015c)

#define C6713_MCASP1_SRCTL0_RG		((unsigned *) 0x01B50180)
#define C6713_MCASP1_SRCTL1_RG		((unsigned *) 0x01B50184)
#define C6713_MCASP1_SRCTL2_RG		((unsigned *) 0x01B50188)
#define C6713_MCASP1_SRCTL3_RG		((unsigned *) 0x01B5018c)
#define C6713_MCASP1_SRCTL4_RG		((unsigned *) 0x01B50190)
#define C6713_MCASP1_SRCTL5_RG		((unsigned *) 0x01B50194)
#define C6713_MCASP1_SRCTL6_RG		((unsigned *) 0x01B50198)
#define C6713_MCASP1_SRCTL7_RG		((unsigned *) 0x01B5019c)

#define C6713_MCASP1_XBUF0_RG		((unsigned *) 0x01B50200)
#define C6713_MCASP1_XBUF1_RG		((unsigned *) 0x01B50204)
#define C6713_MCASP1_XBUF2_RG		((unsigned *) 0x01B50208)
#define C6713_MCASP1_XBUF3_RG		((unsigned *) 0x01B5020c)
#define C6713_MCASP1_XBUF4_RG		((unsigned *) 0x01B50210)
#define C6713_MCASP1_XBUF5_RG		((unsigned *) 0x01B50214)
#define C6713_MCASP1_XBUF6_RG		((unsigned *) 0x01B50218)
#define C6713_MCASP1_XBUF7_RG		((unsigned *) 0x01B5021c)
#define C6713_MCASP1_RBUF0_RG		((unsigned *) 0x01B50280)
#define C6713_MCASP1_RBUF1_RG		((unsigned *) 0x01B50284)
#define C6713_MCASP1_RBUF2_RG		((unsigned *) 0x01B50288)
#define C6713_MCASP1_RBUF3_RG		((unsigned *) 0x01B5028c)
#define C6713_MCASP1_RBUF4_RG		((unsigned *) 0x01B50290)
#define C6713_MCASP1_RBUF5_RG		((unsigned *) 0x01B50294)
#define C6713_MCASP1_RBUF6_RG		((unsigned *) 0x01B50298)
#define C6713_MCASP1_RBUF7_RG		((unsigned *) 0x01B5029c)



//------------ C6713 I2C registerss ------------------------------
#define C6713_I2C0_OAR_RG		((unsigned *) 0x01B40000)
#define C6713_I2C0_IER_RG		((unsigned *) 0x01B40004)
#define C6713_I2C0_STR_RG		((unsigned *) 0x01B40008)
#define C6713_I2C0_CLKL_RG		((unsigned *) 0x01B4000c)
#define C6713_I2C0_CLKH_RG		((unsigned *) 0x01B40010)
#define C6713_I2C0_CNT_RG		((unsigned *) 0x01B40014)
#define C6713_I2C0_DRR_RG		((unsigned *) 0x01B40018)
#define C6713_I2C0_SAR_RG		((unsigned *) 0x01B4001c)
#define C6713_I2C0_DXR_RG		((unsigned *) 0x01B40020)
#define C6713_I2C0_MDR_RG		((unsigned *) 0x01B40024)
#define C6713_I2C0_ISR_RG		((unsigned *) 0x01B40028)
#define C6713_I2C0_PSC_RG		((unsigned *) 0x01B40030)
#define C6713_I2C0_PID1_RG		((unsigned *) 0x01B40034)
#define C6713_I2C0_PID2_RG		((unsigned *) 0x01B40038)

#define C6713_I2C1_OAR_RG		((unsigned *) 0x01B44000)
#define C6713_I2C1_IER_RG		((unsigned *) 0x01B44004)
#define C6713_I2C1_STR_RG		((unsigned *) 0x01B44008)
#define C6713_I2C1_CLKL_RG		((unsigned *) 0x01B4400c)
#define C6713_I2C1_CLKH_RG		((unsigned *) 0x01B44010)
#define C6713_I2C1_CNT_RG		((unsigned *) 0x01B44014)
#define C6713_I2C1_DRR_RG		((unsigned *) 0x01B44018)
#define C6713_I2C1_SAR_RG		((unsigned *) 0x01B4401c)
#define C6713_I2C1_DXR_RG		((unsigned *) 0x01B44020)
#define C6713_I2C1_MDR_RG		((unsigned *) 0x01B44024)
#define C6713_I2C1_ISR_RG		((unsigned *) 0x01B44028)
#define C6713_I2C1_PSC_RG		((unsigned *) 0x01B44030)
#define C6713_I2C1_PID1_RG		((unsigned *) 0x01B44034)
#define C6713_I2C1_PID2_RG		((unsigned *) 0x01B44038)

//----------------------------------------------------------------
#endif
//----------------------------------------------------------------
//================================================================



//============ CPU REGISTERS =====================================
extern cregister volatile unsigned int AMR;		// Address Mode Register
extern cregister volatile unsigned int CSR;		// Control Status Register
extern cregister volatile unsigned int IFR;		// Interrupt Flag Register
extern cregister volatile unsigned int ISR;		// Interrupt Set Register
extern cregister volatile unsigned int ICR;		// Interrupt Clear Register
extern cregister volatile unsigned int IER;		// Interrupt Enable	Register
extern cregister volatile unsigned int ISTP;	// Interrupt Service Tbl Ptr
extern cregister volatile unsigned int IRP;		// Interrupt Return Pointer
extern cregister volatile unsigned int NRP;		// Non-maskable Int Return Ptr
extern cregister volatile unsigned int IN;		// General Purpose Input Reg
extern cregister volatile unsigned int OUT;		// General Purpose Output Reg
//================================================================


//============ C6XXX HPIC register bits defs =====================
#define C6XXX_HPIC_DSPINT_BITMASK		0x2
//================================================================


//============ C6XXX macros ======================================
//------------ Cache control macros ------------------------------
// C621x/C671x/C6416: L1 program and data caches cannot be disabled.
//----------------------------------------------------------------
#define C6XXX_SET_L1P_CACHE_INVALIDATE	*C6XXX_CCFG_RG |= 0x200	// set L1 program cache invalidation
#define C6XXX_SET_L1P_CACHE_NORMAL		*C6XXX_CCFG_RG &=~0x200	// set L1 program cache normal operation

#define C6XXX_SET_L1D_CACHE_INVALIDATE	*C6XXX_CCFG_RG |= 0x100	// set L1 data cache invalidation
#define C6XXX_SET_L1D_CACHE_NORMAL		*C6XXX_CCFG_RG &=~0x100	// set L1 data cache normal operation

#define C6XXX_GET_L2_CACHE_MODE			((*C6XXX_CCFG_RG) &0x7)										// returns L2 cache mode
#define C6XXX_SET_L2_CACHE_MODE(mode)	*C6XXX_CCFG_RG = ((*C6XXX_CCFG_RG) & ~0x7) | (mode&0x7))	// set L2 cache mode
//----------------------------------------------------------------


#ifdef	__C6XXX_SELECT_C6416_DSP__
//----------------------------------------------------------------
#define C6XXX_L2_CACHE_MODE_NO_CACHE		0	// no cache, full SRAM allocation
#define C6XXX_L2_CACHE_MODE_1_32_CACHE		1	// cache occupies 1/32 of SRAM
#define C6XXX_L2_CACHE_MODE_1_16_CACHE		2	// cache occupies 1/16 of SRAM
#define C6XXX_L2_CACHE_MODE_1_8_CACHE		3	// cache occupies 1/8 of SRAM
#define C6XXX_L2_CACHE_MODE_1_4_CACHE		7	// cache occupies 1/4 of SRAM
//----------------------------------------------------------------
#endif



#ifdef	__C6XXX_SELECT_C6713_DSP__
//----------------------------------------------------------------
#define C6XXX_L2_CACHE_MODE_NO_CACHE		0	// no cache, full 256k SRAM allocation
#define C6XXX_L2_CACHE_MODE_1_16_CACHE		1	// cache occupies 1/16 of SRAM (16k)
#define C6XXX_L2_CACHE_MODE_1_8_CACHE		2	// cache occupies 1/8 of SRAM (32k)
#define C6XXX_L2_CACHE_MODE_1_533_CACHE		3	// cache occupies 1/5.333 of SRAM (48k)
#define C6XXX_L2_CACHE_MODE_1_4_CACHE		7	// cache occupies 1/4 of SRAM (64k)
//----------------------------------------------------------------
#endif


//------------ Silicon Revision ID access macros (available for C6416 DSP only)
#ifdef	__C6XXX_SELECT_C6416_DSP__
//----------------------------------------------------------------
#define C6416_SILREV_BITMASK				0xf0000
#define C6416_GET_SILREV					((*C6XXX_DEVICE_REV_RG) & C6416_SILREV_BITMASK)

#define C6416_SILREV_IS_SILREV103			(C6416_GET_SILREV == 0x10000)
#define C6416_SILREV_IS_SILREV11			(C6416_GET_SILREV == 0x20000)
#define C6416_SILREV_IS_EARLIERSILREV103	(!(C6416_SILREV_IS_SILREV103 || C6416_SILREV_IS_SILREV11))
//----------------------------------------------------------------
#endif



//------------ IRQ control ---------------------------------------
#define C6XXX_SET_GINT_ENABLE_OFF			{CSR &=~1;}
#define C6XXX_SET_GINT_ENABLE_ON			{IER |=2; CSR |=1;}
#define C6XXX_SET_NMI_ENABLE_ON				{IER |=2;}
#define C6XXX_SET_PGINT_ENABLE_ONE			{CSR |=2;}
#define C6XXX_SET_PGINT_ENABLE_OFF			{CSR &=~2;}

#define C6XXX_SET_INT_OFF_ALL				{ICR = 0xfff0;}

#define C6XXX_SET_INT_OFF(n)				{ICR = 1<<(n);}
#define C6XXX_SET_INT_ON(n)					{ISR = 1<<(n);}

#define C6XXX_INT_IS_OFF(n)					((IFR&(1<<(n)))==0)
#define C6XXX_INT_IS_ON(n)					((IFR&(1<<(n)))!=0)

#define C6XXX_SET_INT_ENABLE_ON(n)			{IER |= (1<<(n));}
#define C6XXX_SET_INT_ENABLE_OFF(n)			{IER &= ~(1<<(n));}
#define C6XXX_SET_INT_ENABLE_OFF_ALL		{IER = 0;}

#define C6XXX_INT_ENABLE_IS_OFF(n)			((IER&(1<<(n)))==0)
#define C6XXX_INT_ENABLE_IS_ON(n)			((IER&(1<<(n)))!=0)
//----------------------------------------------------------------



//================================================================
#ifndef	__C6XXX_EXCLUDE_SET_INTMUX__
//----------------------------------------------------------------
// This function sets INT MUX register in order to map particular source
// interrupt x to C6XXX interrupt line i
int C6XXX_SET_INTMUX(i,x)
{
	if ((i) < 4 || (i) > 15 ||
#ifdef	__C6XXX_SELECT_C671X_DSP__
		(x) > 31)
#endif
#ifdef	__C6XXX_SELECT_C6416_DSP__
		(x) > 23)
#endif
		return(-1);	// exit with error on erroneus params

	if ((i)>=4 && (i)<=9)
	{
		(*C6XXX_INT_MUXL_RG)  &= ~(0x1f		  <<((((i)-4)*5)+(((i)>=7)?1:0)));
		(*C6XXX_INT_MUXL_RG)  |=  (((x) & 0x1f)	<<((((i)-4)*5)+(((i)>=7)?1:0)));
	}
	else
	{
		(*C6XXX_INT_MUXH_RG) &= ~(0x1f		  <<((((i)-10)*5)+(((i)>=13)?1:0)));
		(*C6XXX_INT_MUXH_RG) |=  (((x) & 0x1f)	<<((((i)-10)*5)+(((i)>=13)?1:0)));
	}
	return(0);	// exit OK
}
//----------------------------------------------------------------
#endif
//================================================================



//================================================================
	// INT selector codes for INT-MUX mapping
#define C6XXX_INTSEL_DSPINT				0
#define C6XXX_INTSEL_TINT0				1
#define C6XXX_INTSEL_TINT1				2
#define C6XXX_INTSEL_SDINT				3
#define C6XXX_INTSEL_SDINTA				3	// C6416 only
#define C6XXX_INTSEL_XINT4				4
#define C6XXX_INTSEL_GPINT4				4	// C6416 and C621x_C671x only
#define C6XXX_INTSEL_XINT5				5
#define C6XXX_INTSEL_GPINT5				5	// C6416 and C621x_C671x only
#define C6XXX_INTSEL_XINT6				6
#define C6XXX_INTSEL_GPINT6				6	// C6416 and C621x_C671x only
#define C6XXX_INTSEL_XINT7				7
#define C6XXX_INTSEL_GPINT7				7	// C6416 and C621x_C671x only
#define C6XXX_INTSEL_DMA0				8
#define C6XXX_INTSEL_EDMA				8	// C6416 and C621x_C671x only
#define C6XXX_INTSEL_DMA1				9
#define C6XXX_INTSEL_EMUDTDMA			9	// C621x_C671x only
#define C6XXX_INTSEL_DMA2				10
#define C6XXX_INTSEL_EMURTDXRX			10	// C621x_C671x only
#define C6XXX_INTSEL_DMA3				11
#define C6XXX_INTSEL_EMURTDXTX			11	// C621x_C671x only
#define C6XXX_INTSEL_MCBSP0_XINT		12
#define C6XXX_INTSEL_MCBSP0_RINT		13
#define C6XXX_INTSEL_MCBSP1_XINT		14
#define C6XXX_INTSEL_MCBSP1_RINT		15
#define C6XXX_INTSEL_GPINT0				16	// C6416 and C621x_C671x only
#define C6XXX_INTSEL_MCBSP2_XINT		17
#define C6XXX_INTSEL_MCBSP2_RINT		18
#define C6XXX_INTSEL_TINT2				19	// C6416 only
#define C6XXX_INTSEL_SDINTB				20	// C6416 only
#define C6XXX_INTSEL_C6416_PCI_WAKEUP	21	// C6416 only
#define C6XXX_INTSEL_I2CINT0			22	// C621x_C671x only
#define C6XXX_INTSEL_UINT				23	// C6416 only
#define C6XXX_INTSEL_I2CINT1			23	// C621x_C671x only
#define C6XXX_INTSEL_AXINT0				28	// C621x_C671x only
#define C6XXX_INTSEL_ARINT0				29	// C621x_C671x only
#define C6XXX_INTSEL_AXINT1				30	// C621x_C671x only
#define C6XXX_INTSEL_ARINT1				31	// C621x_C671x only


#define C6XXX_XINT_POLARITY_POS			0
#define C6XXX_XINT_POLARITY_NEG			1
#define C6XXX_XINT4						4
#define C6XXX_XINT5						5
#define C6XXX_XINT6						6
#define C6XXX_XINT7						7

#define C6XXX_SET_XINT_POLARITY(i,p)	{*C6XXX_INT_EXTPOL_RG &=~(1<<((i)-4));*C6XXX_INT_EXTPOL_RG |=(((p)&1)<<((i)-4));}
#define C6XXX_SET_XINT_POLARITY_ALL(p)	{*C6XXX_INT_EXTPOL_RG = ((p)==0)? 0:0xf;}
//================================================================



//------------ GPIO control --------------------------------------
// GPIO enable (GPEN reg)
#define C6XXX_GPIO_ENABLE_OFF			0
#define C6XXX_GPIO_ENABLE_ON			1

// used for GPDIR register to define GPIO direction
#define C6XXX_GPIO_DIR_INPUT			0
#define C6XXX_GPIO_DIR_OUTPUT			1

// used for GPVAL, GPDH, GPDL, GPHM, GPLM regs
#define C6XXX_GPIO_DATA_OFF				0
#define C6XXX_GPIO_DATA_ON				1

#define C6XXX_GPIO_DELTA_OFF			0
#define C6XXX_GPIO_DELTA_ON				1

#define C6XXX_GPIO_MASK_OFF				0
#define C6XXX_GPIO_MASK_ON				1

// GPEN, GPVAL, GPDI, GPDH/GPDL, GPHM/GPLM registers set/get macros
// These macros operate with individual bits only and use universal shifted left 
// bit defs above (v) and require bit # (i) in order to set/get register value.
// Returned value is shifted right to comply with above defs.
// Bit # (i) must be within 0..15 range. Bit value (v) must be 0..1.

#define C6XXX_SET_GPIO_ENABLE(i,v)		*C6XXX_GPEN_RG = ( ((*C6XXX_GPEN_RG) & ~(1<<(i&0xf))) | ((v&1) << (i&0xf)) )
#define C6XXX_GET_GPIO_ENABLE(i)		( ((*C6XXX_GPEN_RG) & (1<<(i&0xf))) >> (i&0xf) ) 

#define C6XXX_SET_GPIO_DIR(i,v)			*C6XXX_GPDIR_RG = ( ((*C6XXX_GPDIR_RG) & ~(1<<(i&0xf))) | ((v&1) << (i&0xf)) )
#define C6XXX_GET_GPIO_DIR(i)			( ((*C6XXX_GPDIR_RG) & (1<<(i&0xf))) >> (i&0xf) ) 

#define C6XXX_SET_GPIO_DATA(i,v)		*C6XXX_GPVAL_RG = ( ((*C6XXX_GPVAL_RG) & ~(1<<(i&0xf))) | ((v&1) << (i&0xf)) )
#define C6XXX_GET_GPIO_DATA(i)			( ((*C6XXX_GPVAL_RG) & (1<<(i&0xf))) >> (i&0xf)	) 

#define C6XXX_CLEAR_GPIO_DH(i)			*C6XXX_GPDH_RG = (1 << (i&0xf))
#define C6XXX_GET_GPIO_DH(i)			( ((*C6XXX_GPDH_RG) & (1<<(i&0xf))) >> (i&0xf) ) 

#define C6XXX_CLEAR_GPIO_DL(i)			*C6XXX_GPDL_RG = (1 << (i&0xf))
#define C6XXX_GET_GPIO_DL(i)			( ((*C6XXX_GPDL_RG) & (1<<(i&0xf))) >> (i&0xf) ) 

#define C6XXX_SET_GPIO_HM(i,v)			*C6XXX_GPHM_RG = ( ((*C6XXX_GPHM_RG) & ~(1<<(i&0xf))) | ((v&1) << (i&0xf)) )
#define C6XXX_GET_GPIO_HM(i)			( ((*C6XXX_GPHM_RG) & (1<<(i&0xf))) >> (i&0xf) ) 

#define C6XXX_SET_GPIO_LM(i,v)			*C6XXX_GPLM_RG = ( ((*C6XXX_GPLM_RG) & ~(1<<(i&0xf))) | ((v&1) << (i&0xf)) )
#define C6XXX_GET_GPIO_LM(i)			( ((*C6XXX_GPLM_RG) & (1<<(i&0xf))) >> (i&0xf) ) 


// macros to set/read all GPIO control registers
// These macros write/read full register contents only with built-in mask applied.
#define C6XXX_SET_GPIO_ENABLE_RG(v)		*C6XXX_GPEN_RG = (v & 0xffff)
#define C6XXX_GET_GPIO_ENABLE_RG()		((*C6XXX_GPEN_RG) & 0xffff)

#define C6XXX_SET_GPIO_DIR_RG(v)		*C6XXX_GPDIR_RG = (v & 0xffff)
#define C6XXX_GET_GPIO_DIR_RG()			((*C6XXX_GPDIR_RG) &	0xffff)

#define C6XXX_SET_GPIO_DATA_RG(v)		*C6XXX_GPVAL_RG = (v & 0xffff)
#define C6XXX_GET_GPIO_DATA_RG()		((*C6XXX_GPVAL_RG) &	0xffff)

#define C6XXX_SET_GPIO_DH_RG(v)			*C6XXX_GPDH_RG = (v & 0xffff)
#define C6XXX_GET_GPIO_DH_RG()			((*C6XXX_GPDH_RG) & 0xffff)

#define C6XXX_SET_GPIO_DL_RG(v)			*C6XXX_GPDL_RG = (v & 0xffff)
#define C6XXX_GET_GPIO_DL_RG()			((*C6XXX_GPDL_RG) & 0xffff)

#define C6XXX_SET_GPIO_HM_RG(v)			*C6XXX_GPHM_RG = (v & 0xffff)
#define C6XXX_GET_GPIO_HM_RG()			((*C6XXX_GPHM_RG) & 0xffff)

#define C6XXX_SET_GPIO_LM_RG(v)			*C6XXX_GPLM_RG = (v & 0xffff)
#define C6XXX_GET_GPIO_LM_RG()			((*C6XXX_GPLM_RG) & 0xffff)

#define C6XXX_SET_GPIO_GC_RG(v)			*C6XXX_GPGC_RG = (v & 0x37)
#define C6XXX_GET_GPIO_GC_RG()			((*C6XXX_GPGC_RG) & 0x37)

#define C6XXX_SET_GPIO_POL_RG(v)		*C6XXX_GPPOL_RG = (v & 0xf1)
#define C6XXX_GET_GPIO_POL_RG()			((*C6XXX_GPPOL_RG) & 0xf1)
//----------------------------------------------------------------



#ifdef	__C6XXX_SELECT_C6713_DSP__
//----------------------------------------------------------------
//============ C6713 peripheral registers configuration ==========

//------------ C6713 DEVCFG device configuration register macros
/*----------------------------------------------------------------
 C6713 DEVCFG device configuration register is used for peripheral selection 
 (control the pin availability of the McBSP-0, McBSP-1, McASP-0, I2C-1 ports and Timers)
 and device configuration (control EMIF input clock source and the timer output pins sources)
 Default state is 0x00:
		1. SYSCLK3 (from PLL clock generator) is the EMIF input clock source;
		2. TOUT0 and TOUT1 pins function as Timer-0 and Timer-1 output pins;
		3. McBSP-0 and McBSP-1 peripheral pins are enabled.
 Note!!! In order to enable DSP serial port on E2/6713 board it is necessary
 to enable the appropriate buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register!
 (see T2E6XXX_DSP.h)
----------------------------------------------------------------*/
#define C6713_DEVCFG_RG_BITMASK				0x1f

#define C6713_DEVCFG_EKSRC_BITMASK			0x10
#define C6713_DEVCFG_TOUT1SEL_BITMASK		0x08
#define C6713_DEVCFG_TOUT0SEL_BITMASK		0x04
#define C6713_DEVCFG_MCBSP0DIS_BITMASK		0x02
#define C6713_DEVCFG_MCBSP1DIS_BITMASK		0x01
#define C6713_DEVCFG_MCASP0_EN_BITMASK		0x0f
#define C6713_DEVCFG_PERIPH_CFG_BITMASK		0x0f

#define C6713_DEVCFG_EKSRC_SEL_SYSCLK3		0x0
#define C6713_DEVCFG_EKSRC_SEL_ECLKIN		0x10
#define C6713_DEVCFG_TOUT1SEL_TOUT1			0x0
#define C6713_DEVCFG_TOUT1SEL_AXR04			0x08
#define C6713_DEVCFG_TOUT0SEL_TOUT0			0x0
#define C6713_DEVCFG_TOUT0SEL_AXR02			0x04
#define C6713_DEVCFG_MCBSP0DIS_OFF			0x0
#define C6713_DEVCFG_MCBSP0DIS_ON			0x02
#define C6713_DEVCFG_MCBSP1DIS_OFF			0x0
#define C6713_DEVCFG_MCBSP1DIS_ON			0x01
#define C6713_DEVCFG_MCASP0_EN_OFF			0x0
#define C6713_DEVCFG_MCASP0_EN_ON			0x0f

#define C6713_get_devcfg_rg()				((*C6713_DEVCFG_RG) & C6713_DEVCFG_RG_BITMASK)
#define C6713_set_devcfg_rg(v)				*C6713_DEVCFG_RG = (v & C6713_DEVCFG_RG_BITMASK)

	// dedicated bit specific macros
#define C6713_get_devcfg_eksrc()			(C6713_get_devcfg_rg() & C6713_DEVCFG_EKSRC_BITMASK)
#define C6713_set_devcfg_eksrc(v)			(C6713_set_devcfg_rg((C6713_get_devcfg_rg() & ~C6713_DEVCFG_EKSRC_BITMASK) | (v & C6713_DEVCFG_EKSRC_BITMASK)))
#define C6713_get_devcfg_tout1sel()			(C6713_get_devcfg_rg() & C6713_DEVCFG_TOUT1SEL_BITMASK)
#define C6713_set_devcfg_tout1sel(v)		(C6713_set_devcfg_rg((C6713_get_devcfg_rg() & ~C6713_DEVCFG_TOUT1SEL_BITMASK) | (v & C6713_DEVCFG_TOUT1SEL_BITMASK)))
#define C6713_get_devcfg_tout0sel()			(C6713_get_devcfg_rg() & C6713_DEVCFG_TOUT0SEL_BITMASK)
#define C6713_set_devcfg_tout0sel(v)		(C6713_set_devcfg_rg((C6713_get_devcfg_rg() & ~C6713_DEVCFG_TOUT0SEL_BITMASK) | (v & C6713_DEVCFG_TOUT0SEL_BITMASK)))
#define C6713_get_devcfg_mcbsp0dis()		(C6713_get_devcfg_rg() & C6713_DEVCFG_MCBSP0DIS_BITMASK)
#define C6713_set_devcfg_mcbsp0dis(v)		(C6713_set_devcfg_rg((C6713_get_devcfg_rg() & ~C6713_DEVCFG_MCBSP0DIS_BITMASK) | (v & C6713_DEVCFG_MCBSP0DIS_BITMASK)))
#define C6713_get_devcfg_mcbsp1dis()		(C6713_get_devcfg_rg() & C6713_DEVCFG_MCBSP1DIS_BITMASK)
#define C6713_set_devcfg_mcbsp1dis(v)		(C6713_set_devcfg_rg((C6713_get_devcfg_rg() & ~C6713_DEVCFG_MCBSP1DIS_BITMASK) | (v & C6713_DEVCFG_MCBSP1DIS_BITMASK)))
#define C6713_get_devcfg_mcasp0_en()		(C6713_get_devcfg_rg() & C6713_DEVCFG_MCASP0_EN_BITMASK)
#define C6713_set_devcfg_mcasp0_en(v)		(C6713_set_devcfg_rg((C6713_get_devcfg_rg() & ~C6713_DEVCFG_MCASP0_EN_BITMASK) | (v & C6713_DEVCFG_MCASP0_EN_BITMASK)))
#define C6713_get_devcfg_periph_cfg()		(C6713_get_devcfg_rg() & C6713_DEVCFG_PERIPH_CFG_BITMASK)
#define C6713_set_devcfg_periph_cfg(v)		(C6713_set_devcfg_rg((C6713_get_devcfg_rg() & ~C6713_DEVCFG_PERIPH_CFG_BITMASK) | (v & C6713_DEVCFG_PERIPH_CFG_BITMASK)))

	// direct bit set macros
#define C6713_SET_DEVCFG_EKSRC_SYSCLK3		(C6713_set_devcfg_eksrc(C6713_DEVCFG_EKSRC_SEL_SYSCLK3))
#define C6713_SET_DEVCFG_EKSRC_ECLKIN		(C6713_set_devcfg_eksrc(C6713_DEVCFG_EKSRC_SEL_ECLKIN))
#define C6713_SET_DEVCFG_TOUT1SEL_TOUT1		(C6713_set_devcfg_tout1sel(C6713_DEVCFG_TOUT1SEL_TOUT1))
#define C6713_SET_DEVCFG_TOUT1SEL_AXR04		(C6713_set_devcfg_tout1sel(C6713_DEVCFG_TOUT1SEL_AXR04))
#define C6713_SET_DEVCFG_TOUT0SEL_TOUT0		(C6713_set_devcfg_tout0sel(C6713_DEVCFG_TOUT0SEL_TOUT0))
#define C6713_SET_DEVCFG_TOUT0SEL_AXR02		(C6713_set_devcfg_tout0sel(C6713_DEVCFG_TOUT0SEL_AXR02))
#define C6713_SET_DEVCFG_MCBSP0DIS_OFF		(C6713_set_devcfg_mcbsp0dis(C6713_DEVCFG_MCBSP0DIS_OFF))
#define C6713_SET_DEVCFG_MCBSP0DIS_ON		(C6713_set_devcfg_mcbsp0dis(C6713_DEVCFG_MCBSP0DIS_ON))
#define C6713_SET_DEVCFG_MCBSP1DIS_OFF		(C6713_set_devcfg_mcbsp1dis(C6713_DEVCFG_MCBSP1DIS_OFF))
#define C6713_SET_DEVCFG_MCBSP1DIS_ON		(C6713_set_devcfg_mcbsp1dis(C6713_DEVCFG_MCBSP1DIS_ON))
#define C6713_SET_DEVCFG_MCASP0_EN_OFF		(C6713_set_devcfg_mcasp0_en(C6713_DEVCFG_MCASP0_EN_OFF))
#define C6713_SET_DEVCFG_MCASP0_EN_ON		(C6713_set_devcfg_mcasp0_en(C6713_DEVCFG_MCASP0_EN_ON))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_DEVCFG_EKSRC_IS_ECLKIN		(C6713_get_devcfg_eksrc() == C6713_DEVCFG_EKSRC_SEL_ECLKIN)
#define C6713_DEVCFG_TOUT1SEL_IS_TOUT1		(C6713_get_devcfg_tout1sel() == C6713_DEVCFG_TOUT1SEL_TOUT1)
#define C6713_DEVCFG_TOUT0SEL_IS_TOUT0		(C6713_get_devcfg_tout0sel() == C6713_DEVCFG_TOUT0SEL_TOUT0)
#define C6713_DEVCFG_MCBSP0DIS_IS_ON		(C6713_get_devcfg_mcbsp0dis() == C6713_DEVCFG_MCBSP0DIS_ON)
#define C6713_DEVCFG_MCBSP1DIS_IS_ON		(C6713_get_devcfg_mcbsp1dis() == C6713_DEVCFG_MCBSP1DIS_ON)
#define C6713_DEVCFG_MCASP0_EN_IS_ON		(C6713_get_devcfg_mcasp0_en() == C6713_DEVCFG_MCASP0_EN_ON)



//----------------------------------------------------------------
//------------ C6713 PLL Control registers macros ----------------
/*----------------------------------------------------------------
 C6713 PLL Control registers are used to configure PLL controller to generate different clocks
 for different parts of the system (i.e., DSP core, Peripheral Data Bus, EMIF, McASP and other peripherals).
 By default on startup PLL is disabled and is in reset state, so DSP core is operated at CLKIN clock
 (for E2/6713 is 50 MHz), Peripheral clock (SYSCLK2) is CLKIN/2 (for E2/6713 is 25 MHz),
 EMIF clock ECLKOUT is CLKIN/2 (for E2/6713 is 25 MHz), AUXCLK (clock source for McASP0 and McASP1)
 is equal to CLKIN (for E2/6713 is 50 MHz).
 For correct functionality of DSP board (E2/6713 assumed) PLL controller must be configured as followed
 (refer to spru233c):
		1. Program PLL Multiplier Control register PLLM to x6 (0x6) in order to achieve 300 MHz DSP	core
			clock for C6713B DSP chip (PLLDIV0 is /1 in default state);
		2. Program OSCDIV1 register to /1 (0x8000) in order to observe CLKIN 50 MHz clock at CLKOUT3 pin;
		3. Program PLLDIV3 to /3 (0x8002) in order to achieve 100 MHz EMIF clock ECLKOUT (SYSCLK3) (CLKIN x6 /3).
			PLLDIV1 and PLLDIV2 are in their default states: /1 (0x8000) and /2 (0x8001),
			so DSP core clock (SYSCLK1) is 300 MHz (CLKIN x6 /1), Peripheral clock (SYSCLK2) is 150 MHz (CLKIN x6 /2);
		4. Wait for PLL to properly reset. PLL reset time is 125 ns min for C6713B DSP.
		5. Write PLLRST = 0 in PLLCSR to bring PLL out of reset;
		6. Wait for PLL to lock. PLL lock time is 75 microseconds typ and 187.5 microseconds max for C6713B DSP.
		7. Write PLLEN = 1 in PLLCSR to enable PLL mode.
 Note! In order to clock EMIF clock ECLKOUT by SYSCLK3 (generated by PLL from CLKIN) EMIF_CLK_SRC_SEL bit
 in DEVCFG register must be set to 0 (default state). And correspondingly to clock EMIF clock ECLKOUT
 by an external reference clock via the ECLKIN pin EMIF_CLK_SRC_SEL bit in DEVCFG register must be set to 1.
----------------------------------------------------------------*/

//------------ C6713 PLL Peripheral identification register (PLL_PID) macros
#define C6713_PLL_PID_RG_BITMASK		0xffffffff

#define C6713_PLL_PID_C6713				0x00010801

#define C6713_get_pll_pid_rg()			((*C6713_PLL_PID_RG) & C6713_PLL_PID_RG_BITMASK)

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_PLL_PID_IS_C6713			(C6713_get_pll_pid_rg() == C6713_PLL_PID_C6713)


//------------ C6713 PLL control/status register PLL_CSR macros
// Default state is 0x48: PLL_EN is OFF, PLL_PWRDN is OFF, PLL_RST is ON,
// PLL_STABLE is ON
#define C6713_PLL_CSR_RG_BITMASK		0x4f

#define C6713_PLL_CSR_EN_BITMASK		0x01
#define C6713_PLL_CSR_PWRDN_BITMASK		0x02
#define C6713_PLL_CSR_RST_BITMASK		0x08
#define C6713_PLL_CSR_STABLE_BITMASK	0x40

#define C6713_PLL_CSR_EN_ON				0x01
#define C6713_PLL_CSR_EN_OFF			0x0
#define C6713_PLL_CSR_PWRDN_ON			0x02
#define C6713_PLL_CSR_PWRDN_OFF			0x0
#define C6713_PLL_CSR_RST_ON			0x08
#define C6713_PLL_CSR_RST_OFF			0x0
#define C6713_PLL_CSR_STABLE_ON			0x40
#define C6713_PLL_CSR_STABLE_OFF		0x0

#define C6713_get_pll_csr_rg()			((*C6713_PLL_CSR_RG) & C6713_PLL_CSR_RG_BITMASK)
#define C6713_set_pll_csr_rg(v)			*C6713_PLL_CSR_RG = (v & C6713_PLL_CSR_RG_BITMASK)

	// dedicated bit specific macros
#define C6713_get_pll_csr_en()			(C6713_get_pll_csr_rg() & C6713_PLL_CSR_EN_BITMASK)
#define C6713_set_pll_csr_en(v)			(C6713_set_pll_csr_rg((C6713_get_pll_csr_rg() & ~C6713_PLL_CSR_EN_BITMASK) | (v & C6713_PLL_CSR_EN_BITMASK)))
#define C6713_get_pll_csr_pwrdn()		(C6713_get_pll_csr_rg() & C6713_PLL_CSR_PWRDN_BITMASK)
#define C6713_set_pll_csr_pwrdn(v)		(C6713_set_pll_csr_rg((C6713_get_pll_csr_rg() & ~C6713_PLL_CSR_PWRDN_BITMASK) | (v & C6713_PLL_CSR_PWRDN_BITMASK)))
#define C6713_get_pll_csr_rst()			(C6713_get_pll_csr_rg() & C6713_PLL_CSR_RST_BITMASK)
#define C6713_set_pll_csr_rst(v)		(C6713_set_pll_csr_rg((C6713_get_pll_csr_rg() & ~C6713_PLL_CSR_RST_BITMASK) | (v & C6713_PLL_CSR_RST_BITMASK)))
#define C6713_get_pll_csr_stable()		(C6713_get_pll_csr_rg() & C6713_PLL_CSR_STABLE_BITMASK)

	// direct bit set macros
#define C6713_SET_PLL_CSR_EN_OFF		(C6713_set_pll_csr_en(C6713_PLL_CSR_EN_OFF))
#define C6713_SET_PLL_CSR_EN_ON			(C6713_set_pll_csr_en(C6713_PLL_CSR_EN_ON))
#define C6713_SET_PLL_CSR_PWRDN_OFF		(C6713_set_pll_csr_pwrdn(C6713_PLL_CSR_PWRDN_OFF))
#define C6713_SET_PLL_CSR_PWRDN_ON		(C6713_set_pll_csr_pwrdn(C6713_PLL_CSR_PWRDN_ON))
#define C6713_SET_PLL_CSR_RST_OFF		(C6713_set_pll_csr_rst(C6713_PLL_CSR_RST_OFF))
#define C6713_SET_PLL_CSR_RST_ON		(C6713_set_pll_csr_rst(C6713_PLL_CSR_RST_ON))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_PLL_CSR_EN_IS_ON			(C6713_get_pll_csr_en() == C6713_PLL_CSR_EN_ON)
#define C6713_PLL_CSR_PWRDN_IS_ON		(C6713_get_pll_csr_pwrdn() == C6713_PLL_CSR_PWRDN_ON)
#define C6713_PLL_CSR_RST_IS_ON			(C6713_get_pll_csr_rst() == C6713_PLL_CSR_RST_ON)
#define C6713_PLL_CSR_STABLE_IS_ON		(C6713_get_pll_csr_stable() == C6713_PLL_CSR_STABLE_ON)



//------------ C6713 PLL multiplier control register (PLL_M) macros
// Default state is x7 (0x07) and it has to be changed to x6 (0x06)
// to achieve 300 MHz for DSP core clock (SYSCLK1) from CLKIN clock (50 MHz)
#define C6713_PLL_M_RG_BITMASK			0x1f

#define C6713_PLL_M_MULT_4				0x04
#define C6713_PLL_M_MULT_5				0x05
#define C6713_PLL_M_MULT_6				0x06
#define C6713_PLL_M_MULT_7				0x07
#define C6713_PLL_M_MULT_8				0x08
#define C6713_PLL_M_MULT_9				0x09
#define C6713_PLL_M_MULT_10				0x0a

#define C6713_get_pll_m_rg()			((*C6713_PLL_M_RG) & C6713_PLL_M_RG_BITMASK)
#define C6713_set_pll_m_rg(v)			*C6713_PLL_M_RG = (v & C6713_PLL_M_RG_BITMASK)

#define C6713_SET_PLL_M_MULT_6			(C6713_set_pll_m_rg(C6713_PLL_M_MULT_6))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_PLL_M_MULT_IS_6			(C6713_get_pll_m_rg() == C6713_PLL_M_MULT_6)
#define C6713_PLL_M_MULT_IS_7			(C6713_get_pll_m_rg() == C6713_PLL_M_MULT_7)



//------------ C6713 PLL controller prescaler divider 0 register (PLL_DIV0) macros
// Default state is /1 (0x8000) and it has not to be changed
#define C6713_PLL_DIV0_RG_BITMASK		0x801f

#define C6713_PLL_DIV0_1				0x8000

#define C6713_get_pll_div0_rg()			((*C6713_PLL_DIV0_RG) & C6713_PLL_DIV0_RG_BITMASK)
#define C6713_set_pll_div0_rg(v)		*C6713_PLL_DIV0_RG = (v & C6713_PLL_DIV0_RG_BITMASK)

#define C6713_SET_PLL_DIV0_1			(C6713_set_pll_div0_rg(C6713_PLL_DIV0_1))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_PLL_DIV0_IS_1				(C6713_get_pll_div0_rg() == C6713_PLL_DIV0_1)



//------------ C6713 PLL controller post-scaler divider 1 register (PLL_DIV1) macros
// Default state is /1 (0x8000) and it has not to be changed
// to achieve 300 MHz for DSP core clock (SYSCLK1) from PLLOUT clock (300 MHz)
#define C6713_PLL_DIV1_RG_BITMASK		0x801f

#define C6713_PLL_DIV1_1				0x8000

#define C6713_get_pll_div1_rg()			((*C6713_PLL_DIV1_RG) & C6713_PLL_DIV1_RG_BITMASK)
#define C6713_set_pll_div1_rg(v)		*C6713_PLL_DIV1_RG = (v & C6713_PLL_DIV1_RG_BITMASK)

#define C6713_SET_PLL_DIV1_1			(C6713_set_pll_div1_rg(C6713_PLL_DIV1_1))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_PLL_DIV1_IS_1				(C6713_get_pll_div1_rg() == C6713_PLL_DIV1_1)



//------------ C6713 PLL controller post-scaler divider 2 register (PLL_DIV2) macros
// Default state is /2 (0x8001) and it has not to be changed
// to achieve 150 MHz for Peripherals clock (SYSCLK2) from PLLOUT clock (300 MHz)
// SYSCLK2 must be programed to be half of the SYSCLK1 rate!!!
#define C6713_PLL_DIV2_RG_BITMASK		0x801f

#define C6713_PLL_DIV2_2				0x8001

#define C6713_get_pll_div2_rg()			((*C6713_PLL_DIV2_RG) & C6713_PLL_DIV2_RG_BITMASK)
#define C6713_set_pll_div2_rg(v)		*C6713_PLL_DIV2_RG = (v & C6713_PLL_DIV2_RG_BITMASK)

#define C6713_SET_PLL_DIV2_2			(C6713_set_pll_div2_rg(C6713_PLL_DIV2_2))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_PLL_DIV2_IS_2				(C6713_get_pll_div2_rg() == C6713_PLL_DIV2_2)



//------------ C6713 PLL controller post-scaler divider 3 register (PLL_DIV3) macros
// Default state is /2 (0x8001) and it has to be changed to /3 (0x8002)
// to achieve 100 MHz for EMIF clock (SYSCLK3) from PLLOUT clock (300 MHz)
#define C6713_PLL_DIV3_RG_BITMASK		0x801f

#define C6713_PLL_DIV3_2				0x8001
#define C6713_PLL_DIV3_3				0x8002
#define C6713_PLL_DIV3_OFF				0x1

#define C6713_get_pll_div3_rg()			((*C6713_PLL_DIV3_RG) & C6713_PLL_DIV3_RG_BITMASK)
#define C6713_set_pll_div3_rg(v)		*C6713_PLL_DIV3_RG = (v & C6713_PLL_DIV3_RG_BITMASK)

#define C6713_SET_PLL_DIV3_3			(C6713_set_pll_div3_rg(C6713_PLL_DIV3_3))
#define C6713_SET_PLL_DIV3_OFF			(C6713_set_pll_div3_rg(C6713_PLL_DIV3_OFF))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_PLL_DIV3_IS_2				(C6713_get_pll_div3_rg() == C6713_PLL_DIV3_2)
#define C6713_PLL_DIV3_IS_3				(C6713_get_pll_div3_rg() == C6713_PLL_DIV3_3)
#define C6713_PLL_DIV3_IS_OFF			(C6713_get_pll_div3_rg() == C6713_PLL_DIV3_OFF)



//------------ C6713 oscillator divider 1 register (PLL_OSCDIV1) macros
// Default state is /8 (0x8007) and it has to be changed to /1 (0x8000)
// to achieve pure CLKIN 50 MHz on CLKOUT3 pin (for testing purposes)
#define C6713_PLL_OSCDIV1_RG_BITMASK	0x801f

#define C6713_PLL_OSCDIV1_1				0x8000
#define C6713_PLL_OSCDIV1_8				0x8007

#define C6713_get_pll_oscdiv1_rg()		((*C6713_PLL_OSCDIV1_RG) & C6713_PLL_OSCDIV1_RG_BITMASK)
#define C6713_set_pll_oscdiv1_rg(v)		*C6713_PLL_OSCDIV1_RG = (v & C6713_PLL_OSCDIV1_RG_BITMASK)

#define C6713_SET_PLL_OSCDIV1_1			(C6713_set_pll_oscdiv1_rg(C6713_PLL_OSCDIV1_1))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_PLL_OSCDIV1_IS_1			(C6713_get_pll_oscdiv1_rg() == C6713_PLL_OSCDIV1_1)
#define C6713_PLL_OSCDIV1_IS_8			(C6713_get_pll_oscdiv1_rg() == C6713_PLL_OSCDIV1_8)



//----------------------------------------------------------------
//------------ C6713 I2C Ports Control registers macros ----------
// C6713B has two I2C modules and also includes two I2C serial ports
// This section contains only control and status registers which allow direct bit access

//------------ C6713 I2C0 Interrupt Enable register (I2C0_IER) macros
#define C6713_I2C0_IER_RG_BITMASK		0x1f

#define C6713_I2C0_IER_ICXRDY_BITMASK	0x10
#define C6713_I2C0_IER_ICRRDY_BITMASK	0x08
#define C6713_I2C0_IER_ARDY_BITMASK		0x04
#define C6713_I2C0_IER_NACK_BITMASK		0x02
#define C6713_I2C0_IER_AL_BITMASK		0x01

#define C6713_I2C0_IER_ICXRDY_EN		0x10
#define C6713_I2C0_IER_ICXRDY_DIS		0x0
#define C6713_I2C0_IER_ICRRDY_EN		0x08
#define C6713_I2C0_IER_ICRRDY_DIS		0x0
#define C6713_I2C0_IER_ARDY_EN			0x04
#define C6713_I2C0_IER_ARDY_DIS			0x0
#define C6713_I2C0_IER_NACK_EN			0x02
#define C6713_I2C0_IER_NACK_DIS			0x0
#define C6713_I2C0_IER_AL_EN			0x01
#define C6713_I2C0_IER_AL_DIS			0x0

	//access to C6713 I2C0 Interrupt Enable register
#define C6713_get_i2c0_ier_rg()			((*C6713_I2C0_IER_RG) & C6713_I2C0_IER_RG_BITMASK)
#define C6713_set_i2c0_ier_rg(v)		*C6713_I2C0_IER_RG = (v & C6713_I2C0_IER_RG_BITMASK)

	// dedicated bit specific macros
#define C6713_get_i2c0_ier_icxrdy()		(C6713_get_i2c0_ier_rg() & C6713_I2C0_IER_ICXRDY_BITMASK)
#define C6713_set_i2c0_ier_icxrdy(v)	(C6713_set_i2c0_ier_rg((C6713_get_i2c0_ier_rg() & ~C6713_I2C0_IER_ICXRDY_BITMASK) | (v & C6713_I2C0_IER_ICXRDY_BITMASK)))
#define C6713_get_i2c0_ier_icrrdy()		(C6713_get_i2c0_ier_rg() & C6713_I2C0_IER_ICRRDY_BITMASK)
#define C6713_set_i2c0_ier_icrrdy(v)	(C6713_set_i2c0_ier_rg((C6713_get_i2c0_ier_rg() & ~C6713_I2C0_IER_ICRRDY_BITMASK) | (v & C6713_I2C0_IER_ICRRDY_BITMASK)))
#define C6713_get_i2c0_ier_ardy()		(C6713_get_i2c0_ier_rg() & C6713_I2C0_IER_ARDY_BITMASK)
#define C6713_set_i2c0_ier_ardy(v)		(C6713_set_i2c0_ier_rg((C6713_get_i2c0_ier_rg() & ~C6713_I2C0_IER_ARDY_BITMASK) | (v & C6713_I2C0_IER_ARDY_BITMASK)))
#define C6713_get_i2c0_ier_nack()		(C6713_get_i2c0_ier_rg() & C6713_I2C0_IER_NACK_BITMASK)
#define C6713_set_i2c0_ier_nack(v)		(C6713_set_i2c0_ier_rg((C6713_get_i2c0_ier_rg() & ~C6713_I2C0_IER_NACK_BITMASK) | (v & C6713_I2C0_IER_NACK_BITMASK)))
#define C6713_get_i2c0_ier_al()			(C6713_get_i2c0_ier_rg() & C6713_I2C0_IER_AL_BITMASK)
#define C6713_set_i2c0_ier_al(v)		(C6713_set_i2c0_ier_rg((C6713_get_i2c0_ier_rg() & ~C6713_I2C0_IER_AL_BITMASK) | (v & C6713_I2C0_IER_AL_BITMASK)))

	// direct bit set macros
#define C6713_SET_I2C0_IER_ICXRDY_DIS	(C6713_set_i2c0_ier_icxrdy(C6713_I2C0_IER_ICXRDY_DIS))
#define C6713_SET_I2C0_IER_ICXRDY_EN	(C6713_set_i2c0_ier_icxrdy(C6713_I2C0_IER_ICXRDY_EN))
#define C6713_SET_I2C0_IER_ICRRDY_DIS	(C6713_set_i2c0_ier_icrrdy(C6713_I2C0_IER_ICRRDY_DIS))
#define C6713_SET_I2C0_IER_ICRRDY_EN	(C6713_set_i2c0_ier_icrrdy(C6713_I2C0_IER_ICRRDY_EN))
#define C6713_SET_I2C0_IER_ARDY_DIS		(C6713_set_i2c0_ier_ardy(C6713_I2C0_IER_ARDY_DIS))
#define C6713_SET_I2C0_IER_ARDY_EN		(C6713_set_i2c0_ier_ardy(C6713_I2C0_IER_ARDY_EN))
#define C6713_SET_I2C0_IER_NACK_DIS		(C6713_set_i2c0_ier_nack(C6713_I2C0_IER_NACK_DIS))
#define C6713_SET_I2C0_IER_NACK_EN		(C6713_set_i2c0_ier_nack(C6713_I2C0_IER_NACK_EN))
#define C6713_SET_I2C0_IER_AL_DIS		(C6713_set_i2c0_ier_al(C6713_I2C0_IER_AL_DIS))
#define C6713_SET_I2C0_IER_AL_EN		(C6713_set_i2c0_ier_al(C6713_I2C0_IER_AL_EN))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_I2C0_IER_ICXRDY_IS_EN		(C6713_get_i2c0_ier_icxrdy() == C6713_I2C0_IER_ICXRDY_EN)
#define C6713_I2C0_IER_ICRRDY_IS_EN		(C6713_get_i2c0_ier_icrrdy() == C6713_I2C0_IER_ICRRDY_EN)
#define C6713_I2C0_IER_ARDY_IS_EN		(C6713_get_i2c0_ier_ardy() == C6713_I2C0_IER_ARDY_EN)
#define C6713_I2C0_IER_NACK_IS_EN		(C6713_get_i2c0_ier_nack() == C6713_I2C0_IER_NACK_EN)
#define C6713_I2C0_IER_AL_IS_EN			(C6713_get_i2c0_ier_al() == C6713_I2C0_IER_AL_EN)



//------------ C6713 I2C0 Status register (I2C0_STR) macros ------
// This register contains read-only bits and bits, writing 1 to it clear its value
#define C6713_I2C0_STR_RG_BITMASK		0x3f1f

#define C6713_I2C0_STR_NACKSNT_BITMASK	0x2000
#define C6713_I2C0_STR_BB_BITMASK		0x1000
#define C6713_I2C0_STR_RSFULL_BITMASK	0x0800
#define C6713_I2C0_STR_XSMT_BITMASK		0x0400
#define C6713_I2C0_STR_AAS_BITMASK		0x0200
#define C6713_I2C0_STR_AD0_BITMASK		0x0100
#define C6713_I2C0_STR_ICXRDY_BITMASK	0x0010
#define C6713_I2C0_STR_ICRRDY_BITMASK	0x0008
#define C6713_I2C0_STR_ARDY_BITMASK		0x0004
#define C6713_I2C0_STR_NACK_BITMASK		0x0002
#define C6713_I2C0_STR_AL_BITMASK		0x0001

#define C6713_I2C0_STR_NACKSNT_ON		0x2000
#define C6713_I2C0_STR_NACKSNT_OFF		0x0
#define C6713_I2C0_STR_BB_ON			0x1000
#define C6713_I2C0_STR_BB_OFF			0x0
#define C6713_I2C0_STR_RSFULL_ON		0x0800
#define C6713_I2C0_STR_RSFULL_OFF		0x0
#define C6713_I2C0_STR_XSMT_ON			0x0400
#define C6713_I2C0_STR_XSMT_OFF			0x0
#define C6713_I2C0_STR_AAS_ON			0x0200
#define C6713_I2C0_STR_AAS_OFF			0x0
#define C6713_I2C0_STR_AD0_ON			0x0100
#define C6713_I2C0_STR_AD0_OFF			0x0
#define C6713_I2C0_STR_ICXRDY_ON		0x0010
#define C6713_I2C0_STR_ICXRDY_OFF		0x0
#define C6713_I2C0_STR_ICRRDY_ON		0x0008
#define C6713_I2C0_STR_ICRRDY_OFF		0x0
#define C6713_I2C0_STR_ARDY_ON			0x0004
#define C6713_I2C0_STR_ARDY_OFF			0x0
#define C6713_I2C0_STR_NACK_ON			0x0002
#define C6713_I2C0_STR_NACK_OFF			0x0
#define C6713_I2C0_STR_AL_ON			0x0001
#define C6713_I2C0_STR_AL_OFF			0x0

	//access to C6713 I2C0 Status register
#define C6713_get_i2c0_str_rg()			((*C6713_I2C0_STR_RG) & C6713_I2C0_STR_RG_BITMASK)
#define C6713_set_i2c0_str_rg(v)		*C6713_I2C0_STR_RG = (v & C6713_I2C0_STR_RG_BITMASK)

	// dedicated bit specific macros
#define C6713_get_i2c0_str_nacksnt()	(C6713_get_i2c0_str_rg() & C6713_I2C0_STR_NACKSNT_BITMASK)
#define C6713_set_i2c0_str_nacksnt(v)	(C6713_set_i2c0_str_rg((C6713_get_i2c0_str_rg() & ~C6713_I2C0_STR_NACKSNT_BITMASK) | (v & C6713_I2C0_STR_NACKSNT_BITMASK)))
#define C6713_get_i2c0_str_bb()			(C6713_get_i2c0_str_rg() & C6713_I2C0_STR_BB_BITMASK)
#define C6713_set_i2c0_str_bb(v)		(C6713_set_i2c0_str_rg((C6713_get_i2c0_str_rg() & ~C6713_I2C0_STR_BB_BITMASK) | (v & C6713_I2C0_STR_BB_BITMASK)))
#define C6713_get_i2c0_str_rsfull()		(C6713_get_i2c0_str_rg() & C6713_I2C0_STR_RSFULL_BITMASK)
#define C6713_get_i2c0_str_xsmt()		(C6713_get_i2c0_str_rg() & C6713_I2C0_STR_XSMT_BITMASK)
#define C6713_get_i2c0_str_aas()		(C6713_get_i2c0_str_rg() & C6713_I2C0_STR_AAS_BITMASK)
#define C6713_get_i2c0_str_ad0()		(C6713_get_i2c0_str_rg() & C6713_I2C0_STR_AD0_BITMASK)
#define C6713_get_i2c0_str_icxrdy()		(C6713_get_i2c0_str_rg() & C6713_I2C0_STR_ICXRDY_BITMASK)
#define C6713_set_i2c0_str_icxrdy(v)	(C6713_set_i2c0_str_rg((C6713_get_i2c0_str_rg() & ~C6713_I2C0_STR_ICXRDY_BITMASK) | (v & C6713_I2C0_STR_ICXRDY_BITMASK)))
#define C6713_get_i2c0_str_icrrdy()		(C6713_get_i2c0_str_rg() & C6713_I2C0_STR_ICRRDY_BITMASK)
#define C6713_set_i2c0_str_icrrdy(v)	(C6713_set_i2c0_str_rg((C6713_get_i2c0_str_rg() & ~C6713_I2C0_STR_ICRRDY_BITMASK) | (v & C6713_I2C0_STR_ICRRDY_BITMASK)))
#define C6713_get_i2c0_str_ardy()		(C6713_get_i2c0_str_rg() & C6713_I2C0_STR_ARDY_BITMASK)
#define C6713_set_i2c0_str_ardy(v)		(C6713_set_i2c0_str_rg((C6713_get_i2c0_str_rg() & ~C6713_I2C0_STR_ARDY_BITMASK) | (v & C6713_I2C0_STR_ARDY_BITMASK)))
#define C6713_get_i2c0_str_nack()		(C6713_get_i2c0_str_rg() & C6713_I2C0_STR_NACK_BITMASK)
#define C6713_set_i2c0_str_nack(v)		(C6713_set_i2c0_str_rg((C6713_get_i2c0_str_rg() & ~C6713_I2C0_STR_NACK_BITMASK) | (v & C6713_I2C0_STR_NACK_BITMASK)))
#define C6713_get_i2c0_str_al()			(C6713_get_i2c0_str_rg() & C6713_I2C0_STR_AL_BITMASK)
#define C6713_set_i2c0_str_al(v)		(C6713_set_i2c0_str_rg((C6713_get_i2c0_str_rg() & ~C6713_I2C0_STR_AL_BITMASK) | (v & C6713_I2C0_STR_AL_BITMASK)))

	// direct bit set macros
#define C6713_CLEAR_I2C0_STR_NACKSNT	(C6713_set_i2c0_str_nacksnt(C6713_I2C0_STR_NACKSNT_ON))
#define C6713_CLEAR_I2C0_STR_BB			(C6713_set_i2c0_str_bb(C6713_I2C0_STR_BB_ON))
#define C6713_CLEAR_I2C0_STR_ICXRDY		(C6713_set_i2c0_str_icxrdy(C6713_I2C0_STR_ICXRDY_ON))
#define C6713_CLEAR_I2C0_STR_ICRRDY		(C6713_set_i2c0_str_icrrdy(C6713_I2C0_STR_ICRRDY_ON))
#define C6713_CLEAR_I2C0_STR_ARDY		(C6713_set_i2c0_str_ardy(C6713_I2C0_STR_ARDY_ON))
#define C6713_CLEAR_I2C0_STR_NACK		(C6713_set_i2c0_str_nack(C6713_I2C0_STR_NACK_ON))
#define C6713_CLEAR_I2C0_STR_AL			(C6713_set_i2c0_str_al(C6713_I2C0_STR_AL_ON))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_I2C0_STR_NACKSNT_IS_ON	(C6713_get_i2c0_str_nacksnt() == C6713_I2C0_STR_NACKSNT_ON)
#define C6713_I2C0_STR_BB_IS_ON			(C6713_get_i2c0_str_bb() == C6713_I2C0_STR_BB_ON)
#define C6713_I2C0_STR_RSFULL_IS_ON		(C6713_get_i2c0_str_rsfull() == C6713_I2C0_STR_RSFULL_ON)
#define C6713_I2C0_STR_XSMT_IS_ON		(C6713_get_i2c0_str_xsmt() == C6713_I2C0_STR_XSMT_ON)
#define C6713_I2C0_STR_AAS_IS_ON		(C6713_get_i2c0_str_aas() == C6713_I2C0_STR_AAS_ON)
#define C6713_I2C0_STR_AD0_IS_ON		(C6713_get_i2c0_str_ad0() == C6713_I2C0_STR_AD0_ON)
#define C6713_I2C0_STR_ICXRDY_IS_ON		(C6713_get_i2c0_str_icxrdy() == C6713_I2C0_STR_ICXRDY_ON)
#define C6713_I2C0_STR_ICRRDY_IS_ON		(C6713_get_i2c0_str_icrrdy() == C6713_I2C0_STR_ICRRDY_ON)
#define C6713_I2C0_STR_ARDY_IS_ON		(C6713_get_i2c0_str_ardy() == C6713_I2C0_STR_ARDY_ON)
#define C6713_I2C0_STR_NACK_IS_ON		(C6713_get_i2c0_str_nack() == C6713_I2C0_STR_NACK_ON)
#define C6713_I2C0_STR_AL_IS_ON			(C6713_get_i2c0_str_al() == C6713_I2C0_STR_AL_ON)



//------------ C6713 I2C0 Mode register (I2C0_MDR) macros --------
#define C6713_I2C0_MDR_RG_BITMASK		0xefff

#define C6713_I2C0_MDR_NACKMOD_BITMASK	0x8000
#define C6713_I2C0_MDR_FREE_BITMASK		0x4000
#define C6713_I2C0_MDR_STT_BITMASK		0x2000
#define C6713_I2C0_MDR_STP_BITMASK		0x0800
#define C6713_I2C0_MDR_MST_BITMASK		0x0400
#define C6713_I2C0_MDR_TRX_BITMASK		0x0200
#define C6713_I2C0_MDR_XA_BITMASK		0x0100
#define C6713_I2C0_MDR_RM_BITMASK		0x0080
#define C6713_I2C0_MDR_DLB_BITMASK		0x0040
#define C6713_I2C0_MDR_IRS_BITMASK		0x0020
#define C6713_I2C0_MDR_STB_BITMASK		0x0010
#define C6713_I2C0_MDR_FDF_BITMASK		0x0008
#define C6713_I2C0_MDR_BC_BITMASK		0x0007

#define C6713_I2C0_MDR_NACKMOD_ON		0x8000
#define C6713_I2C0_MDR_NACKMOD_OFF		0x0
#define C6713_I2C0_MDR_FREE_ON			0x4000
#define C6713_I2C0_MDR_FREE_OFF			0x0
#define C6713_I2C0_MDR_STT_ON			0x2000
#define C6713_I2C0_MDR_STT_OFF			0x0
#define C6713_I2C0_MDR_STP_ON			0x0800
#define C6713_I2C0_MDR_STP_OFF			0x0
#define C6713_I2C0_MDR_MST_ON			0x0400
#define C6713_I2C0_MDR_MST_OFF			0x0
#define C6713_I2C0_MDR_TRX_ON			0x0200
#define C6713_I2C0_MDR_TRX_OFF			0x0
#define C6713_I2C0_MDR_XA_ON			0x0100
#define C6713_I2C0_MDR_XA_OFF			0x0
#define C6713_I2C0_MDR_RM_ON			0x0080
#define C6713_I2C0_MDR_RM_OFF			0x0
#define C6713_I2C0_MDR_DLB_ON			0x0040
#define C6713_I2C0_MDR_DLB_OFF			0x0
#define C6713_I2C0_MDR_IRS_ON			0x0020
#define C6713_I2C0_MDR_IRS_OFF			0x0
#define C6713_I2C0_MDR_STB_ON			0x0010
#define C6713_I2C0_MDR_STB_OFF			0x0
#define C6713_I2C0_MDR_FDF_ON			0x0008
#define C6713_I2C0_MDR_FDF_OFF			0x0
#define C6713_I2C0_MDR_BC_8BIT			0x0
#define C6713_I2C0_MDR_BC_1BIT			0x1
#define C6713_I2C0_MDR_BC_2BIT			0x2
#define C6713_I2C0_MDR_BC_3BIT			0x3
#define C6713_I2C0_MDR_BC_4BIT			0x4
#define C6713_I2C0_MDR_BC_5BIT			0x5
#define C6713_I2C0_MDR_BC_6BIT			0x6
#define C6713_I2C0_MDR_BC_7BIT			0x7

	//access to C6713 I2C0 Mode register
#define C6713_get_i2c0_mdr_rg()			((*C6713_I2C0_MDR_RG) & C6713_I2C0_MDR_RG_BITMASK)
#define C6713_set_i2c0_mdr_rg(v)		*C6713_I2C0_MDR_RG = (v & C6713_I2C0_MDR_RG_BITMASK)

	// dedicated bit specific macros
#define C6713_get_i2c0_mdr_nackmod()	(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_NACKMOD_BITMASK)
#define C6713_set_i2c0_mdr_nackmod(v)	(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_NACKMOD_BITMASK) | (v & C6713_I2C0_MDR_NACKMOD_BITMASK)))
#define C6713_get_i2c0_mdr_free()		(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_FREE_BITMASK)
#define C6713_set_i2c0_mdr_free(v)		(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_FREE_BITMASK) | (v & C6713_I2C0_MDR_FREE_BITMASK)))
#define C6713_get_i2c0_mdr_stt()		(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_STT_BITMASK)
#define C6713_set_i2c0_mdr_stt(v)		(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_STT_BITMASK) | (v & C6713_I2C0_MDR_STT_BITMASK)))
#define C6713_get_i2c0_mdr_stp()		(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_STP_BITMASK)
#define C6713_set_i2c0_mdr_stp(v)		(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_STP_BITMASK) | (v & C6713_I2C0_MDR_STP_BITMASK)))
#define C6713_get_i2c0_mdr_mst()		(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_MST_BITMASK)
#define C6713_set_i2c0_mdr_mst(v)		(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_MST_BITMASK) | (v & C6713_I2C0_MDR_MST_BITMASK)))
#define C6713_get_i2c0_mdr_trx()		(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_TRX_BITMASK)
#define C6713_set_i2c0_mdr_trx(v)		(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_TRX_BITMASK) | (v & C6713_I2C0_MDR_TRX_BITMASK)))
#define C6713_get_i2c0_mdr_xa()			(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_XA_BITMASK)
#define C6713_set_i2c0_mdr_xa(v)		(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_XA_BITMASK) | (v & C6713_I2C0_MDR_XA_BITMASK)))
#define C6713_get_i2c0_mdr_rm()			(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_RM_BITMASK)
#define C6713_set_i2c0_mdr_rm(v)		(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_RM_BITMASK) | (v & C6713_I2C0_MDR_RM_BITMASK)))
#define C6713_get_i2c0_mdr_dlb()		(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_DLB_BITMASK)
#define C6713_set_i2c0_mdr_dlb(v)		(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_DLB_BITMASK) | (v & C6713_I2C0_MDR_DLB_BITMASK)))
#define C6713_get_i2c0_mdr_irs()		(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_IRS_BITMASK)
#define C6713_set_i2c0_mdr_irs(v)		(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_IRS_BITMASK) | (v & C6713_I2C0_MDR_IRS_BITMASK)))
#define C6713_get_i2c0_mdr_stb()		(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_STB_BITMASK)
#define C6713_set_i2c0_mdr_stb(v)		(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_STB_BITMASK) | (v & C6713_I2C0_MDR_STB_BITMASK)))
#define C6713_get_i2c0_mdr_fdf()		(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_FDF_BITMASK)
#define C6713_set_i2c0_mdr_fdf(v)		(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_FDF_BITMASK) | (v & C6713_I2C0_MDR_FDF_BITMASK)))
#define C6713_get_i2c0_mdr_bc()			(C6713_get_i2c0_mdr_rg() & C6713_I2C0_MDR_BC_BITMASK)
#define C6713_set_i2c0_mdr_bc(v)		(C6713_set_i2c0_mdr_rg((C6713_get_i2c0_mdr_rg() & ~C6713_I2C0_MDR_BC_BITMASK) | (v & C6713_I2C0_MDR_BC_BITMASK)))

	// direct bit set macros
#define C6713_SET_I2C0_MDR_NACKMOD_OFF	(C6713_set_i2c0_mdr_nackmod(C6713_I2C0_MDR_NACKMOD_OFF))
#define C6713_SET_I2C0_MDR_NACKMOD_ON	(C6713_set_i2c0_mdr_nackmod(C6713_I2C0_MDR_NACKMOD_ON))
#define C6713_SET_I2C0_MDR_FREE_OFF		(C6713_set_i2c0_mdr_free(C6713_I2C0_MDR_FREE_OFF))
#define C6713_SET_I2C0_MDR_FREE_ON		(C6713_set_i2c0_mdr_free(C6713_I2C0_MDR_FREE_ON))
#define C6713_SET_I2C0_MDR_STT_OFF		(C6713_set_i2c0_mdr_stt(C6713_I2C0_MDR_STT_OFF))
#define C6713_SET_I2C0_MDR_STT_ON		(C6713_set_i2c0_mdr_stt(C6713_I2C0_MDR_STT_ON))
#define C6713_SET_I2C0_MDR_STP_OFF		(C6713_set_i2c0_mdr_stp(C6713_I2C0_MDR_STP_OFF))
#define C6713_SET_I2C0_MDR_STP_ON		(C6713_set_i2c0_mdr_stp(C6713_I2C0_MDR_STP_ON))
#define C6713_SET_I2C0_MDR_MST_OFF		(C6713_set_i2c0_mdr_mst(C6713_I2C0_MDR_MST_OFF))
#define C6713_SET_I2C0_MDR_MST_ON		(C6713_set_i2c0_mdr_mst(C6713_I2C0_MDR_MST_ON))
#define C6713_SET_I2C0_MDR_TRX_OFF		(C6713_set_i2c0_mdr_trx(C6713_I2C0_MDR_TRX_OFF))
#define C6713_SET_I2C0_MDR_TRX_ON		(C6713_set_i2c0_mdr_trx(C6713_I2C0_MDR_TRX_ON))
#define C6713_SET_I2C0_MDR_XA_OFF		(C6713_set_i2c0_mdr_xa(C6713_I2C0_MDR_XA_OFF))
#define C6713_SET_I2C0_MDR_XA_ON		(C6713_set_i2c0_mdr_xa(C6713_I2C0_MDR_XA_ON))
#define C6713_SET_I2C0_MDR_RM_OFF		(C6713_set_i2c0_mdr_rm(C6713_I2C0_MDR_RM_OFF))
#define C6713_SET_I2C0_MDR_RM_ON		(C6713_set_i2c0_mdr_rm(C6713_I2C0_MDR_RM_ON))
#define C6713_SET_I2C0_MDR_DLB_OFF		(C6713_set_i2c0_mdr_dlb(C6713_I2C0_MDR_DLB_OFF))
#define C6713_SET_I2C0_MDR_DLB_ON		(C6713_set_i2c0_mdr_dlb(C6713_I2C0_MDR_DLB_ON))
#define C6713_SET_I2C0_MDR_IRS_ON		(C6713_set_i2c0_mdr_irs(C6713_I2C0_MDR_IRS_OFF))
#define C6713_SET_I2C0_MDR_IRS_OFF		(C6713_set_i2c0_mdr_irs(C6713_I2C0_MDR_IRS_OFF))
#define C6713_SET_I2C0_MDR_STB_OFF		(C6713_set_i2c0_mdr_stb(C6713_I2C0_MDR_STB_OFF))
#define C6713_SET_I2C0_MDR_STB_ON		(C6713_set_i2c0_mdr_stb(C6713_I2C0_MDR_STB_ON))
#define C6713_SET_I2C0_MDR_FDF_OFF		(C6713_set_i2c0_mdr_fdf(C6713_I2C0_MDR_FDF_OFF))
#define C6713_SET_I2C0_MDR_FDF_ON		(C6713_set_i2c0_mdr_fdf(C6713_I2C0_MDR_FDF_ON))
#define C6713_SET_I2C0_MDR_BC_1BIT		(C6713_set_i2c0_mdr_bc(C6713_I2C0_MDR_BC_1BIT))
#define C6713_SET_I2C0_MDR_BC_2BIT		(C6713_set_i2c0_mdr_bc(C6713_I2C0_MDR_BC_2BIT))
#define C6713_SET_I2C0_MDR_BC_3BIT		(C6713_set_i2c0_mdr_bc(C6713_I2C0_MDR_BC_3BIT))
#define C6713_SET_I2C0_MDR_BC_4BIT		(C6713_set_i2c0_mdr_bc(C6713_I2C0_MDR_BC_4BIT))
#define C6713_SET_I2C0_MDR_BC_5BIT		(C6713_set_i2c0_mdr_bc(C6713_I2C0_MDR_BC_5BIT))
#define C6713_SET_I2C0_MDR_BC_6BIT		(C6713_set_i2c0_mdr_bc(C6713_I2C0_MDR_BC_6BIT))
#define C6713_SET_I2C0_MDR_BC_7BIT		(C6713_set_i2c0_mdr_bc(C6713_I2C0_MDR_BC_7BIT))
#define C6713_SET_I2C0_MDR_BC_8BIT		(C6713_set_i2c0_mdr_bc(C6713_I2C0_MDR_BC_8BIT))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_I2C0_MDR_NACKMOD_IS_ON	(C6713_get_i2c0_mdr_nackmod() == C6713_I2C0_MDR_NACKMOD_ON)
#define C6713_I2C0_MDR_FREE_IS_ON		(C6713_get_i2c0_mdr_free() == C6713_I2C0_MDR_FREE_ON)
#define C6713_I2C0_MDR_STT_IS_ON		(C6713_get_i2c0_mdr_stt() == C6713_I2C0_MDR_STT_ON)
#define C6713_I2C0_MDR_STP_IS_ON		(C6713_get_i2c0_mdr_stp() == C6713_I2C0_MDR_STP_ON)
#define C6713_I2C0_MDR_MST_IS_ON		(C6713_get_i2c0_mdr_mst() == C6713_I2C0_MDR_MST_ON)
#define C6713_I2C0_MDR_TRX_IS_ON		(C6713_get_i2c0_mdr_trx() == C6713_I2C0_MDR_TRX_ON)
#define C6713_I2C0_MDR_XA_IS_ON			(C6713_get_i2c0_mdr_xa() == C6713_I2C0_MDR_XA_ON)
#define C6713_I2C0_MDR_RM_IS_ON			(C6713_get_i2c0_mdr_rm() == C6713_I2C0_MDR_RM_ON)
#define C6713_I2C0_MDR_DLB_IS_ON		(C6713_get_i2c0_mdr_dlb() == C6713_I2C0_MDR_DLB_ON)
#define C6713_I2C0_MDR_IRS_IS_ON		(C6713_get_i2c0_mdr_irs() == C6713_I2C0_MDR_IRS_ON)
#define C6713_I2C0_MDR_STB_IS_ON		(C6713_get_i2c0_mdr_stb() == C6713_I2C0_MDR_STB_ON)
#define C6713_I2C0_MDR_FDF_IS_ON		(C6713_get_i2c0_mdr_fdf() == C6713_I2C0_MDR_FDF_ON)
#define C6713_I2C0_MDR_BC_IS_1BIT		(C6713_get_i2c0_mdr_bc() == C6713_I2C0_MDR_BC_1BIT)
#define C6713_I2C0_MDR_BC_IS_2BIT		(C6713_get_i2c0_mdr_bc() == C6713_I2C0_MDR_BC_2BIT)
#define C6713_I2C0_MDR_BC_IS_3BIT		(C6713_get_i2c0_mdr_bc() == C6713_I2C0_MDR_BC_3BIT)
#define C6713_I2C0_MDR_BC_IS_4BIT		(C6713_get_i2c0_mdr_bc() == C6713_I2C0_MDR_BC_4BIT)
#define C6713_I2C0_MDR_BC_IS_5BIT		(C6713_get_i2c0_mdr_bc() == C6713_I2C0_MDR_BC_5BIT)
#define C6713_I2C0_MDR_BC_IS_6BIT		(C6713_get_i2c0_mdr_bc() == C6713_I2C0_MDR_BC_6BIT)
#define C6713_I2C0_MDR_BC_IS_7BIT		(C6713_get_i2c0_mdr_bc() == C6713_I2C0_MDR_BC_7BIT)
#define C6713_I2C0_MDR_BC_IS_8BIT		(C6713_get_i2c0_mdr_bc() == C6713_I2C0_MDR_BC_8BIT)



//------------ C6713 I2C0 Interrupt Source register (I2C0_ISR) macros
// This register is read-only
#define C6713_I2C0_ISR_RG_BITMASK		0x7

#define C6713_I2C0_ISR_NONE				0x0
#define C6713_I2C0_ISR_AL				0x1
#define C6713_I2C0_ISR_NACK				0x2
#define C6713_I2C0_ISR_RAR				0x3
#define C6713_I2C0_ISR_RDR				0x4
#define C6713_I2C0_ISR_XDR				0x5

	//access to C6713 I2C0 Interrupt Source register
#define C6713_get_i2c0_isr_rg()			((*C6713_I2C0_ISR_RG) & C6713_I2C0_ISR_RG_BITMASK)

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_I2C0_ISR_IS_NONE			(C6713_get_i2c0_isr_rg() == C6713_I2C0_ISR_NONE)
#define C6713_I2C0_ISR_IS_AL			(C6713_get_i2c0_isr_rg() == C6713_I2C0_ISR_AL)
#define C6713_I2C0_ISR_IS_NACK			(C6713_get_i2c0_isr_rg() == C6713_I2C0_ISR_NACK)
#define C6713_I2C0_ISR_IS_RAR			(C6713_get_i2c0_isr_rg() == C6713_I2C0_ISR_RAR)
#define C6713_I2C0_ISR_IS_RDR			(C6713_get_i2c0_isr_rg() == C6713_I2C0_ISR_RDR)
#define C6713_I2C0_ISR_IS_XDR			(C6713_get_i2c0_isr_rg() == C6713_I2C0_ISR_XDR)



//------------ C6713 I2C0 Peripheral identification register 1 (I2C0_PID1) macros
#define C6713_I2C0_PID1_RG_BITMASK		0xffff

#define C6713_I2C0_PID1_C6713			0x0103

#define C6713_get_i2c0_pid1_rg()		((*C6713_I2C0_PID1_RG) & C6713_I2C0_PID1_RG_BITMASK)

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_I2C0_PID1_IS_C6713		(C6713_get_i2c0_pid1_rg() == C6713_I2C0_PID1_C6713)



//------------ C6713 I2C0 Peripheral identification register 2 (I2C0_PID2) macros
#define C6713_I2C0_PID2_RG_BITMASK		0xff

#define C6713_I2C0_PID2_I2C				0x05

#define C6713_get_i2c0_pid2_rg()		((*C6713_I2C0_PID2_RG) & C6713_I2C0_PID2_RG_BITMASK)

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_I2C0_PID2_IS_I2C			(C6713_get_i2c0_pid2_rg() == C6713_I2C0_PID2_I2C)



//------------ I2C1 Control registers ----------------------------
//------------ C6713 I2C1 Interrupt Enable register (I2C1_IER) macros
#define C6713_I2C1_IER_RG_BITMASK		0x1f

#define C6713_I2C1_IER_ICXRDY_BITMASK	0x10
#define C6713_I2C1_IER_ICRRDY_BITMASK	0x08
#define C6713_I2C1_IER_ARDY_BITMASK		0x04
#define C6713_I2C1_IER_NACK_BITMASK		0x02
#define C6713_I2C1_IER_AL_BITMASK		0x01

#define C6713_I2C1_IER_ICXRDY_EN		0x10
#define C6713_I2C1_IER_ICXRDY_DIS		0x0
#define C6713_I2C1_IER_ICRRDY_EN		0x08
#define C6713_I2C1_IER_ICRRDY_DIS		0x0
#define C6713_I2C1_IER_ARDY_EN			0x04
#define C6713_I2C1_IER_ARDY_DIS			0x0
#define C6713_I2C1_IER_NACK_EN			0x02
#define C6713_I2C1_IER_NACK_DIS			0x0
#define C6713_I2C1_IER_AL_EN			0x01
#define C6713_I2C1_IER_AL_DIS			0x0

	//access to C6713 I2C1 Interrupt Enable register
#define C6713_get_i2c1_ier_rg()			((*C6713_I2C1_IER_RG) & C6713_I2C1_IER_RG_BITMASK)
#define C6713_set_i2c1_ier_rg(v)		*C6713_I2C1_IER_RG = (v & C6713_I2C1_IER_RG_BITMASK)

	// dedicated bit specific macros
#define C6713_get_i2c1_ier_icxrdy()		(C6713_get_i2c1_ier_rg() & C6713_I2C1_IER_ICXRDY_BITMASK)
#define C6713_set_i2c1_ier_icxrdy(v)	(C6713_set_i2c1_ier_rg((C6713_get_i2c1_ier_rg() & ~C6713_I2C1_IER_ICXRDY_BITMASK) | (v & C6713_I2C1_IER_ICXRDY_BITMASK)))
#define C6713_get_i2c1_ier_icrrdy()		(C6713_get_i2c1_ier_rg() & C6713_I2C1_IER_ICRRDY_BITMASK)
#define C6713_set_i2c1_ier_icrrdy(v)	(C6713_set_i2c1_ier_rg((C6713_get_i2c1_ier_rg() & ~C6713_I2C1_IER_ICRRDY_BITMASK) | (v & C6713_I2C1_IER_ICRRDY_BITMASK)))
#define C6713_get_i2c1_ier_ardy()		(C6713_get_i2c1_ier_rg() & C6713_I2C1_IER_ARDY_BITMASK)
#define C6713_set_i2c1_ier_ardy(v)		(C6713_set_i2c1_ier_rg((C6713_get_i2c1_ier_rg() & ~C6713_I2C1_IER_ARDY_BITMASK) | (v & C6713_I2C1_IER_ARDY_BITMASK)))
#define C6713_get_i2c1_ier_nack()		(C6713_get_i2c1_ier_rg() & C6713_I2C1_IER_NACK_BITMASK)
#define C6713_set_i2c1_ier_nack(v)		(C6713_set_i2c1_ier_rg((C6713_get_i2c1_ier_rg() & ~C6713_I2C1_IER_NACK_BITMASK) | (v & C6713_I2C1_IER_NACK_BITMASK)))
#define C6713_get_i2c1_ier_al()			(C6713_get_i2c1_ier_rg() & C6713_I2C1_IER_AL_BITMASK)
#define C6713_set_i2c1_ier_al(v)		(C6713_set_i2c1_ier_rg((C6713_get_i2c1_ier_rg() & ~C6713_I2C1_IER_AL_BITMASK) | (v & C6713_I2C1_IER_AL_BITMASK)))

	// direct bit set macros
#define C6713_SET_I2C1_IER_ICXRDY_DIS	(C6713_set_i2c1_ier_icxrdy(C6713_I2C1_IER_ICXRDY_DIS))
#define C6713_SET_I2C1_IER_ICXRDY_EN	(C6713_set_i2c1_ier_icxrdy(C6713_I2C1_IER_ICXRDY_EN))
#define C6713_SET_I2C1_IER_ICRRDY_DIS	(C6713_set_i2c1_ier_icrrdy(C6713_I2C1_IER_ICRRDY_DIS))
#define C6713_SET_I2C1_IER_ICRRDY_EN	(C6713_set_i2c1_ier_icrrdy(C6713_I2C1_IER_ICRRDY_EN))
#define C6713_SET_I2C1_IER_ARDY_DIS		(C6713_set_i2c1_ier_ardy(C6713_I2C1_IER_ARDY_DIS))
#define C6713_SET_I2C1_IER_ARDY_EN		(C6713_set_i2c1_ier_ardy(C6713_I2C1_IER_ARDY_EN))
#define C6713_SET_I2C1_IER_NACK_DIS		(C6713_set_i2c1_ier_nack(C6713_I2C1_IER_NACK_DIS))
#define C6713_SET_I2C1_IER_NACK_EN		(C6713_set_i2c1_ier_nack(C6713_I2C1_IER_NACK_EN))
#define C6713_SET_I2C1_IER_AL_DIS		(C6713_set_i2c1_ier_al(C6713_I2C1_IER_AL_DIS))
#define C6713_SET_I2C1_IER_AL_EN		(C6713_set_i2c1_ier_al(C6713_I2C1_IER_AL_EN))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_I2C1_IER_ICXRDY_IS_EN		(C6713_get_i2c1_ier_icxrdy() == C6713_I2C1_IER_ICXRDY_EN)
#define C6713_I2C1_IER_ICRRDY_IS_EN		(C6713_get_i2c1_ier_icrrdy() == C6713_I2C1_IER_ICRRDY_EN)
#define C6713_I2C1_IER_ARDY_IS_EN		(C6713_get_i2c1_ier_ardy() == C6713_I2C1_IER_ARDY_EN)
#define C6713_I2C1_IER_NACK_IS_EN		(C6713_get_i2c1_ier_nack() == C6713_I2C1_IER_NACK_EN)
#define C6713_I2C1_IER_AL_IS_EN			(C6713_get_i2c1_ier_al() == C6713_I2C1_IER_AL_EN)



//------------ C6713 I2C1 Status register (I2C1_STR) macros ------
// This register contains read-only bits and bits, writing 1 to it clear its value
#define C6713_I2C1_STR_RG_BITMASK		0x3f1f

#define C6713_I2C1_STR_NACKSNT_BITMASK	0x2000
#define C6713_I2C1_STR_BB_BITMASK		0x1000
#define C6713_I2C1_STR_RSFULL_BITMASK	0x0800
#define C6713_I2C1_STR_XSMT_BITMASK		0x0400
#define C6713_I2C1_STR_AAS_BITMASK		0x0200
#define C6713_I2C1_STR_AD0_BITMASK		0x0100
#define C6713_I2C1_STR_ICXRDY_BITMASK	0x0010
#define C6713_I2C1_STR_ICRRDY_BITMASK	0x0008
#define C6713_I2C1_STR_ARDY_BITMASK		0x0004
#define C6713_I2C1_STR_NACK_BITMASK		0x0002
#define C6713_I2C1_STR_AL_BITMASK		0x0001

#define C6713_I2C1_STR_NACKSNT_ON		0x2000
#define C6713_I2C1_STR_NACKSNT_OFF		0x0
#define C6713_I2C1_STR_BB_ON			0x1000
#define C6713_I2C1_STR_BB_OFF			0x0
#define C6713_I2C1_STR_RSFULL_ON		0x0800
#define C6713_I2C1_STR_RSFULL_OFF		0x0
#define C6713_I2C1_STR_XSMT_ON			0x0400
#define C6713_I2C1_STR_XSMT_OFF			0x0
#define C6713_I2C1_STR_AAS_ON			0x0200
#define C6713_I2C1_STR_AAS_OFF			0x0
#define C6713_I2C1_STR_AD0_ON			0x0100
#define C6713_I2C1_STR_AD0_OFF			0x0
#define C6713_I2C1_STR_ICXRDY_ON		0x0010
#define C6713_I2C1_STR_ICXRDY_OFF		0x0
#define C6713_I2C1_STR_ICRRDY_ON		0x0008
#define C6713_I2C1_STR_ICRRDY_OFF		0x0
#define C6713_I2C1_STR_ARDY_ON			0x0004
#define C6713_I2C1_STR_ARDY_OFF			0x0
#define C6713_I2C1_STR_NACK_ON			0x0002
#define C6713_I2C1_STR_NACK_OFF			0x0
#define C6713_I2C1_STR_AL_ON			0x0001
#define C6713_I2C1_STR_AL_OFF			0x0

	//access to C6713 I2C1 Status register
#define C6713_get_i2c1_str_rg()			((*C6713_I2C1_STR_RG) & C6713_I2C1_STR_RG_BITMASK)
#define C6713_set_i2c1_str_rg(v)		*C6713_I2C1_STR_RG = (v & C6713_I2C1_STR_RG_BITMASK)

	// dedicated bit specific macros
#define C6713_get_i2c1_str_nacksnt()	(C6713_get_i2c1_str_rg() & C6713_I2C1_STR_NACKSNT_BITMASK)
#define C6713_set_i2c1_str_nacksnt(v)	(C6713_set_i2c1_str_rg((C6713_get_i2c1_str_rg() & ~C6713_I2C1_STR_NACKSNT_BITMASK) | (v & C6713_I2C1_STR_NACKSNT_BITMASK)))
#define C6713_get_i2c1_str_bb()			(C6713_get_i2c1_str_rg() & C6713_I2C1_STR_BB_BITMASK)
#define C6713_set_i2c1_str_bb(v)		(C6713_set_i2c1_str_rg((C6713_get_i2c1_str_rg() & ~C6713_I2C1_STR_BB_BITMASK) | (v & C6713_I2C1_STR_BB_BITMASK)))
#define C6713_get_i2c1_str_rsfull()		(C6713_get_i2c1_str_rg() & C6713_I2C1_STR_RSFULL_BITMASK)
#define C6713_get_i2c1_str_xsmt()		(C6713_get_i2c1_str_rg() & C6713_I2C1_STR_XSMT_BITMASK)
#define C6713_get_i2c1_str_aas()		(C6713_get_i2c1_str_rg() & C6713_I2C1_STR_AAS_BITMASK)
#define C6713_get_i2c1_str_ad0()		(C6713_get_i2c1_str_rg() & C6713_I2C1_STR_AD0_BITMASK)
#define C6713_get_i2c1_str_icxrdy()		(C6713_get_i2c1_str_rg() & C6713_I2C1_STR_ICXRDY_BITMASK)
#define C6713_set_i2c1_str_icxrdy(v)	(C6713_set_i2c1_str_rg((C6713_get_i2c1_str_rg() & ~C6713_I2C1_STR_ICXRDY_BITMASK) | (v & C6713_I2C1_STR_ICXRDY_BITMASK)))
#define C6713_get_i2c1_str_icrrdy()		(C6713_get_i2c1_str_rg() & C6713_I2C1_STR_ICRRDY_BITMASK)
#define C6713_set_i2c1_str_icrrdy(v)	(C6713_set_i2c1_str_rg((C6713_get_i2c1_str_rg() & ~C6713_I2C1_STR_ICRRDY_BITMASK) | (v & C6713_I2C1_STR_ICRRDY_BITMASK)))
#define C6713_get_i2c1_str_ardy()		(C6713_get_i2c1_str_rg() & C6713_I2C1_STR_ARDY_BITMASK)
#define C6713_set_i2c1_str_ardy(v)		(C6713_set_i2c1_str_rg((C6713_get_i2c1_str_rg() & ~C6713_I2C1_STR_ARDY_BITMASK) | (v & C6713_I2C1_STR_ARDY_BITMASK)))
#define C6713_get_i2c1_str_nack()		(C6713_get_i2c1_str_rg() & C6713_I2C1_STR_NACK_BITMASK)
#define C6713_set_i2c1_str_nack(v)		(C6713_set_i2c1_str_rg((C6713_get_i2c1_str_rg() & ~C6713_I2C1_STR_NACK_BITMASK) | (v & C6713_I2C1_STR_NACK_BITMASK)))
#define C6713_get_i2c1_str_al()			(C6713_get_i2c1_str_rg() & C6713_I2C1_STR_AL_BITMASK)
#define C6713_set_i2c1_str_al(v)		(C6713_set_i2c1_str_rg((C6713_get_i2c1_str_rg() & ~C6713_I2C1_STR_AL_BITMASK) | (v & C6713_I2C1_STR_AL_BITMASK)))

	// direct bit set macros
#define C6713_CLEAR_I2C1_STR_NACKSNT	(C6713_set_i2c1_str_nacksnt(C6713_I2C1_STR_NACKSNT_ON))
#define C6713_CLEAR_I2C1_STR_BB			(C6713_set_i2c1_str_bb(C6713_I2C1_STR_BB_ON))
#define C6713_CLEAR_I2C1_STR_ICXRDY		(C6713_set_i2c1_str_icxrdy(C6713_I2C1_STR_ICXRDY_ON))
#define C6713_CLEAR_I2C1_STR_ICRRDY		(C6713_set_i2c1_str_icrrdy(C6713_I2C1_STR_ICRRDY_ON))
#define C6713_CLEAR_I2C1_STR_ARDY		(C6713_set_i2c1_str_ardy(C6713_I2C1_STR_ARDY_ON))
#define C6713_CLEAR_I2C1_STR_NACK		(C6713_set_i2c1_str_nack(C6713_I2C1_STR_NACK_ON))
#define C6713_CLEAR_I2C1_STR_AL			(C6713_set_i2c1_str_al(C6713_I2C1_STR_AL_ON))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_I2C1_STR_NACKSNT_IS_ON	(C6713_get_i2c1_str_nacksnt() == C6713_I2C1_STR_NACKSNT_ON)
#define C6713_I2C1_STR_BB_IS_ON			(C6713_get_i2c1_str_bb() == C6713_I2C1_STR_BB_ON)
#define C6713_I2C1_STR_RSFULL_IS_ON		(C6713_get_i2c1_str_rsfull() == C6713_I2C1_STR_RSFULL_ON)
#define C6713_I2C1_STR_XSMT_IS_ON		(C6713_get_i2c1_str_xsmt() == C6713_I2C1_STR_XSMT_ON)
#define C6713_I2C1_STR_AAS_IS_ON		(C6713_get_i2c1_str_aas() == C6713_I2C1_STR_AAS_ON)
#define C6713_I2C1_STR_AD0_IS_ON		(C6713_get_i2c1_str_ad0() == C6713_I2C1_STR_AD0_ON)
#define C6713_I2C1_STR_ICXRDY_IS_ON		(C6713_get_i2c1_str_icxrdy() == C6713_I2C1_STR_ICXRDY_ON)
#define C6713_I2C1_STR_ICRRDY_IS_ON		(C6713_get_i2c1_str_icrrdy() == C6713_I2C1_STR_ICRRDY_ON)
#define C6713_I2C1_STR_ARDY_IS_ON		(C6713_get_i2c1_str_ardy() == C6713_I2C1_STR_ARDY_ON)
#define C6713_I2C1_STR_NACK_IS_ON		(C6713_get_i2c1_str_nack() == C6713_I2C1_STR_NACK_ON)
#define C6713_I2C1_STR_AL_IS_ON			(C6713_get_i2c1_str_al() == C6713_I2C1_STR_AL_ON)



//------------ C6713 I2C1 Mode register (I2C1_MDR) macros --------
#define C6713_I2C1_MDR_RG_BITMASK		0xefff

#define C6713_I2C1_MDR_NACKMOD_BITMASK	0x8000
#define C6713_I2C1_MDR_FREE_BITMASK		0x4000
#define C6713_I2C1_MDR_STT_BITMASK		0x2000
#define C6713_I2C1_MDR_STP_BITMASK		0x0800
#define C6713_I2C1_MDR_MST_BITMASK		0x0400
#define C6713_I2C1_MDR_TRX_BITMASK		0x0200
#define C6713_I2C1_MDR_XA_BITMASK		0x0100
#define C6713_I2C1_MDR_RM_BITMASK		0x0080
#define C6713_I2C1_MDR_DLB_BITMASK		0x0040
#define C6713_I2C1_MDR_IRS_BITMASK		0x0020
#define C6713_I2C1_MDR_STB_BITMASK		0x0010
#define C6713_I2C1_MDR_FDF_BITMASK		0x0008
#define C6713_I2C1_MDR_BC_BITMASK		0x0007

#define C6713_I2C1_MDR_NACKMOD_ON		0x8000
#define C6713_I2C1_MDR_NACKMOD_OFF		0x0
#define C6713_I2C1_MDR_FREE_ON			0x4000
#define C6713_I2C1_MDR_FREE_OFF			0x0
#define C6713_I2C1_MDR_STT_ON			0x2000
#define C6713_I2C1_MDR_STT_OFF			0x0
#define C6713_I2C1_MDR_STP_ON			0x0800
#define C6713_I2C1_MDR_STP_OFF			0x0
#define C6713_I2C1_MDR_MST_ON			0x0400
#define C6713_I2C1_MDR_MST_OFF			0x0
#define C6713_I2C1_MDR_TRX_ON			0x0200
#define C6713_I2C1_MDR_TRX_OFF			0x0
#define C6713_I2C1_MDR_XA_ON			0x0100
#define C6713_I2C1_MDR_XA_OFF			0x0
#define C6713_I2C1_MDR_RM_ON			0x0080
#define C6713_I2C1_MDR_RM_OFF			0x0
#define C6713_I2C1_MDR_DLB_ON			0x0040
#define C6713_I2C1_MDR_DLB_OFF			0x0
#define C6713_I2C1_MDR_IRS_ON			0x0020
#define C6713_I2C1_MDR_IRS_OFF			0x0
#define C6713_I2C1_MDR_STB_ON			0x0010
#define C6713_I2C1_MDR_STB_OFF			0x0
#define C6713_I2C1_MDR_FDF_ON			0x0008
#define C6713_I2C1_MDR_FDF_OFF			0x0
#define C6713_I2C1_MDR_BC_8BIT			0x0
#define C6713_I2C1_MDR_BC_1BIT			0x1
#define C6713_I2C1_MDR_BC_2BIT			0x2
#define C6713_I2C1_MDR_BC_3BIT			0x3
#define C6713_I2C1_MDR_BC_4BIT			0x4
#define C6713_I2C1_MDR_BC_5BIT			0x5
#define C6713_I2C1_MDR_BC_6BIT			0x6
#define C6713_I2C1_MDR_BC_7BIT			0x7

	//access to C6713 I2C1 Mode register
#define C6713_get_i2c1_mdr_rg()			((*C6713_I2C1_MDR_RG) & C6713_I2C1_MDR_RG_BITMASK)
#define C6713_set_i2c1_mdr_rg(v)		*C6713_I2C1_MDR_RG = (v & C6713_I2C1_MDR_RG_BITMASK)

	// dedicated bit specific macros
#define C6713_get_i2c1_mdr_nackmod()	(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_NACKMOD_BITMASK)
#define C6713_set_i2c1_mdr_nackmod(v)	(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_NACKMOD_BITMASK) | (v & C6713_I2C1_MDR_NACKMOD_BITMASK)))
#define C6713_get_i2c1_mdr_free()		(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_FREE_BITMASK)
#define C6713_set_i2c1_mdr_free(v)		(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_FREE_BITMASK) | (v & C6713_I2C1_MDR_FREE_BITMASK)))
#define C6713_get_i2c1_mdr_stt()		(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_STT_BITMASK)
#define C6713_set_i2c1_mdr_stt(v)		(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_STT_BITMASK) | (v & C6713_I2C1_MDR_STT_BITMASK)))
#define C6713_get_i2c1_mdr_stp()		(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_STP_BITMASK)
#define C6713_set_i2c1_mdr_stp(v)		(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_STP_BITMASK) | (v & C6713_I2C1_MDR_STP_BITMASK)))
#define C6713_get_i2c1_mdr_mst()		(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_MST_BITMASK)
#define C6713_set_i2c1_mdr_mst(v)		(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_MST_BITMASK) | (v & C6713_I2C1_MDR_MST_BITMASK)))
#define C6713_get_i2c1_mdr_trx()		(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_TRX_BITMASK)
#define C6713_set_i2c1_mdr_trx(v)		(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_TRX_BITMASK) | (v & C6713_I2C1_MDR_TRX_BITMASK)))
#define C6713_get_i2c1_mdr_xa()			(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_XA_BITMASK)
#define C6713_set_i2c1_mdr_xa(v)		(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_XA_BITMASK) | (v & C6713_I2C1_MDR_XA_BITMASK)))
#define C6713_get_i2c1_mdr_rm()			(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_RM_BITMASK)
#define C6713_set_i2c1_mdr_rm(v)		(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_RM_BITMASK) | (v & C6713_I2C1_MDR_RM_BITMASK)))
#define C6713_get_i2c1_mdr_dlb()		(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_DLB_BITMASK)
#define C6713_set_i2c1_mdr_dlb(v)		(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_DLB_BITMASK) | (v & C6713_I2C1_MDR_DLB_BITMASK)))
#define C6713_get_i2c1_mdr_irs()		(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_IRS_BITMASK)
#define C6713_set_i2c1_mdr_irs(v)		(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_IRS_BITMASK) | (v & C6713_I2C1_MDR_IRS_BITMASK)))
#define C6713_get_i2c1_mdr_stb()		(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_STB_BITMASK)
#define C6713_set_i2c1_mdr_stb(v)		(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_STB_BITMASK) | (v & C6713_I2C1_MDR_STB_BITMASK)))
#define C6713_get_i2c1_mdr_fdf()		(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_FDF_BITMASK)
#define C6713_set_i2c1_mdr_fdf(v)		(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_FDF_BITMASK) | (v & C6713_I2C1_MDR_FDF_BITMASK)))
#define C6713_get_i2c1_mdr_bc()			(C6713_get_i2c1_mdr_rg() & C6713_I2C1_MDR_BC_BITMASK)
#define C6713_set_i2c1_mdr_bc(v)		(C6713_set_i2c1_mdr_rg((C6713_get_i2c1_mdr_rg() & ~C6713_I2C1_MDR_BC_BITMASK) | (v & C6713_I2C1_MDR_BC_BITMASK)))

	// direct bit set macros
#define C6713_SET_I2C1_MDR_NACKMOD_OFF	(C6713_set_i2c1_mdr_nackmod(C6713_I2C1_MDR_NACKMOD_OFF))
#define C6713_SET_I2C1_MDR_NACKMOD_ON	(C6713_set_i2c1_mdr_nackmod(C6713_I2C1_MDR_NACKMOD_ON))
#define C6713_SET_I2C1_MDR_FREE_OFF		(C6713_set_i2c1_mdr_free(C6713_I2C1_MDR_FREE_OFF))
#define C6713_SET_I2C1_MDR_FREE_ON		(C6713_set_i2c1_mdr_free(C6713_I2C1_MDR_FREE_ON))
#define C6713_SET_I2C1_MDR_STT_OFF		(C6713_set_i2c1_mdr_stt(C6713_I2C1_MDR_STT_OFF))
#define C6713_SET_I2C1_MDR_STT_ON		(C6713_set_i2c1_mdr_stt(C6713_I2C1_MDR_STT_ON))
#define C6713_SET_I2C1_MDR_STP_OFF		(C6713_set_i2c1_mdr_stp(C6713_I2C1_MDR_STP_OFF))
#define C6713_SET_I2C1_MDR_STP_ON		(C6713_set_i2c1_mdr_stp(C6713_I2C1_MDR_STP_ON))
#define C6713_SET_I2C1_MDR_MST_OFF		(C6713_set_i2c1_mdr_mst(C6713_I2C1_MDR_MST_OFF))
#define C6713_SET_I2C1_MDR_MST_ON		(C6713_set_i2c1_mdr_mst(C6713_I2C1_MDR_MST_ON))
#define C6713_SET_I2C1_MDR_TRX_OFF		(C6713_set_i2c1_mdr_trx(C6713_I2C1_MDR_TRX_OFF))
#define C6713_SET_I2C1_MDR_TRX_ON		(C6713_set_i2c1_mdr_trx(C6713_I2C1_MDR_TRX_ON))
#define C6713_SET_I2C1_MDR_XA_OFF		(C6713_set_i2c1_mdr_xa(C6713_I2C1_MDR_XA_OFF))
#define C6713_SET_I2C1_MDR_XA_ON		(C6713_set_i2c1_mdr_xa(C6713_I2C1_MDR_XA_ON))
#define C6713_SET_I2C1_MDR_RM_OFF		(C6713_set_i2c1_mdr_rm(C6713_I2C1_MDR_RM_OFF))
#define C6713_SET_I2C1_MDR_RM_ON		(C6713_set_i2c1_mdr_rm(C6713_I2C1_MDR_RM_ON))
#define C6713_SET_I2C1_MDR_DLB_OFF		(C6713_set_i2c1_mdr_dlb(C6713_I2C1_MDR_DLB_OFF))
#define C6713_SET_I2C1_MDR_DLB_ON		(C6713_set_i2c1_mdr_dlb(C6713_I2C1_MDR_DLB_ON))
#define C6713_SET_I2C1_MDR_IRS_ON		(C6713_set_i2c1_mdr_irs(C6713_I2C1_MDR_IRS_OFF))
#define C6713_SET_I2C1_MDR_IRS_OFF		(C6713_set_i2c1_mdr_irs(C6713_I2C1_MDR_IRS_OFF))
#define C6713_SET_I2C1_MDR_STB_OFF		(C6713_set_i2c1_mdr_stb(C6713_I2C1_MDR_STB_OFF))
#define C6713_SET_I2C1_MDR_STB_ON		(C6713_set_i2c1_mdr_stb(C6713_I2C1_MDR_STB_ON))
#define C6713_SET_I2C1_MDR_FDF_OFF		(C6713_set_i2c1_mdr_fdf(C6713_I2C1_MDR_FDF_OFF))
#define C6713_SET_I2C1_MDR_FDF_ON		(C6713_set_i2c1_mdr_fdf(C6713_I2C1_MDR_FDF_ON))
#define C6713_SET_I2C1_MDR_BC_1BIT		(C6713_set_i2c1_mdr_bc(C6713_I2C1_MDR_BC_1BIT))
#define C6713_SET_I2C1_MDR_BC_2BIT		(C6713_set_i2c1_mdr_bc(C6713_I2C1_MDR_BC_2BIT))
#define C6713_SET_I2C1_MDR_BC_3BIT		(C6713_set_i2c1_mdr_bc(C6713_I2C1_MDR_BC_3BIT))
#define C6713_SET_I2C1_MDR_BC_4BIT		(C6713_set_i2c1_mdr_bc(C6713_I2C1_MDR_BC_4BIT))
#define C6713_SET_I2C1_MDR_BC_5BIT		(C6713_set_i2c1_mdr_bc(C6713_I2C1_MDR_BC_5BIT))
#define C6713_SET_I2C1_MDR_BC_6BIT		(C6713_set_i2c1_mdr_bc(C6713_I2C1_MDR_BC_6BIT))
#define C6713_SET_I2C1_MDR_BC_7BIT		(C6713_set_i2c1_mdr_bc(C6713_I2C1_MDR_BC_7BIT))
#define C6713_SET_I2C1_MDR_BC_8BIT		(C6713_set_i2c1_mdr_bc(C6713_I2C1_MDR_BC_8BIT))

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_I2C1_MDR_NACKMOD_IS_ON	(C6713_get_i2c1_mdr_nackmod() == C6713_I2C1_MDR_NACKMOD_ON)
#define C6713_I2C1_MDR_FREE_IS_ON		(C6713_get_i2c1_mdr_free() == C6713_I2C1_MDR_FREE_ON)
#define C6713_I2C1_MDR_STT_IS_ON		(C6713_get_i2c1_mdr_stt() == C6713_I2C1_MDR_STT_ON)
#define C6713_I2C1_MDR_STP_IS_ON		(C6713_get_i2c1_mdr_stp() == C6713_I2C1_MDR_STP_ON)
#define C6713_I2C1_MDR_MST_IS_ON		(C6713_get_i2c1_mdr_mst() == C6713_I2C1_MDR_MST_ON)
#define C6713_I2C1_MDR_TRX_IS_ON		(C6713_get_i2c1_mdr_trx() == C6713_I2C1_MDR_TRX_ON)
#define C6713_I2C1_MDR_XA_IS_ON			(C6713_get_i2c1_mdr_xa() == C6713_I2C1_MDR_XA_ON)
#define C6713_I2C1_MDR_RM_IS_ON			(C6713_get_i2c1_mdr_rm() == C6713_I2C1_MDR_RM_ON)
#define C6713_I2C1_MDR_DLB_IS_ON		(C6713_get_i2c1_mdr_dlb() == C6713_I2C1_MDR_DLB_ON)
#define C6713_I2C1_MDR_IRS_IS_ON		(C6713_get_i2c1_mdr_irs() == C6713_I2C1_MDR_IRS_ON)
#define C6713_I2C1_MDR_STB_IS_ON		(C6713_get_i2c1_mdr_stb() == C6713_I2C1_MDR_STB_ON)
#define C6713_I2C1_MDR_FDF_IS_ON		(C6713_get_i2c1_mdr_fdf() == C6713_I2C1_MDR_FDF_ON)
#define C6713_I2C1_MDR_BC_IS_1BIT		(C6713_get_i2c1_mdr_bc() == C6713_I2C1_MDR_BC_1BIT)
#define C6713_I2C1_MDR_BC_IS_2BIT		(C6713_get_i2c1_mdr_bc() == C6713_I2C1_MDR_BC_2BIT)
#define C6713_I2C1_MDR_BC_IS_3BIT		(C6713_get_i2c1_mdr_bc() == C6713_I2C1_MDR_BC_3BIT)
#define C6713_I2C1_MDR_BC_IS_4BIT		(C6713_get_i2c1_mdr_bc() == C6713_I2C1_MDR_BC_4BIT)
#define C6713_I2C1_MDR_BC_IS_5BIT		(C6713_get_i2c1_mdr_bc() == C6713_I2C1_MDR_BC_5BIT)
#define C6713_I2C1_MDR_BC_IS_6BIT		(C6713_get_i2c1_mdr_bc() == C6713_I2C1_MDR_BC_6BIT)
#define C6713_I2C1_MDR_BC_IS_7BIT		(C6713_get_i2c1_mdr_bc() == C6713_I2C1_MDR_BC_7BIT)
#define C6713_I2C1_MDR_BC_IS_8BIT		(C6713_get_i2c1_mdr_bc() == C6713_I2C1_MDR_BC_8BIT)



//------------ C6713 I2C1 Interrupt Source register (I2C1_ISR) macros
// This register is read-only
#define C6713_I2C1_ISR_RG_BITMASK		0x7

#define C6713_I2C1_ISR_NONE				0x0
#define C6713_I2C1_ISR_AL				0x1
#define C6713_I2C1_ISR_NACK				0x2
#define C6713_I2C1_ISR_RAR				0x3
#define C6713_I2C1_ISR_RDR				0x4
#define C6713_I2C1_ISR_XDR				0x5

	//access to C6713 I2C1 Interrupt Source register
#define C6713_get_i2c1_isr_rg()			((*C6713_I2C1_ISR_RG) & C6713_I2C1_ISR_RG_BITMASK)

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_I2C1_ISR_IS_NONE			(C6713_get_i2c1_isr_rg() == C6713_I2C1_ISR_NONE)
#define C6713_I2C1_ISR_IS_AL			(C6713_get_i2c1_isr_rg() == C6713_I2C1_ISR_AL)
#define C6713_I2C1_ISR_IS_NACK			(C6713_get_i2c1_isr_rg() == C6713_I2C1_ISR_NACK)
#define C6713_I2C1_ISR_IS_RAR			(C6713_get_i2c1_isr_rg() == C6713_I2C1_ISR_RAR)
#define C6713_I2C1_ISR_IS_RDR			(C6713_get_i2c1_isr_rg() == C6713_I2C1_ISR_RDR)
#define C6713_I2C1_ISR_IS_XDR			(C6713_get_i2c1_isr_rg() == C6713_I2C1_ISR_XDR)



//------------ C6713 I2C1 Peripheral identification register 1 (I2C1_PID1) macros
#define C6713_I2C1_PID1_RG_BITMASK		0xffff

#define C6713_I2C1_PID1_C6713			0x0103

#define C6713_get_i2c1_pid1_rg()		((*C6713_I2C1_PID1_RG) & C6713_I2C1_PID1_RG_BITMASK)

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_I2C1_PID1_IS_C6713		(C6713_get_i2c1_pid1_rg() == C6713_I2C1_PID1_C6713)



//------------ C6713 I2C1 Peripheral identification register 2 (I2C1_PID2) macros
#define C6713_I2C1_PID2_RG_BITMASK		0xff

#define C6713_I2C1_PID2_I2C				0x05

#define C6713_get_i2c1_pid2_rg()		((*C6713_I2C1_PID2_RG) & C6713_I2C1_PID2_RG_BITMASK)

	// condition check macros (for use in IF() and other conditional operators)
#define C6713_I2C1_PID2_IS_I2C			(C6713_get_i2c1_pid2_rg() == C6713_I2C1_PID2_I2C)
//================================================================
#endif



#ifdef	__C6XXX_SELECT_C6416_DSP__
//============ C6416 DSP memory areas ============================

#define C6416_ONCHIP_RAM_SADDR			0x00000000
#define C6416_ONCHIP_RAM_EADDR			0x000fffff
#define C6416_ONCHIP_RAM_LEN			0x00100000

#define C6XXX_ONCHIP_RAM_SADDR			C6416_ONCHIP_RAM_SADDR
#define C6XXX_ONCHIP_RAM_EADDR			C6416_ONCHIP_RAM_EADDR
#define C6XXX_ONCHIP_RAM_LEN			C6416_ONCHIP_RAM_LEN


#define C6XXX_ONCHIP_L2RAM_SADDR		C6416_ONCHIP_RAM_SADDR
#define C6XXX_ONCHIP_L2RAM_EADDR		C6416_ONCHIP_RAM_EADDR
#define C6XXX_ONCHIP_L2RAM_LEN			C6416_ONCHIP_RAM_LEN

#define C6XXX_ONCHIP_PRAM_SADDR			C6416_ONCHIP_RAM_SADDR
#define C6XXX_ONCHIP_PRAM_EADDR			C6416_ONCHIP_RAM_EADDR
#define C6XXX_ONCHIP_PRAM_LEN			C6416_ONCHIP_RAM_LEN

#define C6XXX_ONCHIP_DRAM_SADDR			C6416_ONCHIP_RAM_SADDR
#define C6XXX_ONCHIP_DRAM_EADDR			C6416_ONCHIP_RAM_EADDR
#define C6XXX_ONCHIP_DRAM_LEN			C6416_ONCHIP_RAM_LEN


#define C6416_EMIFA_CE0_AREA_SADDR		0x80000000
#define C6416_EMIFA_CE0_AREA_EADDR		0x8fffffff
#define C6416_EMIFA_CE0_AREA_LEN		0x10000000

#define C6416_EMIFA_CE1_AREA_SADDR		0x90000000
#define C6416_EMIFA_CE1_AREA_EADDR		0x9fffffff
#define C6416_EMIFA_CE1_AREA_LEN		0x10000000

#define C6416_EMIFA_CE2_AREA_SADDR		0xa0000000
#define C6416_EMIFA_CE2_AREA_EADDR		0xafffffff
#define C6416_EMIFA_CE2_AREA_LEN		0x10000000

#define C6416_EMIFA_CE3_AREA_SADDR		0xb0000000
#define C6416_EMIFA_CE3_AREA_EADDR		0xbfffffff
#define C6416_EMIFA_CE3_AREA_LEN		0x10000000


#define C6XXX_EMIFA_CE0_AREA_SADDR		C6416_EMIFA_CE0_AREA_SADDR
#define C6XXX_EMIFA_CE0_AREA_EADDR		C6416_EMIFA_CE0_AREA_EADDR
#define C6XXX_EMIFA_CE0_AREA_LEN		C6416_EMIFA_CE0_AREA_LEN

#define C6XXX_EMIFA_CE1_AREA_SADDR		C6416_EMIFA_CE1_AREA_SADDR
#define C6XXX_EMIFA_CE1_AREA_EADDR		C6416_EMIFA_CE1_AREA_EADDR
#define C6XXX_EMIFA_CE1_AREA_LEN		C6416_EMIFA_CE1_AREA_LEN

#define C6XXX_EMIFA_CE2_AREA_SADDR		C6416_EMIFA_CE2_AREA_SADDR
#define C6XXX_EMIFA_CE2_AREA_EADDR		C6416_EMIFA_CE2_AREA_EADDR
#define C6XXX_EMIFA_CE2_AREA_LEN		C6416_EMIFA_CE2_AREA_LEN

#define C6XXX_EMIFA_CE3_AREA_SADDR		C6416_EMIFA_CE3_AREA_SADDR
#define C6XXX_EMIFA_CE3_AREA_EADDR		C6416_EMIFA_CE3_AREA_EADDR
#define C6XXX_EMIFA_CE3_AREA_LEN		C6416_EMIFA_CE3_AREA_LEN

#define C6XXX_CE0_AREA_SADDR			C6416_EMIFA_CE0_AREA_SADDR
#define C6XXX_CE0_AREA_EADDR			C6416_EMIFA_CE0_AREA_EADDR
#define C6XXX_CE0_AREA_LEN				C6416_EMIFA_CE0_AREA_LEN

#define C6XXX_CE1_AREA_SADDR			C6416_EMIFA_CE1_AREA_SADDR
#define C6XXX_CE1_AREA_EADDR			C6416_EMIFA_CE1_AREA_EADDR
#define C6XXX_CE1_AREA_LEN				C6416_EMIFA_CE1_AREA_LEN

#define C6XXX_CE2_AREA_SADDR			C6416_EMIFA_CE2_AREA_SADDR
#define C6XXX_CE2_AREA_EADDR			C6416_EMIFA_CE2_AREA_EADDR
#define C6XXX_CE2_AREA_LEN				C6416_EMIFA_CE2_AREA_LEN

#define C6XXX_CE3_AREA_SADDR			C6416_EMIFA_CE3_AREA_SADDR
#define C6XXX_CE3_AREA_EADDR			C6416_EMIFA_CE3_AREA_EADDR
#define C6XXX_CE3_AREA_LEN				C6416_EMIFA_CE3_AREA_LEN


#define C6416_EMIFB_CE0_AREA_SADDR		0x60000000
#define C6416_EMIFB_CE0_AREA_EADDR		0x63ffffff
#define C6416_EMIFB_CE0_AREA_LEN		0x04000000

#define C6416_EMIFB_CE1_AREA_SADDR		0x64000000
#define C6416_EMIFB_CE1_AREA_EADDR		0x67ffffff
#define C6416_EMIFB_CE1_AREA_LEN		0x04000000

#define C6416_EMIFB_CE2_AREA_SADDR		0x68000000
#define C6416_EMIFB_CE2_AREA_EADDR		0x6Bffffff
#define C6416_EMIFB_CE2_AREA_LEN		0x04000000

#define C6416_EMIFB_CE3_AREA_SADDR		0x6C000000
#define C6416_EMIFB_CE3_AREA_EADDR		0x6fffffff
#define C6416_EMIFB_CE3_AREA_LEN		0x04000000

#define C6XXX_EMIFB_CE0_AREA_SADDR		C6416_EMIFB_CE0_AREA_SADDR
#define C6XXX_EMIFB_CE0_AREA_EADDR		C6416_EMIFB_CE0_AREA_EADDR
#define C6XXX_EMIFB_CE0_AREA_LEN		C6416_EMIFB_CE0_AREA_LEN

#define C6XXX_EMIFB_CE1_AREA_SADDR		C6416_EMIFB_CE1_AREA_SADDR
#define C6XXX_EMIFB_CE1_AREA_EADDR		C6416_EMIFB_CE1_AREA_EADDR
#define C6XXX_EMIFB_CE1_AREA_LEN		C6416_EMIFB_CE1_AREA_LEN

#define C6XXX_EMIFB_CE2_AREA_SADDR		C6416_EMIFB_CE2_AREA_SADDR
#define C6XXX_EMIFB_CE2_AREA_EADDR		C6416_EMIFB_CE2_AREA_EADDR
#define C6XXX_EMIFB_CE2_AREA_LEN		C6416_EMIFB_CE2_AREA_LEN

#define C6XXX_EMIFB_CE3_AREA_SADDR		C6416_EMIFB_CE3_AREA_SADDR
#define C6XXX_EMIFB_CE3_AREA_EADDR		C6416_EMIFB_CE3_AREA_EADDR
#define C6XXX_EMIFB_CE3_AREA_LEN		C6416_EMIFB_CE3_AREA_LEN


#define C6416_MCBSP0_EDMA_DATA_AREA_SADDR	0x30000000
#define C6416_MCBSP0_EDMA_DATA_AREA_EADDR	0x33ffffff
#define C6416_MCBSP0_EDMA_DATA_AREA_LEN		0x04000000

#define C6416_MCBSP1_EDMA_DATA_AREA_SADDR	0x34000000
#define C6416_MCBSP1_EDMA_DATA_AREA_EADDR	0x37ffffff
#define C6416_MCBSP1_EDMA_DATA_AREA_LEN		0x04000000

#define C6416_MCBSP2_EDMA_DATA_AREA_SADDR	0x38000000
#define C6416_MCBSP2_EDMA_DATA_AREA_EADDR	0x3bffffff
#define C6416_MCBSP2_EDMA_DATA_AREA_LEN		0x04000000


#define C6XXX_MCBSP0_EDMA_DATA_AREA_SADDR	C6416_MCBSP0_EDMA_DATA_AREA_SADDR
#define C6XXX_MCBSP0_EDMA_DATA_AREA_EADDR	C6416_MCBSP0_EDMA_DATA_AREA_EADDR
#define C6XXX_MCBSP0_EDMA_DATA_AREA_LEN		C6416_MCBSP0_EDMA_DATA_AREA_LEN

#define C6XXX_MCBSP1_EDMA_DATA_AREA_SADDR	C6416_MCBSP1_EDMA_DATA_AREA_SADDR
#define C6XXX_MCBSP1_EDMA_DATA_AREA_EADDR	C6416_MCBSP1_EDMA_DATA_AREA_EADDR
#define C6XXX_MCBSP1_EDMA_DATA_AREA_LEN		C6416_MCBSP1_EDMA_DATA_AREA_LEN

#define C6XXX_MCBSP2_EDMA_DATA_AREA_SADDR	C6416_MCBSP2_EDMA_DATA_AREA_SADDR
#define C6XXX_MCBSP2_EDMA_DATA_AREA_EADDR	C6416_MCBSP2_EDMA_DATA_AREA_EADDR
#define C6XXX_MCBSP2_EDMA_DATA_AREA_LEN		C6416_MCBSP2_EDMA_DATA_AREA_LEN


#define C6416_ONCHIP_RG_AREA_SADDR		0x01800000	// peripheral regs
#define C6416_ONCHIP_RG_AREA_EADDR		0x01c3ffff
#define C6416_ONCHIP_RG_AREA_LEN		0x00440000

#define C6416_ONCHIP_RG_AREA2_SADDR		0x02000000	// QDMA reg area
#define C6416_ONCHIP_RG_AREA2_EADDR		0x02000033
#define C6416_ONCHIP_RG_AREA2_LEN		0x00000034


#define C6XXX_ONCHIP_RG_AREA_SADDR		C6416_ONCHIP_RG_AREA_SADDR
#define C6XXX_ONCHIP_RG_AREA_EADDR		C6416_ONCHIP_RG_AREA_EADDR
#define C6XXX_ONCHIP_RG_AREA_LEN		C6416_ONCHIP_RG_AREA_LEN	

#define C6XXX_ONCHIP_RG_AREA2_SADDR		C6416_ONCHIP_RG_AREA2_SADDR
#define C6XXX_ONCHIP_RG_AREA2_EADDR		C6416_ONCHIP_RG_AREA2_EADDR
#define C6XXX_ONCHIP_RG_AREA2_LEN		C6416_ONCHIP_RG_AREA2_LEN

//----------------------------------------------------------------
#endif



#ifdef	__C6XXX_SELECT_C6713_DSP__
//============ C6713 DSP memory areas ============================

//------------ C6713 memory areas --------------------------------
// Note, that C6713 DSP has L2 memory/cache of a 256K-Byte memory space
// that is shared between program and data space.
// 64K Bytes of the 256K Bytes (start address = 0x00030000) in L2 memory
// can be configured as mapped memory, cache, or combinations of the two.
// The remaining 192K Bytes (start address = 0x00000000) in L2 servers
// as mapped SRAM.

#define C6713_ONCHIP_RAM_SADDR			0x00000000
#define C6713_ONCHIP_RAM_EADDR			0x0002ffff
#define C6713_ONCHIP_RAM_LEN			0x00030000

#define C6XXX_ONCHIP_RAM_SADDR			C6713_ONCHIP_RAM_SADDR
#define C6XXX_ONCHIP_RAM_EADDR			C6713_ONCHIP_RAM_EADDR
#define C6XXX_ONCHIP_RAM_LEN			C6713_ONCHIP_RAM_LEN

#define C6XXX_ONCHIP_PRAM_SADDR			C6713_ONCHIP_RAM_SADDR
#define C6XXX_ONCHIP_PRAM_EADDR			C6713_ONCHIP_RAM_EADDR
#define C6XXX_ONCHIP_PRAM_LEN			C6713_ONCHIP_RAM_LEN

#define C6XXX_ONCHIP_DRAM_SADDR			C6713_ONCHIP_RAM_SADDR
#define C6XXX_ONCHIP_DRAM_EADDR			C6713_ONCHIP_RAM_EADDR
#define C6XXX_ONCHIP_DRAM_LEN			C6713_ONCHIP_RAM_LEN

#define C6713_ONCHIP_L2RAM_SADDR		0x00030000
#define C6713_ONCHIP_L2RAM_EADDR		0x0003ffff
#define C6713_ONCHIP_L2RAM_LEN			0x00010000

#define C6XXX_ONCHIP_L2RAM_SADDR		C6713_ONCHIP_L2RAM_SADDR
#define C6XXX_ONCHIP_L2RAM_EADDR		C6713_ONCHIP_L2RAM_EADDR
#define C6XXX_ONCHIP_L2RAM_LEN			C6713_ONCHIP_L2RAM_LEN


#define C6713_CE0_AREA_SADDR			0x80000000
#define C6713_CE0_AREA_EADDR			0x8fffffff
#define C6713_CE0_AREA_LEN				0x10000000

#define C6713_CE1_AREA_SADDR			0x90000000
#define C6713_CE1_AREA_EADDR			0x9fffffff
#define C6713_CE1_AREA_LEN				0x10000000

#define C6713_CE2_AREA_SADDR			0xa0000000
#define C6713_CE2_AREA_EADDR			0xafffffff
#define C6713_CE2_AREA_LEN				0x10000000

#define C6713_CE3_AREA_SADDR			0xb0000000
#define C6713_CE3_AREA_EADDR			0xbfffffff
#define C6713_CE3_AREA_LEN				0x10000000


#define C6XXX_CE0_AREA_SADDR			C6713_CE0_AREA_SADDR
#define C6XXX_CE0_AREA_EADDR			C6713_CE0_AREA_EADDR
#define C6XXX_CE0_AREA_LEN				C6713_CE0_AREA_LEN

#define C6XXX_CE1_AREA_SADDR			C6713_CE1_AREA_SADDR
#define C6XXX_CE1_AREA_EADDR			C6713_CE1_AREA_EADDR
#define C6XXX_CE1_AREA_LEN				C6713_CE1_AREA_LEN

#define C6XXX_CE2_AREA_SADDR			C6713_CE2_AREA_SADDR
#define C6XXX_CE2_AREA_EADDR			C6713_CE2_AREA_EADDR
#define C6XXX_CE2_AREA_LEN				C6713_CE2_AREA_LEN

#define C6XXX_CE3_AREA_SADDR			C6713_CE3_AREA_SADDR
#define C6XXX_CE3_AREA_EADDR			C6713_CE3_AREA_EADDR
#define C6XXX_CE3_AREA_LEN				C6713_CE3_AREA_LEN


#define C6713_MCBSP0_EDMA_DATA_AREA_SADDR		0x30000000
#define C6713_MCBSP0_EDMA_DATA_AREA_EADDR		0x33ffffff
#define C6713_MCBSP0_EDMA_DATA_AREA_LEN			0x04000000

#define C6713_MCBSP1_EDMA_DATA_AREA_SADDR		0x34000000
#define C6713_MCBSP1_EDMA_DATA_AREA_EADDR		0x37ffffff
#define C6713_MCBSP1_EDMA_DATA_AREA_LEN			0x04000000


#define C6XXX_MCBSP0_EDMA_DATA_AREA_SADDR		C6713_MCBSP0_EDMA_DATA_AREA_SADDR
#define C6XXX_MCBSP0_EDMA_DATA_AREA_EADDR		C6713_MCBSP0_EDMA_DATA_AREA_EADDR
#define C6XXX_MCBSP0_EDMA_DATA_AREA_LEN			C6713_MCBSP0_EDMA_DATA_AREA_LEN

#define C6XXX_MCBSP1_EDMA_DATA_AREA_SADDR		C6713_MCBSP1_EDMA_DATA_AREA_SADDR
#define C6XXX_MCBSP1_EDMA_DATA_AREA_EADDR		C6713_MCBSP1_EDMA_DATA_AREA_EADDR
#define C6XXX_MCBSP1_EDMA_DATA_AREA_LEN			C6713_MCBSP1_EDMA_DATA_AREA_LEN


#define C6713_MCASP0_EDMA_DATA_AREA_SADDR		0x3c000000
#define C6713_MCASP0_EDMA_DATA_AREA_EADDR		0x3c0fffff
#define C6713_MCASP0_EDMA_DATA_AREA_LEN			0x00100000

#define C6713_MCASP1_EDMA_DATA_AREA_SADDR		0x3c100000
#define C6713_MCASP1_EDMA_DATA_AREA_EADDR		0x3c1fffff
#define C6713_MCASP1_EDMA_DATA_AREA_LEN			0x00100000


#define C6XXX_MCASP0_EDMA_DATA_AREA_SADDR		C6713_MCASP0_EDMA_DATA_AREA_SADDR
#define C6XXX_MCASP0_EDMA_DATA_AREA_EADDR		C6713_MCASP0_EDMA_DATA_AREA_EADDR
#define C6XXX_MCASP0_EDMA_DATA_AREA_LEN			C6713X_MCASP0_EDMA_DATA_AREA_LEN

#define C6XXX_MCASP1_EDMA_DATA_AREA_SADDR		C6713_MCASP1_EDMA_DATA_AREA_SADDR
#define C6XXX_MCASP1_EDMA_DATA_AREA_EADDR		C6713_MCASP1_EDMA_DATA_AREA_EADDR
#define C6XXX_MCASP1_EDMA_DATA_AREA_LEN			C6713_MCASP1_EDMA_DATA_AREA_LEN


#define C6713_ONCHIP_RG_AREA_SADDR		0x01800000	// peripheral regs
#define C6713_ONCHIP_RG_AREA_EADDR		0x01bfffff
#define C6713_ONCHIP_RG_AREA_LEN		0x00400000

#define C6713_ONCHIP_RG_AREA2_SADDR		0x02000000	// QDMA reg area
#define C6713_ONCHIP_RG_AREA2_EADDR		0x02000033
#define C6713_ONCHIP_RG_AREA2_LEN		0x00000034


#define C6XXX_ONCHIP_RG_AREA_SADDR		C6713_ONCHIP_RG_AREA_SADDR
#define C6XXX_ONCHIP_RG_AREA_EADDR		C6713_ONCHIP_RG_AREA_EADDR
#define C6XXX_ONCHIP_RG_AREA_LEN		C6713_ONCHIP_RG_AREA_LEN

#define C6XXX_ONCHIP_RG_AREA2_SADDR		C6713_ONCHIP_RG_AREA2_SADDR
#define C6XXX_ONCHIP_RG_AREA2_EADDR		C6713_ONCHIP_RG_AREA2_EADDR
#define C6XXX_ONCHIP_RG_AREA2_LEN		C6713_ONCHIP_RG_AREA2_LEN

#endif
//================================================================

// This C-header file contains aliases for old general C6416 DSP definitions
#include "c6x_def_old_aliases.hxx"

#endif

