/********************************************************************************
	TORNADO-E2/6xxx (E2/6713) Second Generation E6xxx controllers DSP Utilities. Rev.1A1-6
	(C) MicroLAB Systems, 2007-2008

	File:	extended T2E6XXX API functions
	-----

	Notes:
	------
	1.	This C-header file is include file for TI C6000 compile tools,
		which is used with T2E6XXX_DSP.H C-header file.
********************************************************************************/

// check for this file has been already included
#ifndef	__T2E6XXX_DSP_AUX__
#define	__T2E6XXX_DSP_AUX__					1

//============================================================================
//======== extended T2E6XXX API functions defs/declarations (see below) ======

//------------ DSP initialization --------------------------------------------
// This function is used to configure DSP PLL controller and DSP EMIF registers for E2/6xxx board
// This function has a parameter which defines E2/6xxx board configuration
int T2E6XXX_init_dsp(unsigned dsp_init_cnf);

//------------ DSP on-chip peripherals (McBSPs, McASPs, I2C-1) configuration function
// This function is used to configure DSP on-chip serial ports (McBSPs, McASPs, I2C-1) for E2/6713 board
int T2E6XXX_set_dsp_ports_cnf(unsigned cnf_id);

//------------ FLASH PROGRAMMING CONTROL utilities ---------------------------
// General defs for FLASH chips
#define T2E6XXX_FLASH_MANUF_ID_AMD					0x01
#define T2E6XXX_FLASH_SECTOR_PROTECTED				1
#define T2E6XXX_FLASH_SECTOR_UNPROTECTED			0
#define T2E6XXX_FLASH_DATA_BITMASK					0xff

// AMD FLASH chips ID returned by the T2E6XXX_flash_info() API function
#define T2E6XXX_FLASH_DEV_ID_AMD_512KX8				0x4f	// AMD embedded 512Kx8 FLASH used in E2/6713 f/w rev.1A boards
#define T2E6XXX_FLASH_DEV_ID_AMD_1MX8				0x38	// AMD embedded 1Mx8 FLASH used in E2/6713 f/w rev.1A boards
#define T2E6XXX_FLASH_DEV_ID_AMD_8MX8				0x93	// AMD embedded 8Mx8 FLASH used in E2/6713 f/w rev.1A boards
#define T2E6XXX_FLASH_DEV_ID_AMD_64MX8_FIRST_CYCLE	0x7e	// AMD embedded 64Mx8 FLASH used in E2/6713 f/w rev.1A boards first cycle ID
#define T2E6XXX_FLASH_DEV_ID_AMD_64MX8				0x23	// AMD embedded 64Mx8 FLASH used in E2/6713 f/w rev.1A boards
#define T2E6XXX_FLASH_DEV_ID_AMD_64MX8_LAST_CYCLE	0x01	// AMD embedded 64Mx8 FLASH used in E2/6713 f/w rev.1A boards last cycle ID

// FLASH PROGRAMMING CONTROL functions
int T2E6XXX_get_flash_info(unsigned *manuf_id, unsigned *dev_id,unsigned *len,unsigned *sectors, unsigned *sector_len);
int T2E6XXX_get_flash_sector_wrprot(unsigned a);
int T2E6XXX_erase_flash_sector(unsigned a,unsigned vf);
int T2E6XXX_erase_flash_chip(unsigned vf);
int T2E6XXX_write_flash(unsigned a, unsigned d);
int T2E6XXX_read_flash(unsigned a);



//------------ General API functions -----------------------------------------
int T2E6XXX_get_last_err();
int T2E6XXX_get_err_flag();
int T2E6XXX_clear_err_flag();


//------------ Returned error codes ------------------------------------------
#define T2E6XXX_OK									0		// no errors
#define T2E6XXX_PARAM_ERR							-1		// erroneous function parameter
#define T2E6XXX_INVALID_HW_ERR						-2		// invalid H/W error (invalid E2/6xxx board, etc.)
#define T2E6XXX_HW_ERR								-3		// H/W error (error writing to the DSP external control registers, etc)
#define T2E6XXX_INCOMPATIBLE_HW_ERR					-4		// incompatible H/W error (the setting is not allowed on this board)
#define C6XXX_HW_ERR								-10		// error writing to C6xxx DSP on-chip registers
#define T2E6XXX_PLL_INIT_ERR						-20		// error during PLL configuration

#define T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR			-30		// ASIOX rev.D DCM is not installed
#define T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR		-31		// incompatible DSP ports configuration

#define T2E6XXX_FLASH_INV_DEV_ERR					-100	// unsupported FLASH device
#define T2E6XXX_FLASH_ERASE_ERR						-101	// FLASH erase error
#define T2E6XXX_FLASH_WR_ERR						-102	// FLASH write error
#define T2E6XXX_FLASH_CANNOT_WR_ERR					-103	// FLASH contents does not allow to write this data
#define T2E6XXX_FLASH_INV_RD_ERR					-104	// invalid FLASH read data during AUTO-SELECT
#define T2E6XXX_FLASH_XWRPROT_ERR					-105	// FLASH writes are disabled by on-board SWITCH or Host Controller
#define T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_ERR	-106	// Writes to FLASH 64Mx8 BOOT SECTOR are disabled by on-board SWITCH or Host Controller

//----------------------------------------------------------------------------



#if (!defined(__T2E6XXX_EXCLUDE_AUX_FUNCTIONS__) || defined(__T2E6XXX_INCLUDE_FLASH_CONTROL__))
/*------------ General extended API functions --------------------------------
	GENERAL EXTENDED API FUNCTIONS shall be included in case of any extended
	API functions have been included.

	General extended T2E6XXX API functions are used to handle the run-time
	errors for FLASH programming control and other extended API functions:
	T2E6XXX_get_last_err
	T2E6XXX_get_err_flag
	T2E6XXX_clear_err_flag

	Each function returns error code (<0). In case the function must also
	return data (as T2E6XXX_read_flash()), then data can be recognized in case
	returned code is >=0, and error is recognized in case returned code is
	<0.
*/

static int _T2E6XXX_last_err =0,
			_T2E6XXX_err_flag =0;


int T2E6XXX_get_last_err()
	// T2E6XXX_GET_LAST_ERR function returns error code of last executed API function.
{
	return(_T2E6XXX_last_err);
}


int T2E6XXX_get_err_flag()
	// T2E6XXX_GET_ERR_FLAG function returns status of ERR_FLAG for API
	// functions. ERR_FLAG is set by each API function in case
	// error has been detected. ERR_FLAG can be reset by
	// T2E6XXX_CLEAR_ERR_FLAG API function
{
	return(_T2E6XXX_err_flag);
}

int T2E6XXX_clear_err_flag()
{
	_T2E6XXX_err_flag = T2E6XXX_OFF;
	return(T2E6XXX_OK);
}

	// local/non-API function,
	// used on exit fm API functions in order to set error code
static int _T2E6XXX_set_err(int e)
{
	if (e < 0)
	{
		_T2E6XXX_err_flag = 1;
		_T2E6XXX_last_err = e;
	}
	else
		_T2E6XXX_last_err = T2E6XXX_OK;
	return(e);
}

//----------------------------------------------------------------------------
#endif



//----------------------------------------------------------------------------
/*=============== Extended T2E6XXX DSP API functions ==========================
 Extended T2E6XXX DSP API functions include functions for DSP PLL/EMIF and DSP ports configuration,
 and FLASH programming control. However, in order to reduce the size of DSP code
 and in order to exclude mutiple function body appearance, any of the Extended API
 functions can be included/excluded during the compilation process. Inclusion/exclusion
 of particular Extended API function is controled via global vars, which can be defined
 in user code to perferm a particular action:

	__T2E6XXX_EXCLUDE_AUX_FUNCTIONS__
		- if defined in user code, then the DSP initialization and DSP on-chip ports configuration
		  functions are excluded from the user source code. Default is INCLUDED.

	__T2E6XXX_INCLUDE_FLASH_CONTROL__
		- if defined in user code, then the FLASH PROGRAMMING CONTROL function
		  are included into the user source code. Default is EXCLUDED.
==============================================================================*/

#ifdef	__T2E6XXX_SELECT_E6713__

#ifndef	__T2E6XXX_EXCLUDE_AUX_FUNCTIONS__
//------------ DSP PLL/EMIF and DSP ports configuration functions ------------

/*------------ DSP initialization function -----------------------
 This function performs configuration of DSP PLL controller and DSP EMIF
 configiration registers in accordance with the E2/6xxx board type.

 The function parameter contains configuration conditions for particular E2/6xxx board using bit-fields.
 For E2/6713 the function parameter contains only one LSB and defines
 if auxillary EMIF Spread Spectrum Clock Oscillator (100 MHz) is used or not.
 If EMIF Spread Spectrum Clock Oscillator (100 MHz) is not used,
 EMIF clock is derived from DSP input clock through PLL configuration.
 In this case only one Clock generator (CLKIN = 50 MHz) is installed on E2/6713 board and PLL is configured
 to set DSP core clock (SYSCLK1) = 300 MHz (C6713B DSP), Peripherals clock (SYSCLK2) = 150 MHz,
 EMIF clock (SYSCLK3) = 100 MHz, Internal clock source for McASPs (AUXCLK) = 50 MHz (equal to CLKIN)
 and CLKOUT3 output clock = 50 MHz (for testing purposes).
 	If EMIF Spread Spectrum Clock Oscillator (100 MHz) is used,
 EMIF clock is derived from this external source (configured via C6713B on-chip DEVCFG device configuration
 register) and PLL is configured to set DSP core clock (SYSCLK1) = 300 MHz (C6713B DSP),
 Peripherals clock (SYSCLK2) = 150 MHz, Internal clock source for McASPs (AUXCLK) = 50 MHz (equal to CLKIN)
 and CLKOUT3 output clock = 50 MHz (for testing purposes).
 SYSCLK3 is disabled and EMIF clock is derived from ECLKIN input (100 MHz).

 By default on startup PLL is disabled and is in reset state, so DSP core is operated at CLKIN clock
 (for E2/6713 is 50 MHz), Peripheral clock (SYSCLK2) is CLKIN/2 (for E2/6713 is 25 MHz),
 EMIF clock ECLKOUT is CLKIN/2 (for E2/6713 is 25 MHz), AUXCLK (clock source for McASP0 and McASP1)
 is equal to CLKIN (for E2/6713 is 50 MHz).

 For more details about PLL configuration see C6XXX_DEF.H file.

 E2/6xxx boards may differ in SDRAM capacity installed,
 which results in different EMIF control register settings, so this function
 performs configuration of DSP EMIF configiration registers in accordance
 with the E2/6xxx board type.
-----------------------------------------------------------------------------*/

// For E2/6713 the function parameter contains only one LSB and defines
// if auxillary EMIF Spread Spectrum Clock Oscillator (100 MHz) is used or not.
#define T2E6713_DSP_INIT_CNF_SSCLK_BITMASK			0x1

#define T2E6713_EMIF_CLK_SEL_SSCLK					1
#define T2E6713_EMIF_CLK_SEL_PLL_CLK				0
//----------------------------------------------------------------------------

int T2E6XXX_init_dsp(unsigned dsp_init_cnf)
{
	int i;
	if (T2E6713_BOARD)
	{
		// Reset C6713B on-chip DEVCFG device configuration register to default state
		C6713_set_devcfg_periph_cfg(0x0);
		if (C6713_get_devcfg_periph_cfg() != 0x0)
			return(_T2E6XXX_set_err(C6XXX_HW_ERR));
		// Disable all DSP ports buffers via T2E6XXX_DSP_PORTS_CNTR_RG register
		T2E6XXX_set_dsp_ports_cntr_rg(0x0);
		if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x0)
			return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));

		// First of all check PLL PID for C6713B DSP
		if (!C6713_PLL_PID_IS_C6713)
			return(_T2E6XXX_set_err(T2E6XXX_INVALID_HW_ERR));
		// Wait for input clock will be stabilized
		while (!C6713_PLL_CSR_STABLE_IS_ON);
		// Set PLL_ENABLE off (bypass mode)
		C6713_SET_PLL_CSR_EN_OFF;
		if (C6713_PLL_CSR_EN_IS_ON)
			return(_T2E6XXX_set_err(T2E6XXX_PLL_INIT_ERR));
		// Wait 4 cycles of CLKIN clock signal
		for (i = 0; i < 4; i++);
		// Set PLL reset
		C6713_SET_PLL_CSR_RST_ON;
		if (!C6713_PLL_CSR_RST_IS_ON)
			return(_T2E6XXX_set_err(T2E6XXX_PLL_INIT_ERR));
		if ((dsp_init_cnf & T2E6713_DSP_INIT_CNF_SSCLK_BITMASK) == T2E6713_EMIF_CLK_SEL_SSCLK)
		{
			// In this case EMIF clock is derived from the external EMIF Spread Spectrum Clock Oscillator
			// Check if SSCLK_ID in T2E6XXX_SYS_CNF2_RG is T2E6XXX_SSCLK_ID_INSTALLED
			if (!T2E6XXX_SSCLK_ID_IS_INSTALLED)
				return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_HW_ERR));
			// Set EMIF clock source to external ECLKIN pin
			// via C6713B on-chip DEVCFG device configuration register
			C6713_SET_DEVCFG_EKSRC_ECLKIN;
			if (!C6713_DEVCFG_EKSRC_IS_ECLKIN)
				return(_T2E6XXX_set_err(C6XXX_HW_ERR));
			// Disable PLL_DIV3
			C6713_SET_PLL_DIV3_OFF;
			if (!C6713_PLL_DIV3_IS_OFF)
				return(_T2E6XXX_set_err(T2E6XXX_PLL_INIT_ERR));
		}
		else
		{
			// In this case EMIF clock is derived from the on-chip PLL
			// Set EMIF clock source to internal SYSCLK3 clock
			// via C6713B on-chip DEVCFG device configuration register
			C6713_SET_DEVCFG_EKSRC_SYSCLK3;
			if (C6713_DEVCFG_EKSRC_IS_ECLKIN)
				return(_T2E6XXX_set_err(C6XXX_HW_ERR));
			// Set appropriate values to PLL_DIV3 to achieve 100 MHz for EMIF clock (SYSCLK3)
			// from PLLOUT clock (300 MHz)
			C6713_SET_PLL_DIV3_3;
			if (!C6713_PLL_DIV3_IS_3)
				return(_T2E6XXX_set_err(T2E6XXX_PLL_INIT_ERR));
		}
		// Wait 16 cycles of CLKIN clock signal
		// Note that there must be wait states between accesses to PLLDIV1-3
		// Each wait state is 8 cycles of the slowest of the old and new SYSCLK1-3 clock rates.
		// The slowest clock rate is SYSCLK3 = CLKIN / 2 = 25 MHz, so each wait state is 16 cycles
		// of CLKIN clock signal (DSP core is operated at CLKIN clock)
		for (i = 0; i < 16; i++);
		// Check PLLDIV0 value (must be default 0x8000)
		if (!C6713_PLL_DIV0_IS_1)
			return(_T2E6XXX_set_err(T2E6XXX_PLL_INIT_ERR));
		// Set appropriate values to multiplier and OSCDIV control registers
		C6713_SET_PLL_M_MULT_6;
		if (!C6713_PLL_M_MULT_IS_6)
			return(_T2E6XXX_set_err(T2E6XXX_PLL_INIT_ERR));
		C6713_SET_PLL_OSCDIV1_1;
		if (!C6713_PLL_OSCDIV1_IS_1)
			return(_T2E6XXX_set_err(T2E6XXX_PLL_INIT_ERR));
		// Check PLLDIV1 value (must be default 0x8000)
		if (!C6713_PLL_DIV1_IS_1)
			return(_T2E6XXX_set_err(T2E6XXX_PLL_INIT_ERR));
		// Wait 16 cycles of CLKIN clock signal (see spru233c.pdf)
		for (i = 0; i < 16; i++);
		// Check PLLDIV2 value (must be default 0x8001)
		if (!C6713_PLL_DIV2_IS_2)
			return(_T2E6XXX_set_err(T2E6XXX_PLL_INIT_ERR));
		// After configuration bring PLL out of reset and wait for PLL to lock
		C6713_SET_PLL_CSR_RST_OFF;
		if (C6713_PLL_CSR_RST_IS_ON)
			return(_T2E6XXX_set_err(T2E6XXX_PLL_INIT_ERR));
		// Wait 10000 cycles of CLKIN clock signal (200 us) for PLL to lock
		for (i = 0; i < 10000; i++);
		// Now set PLL_ENABLE
		C6713_SET_PLL_CSR_EN_ON;
		if (!C6713_PLL_CSR_EN_IS_ON)
			return(_T2E6XXX_set_err(T2E6XXX_PLL_INIT_ERR));

		// E2/6713 board EMIF initialization.
		// The E2/6713 board may differ in SDRAM capacity installed,
		// which result in different EMIF control register settings.

		// at first, set the EMIF control registers, which settings do not depend upon
		// SDRAM capacity installed.
		*C6XXX_EMIF_GBLCTL_RG = T2E6713_EMIF_GCR_DATA;
		*C6XXX_EMIF_CECTL0_RG = T2E6713_EMIF_CE0_SBSRAM_DATA;
		*C6XXX_EMIF_CECTL1_RG = T2E6713_EMIF_CE1_DATA;
		*C6XXX_EMIF_CECTL2_RG = T2E6713_EMIF_CE2_SDRAM_DATA;
		*C6XXX_EMIF_CECTL3_RG = T2E6713_EMIF_CE3_DATA;

		// SDRAM control must be initialized upon the SDRAM capacity
		if (T2E6713_REV_ID_IS_REV1A)
		{
			if (T2E6XXX_SDRAM_LEN_IS_16MX32)
			{
				*C6XXX_EMIF_SDCTL_RG = T2E6713_EMIF_SDRAM16M_DATA;
				*C6XXX_EMIF_SDTIM_RG = T2E6713_EMIF_SDRAM16M_TIMER_DATA;
			}
			if (T2E6XXX_SDRAM_LEN_IS_4MX32)
			{
				*C6XXX_EMIF_SDCTL_RG = T2E6713_EMIF_SDRAM4M_DATA;
				*C6XXX_EMIF_SDTIM_RG = T2E6713_EMIF_SDRAM4M_TIMER_DATA;
			}
			if (T2E6XXX_SDRAM_LEN_IS_0M)
			{
				// if SDRAM is not installed, then re-configure EMIF@CE2 area, which is reserved for SDRAM, as
				// the SBSRAM area (EMIF@CE0) in order to exclude SDRAM refresh cycles and increase the
				// system performance. The SDRAM control register and SDRAM timer register are configured as
				// that for 4Mx64 SDRAM in order to provide correct operation.
				*C6XXX_EMIF_CECTL2_RG = T2E6713_EMIF_CE0_SBSRAM_DATA;
				*C6XXX_EMIF_SDCTL_RG = T2E6713_EMIF_SDRAM4M_DATA;
				*C6XXX_EMIF_SDTIM_RG = T2E6713_EMIF_SDRAM4M_TIMER_DATA;
			}
			*C6XXX_EMIF_SDEXT_RG = T2E6713_EMIF_SDRAM_EXT_DATA;
		}
		return(_T2E6XXX_set_err(T2E6XXX_OK));
	}
	else
		return(_T2E6XXX_set_err(T2E6XXX_INVALID_HW_ERR));
}
//----------------------------------------------------------------------------


/*------------ DSP on-chip ports configuration function ------------------------
	This function performs configuration of DSP on-chip ports for E2/6713 board (McBSPs, McASPs, I2C-1).
	For TORNADO-E2/6713 controller with TMS320C6713 DSP, the DSP IC package pins for serial ports are shared
 between McBSP ports, McASP ports, I2C ports and HPI port in order to minimize number of package pins.
 This implies restrictions for available DSP serial ports configurations,
 and these restrictions are different for DSP stand-alone and host operation modes.
 McBSP-0 port is shared peripheral pins with McASP-0 port, McBSP-1 is shared peripheral pins
 with McASP-0 and I2C-1, McASP-0 is shared pins with Timers, McASP-1 is shared pins with HPI port.
	Default state is:
		- McBSPs DSP pins are enabled;
		- TOUTs DSP pins function as Timers output pins;
		- HPI DSP pins are disabled (HPI_EN = 0), McASP1 DSP pins are enabled in DSP stand-alone operation mode;
		- All on-chip serial peripheral ports are disabled on E2/6713 board via
			T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register (except I2C-0 port which is always enabled).
	Function parameter defines configuration number which are listed in Table 2-7 of "TORNADO E2/6xxx User's Guide"
 and below in this file. The configuration explicitly defines enabled DSP on-chip peripherals on E2/6713 board.
 The following lists all available DSP ports configurations depending upon DSP operation mode and
 installed DCM on E2/6713 DSP controller.
-----------------------------------------------------------------------------*/


//------------ Configurations which can be used in both DSP stand-alone ------
//------------------ and host operation modes --------------------------------

//------------ Configurations which can be used for both SIOX rev.B DCM and ASIOX rev.D DCM
#define T2E6713_DSP_PORTS_CNF_MCBSP0							1
#define T2E6713_DSP_PORTS_CNF_MCBSP0_MCBSP1						2
#define T2E6713_DSP_PORTS_CNF_MCBSP0_I2C1						3
#define T2E6713_DSP_PORTS_CNF_MCBSP1							4
#define T2E6713_DSP_PORTS_CNF_I2C1								5

//------------ Configurations which can be used for SIOX rev.B DCM only
// Configurations used McBSP-0 serial port
#define T2E6713_DSP_PORTS_CNF_MCBSP0_TOUT0						6
#define T2E6713_DSP_PORTS_CNF_MCBSP0_TOUT1						7
#define T2E6713_DSP_PORTS_CNF_MCBSP0_MCBSP1_TOUT0				8
#define T2E6713_DSP_PORTS_CNF_MCBSP0_MCBSP1_TOUT1				9
#define T2E6713_DSP_PORTS_CNF_MCBSP0_TOUT0_I2C1					10
#define T2E6713_DSP_PORTS_CNF_MCBSP0_TOUT0_TOUT1				11
#define T2E6713_DSP_PORTS_CNF_MCBSP0_TOUT1_I2C1					12
#define T2E6713_DSP_PORTS_CNF_MCBSP0_MCBSP1_TOUT0_TOUT1			13
#define T2E6713_DSP_PORTS_CNF_MCBSP0_TOUT0_TOUT1_I2C1			14
// Configurations used McBSP-1 serial port only
#define T2E6713_DSP_PORTS_CNF_MCBSP1_TOUT0						15
#define T2E6713_DSP_PORTS_CNF_MCBSP1_TOUT1						16
#define T2E6713_DSP_PORTS_CNF_MCBSP1_TOUT0_TOUT1				17
// Configurations used DSP Timers only
#define T2E6713_DSP_PORTS_CNF_TOUT0								18
#define T2E6713_DSP_PORTS_CNF_TOUT1								19
#define T2E6713_DSP_PORTS_CNF_TOUT0_TOUT1						20
#define T2E6713_DSP_PORTS_CNF_TOUT0_I2C1						21
#define T2E6713_DSP_PORTS_CNF_TOUT1_I2C1						22
#define T2E6713_DSP_PORTS_CNF_TOUT0_TOUT1_I2C1					23

//------------ Configurations which can be used in DSP stand-alone operation mode
//--------------- and in DSP host operation mode when HPI port is disabled ---

//------------ Configurations which can be used for ASIOX rev.D DCM only
// Configurations used McBSP-0 serial port
#define T2E6713_DSP_PORTS_CNF_MCBSP0_MCASP1						24
#define T2E6713_DSP_PORTS_CNF_MCBSP0_MCBSP1_MCASP1				25
#define T2E6713_DSP_PORTS_CNF_MCBSP0_I2C1_MCASP1				26
// Configurations used McBSP-1 serial port
#define T2E6713_DSP_PORTS_CNF_MCBSP1_MCASP0REDUCED				27
#define T2E6713_DSP_PORTS_CNF_MCBSP1_MCASP1						28
#define T2E6713_DSP_PORTS_CNF_MCBSP1_MCASP0REDUCED_MCASP1		29
// Configurations used McASP audio serial ports only
#define T2E6713_DSP_PORTS_CNF_MCASP0							30
#define T2E6713_DSP_PORTS_CNF_MCASP0_MCASP1						31
#define T2E6713_DSP_PORTS_CNF_MCASP0_I2C1						32
#define T2E6713_DSP_PORTS_CNF_MCASP1_I2C1						33
#define T2E6713_DSP_PORTS_CNF_MCASP0_I2C1_MCASP1				34

//------------ Configurations which can be used in DSP host operation mode
//------------------- when HPI port is enabled -------------------------------

// Configurations used McBSP-1 serial port with HPI enabled
#define T2E6713_DSP_PORTS_CNF_HPI_MCBSP1_MCASP0REDUCED			35
// Configurations used McASP audio serial ports only with HPI enabled
#define T2E6713_DSP_PORTS_CNF_HPI_MCASP0						36
#define T2E6713_DSP_PORTS_CNF_HPI_MCASP0_I2C1					37

//----------------------------------------------------------------------------
//----------------------------------------------------------------------------

int T2E6XXX_set_dsp_ports_cnf(unsigned cnf_id)
{
	if (T2E6713_BOARD)
	{
		// Disable all DSP ports buffers via T2E6XXX_DSP_PORTS_CNTR_RG register
		T2E6XXX_set_dsp_ports_cntr_rg(0x0);
		if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x0)
			return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));

		switch(cnf_id)
		{
			case T2E6713_DSP_PORTS_CNF_MCBSP0:
				// This configuration enables McBSP-0 serial port only.
				// Enable McBSP-0 port and disable McBSP-1 port and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xd);
				if (C6713_get_devcfg_periph_cfg() != 0xd)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 buffer via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x20);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x20)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_MCBSP1:
				// This configuration enables McBSP-0 and McBSP-1 serial ports only.
				// Enable McBSP-0 and McBSP-1 ports and disable Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xc);
				if (C6713_get_devcfg_periph_cfg() != 0xc)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 and McBSP-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x60);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x60)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_I2C1:
				// This configuration enables McBSP-0 and I2C-1 serial ports only.
				// Enable McBSP-0 port and disable McBSP-1 port and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xd);
				if (C6713_get_devcfg_periph_cfg() != 0xd)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 and I2C-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0xa0);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0xa0)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP1:
				// This configuration enables McBSP-1 serial port only.
				// Enable McBSP-1 port and disable McBSP-0 port and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xe);
				if (C6713_get_devcfg_periph_cfg() != 0xe)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-1 buffer via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x40);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x40)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_I2C1:
				// This configuration enables I2C-1 serial port only.
				// Disable McBSP-0 and McBSP-1 ports and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xf);
				if (C6713_get_devcfg_periph_cfg() != 0xf)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable I2C-1 buffer via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x80);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x80)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_TOUT0:
				// This configuration enables McBSP-0 serial port and Timer-0 only.
				// Enable McBSP-0 port and Timer-0 and disable McBSP-1 and Timer-1
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x9);
				if (C6713_get_devcfg_periph_cfg() != 0x9)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 buffer via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x20);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x20)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_TOUT1:
				// This configuration enables McBSP-0 serial port and Timer-1 only.
				// Enable McBSP-0 port and Timer-1 and disable McBSP-1 and Timer-0
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x5);
				if (C6713_get_devcfg_periph_cfg() != 0x5)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 buffer via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x20);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x20)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_MCBSP1_TOUT0:
				// This configuration enables McBSP-0 and McBSP-1 serial ports and Timer-0 only.
				// Enable McBSP-0, McBSP-1 ports and Timer-0 and disable Timer-1
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x8);
				if (C6713_get_devcfg_periph_cfg() != 0x8)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 and McBSP-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x60);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x60)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_MCBSP1_TOUT1:
				// This configuration enables McBSP-0 and McBSP-1 serial ports and Timer-1 only.
				// Enable McBSP-0, McBSP-1 ports and Timer-1 and disable Timer-0
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x4);
				if (C6713_get_devcfg_periph_cfg() != 0x4)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 and McBSP-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x60);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x60)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_TOUT0_I2C1:
				// This configuration enables McBSP-0, I2C-1 serial ports and Timer-0 only.
				// Enable McBSP-0 port and Timer-0 and disable McBSP-1 and Timer-1
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x9);
				if (C6713_get_devcfg_periph_cfg() != 0x9)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 and I2C-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0xa0);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0xa0)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_TOUT0_TOUT1:
				// This configuration enables McBSP-0 serial port and Timers only.
				// Enable McBSP-0 port and Timers and disable McBSP-1
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x1);
				if (C6713_get_devcfg_periph_cfg() != 0x1)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 buffer via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x20);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x20)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_TOUT1_I2C1:
				// This configuration enables McBSP-0, I2C-1 serial ports and Timer-1 only.
				// Enable McBSP-0 port and Timer-0 and disable McBSP-1 and Timer-0
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x5);
				if (C6713_get_devcfg_periph_cfg() != 0x5)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 and I2C-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0xa0);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0xa0)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_MCBSP1_TOUT0_TOUT1:
				// This configuration enables McBSP-0 and McBSP-1 serial ports and Timers only.
				// Enable McBSP-0, McBSP-1 ports and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x0);
				if (C6713_get_devcfg_periph_cfg() != 0x0)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 and McBSP-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x60);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x60)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_TOUT0_TOUT1_I2C1:
				// This configuration enables McBSP-0, I2C-1 serial ports and Timers only.
				// Enable McBSP-0 port and Timers and disable McBSP-1
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x1);
				if (C6713_get_devcfg_periph_cfg() != 0x1)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 and I2C-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0xa0);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0xa0)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP1_TOUT0:
				// This configuration enables McBSP-1 serial port and Timer-0 only.
				// Enable McBSP-1 port and Timer-0 and disable McBSP-0 and Timer-1
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xa);
				if (C6713_get_devcfg_periph_cfg() != 0xa)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-1 buffer via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x40);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x40)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP1_TOUT1:
				// This configuration enables McBSP-1 serial port and Timer-1 only.
				// Enable McBSP-1 port and Timer-1 and disable McBSP-0 and Timer-0
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x6);
				if (C6713_get_devcfg_periph_cfg() != 0x6)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-1 buffer via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x40);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x40)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP1_TOUT0_TOUT1:
				// This configuration enables McBSP-1 serial port and Timers only.
				// Enable McBSP-1 port and Timers and disable McBSP-0
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x2);
				if (C6713_get_devcfg_periph_cfg() != 0x2)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-1 buffer via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x40);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x40)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_TOUT0:
				// This configuration enables Timer-0 only.
				// Enable Timer-0 and disable McBSP-0, McBSP-1 and Timer-1
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xb);
				if (C6713_get_devcfg_periph_cfg() != 0xb)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Disable all buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x0);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x0)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_TOUT1:
				// This configuration enables Timer-1 only.
				// Enable Timer-1 and disable McBSP-0, McBSP-1 and Timer-0
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x7);
				if (C6713_get_devcfg_periph_cfg() != 0x7)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Disable all buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x0);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x0)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_TOUT0_TOUT1:
				// This configuration enables Timers only.
				// Enable Timers and disable McBSP-0 and McBSP-1
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x3);
				if (C6713_get_devcfg_periph_cfg() != 0x3)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Disable all buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x0);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x0)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_TOUT0_I2C1:
				// This configuration enables Timer-0 and I2C-1 serial port only.
				// Enable Timer-0 and disable McBSP-0, McBSP-1 ports and Timer-1
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xb);
				if (C6713_get_devcfg_periph_cfg() != 0xb)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable I2C-1 buffer via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x80);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x80)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_TOUT1_I2C1:
				// This configuration enables Timer-1 and I2C-1 serial port only.
				// Enable Timer-1 and disable McBSP-0, McBSP-1 ports and Timer-0
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x7);
				if (C6713_get_devcfg_periph_cfg() != 0x7)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable I2C-1 buffer via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x80);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x80)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_TOUT0_TOUT1_I2C1:
				// This configuration enables Timers and I2C-1 serial port only.
				// Enable Timers and disable McBSP-0 and McBSP-1
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0x3);
				if (C6713_get_devcfg_periph_cfg() != 0x3)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable I2C-1 buffer via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x80);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x80)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_MCASP1:
				// This configuration enables McBSP-0 and McASP-1 serial ports only.
				// Check if HPI port is disabled (HPI port is disabled in DSP stand-alone operation mode
				// and in DSP host operation mode via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_ON)
					// HPI port must be disabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Enable McBSP-0 port and disable McBSP-1 and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xd);
				if (C6713_get_devcfg_periph_cfg() != 0xd)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0 and McASP-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x30);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x30)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_MCBSP1_MCASP1:
				// This configuration enables McBSP-0, McBSP-1 and McASP-1 serial ports only.
				// Check if HPI port is disabled (HPI port is disabled in DSP stand-alone operation mode
				// and in DSP host operation mode via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_ON)
					// HPI port must be disabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Enable McBSP-0, McBSP-1 ports and disable Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xc);
				if (C6713_get_devcfg_periph_cfg() != 0xc)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0, McBSP-1 and McASP-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x70);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x70)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP0_I2C1_MCASP1:
				// This configuration enables McBSP-0, I2C-1 and McASP-1 serial ports only.
				// Check if HPI port is disabled (HPI port is disabled in DSP stand-alone operation mode
				// and in DSP host operation mode via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_ON)
					// HPI port must be disabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Enable McBSP-0 port and disable McBSP-1 and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xd);
				if (C6713_get_devcfg_periph_cfg() != 0xd)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-0, I2C-1 and McASP-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0xb0);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0xb0)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP1_MCASP0REDUCED:
				// This configuration enables McBSP-1 and McASP-0 serial ports only.
				// McASP-0 AXR0-5, AXR0-6, AXR0-7, AMUTE0 peripheral pins are disabled in this configuration.
				// Check if HPI port is disabled (HPI port is disabled in DSP stand-alone operation mode
				// and in DSP host operation mode via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_ON)
					// HPI port must be disabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Enable McBSP-1 port and disable McBSP-0 and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xe);
				if (C6713_get_devcfg_periph_cfg() != 0xe)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-1 and McASP-0 buffers (#1,3,4) via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x4d);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x4d)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP1_MCASP1:
				// This configuration enables McBSP-1 and McASP-1 serial ports only.
				// Check if HPI port is disabled (HPI port is disabled in DSP stand-alone operation mode
				// and in DSP host operation mode via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_ON)
					// HPI port must be disabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Enable McBSP-1 port and disable McBSP-0 and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xe);
				if (C6713_get_devcfg_periph_cfg() != 0xe)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-1 and McASP-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x50);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x50)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCBSP1_MCASP0REDUCED_MCASP1:
				// This configuration enables McBSP-1, McASP-0 and McASP-1 serial ports only.
				// McASP-0 AXR0-5, AXR0-6, AXR0-7, AMUTE0 peripheral pins are disabled in this configuration.
				// Check if HPI port is disabled (HPI port is disabled in DSP stand-alone operation mode
				// and in DSP host operation mode via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_ON)
					// HPI port must be disabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Enable McBSP-1 port and disable McBSP-0 and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xe);
				if (C6713_get_devcfg_periph_cfg() != 0xe)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-1, McASP-1 and McASP-0 buffers (#1,3,4) via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x5d);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x5d)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCASP0:
				// This configuration enables McASP-0 audio serial port only.
				// Check if HPI port is disabled (HPI port is disabled in DSP stand-alone operation mode
				// and in DSP host operation mode via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_ON)
					// HPI port must be disabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Disable McBSP-0, McBSP-1 ports and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xf);
				if (C6713_get_devcfg_periph_cfg() != 0xf)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McASP-0 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0xf);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0xf)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCASP0_MCASP1:
				// This configuration enables McASP-0 and McASP-1 audio serial ports only.
				// Check if HPI port is disabled (HPI port is disabled in DSP stand-alone operation mode
				// and in DSP host operation mode via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_ON)
					// HPI port must be disabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Disable McBSP-0, McBSP-1 ports and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xf);
				if (C6713_get_devcfg_periph_cfg() != 0xf)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McASP-0 and McASP-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x1f);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x1f)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCASP0_I2C1:
				// This configuration enables McASP-0 and I2C-1 serial ports only.
				// Check if HPI port is disabled (HPI port is disabled in DSP stand-alone operation mode
				// and in DSP host operation mode via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_ON)
					// HPI port must be disabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Disable McBSP-0, McBSP-1 ports and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xf);
				if (C6713_get_devcfg_periph_cfg() != 0xf)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McASP-0 and I2C-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x8f);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x8f)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCASP1_I2C1:
				// This configuration enables McASP-1 and I2C-1 serial ports only.
				// Check if HPI port is disabled (HPI port is disabled in DSP stand-alone operation mode
				// and in DSP host operation mode via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_ON)
					// HPI port must be disabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Disable McBSP-0, McBSP-1 ports and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xf);
				if (C6713_get_devcfg_periph_cfg() != 0xf)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McASP-1 and I2C-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x90);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x90)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_MCASP0_I2C1_MCASP1:
				// This configuration enables McASP-0, I2C-1 and McASP-1 serial ports only.
				// Check if HPI port is disabled (HPI port is disabled in DSP stand-alone operation mode
				// and in DSP host operation mode via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_ON)
					// HPI port must be disabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Disable McBSP-0, McBSP-1 ports and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xf);
				if (C6713_get_devcfg_periph_cfg() != 0xf)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McASP-0, I2C-1 and McASP-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x9f);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x9f)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_HPI_MCBSP1_MCASP0REDUCED:
				// This configuration enables McBSP-1 and McASP-0 serial ports only with HPI port enabled.
				// McASP-0 AXR0-5, AXR0-6, AXR0-7, AMUTE0 peripheral pins are disabled in this configuration.
				// Check if DSP operation mode is HOST
				if (T2E6XXX_OPMODE_IS_SA)
					// This configuration is used only in DSP host operation mode!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if HPI port is enabled (HPI port is enabled in DSP host operation mode
				// via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_OFF)
					// HPI port must be enabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Enable McBSP-1 port and disable McBSP-0 and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xe);
				if (C6713_get_devcfg_periph_cfg() != 0xe)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McBSP-1 and McASP-0 buffers (#1,3,4) via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x4d);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x4d)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_HPI_MCASP0:
				// This configuration enables McASP-0 audio serial port only with HPI port enabled.
				// Check if DSP operation mode is HOST
				if (T2E6XXX_OPMODE_IS_SA)
					// This configuration is used only in DSP host operation mode!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if HPI port is enabled (HPI port is enabled in DSP host operation mode
				// via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_OFF)
					// HPI port must be enabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Disable McBSP-0, McBSP-1 ports and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xf);
				if (C6713_get_devcfg_periph_cfg() != 0xf)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McASP-0 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0xf);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0xf)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			case T2E6713_DSP_PORTS_CNF_HPI_MCASP0_I2C1:
				// This configuration enables I2C-1 and McASP-0 serial ports only with HPI port enabled.
				// Check if DSP operation mode is HOST
				if (T2E6XXX_OPMODE_IS_SA)
					// This configuration is used only in DSP host operation mode!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if HPI port is enabled (HPI port is enabled in DSP host operation mode
				// via HCX_AX_CNTR2_RG HCX control register)
				if (T2E6XXX_HPI_EN_IS_OFF)
					// HPI port must be enabled for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_INCOMPATIBLE_DSP_PORTS_CNF_ERR));
				// Check if ASIOX rev.D DCM is installed
				if (!T2E6XXX_ASIOX_DCM_IS_INSTALLED)
					// ASIOX rev.D DCM must be installed for this configuration!
					return(_T2E6XXX_set_err(T2E6XXX_ASIOX_DCM_NOT_INSTALLED_ERR));
				// Disable McBSP-0, McBSP-1 ports and Timers
				// via C6713B on-chip DEVCFG device configuration register
				C6713_set_devcfg_periph_cfg(0xf);
				if (C6713_get_devcfg_periph_cfg() != 0xf)
					return(_T2E6XXX_set_err(C6XXX_HW_ERR));
				// Enable McASP-0 and I2C-1 buffers via T2E6XXX_DSP_PORTS_CNTR_RG DSP external control register
				T2E6XXX_set_dsp_ports_cntr_rg(0x8f);
				if (T2E6XXX_get_dsp_ports_cntr_rg() != 0x8f)
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
				break;

			default:
				// incorrect function parameter
				return(_T2E6XXX_set_err(T2E6XXX_PARAM_ERR));
		}
		return(_T2E6XXX_set_err(T2E6XXX_OK));
	}
	else
		return(_T2E6XXX_set_err(T2E6XXX_INVALID_HW_ERR));
}
//----------------------------------------------------------------------------
#endif
//----------------------------------------------------------------------------
#endif



#ifdef __T2E6XXX_INCLUDE_FLASH_CONTROL__
/*------------ FLASH PROGRAMMING CONTROL functions ---------------------------
	IMPORTANT NOTICE !!!
	---------------------
	1. FLASH control utilities (except for the T2E6XXX_FLASH_READ function)
	 require that FLASH WRITE feature is enabled via on-board switch set and
	 via T2E6XXX_SET_FLASH_WR_EN_ON macro, oherwise the T2E6XXX_FLASH_XWRPROT_ERR error
	 will be returned and no operation will be performed. This is due FLASH control
	 utilities are auto-configured via the FLASH MANUF/DEVICE info, which is
	 read from the FLASH chip using AUTO-SELECT command.

		User FLASH API functions:
			T2E6XXX_get_flash_info(),
			T2E6XXX_get_flash_sector_wrprot(),
			T2E6XXX_erase_flash_sector(),
			T2E6XXX_erase_flash_chip(),
			T2E6XXX_write_flash(),
			T2E6XXX_read_flash().

	2. At runtime, FLASH utility automatically detects the presence of the
	 supported FLASH memory chips, and adjusts internal environment.
*/
#include "stddef.h"	// TI C Compiler standard header

// local defs and static vars
#define __T2E6XXX_FLASH_LEN_512KX8			0x00080000
#define __T2E6XXX_FLASH_LEN_1MX8			0x00100000
#define __T2E6XXX_FLASH_LEN_8MX8			0x00800000
#define __T2E6XXX_FLASH_LEN_64MX8			0x04000000

#define __T2E6XXX_FLASH_AMD_512KX8_SECTORS	8
#define __T2E6XXX_FLASH_AMD_1MX8_SECTORS	16
#define __T2E6XXX_FLASH_AMD_8MX8_SECTORS	128
#define __T2E6XXX_FLASH_AMD_64MX8_SECTORS	512

static int	_T2E6XXX_flash_open_flag	= 0,
			_T2E6XXX_flash_manuf_id		= 0,
			_T2E6XXX_flash_dev_id		= 0,
			_T2E6XXX_flash_len			= 0,
			_T2E6XXX_flash_sectors		= 0,
			_T2E6XXX_flash_sector_len	= 0;


//----------------------------------------------------------------------------
static int _T2E6XXX_flash_open()
	// local/non-API function, which is used to check whether
	// FLASH API has been open in order to identify FLASH chip info
	// and configure FLASH API environment
{
	T2E6XXX_FLASH_DATA_TYPE *fptr,rd;
	int r, d;

	// Check for FLASH API has been open already.
	// If not open, then open it.
	if (_T2E6XXX_flash_open_flag == T2E6XXX_ON)
		return(T2E6XXX_OK);	// exit if already opened

	// not open yet, now try to open FLASH utilities
	_T2E6XXX_flash_open_flag = T2E6XXX_OFF;
	fptr = (T2E6XXX_FLASH_DATA_TYPE *) T2E6XXX_FLASH_AREA_SADDR;

	// execute AUTO-SELECT command
	// For FLASH 64Mx8 address is different
	// because of these chips function in BYTE mode
	if (T2E6XXX_FLASH_LEN_IS_64MX8)
	{
		fptr[0xaaa] = 0xaa;
		fptr[0x555] = 0x55;
		fptr[0xaaa] = 0x90;
		_T2E6XXX_flash_manuf_id = fptr[0] & T2E6XXX_FLASH_DATA_BITMASK;
	}
	else
	{
		fptr[0x5555] = 0xaa;
		fptr[0x2aaa] = 0x55;
		fptr[0x5555] = 0x90;
		_T2E6XXX_flash_manuf_id = fptr[0] & T2E6XXX_FLASH_DATA_BITMASK;
	}

	if (_T2E6XXX_flash_manuf_id != T2E6XXX_FLASH_MANUF_ID_AMD)
	{
		if (T2E6XXX_FLASH_XWRPROT_STAT_IS_ON)
			r = T2E6XXX_FLASH_XWRPROT_ERR;	// FLASH writes are disabled externally!
		else
			r = T2E6XXX_FLASH_INV_DEV_ERR;	// unsupported device

		goto exit;
	}

	// now read and verify the device ID
	if (T2E6XXX_FLASH_LEN_IS_64MX8)
		_T2E6XXX_flash_dev_id = fptr[2] & T2E6XXX_FLASH_DATA_BITMASK;
	else
		_T2E6XXX_flash_dev_id = fptr[1] & T2E6XXX_FLASH_DATA_BITMASK;

	switch(_T2E6XXX_flash_dev_id)
	{
			// embedded FLASH memories for E2/6xxx boards
		case T2E6XXX_FLASH_DEV_ID_AMD_512KX8:
			// check whether the FLASH CAPACITY ID matches
			// (from the T2E6XXX_SYS_CNF3_RG register), exit with error otherwise
			if (!T2E6XXX_FLASH_LEN_IS_512KX8)
			{
				r= T2E6XXX_INVALID_HW_ERR;
				goto exit;
			}
			_T2E6XXX_flash_len		= __T2E6XXX_FLASH_LEN_512KX8;
			_T2E6XXX_flash_sectors	= __T2E6XXX_FLASH_AMD_512KX8_SECTORS;
			break;

		case T2E6XXX_FLASH_DEV_ID_AMD_1MX8:
			// check whether the FLASH CAPACITY ID matches
			// (from the T2E6XXX_SYS_CNF3_RG register), exit with error otherwise
			if (!T2E6XXX_FLASH_LEN_IS_1MX8)
			{
				r= T2E6XXX_INVALID_HW_ERR;
				goto exit;
			}
			_T2E6XXX_flash_len		= __T2E6XXX_FLASH_LEN_1MX8;
			_T2E6XXX_flash_sectors	= __T2E6XXX_FLASH_AMD_1MX8_SECTORS;
			break;

		case T2E6XXX_FLASH_DEV_ID_AMD_8MX8:
			// check whether the FLASH CAPACITY ID matches
			// (from the T2E6XXX_SYS_CNF3_RG register), exit with error otherwise
			if (!T2E6XXX_FLASH_LEN_IS_8MX8)
			{
				r= T2E6XXX_INVALID_HW_ERR;
				goto exit;
			}
			_T2E6XXX_flash_len		= __T2E6XXX_FLASH_LEN_8MX8;
			_T2E6XXX_flash_sectors	= __T2E6XXX_FLASH_AMD_8MX8_SECTORS;
			break;

		case T2E6XXX_FLASH_DEV_ID_AMD_64MX8_FIRST_CYCLE:
			// For AMD Flash chip 64Mx8 Device ID read command needs 3 cycles:
			// first is returned 0x7E, second is returned Device ID,
			// third is returned 0x01
			d = fptr[0x1c] & T2E6XXX_FLASH_DATA_BITMASK;
			if (d == T2E6XXX_FLASH_DEV_ID_AMD_64MX8)
			{
				// check whether the FLASH CAPACITY ID matches
				// (from the T2E6XXX_SYS_CNF3_RG register), exit with error otherwise
				if (!T2E6XXX_FLASH_LEN_IS_64MX8)
				{
					r= T2E6XXX_INVALID_HW_ERR;
					goto exit;
				}
				_T2E6XXX_flash_dev_id	= T2E6XXX_FLASH_DEV_ID_AMD_64MX8;
				_T2E6XXX_flash_len		= __T2E6XXX_FLASH_LEN_64MX8;
				_T2E6XXX_flash_sectors	= __T2E6XXX_FLASH_AMD_64MX8_SECTORS;
				d = fptr[0x1e] & T2E6XXX_FLASH_DATA_BITMASK;
				// and finally check whether third cycle is returned 0x01,
				// exit with error otherwise
				if (d != T2E6XXX_FLASH_DEV_ID_AMD_64MX8_LAST_CYCLE)
				{
					r= T2E6XXX_INVALID_HW_ERR;
					goto exit;
				}
				break;
			}
			else
			{
				r= T2E6XXX_INVALID_HW_ERR;
				goto exit;
			}

		default:
			// unsupported FLASH device, exit with error
			r = T2E6XXX_FLASH_INV_DEV_ERR;
			goto exit;
	}

	// FLASH device identification has passed OK. Set FLASH sector length.
	// Set FLASH utilities OPEN flag in order to exclude this procedure for all further API function calls.
	_T2E6XXX_flash_sector_len = _T2E6XXX_flash_len / _T2E6XXX_flash_sectors;

	// That's it, now set FLASH utilities OPEN flag in order to exclude this procedure for
	// all further API function calls
	_T2E6XXX_flash_open_flag = T2E6XXX_ON;
	r = T2E6XXX_OK;

exit:
	// execute RESET command in order to release device from the FLASH command state and enable further reads
	fptr[0] = 0xf0;
	rd = *fptr;			// perform false read
	r = r | (rd&0);		// this is the false operator in order to exclude warning
						// message, which appears since RD var is never used.
	return(r);			// return error code
}
//----------------------------------------------------------------------------



//----------------------------------------------------------------------------
int T2E6XXX_get_flash_info(unsigned *manuf_id, unsigned *dev_id,
					unsigned *len,unsigned *sectors, unsigned *sector_len)
	// Returns FLASH chip info (manuf code, device code, etc.) via
	// supplied params pointers.
	// Returns: error code.
{
	int r;

	// Check for FLASH API has been open already.
	if ((r = _T2E6XXX_flash_open()) != T2E6XXX_OK)
		return(_T2E6XXX_set_err(r));

	if (manuf_id != NULL)		*manuf_id	=_T2E6XXX_flash_manuf_id;
	if (dev_id != NULL)			*dev_id		=_T2E6XXX_flash_dev_id;
	if (len != NULL)			*len		=_T2E6XXX_flash_len;
	if (sectors != NULL)		*sectors	=_T2E6XXX_flash_sectors;
	if( sector_len != NULL)		*sector_len	=_T2E6XXX_flash_sector_len;

	return(_T2E6XXX_set_err(T2E6XXX_OK));
}
//----------------------------------------------------------------------------



//----------------------------------------------------------------------------
int T2E6XXX_get_flash_sector_wrprot(unsigned a)
	// Returns FLASH sector write-protection status for the sector,
	// which corresponds to address A.
	// Returns: <0 error code.
	//          0  - sector is not protected
	//          1  - sector is protected
{
	int r;
	T2E6XXX_FLASH_DATA_TYPE *fptr,rd,rd1;

	// Check for FLASH API has been open already.
	if ((r=_T2E6XXX_flash_open()) != T2E6XXX_OK)
		return(_T2E6XXX_set_err(r));

	// validate params
	if (a >= _T2E6XXX_flash_len)
		return(_T2E6XXX_set_err(T2E6XXX_PARAM_ERR));

	// Check if there is an access to FLASH 64Mx8 BOOT SECTOR
	if (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8)
	{
		if (a == 0)
		{
			if (T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_IS_ON)
			{
				r = T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_ERR;	// Writes to FLASH 64Mx8 BOOT SECTOR are disabled externally!
				return(_T2E6XXX_set_err(r));
			}
		}
	}

	// set FLASH pointer and sector#
	fptr = (T2E6XXX_FLASH_DATA_TYPE *)T2E6XXX_FLASH_AREA_SADDR;

	// Set FLASH_PAGE[0..5] bits for 8Mx8 and 64Mx8 FLASH chips
	// Modify the <A> input flash address so it becomes aligned within the current FLASH PAGE in order to keep the code clear and simple.
	if ((_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_8MX8) || (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8))
	{
		// set FLASH PAGE bits
		T2E6XXX_set_flash_page(a / T2E6XXX_FLASH_PAGE_LEN);
		// verify FLASH PAGE bits
		if (T2E6XXX_get_flash_page() != (a / T2E6XXX_FLASH_PAGE_LEN))
			return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));

			// modify the FLASH address parameter to align it within the FLASH page boundary
		a %= T2E6XXX_FLASH_PAGE_LEN;
	}

	// execute AUTO-SELECT COMMAND for sector protection status
	// For FLASH 64Mx8 address is different
	// because of these chips function in BYTE mode
	if (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8)
	{
		fptr[0xaaa] = 0xaa;
		fptr[0x555] = 0x55;
		fptr[0xaaa] = 0x90;
		// read & verify sector wr-protection status (==0 or ==1)
		r = T2E6XXX_FLASH_INV_RD_ERR;	// assume error
		// Note, that we must read data at the <sector_start_address + 2>
		// in order to get the sector write protection feature!
		rd = fptr[((a / _T2E6XXX_flash_sector_len) * _T2E6XXX_flash_sector_len) + 4] & T2E6XXX_FLASH_DATA_BITMASK;
	}
	else
	{
		fptr[0x5555] = 0xaa;
		fptr[0x2aaa] = 0x55;
		fptr[0x5555] = 0x90;
		// read & verify sector wr-protection status (==0 or ==1)
		r = T2E6XXX_FLASH_INV_RD_ERR;	// assume error
		// Note, that we must read data at the <sector_start_address + 2>
		// in order to get the sector write protection feature!
		rd = fptr[((a / _T2E6XXX_flash_sector_len) * _T2E6XXX_flash_sector_len) + 2] & T2E6XXX_FLASH_DATA_BITMASK;
	}

	if (rd != 0 && rd != 1)
		goto exit;

	r = T2E6XXX_OK;	// exit OK

exit:
	// execute RESET command in order to release device from the FLASH command state and enable further reads
	fptr[0] = 0xf0;
	rd1 = *fptr;			// perform false read
	r = r | (rd1 & 0);		// this is the false operator in order to exclude warning
							// message, which appears since RD1 var is never used.
	return(_T2E6XXX_set_err(r < 0 ? r: rd));
}
//----------------------------------------------------------------------------



//----------------------------------------------------------------------------
int T2E6XXX_erase_flash_sector(unsigned a,unsigned vf)
	// Erase sector, which corresponds to FLASH address A (0...
	// Verify erased sector data if VF==1.
	// returns:  error code
{
	T2E6XXX_FLASH_DATA_TYPE *fptr, rd;
	unsigned sa, i;
	int r;

	// Check for FLASH API has been open already.
	if ((r=_T2E6XXX_flash_open()) != T2E6XXX_OK)
		return(_T2E6XXX_set_err(r));

	// validate params
	if ((a >= _T2E6XXX_flash_len) || (vf > 1))
		return(_T2E6XXX_set_err(T2E6XXX_PARAM_ERR));

	// Check if there is an access to FLASH 64Mx8 BOOT SECTOR
	if (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8)
	{
		if (a == 0)
		{
			if (T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_IS_ON)
			{
				r = T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_ERR;	// Writes to FLASH 64Mx8 BOOT SECTOR are disabled externally!
				return(_T2E6XXX_set_err(r));
			}
		}
	}

	// set FLASH pointer and sector#
	fptr = (T2E6XXX_FLASH_DATA_TYPE *)T2E6XXX_FLASH_AREA_SADDR;

	// Set FLASH_PAGE[0..5] bits for 8Mx8 and 64Mx8 FLASH chips
	// Modify the <A> input flash address so it becomes aligned within the current FLASH PAGE in order to keep the code clear and simple.
	if ((_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_8MX8) || (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8))
	{
		// set FPASH PAGE bits
		T2E6XXX_set_flash_page(a / T2E6XXX_FLASH_PAGE_LEN);
		// verify FLASH PAGE bits
		if (T2E6XXX_get_flash_page() != (a / T2E6XXX_FLASH_PAGE_LEN))
			return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));

			// modify the FLASH address parameter to align it within the FLASH page boundary
		a %= T2E6XXX_FLASH_PAGE_LEN;
	}

	// set FLASH sector# (aligned to the FLASH page)
	sa = (a / _T2E6XXX_flash_sector_len);

	// execute SECTOR ERASE command
	// For FLASH 64Mx8 address is different
	// because of these chips function in BYTE mode
	if (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8)
	{
		fptr[0xaaa] = 0xaa;
		fptr[0x555] = 0x55;
		fptr[0xaaa] = 0x80;
		fptr[0xaaa] = 0xaa;
		fptr[0x555] = 0x55;
		fptr[a]		= 0x30;
	}
	else
	{
		fptr[0x5555]=0xaa;
		fptr[0x2aaa]=0x55;
		fptr[0x5555]=0x80;
		fptr[0x5555]=0xaa;
		fptr[0x2aaa]=0x55;
		fptr[a]		=0x30;
	}

	while(1)
	{
		rd = fptr[a] & T2E6XXX_FLASH_DATA_BITMASK;

		// verify read data
		if (rd == 0xff)
			break;		// exit OK

		// if not OK, then test bit D5 as timeout condition
		if ((rd & 0x20) != 0)
		{
			// if timeout, then read again
			rd = fptr[a] & T2E6XXX_FLASH_DATA_BITMASK;
			// verify read data
			if (rd == 0xff)
				break;	// exit OK
			// error and exit
			// execute RESET command in order to release device from the ERASE state
			fptr[0] = 0xf0;
			return(_T2E6XXX_set_err(T2E6XXX_FLASH_ERASE_ERR));
		}
	}

	// perform erased sector data verification if requested
	// (must read as the 'FF' for correctly erased FLASH memory)
	if (vf != 0)
	{
		for(i=0,
			fptr = (T2E6XXX_FLASH_DATA_TYPE *)(T2E6XXX_FLASH_AREA_SADDR + (sa * _T2E6XXX_flash_sector_len));
			i < _T2E6XXX_flash_sector_len;
			i++,fptr++)
		{
			if((*fptr & T2E6XXX_FLASH_DATA_BITMASK) != 0xff)
				return(_T2E6XXX_set_err(T2E6XXX_FLASH_ERASE_ERR));
		}
	}
	return(_T2E6XXX_set_err(T2E6XXX_OK));	// exit OK
}
//----------------------------------------------------------------------------



//----------------------------------------------------------------------------
int T2E6XXX_erase_flash_chip(unsigned vf)
	// Erase all sectors of FLASH. Verify erased data if VF==1.
	// returns:  error code
{
	T2E6XXX_FLASH_DATA_TYPE *fptr,rd;
	unsigned i;
	int r;

	// Check for FLASH API has been open already.
	if ((r=_T2E6XXX_flash_open()) != T2E6XXX_OK)
		return(_T2E6XXX_set_err(r));

	// validate params
	if (vf > 1)
		return(_T2E6XXX_set_err(T2E6XXX_PARAM_ERR));

	// set FLASH pointer
	fptr = (T2E6XXX_FLASH_DATA_TYPE *)T2E6XXX_FLASH_AREA_SADDR;

	// Reset FLASH_PAGE[0..5] bits for 8Mx8 and 64Mx8 FLASH chips
	if ((_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_8MX8) || (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8))
	{
		// set FPASH PAGE bits
		T2E6XXX_set_flash_page(0);
		// verify FLASH PAGE bits
		if (T2E6XXX_get_flash_page() != 0)
			return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
	}

	// execute ERASE CHIP command
	// For FLASH 64Mx8 address is different
	// because of these chips function in BYTE mode
	if (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8)
	{
		fptr[0xaaa] = 0xaa;
		fptr[0x555] = 0x55;
		fptr[0xaaa] = 0x80;
		fptr[0xaaa] = 0xaa;
		fptr[0x555] = 0x55;
		fptr[0xaaa] = 0x10;
	}
	else
	{
		fptr[0x5555]=0xaa;
		fptr[0x2aaa]=0x55;
		fptr[0x5555]=0x80;
		fptr[0x5555]=0xaa;
		fptr[0x2aaa]=0x55;
		fptr[0x5555]=0x10;
	}

	while(1)
	{
		rd = *fptr & T2E6XXX_FLASH_DATA_BITMASK;

		// verify read data
		if (rd == 0xff)
			break;		// exit OK

		// if not OK, then test bit D5 as timeout condition
		if ((rd & 0x20) != 0)
		{
			// if timeout, then read again
			rd = *fptr & T2E6XXX_FLASH_DATA_BITMASK;
			// verify read data
			if (rd == 0xff)
				break;	// exit OK
			// error and exit
			// execute RESET command in order to release device from the ERASE state
			fptr[0] = 0xf0;
			return(_T2E6XXX_set_err(T2E6XXX_FLASH_ERASE_ERR));	// error and exit
		}
	}

	// perform erased chip data verification if requested
	if (vf != 0)
	{
		for (i = 0; i < _T2E6XXX_flash_sector_len; i++,fptr++)
		{
			// Set the FLASH_PAGE[0..5] bits for 8Mx8 and 64Mx8 FLASH chips
			// Reset the <FPTR> pointer to the FLASH PAGE start in case FLASH PAGE change is detected via the <I> parameter.
			if (((_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_8MX8) || (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8)) && (i != 0) && ((i % T2E6XXX_FLASH_PAGE_LEN) == 0))
			{
				// set FLASH PAGE bits
				T2E6XXX_set_flash_page(i / T2E6XXX_FLASH_PAGE_LEN);
				// verify FLASH PAGE bits
				if (T2E6XXX_get_flash_page() != (i / T2E6XXX_FLASH_PAGE_LEN))
					return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));

				// reset the FPTR parameter to the FLASH PAGE start address.
				fptr = (T2E6XXX_FLASH_DATA_TYPE *)T2E6XXX_FLASH_AREA_SADDR;
			}
			// read and verify the FLASH data (must read as the 'FF' for correctly erased FLASH memory)
			if ((*fptr & T2E6XXX_FLASH_DATA_BITMASK) != 0xff)
				return(_T2E6XXX_set_err(T2E6XXX_FLASH_ERASE_ERR));
		}
	}
	// Reset FLASH_PAGE[0..5] bits for 8Mx8 and 64Mx8 FLASH chips
	if ((_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_8MX8) || (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8))
	{
		// set FPASH PAGE bits
		T2E6XXX_set_flash_page(0);
		// verify FLASH PAGE bits
		if (T2E6XXX_get_flash_page() != 0)
			return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));
	}
	return(_T2E6XXX_set_err(T2E6XXX_OK));	// exit OK
}
//----------------------------------------------------------------------------



//----------------------------------------------------------------------------
int T2E6XXX_write_flash(unsigned a, unsigned d)
	// writes D (bits 0..7 are valid) to FLASH addr #A
	// returns:  error code
{
	T2E6XXX_FLASH_DATA_TYPE *fptr,rd;
	int r;

	// Check for FLASH API has been open already.
	if ((r=_T2E6XXX_flash_open()) != T2E6XXX_OK)
		return(_T2E6XXX_set_err(r));

	// validate params
	if (a >= _T2E6XXX_flash_len || d > T2E6XXX_FLASH_DATA_BITMASK)
		return(_T2E6XXX_set_err(T2E6XXX_PARAM_ERR));

	// Check if there is an access to FLASH 64Mx8 BOOT SECTOR
	if (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8)
	{
		if (a == 0)
		{
			if (T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_IS_ON)
			{
				r = T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_ERR;	// Writes to FLASH 64Mx8 BOOT SECTOR are disabled externally!
				return(_T2E6XXX_set_err(r));
			}
		}
	}

	// set FLASH pointer
	fptr = (T2E6XXX_FLASH_DATA_TYPE *)T2E6XXX_FLASH_AREA_SADDR;

	// Set FLASH_PAGE[0..5] bits for 8Mx8 and 64Mx8 FLASH chips
	// Modify the <A> input flash address so it becomes aligned within the current FLASH PAGE in order to keep the code clear and simple.
	if ((_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_8MX8) || (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8))
	{
		// set FPASH PAGE bits
		T2E6XXX_set_flash_page(a / T2E6XXX_FLASH_PAGE_LEN);
		// verify FLASH PAGE bits
		if (T2E6XXX_get_flash_page() != (a / T2E6XXX_FLASH_PAGE_LEN))
			return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));

			// modify the FLASH address parameter to align it within the FLASH page boundary
		a %= T2E6XXX_FLASH_PAGE_LEN;
	}

	// Verify that FLASH contents at address A is OK to program the <D> data value, i.e. the '1' bits in the <D> word
	// match the '1' bits in the current FLASH contents at this address. Otherwise, FLASH cannot be programmed without
	// being erased.
	if ((fptr[a] & d) != d)
		return(_T2E6XXX_set_err(T2E6XXX_FLASH_CANNOT_WR_ERR));

	// execute PROGRAM BYTE command
	// For FLASH 64Mx8 address is different
	// because of these chips function in BYTE mode
	if (_T2E6XXX_flash_dev_id == T2E6XXX_FLASH_DEV_ID_AMD_64MX8)
	{
		fptr[0xaaa] = 0xaa;
		fptr[0x555] = 0x55;
		fptr[0xaaa] = 0xa0;
		fptr[a]		= d;
	}
	else
	{
		fptr[0x5555]=0xaa;
		fptr[0x2aaa]=0x55;
		fptr[0x5555]=0xa0;
		fptr[a]=d ;
	}

	// verify for program ends and errors
	while(1)
	{
		rd = fptr[a] & T2E6XXX_FLASH_DATA_BITMASK;

		// verify read data
		if (rd == d)
			return(_T2E6XXX_set_err(T2E6XXX_OK));		// exit OK

		// if not OK, then test bit D5 as timeout condition
		if ((rd & 0x20) != 0)
		{
			// if timeout, then read again
			rd = fptr[a] & T2E6XXX_FLASH_DATA_BITMASK;
			//verify read data against the programmed data
			if (rd == d)
				return(_T2E6XXX_set_err(T2E6XXX_OK));	// exit OK
			// set error and exit
			// execute RESET command in order to release device from the PROGRAM state
			fptr[0] = 0xf0;
			return(_T2E6XXX_set_err(T2E6XXX_FLASH_WR_ERR));	// error and exit
		}
	}
}
//----------------------------------------------------------------------------



//----------------------------------------------------------------------------
int T2E6XXX_read_flash(unsigned a)
	// reads/returns data from FLASH addr #A
	// returns: <0 - error occured
	//	    >=0 - FLASH read data
	//
	// Implementation Notes:
	//		T2E6XXX_read_flash() function does not generally require FLASH WRITE feature enabled via the on-board
	//		switch in order to have FLASH utilities running perfectly and to get the FLASH LENGTH parameter in
	//		to verify it against input FLASH address parameter.
	//
	//		For E2/6xxx boards, the FLASH LENGTH is obtained from the read-back DSP_SYS_CNF3_RG register via
	//		FLASH CAPACITY ID field.
	//
{
	T2E6XXX_FLASH_DATA_TYPE *fptr;

	// set FLASH pointer
	fptr = (T2E6XXX_FLASH_DATA_TYPE *)T2E6XXX_FLASH_AREA_SADDR;

	// Verify FLASH ADDRESS value using FLASH CAPACITY ID and set the FLASH_PAGE[0..5] bits for 8Mx8 and 64Mx8 FLASH chips
	// with embedded FLASH memory and FLASH CAPACITY ID available.
	// Modify the <A> input flash address so it becomes aligned within the current FLASH PAGE in order to keep the code clear and simple.
	if (T2E6XXX_FLASH_LEN_IS_8MX8 || T2E6XXX_FLASH_LEN_IS_64MX8)
	{
		// verify the FLASH ADDRESS value using FLASH CAPACITY ID
		if (T2E6XXX_FLASH_IS_NOT_INSTALLED || a >= T2E6XXX_get_flash_len())
			return(_T2E6XXX_set_err(T2E6XXX_PARAM_ERR));
		// set FPASH PAGE bits
		T2E6XXX_set_flash_page(a / T2E6XXX_FLASH_PAGE_LEN);
		// verify FLASH PAGE bits
		if (T2E6XXX_get_flash_page() != (a / T2E6XXX_FLASH_PAGE_LEN))
			return(_T2E6XXX_set_err(T2E6XXX_HW_ERR));

			// modify the FLASH address parameter to align it within the FLASH page boundary
		a %= T2E6XXX_FLASH_PAGE_LEN;
	}

	// execute FLASH OPEN procedure in order to activate
	// FLASH utilities, however ignore returned error code
	_T2E6XXX_flash_open();

	// validate function params
	if((_T2E6XXX_flash_open_flag == T2E6XXX_ON && a >= _T2E6XXX_flash_len)
		|| (_T2E6XXX_flash_open_flag == T2E6XXX_OFF && a >= _T2E6XXX_flash_len))
		return(_T2E6XXX_set_err(T2E6XXX_PARAM_ERR));

	// FLASH address verification completed successfully
	// set last_error code to OK and read/return the FLASH data
	if (_T2E6XXX_flash_open_flag == T2E6XXX_ON)
		_T2E6XXX_last_err = T2E6XXX_OK;	// no errors if FLASH OPEN is OK

	// read and return the FLASH data
	return(fptr[a] & T2E6XXX_FLASH_DATA_BITMASK);
}
//----------------------------------------------------------------------------

#endif
//============================================================================
#endif
