/********************************************************************************
	TORNADO-E2/6xxx (E2/6713) Second Generation E6xxx controllers DSP Utilities. Rev.1A1-6
	(C) MicroLAB Systems, 2007-2008

	File:	Macros
	-----

	Notes:
	------
	1.	This C-header file is include file for TI C6000 compile tools,
		which is used with T2E6XXX_DSP.H C-header file.
********************************************************************************/

// check for this file has been already included
#ifndef	__T2E6XXX_DSP_MACROS__
#define	__T2E6XXX_DSP_MACROS__				1


//============================================================================
//============ Macros for I/O area control ===================================
// T2E6XXX utilities offer the unified utility functions synopsis:
//  - T2E6XXX_set_..._rg(..)    - sets the control register contents
//	- T2E6XXX_get_..._rg()      - returns contents of control register
//  - T2E6XXX_set_...(..)       - sets bit of control register (using particular bit set value)
//  - T2E6XXX_get_...()         - returns bit state of control register (using particular bit set value)
//----------------------------------------------------------------------------

//------------ I/O data type selector for different E2/6xxx controllers ------
// E2/6713 has all I/O peripherals aligned as LSB of 32-bit words, then
// I/O peripherals can be accessed as UNSIGNED, UNSIGNED SHORT and UNSIGNED CHAR.

// The declared T2E6XXX_IO_DATA_TYPE is used to unify below macros and functions and
// to make particular selection at the run-time compilation time.

// The declared T2E6XXX_FLASH_DATA_TYPE is used to unify below macros and functions
// for accessing the FLASH memory.

//----------------------------------------------------------------------------
#ifdef	__T2E6XXX_SELECT_E6713__

typedef unsigned							T2E6XXX_IO_DATA_TYPE;
typedef unsigned char						T2E6XXX_FLASH_DATA_TYPE;

#endif
//----------------------------------------------------------------------------



//----------------------------------------------------------------------------
//------------ Macros to get T2E6XXX controller info from read-only DSP external control registers
//----------------------------------------------------------------------------

//------------ Device ID macros ----------------------------------
	// The T2E6XXX_SYS_CNF1_RG contains Device ID for E2/6xxx board
#define T2E6XXX_get_sys_cnf1_rg()			((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_SYS_CNF1_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
	// bit-specific macros
#define T2E6XXX_get_dev_id()				(T2E6XXX_get_sys_cnf1_rg() & T2E6XXX_DEV_ID_BITMASK)
	// particular device ID board macros
#define T2E6713_BOARD						(T2E6XXX_get_dev_id() == T2E6713_DEV_ID)


//------------ Board & f/w revision ID, DSP clock frequency ID, --
//------------ EMIF SPREAD SPECTRUM CLOCK PRESENCE ID macros
	// The T2E6XXX_SYS_CNF2_RG contains Board & f/w revision ID, DSP SPEED ID, 
	// and EMIF SPREAD SPECTRUM CLOCK PRESENCE ID for E2/6713 board
#define T2E6XXX_get_sys_cnf2_rg()			((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_SYS_CNF2_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
	// bit-specific macros
#define T2E6XXX_get_rev_id()				(T2E6XXX_get_sys_cnf2_rg() & T2E6XXX_REV_ID_BITMASK)
#define T2E6XXX_get_dsp_clk_freq_id()		(T2E6XXX_get_sys_cnf2_rg() & T2E6XXX_DSP_CLK_FREQ_ID_BITMASK)
#define T2E6XXX_get_ssclk_id()				(T2E6XXX_get_sys_cnf2_rg() & T2E6XXX_SSCLK_ID_BITMASK)
	// condition check macros (for use in IF() and similar condition check operators)
#define T2E6713_REV_ID_IS_REV1A				(T2E6XXX_get_rev_id() == T2E6713_REV_ID_REV1A)
#define T2E6713_DSP_CLK_FREQ_IS_300MHZ		(T2E6713_REV_ID_IS_REV1A && (T2E6XXX_get_dsp_clk_freq_id() == T2E6713_DSP_CLK_FREQ_ID_300MHZ))
#define T2E6XXX_SSCLK_ID_IS_INSTALLED		(T2E6XXX_get_ssclk_id() == T2E6XXX_SSCLK_ID_INSTALLED)

	// T2E6XXX API aliases
#define T2E6XXX_DSP_CLK_FREQ_IS_300MHZ		T2E6713_DSP_CLK_FREQ_IS_300MHZ

//------------ Universal macro, which returns DSP clock frequency (floating point value in Hz)
#define T2E6XXX_dsp_clk_freq()				(T2E6XXX_DSP_CLK_FREQ_IS_300MHZ ? T2E6713_DSP_CLK_FREQ_300MHZ : 0)


//------------ SBSRAM/SDRAM/FLASH capacity ID macros -------------
// T2E6XXX_sdram_len(), T2E6XXX_sbsram_len() and T2E6XXX_get_flash_len() macros
// return the SDRAM/SBSRAM/FLASH length upon the corresponding field of T2E6XXX_SYS_CNF3_RG register.
#define T2E6XXX_get_sys_cnf3_rg()			((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_SYS_CNF3_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)

	// dedicated bit specific macros
#define T2E6XXX_get_sbsram_len_id()			(T2E6XXX_get_sys_cnf3_rg() & T2E6XXX_SBSRAM_LEN_ID_BITMASK)
#define T2E6XXX_get_sdram_len_id()			(T2E6XXX_get_sys_cnf3_rg() & T2E6XXX_SDRAM_LEN_ID_BITMASK)
#define T2E6XXX_get_flash_len_id()			(T2E6XXX_get_sys_cnf3_rg() & T2E6XXX_FLASH_LEN_ID_BITMASK)

	// condition check macros (for use in IF() and other conditional operators)
#define T2E6XXX_SBSRAM_LEN_IS_0K			(T2E6XXX_get_sbsram_len_id() == T2E6XXX_SBSRAM_LEN_ID_0K)
#define T2E6XXX_SBSRAM_LEN_IS_128KX32		(T2E6XXX_get_sbsram_len_id() == T2E6XXX_SBSRAM_LEN_ID_128KX32)
#define T2E6XXX_SBSRAM_LEN_IS_512KX32		(T2E6XXX_get_sbsram_len_id() == T2E6XXX_SBSRAM_LEN_ID_512KX32)
#define T2E6XXX_SBSRAM_IS_NOT_INSTALLED		T2E6XXX_SBSRAM_LEN_IS_0K
#define T2E6XXX_SBSRAM_IS_INSTALLED			!T2E6XXX_SBSRAM_IS_NOT_INSTALLED

#define T2E6XXX_SDRAM_LEN_IS_0M				(T2E6XXX_get_sdram_len_id() == T2E6XXX_SDRAM_LEN_ID_0M)
#define T2E6XXX_SDRAM_LEN_IS_4MX32			(T2E6XXX_get_sdram_len_id() == T2E6XXX_SDRAM_LEN_ID_4MX32)
#define T2E6XXX_SDRAM_LEN_IS_16MX32			(T2E6XXX_get_sdram_len_id() == T2E6XXX_SDRAM_LEN_ID_16MX32)
#define T2E6XXX_SDRAM_IS_NOT_INSTALLED		T2E6XXX_SDRAM_LEN_IS_0M
#define T2E6XXX_SDRAM_IS_INSTALLED			!T2E6XXX_SDRAM_IS_NOT_INSTALLED

#define T2E6XXX_FLASH_LEN_IS_0K				(T2E6XXX_get_flash_len_id() == T2E6XXX_FLASH_LEN_ID_0K)
#define T2E6XXX_FLASH_LEN_IS_512KX8			(T2E6XXX_get_flash_len_id() == T2E6XXX_FLASH_LEN_ID_512KX8)
#define T2E6XXX_FLASH_LEN_IS_1MX8			(T2E6XXX_get_flash_len_id() == T2E6XXX_FLASH_LEN_ID_1MX8)
#define T2E6XXX_FLASH_LEN_IS_8MX8			(T2E6XXX_get_flash_len_id() == T2E6XXX_FLASH_LEN_ID_8MX8)
#define T2E6XXX_FLASH_LEN_IS_64MX8			(T2E6XXX_get_flash_len_id() == T2E6XXX_FLASH_LEN_ID_64MX8)
#define T2E6XXX_FLASH_IS_NOT_INSTALLED		T2E6XXX_FLASH_LEN_IS_0K
#define T2E6XXX_FLASH_IS_INSTALLED			!T2E6XXX_FLASH_IS_NOT_INSTALLED

	// aliases for length in bytes
#define T2E6XXX_SBSRAM_LEN_IS_512KX8		T2E6XXX_SBSRAM_LEN_IS_128KX32
#define T2E6XXX_SBSRAM_LEN_IS_2MX8			T2E6XXX_SBSRAM_LEN_IS_512KX32

#define T2E6XXX_SDRAM_LEN_IS_16MX8			T2E6XXX_SDRAM_LEN_IS_4MX32
#define T2E6XXX_SDRAM_LEN_IS_64MX8			T2E6XXX_SDRAM_LEN_IS_16MX32

	// macros returning true SBSRAM/SDRAM/FLASH memories length (in bytes)
#define T2E6XXX_get_sbsram_len()			(T2E6XXX_SBSRAM_LEN_IS_0K ? T2E6XXX_SBSRAM_LEN_0K:\
												(T2E6XXX_SBSRAM_LEN_IS_128KX32 ? T2E6XXX_SBSRAM_LEN_128KX32:T2E6XXX_SBSRAM_LEN_512KX32))

#define T2E6XXX_get_sdram_len()				(T2E6XXX_SDRAM_LEN_IS_0M ? T2E6XXX_SDRAM_LEN_0M:\
												(T2E6XXX_SDRAM_LEN_IS_4MX32 ? T2E6XXX_SDRAM_LEN_4MX32:T2E6XXX_SDRAM_LEN_16MX32))

#define T2E6XXX_get_flash_len()				(T2E6XXX_FLASH_LEN_IS_0K ? T2E6XXX_FLASH_LEN_0K:\
												(T2E6XXX_FLASH_LEN_IS_512KX8 ? T2E6XXX_FLASH_LEN_512KX8:\
													(T2E6XXX_FLASH_LEN_IS_1MX8 ? T2E6XXX_FLASH_LEN_1MX8:\
														(T2E6XXX_FLASH_LEN_IS_8MX8 ? T2E6XXX_FLASH_LEN_8MX8: T2E6XXX_FLASH_LEN_64MX8))))


//------------ Peripherals ID macros -----------------------------
	// The T2E6XXX_SYS_CNF4_RG contains Peripherals ID for E2/6xxx board
#define T2E6XXX_get_sys_cnf4_rg()			((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_SYS_CNF4_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
	// dedicated bit specific macros
#define T2E6XXX_get_usb_id()				(T2E6XXX_get_sys_cnf4_rg() & T2E6XXX_USB_ID_BITMASK)
#define T2E6XXX_get_rtc_id()				(T2E6XXX_get_sys_cnf4_rg() & T2E6XXX_RTC_ID_BITMASK)
	// condition check macros (for use in IF() and other conditional operators)
#define T2E6XXX_USB_ID_IS_NOT_INSTALLED		(T2E6XXX_get_usb_id() == T2E6XXX_USB_ID_NOT_INSTALLED)
#define T2E6XXX_USB_ID_IS_USB1				(T2E6XXX_get_usb_id() == T2E6XXX_USB_ID_USB1)
#define T2E6XXX_USB_ID_IS_USB2				(T2E6XXX_get_usb_id() == T2E6XXX_USB_ID_USB2)
#define T2E6XXX_USB_ID_IS_USB3				(T2E6XXX_get_usb_id() == T2E6XXX_USB_ID_USB3)
#define T2E6XXX_RTC_ID_IS_NOT_INSTALLED		(T2E6XXX_get_rtc_id() == T2E6XXX_RTC_ID_NOT_INSTALLED)
#define T2E6XXX_RTC_ID_IS_RTC1				(T2E6XXX_get_rtc_id() == T2E6XXX_RTC_ID_RTC1)


//------------ Bootmode read-back and DSP environment configuration macros
	// The T2E6XXX_DSP_CNF_RG contains DSP bootmode ID,
	// DSP op-mode ID and HPI enable status for E2/6xxx board
#define T2E6XXX_get_dsp_cnf_rg()			((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_DSP_CNF_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
	// dedicated bit specific macros
#define T2E6XXX_get_bmode()					(T2E6XXX_get_dsp_cnf_rg() & T2E6XXX_BMODE_BITMASK)
#define T2E6XXX_get_hpi_en()				(T2E6XXX_get_dsp_cnf_rg() & T2E6XXX_HPI_EN_BITMASK)
#define T2E6XXX_get_opmode()				(T2E6XXX_get_dsp_cnf_rg() & T2E6XXX_OPMODE_BITMASK)
	// direct get macros
#define T2E6XXX_BMODE_IS_HPI				(T2E6XXX_get_bmode() == T2E6XXX_BMODE_HPI)
#define T2E6XXX_BMODE_IS_FLASH8				(T2E6XXX_get_bmode() == T2E6XXX_BMODE_FLASH8)
#define T2E6XXX_HPI_EN_IS_OFF				(T2E6XXX_get_hpi_en() == T2E6XXX_HPI_EN_OFF)
#define T2E6XXX_HPI_EN_IS_ON				(T2E6XXX_get_hpi_en() == T2E6XXX_HPI_EN_ON)
#define T2E6XXX_OPMODE_IS_SA				(T2E6XXX_get_opmode() == T2E6XXX_OPMODE_SA)
#define T2E6XXX_OPMODE_IS_HOST				(T2E6XXX_get_opmode() == T2E6XXX_OPMODE_HOST)


//------------ DCM installation status macros --------------------
	// The T2E6XXX_DCM_CNF_RG contains DCM installation status for E2/6xxx board
#define T2E6XXX_get_dcm_cnf_rg()			((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_DCM_CNF_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
	// direct get macros
#define T2E6XXX_get_piox_dcm_type()			(T2E6XXX_get_dcm_cnf_rg() & T2E6XXX_PIOX_DCM_TYPE_BITMASK)
#define T2E6XXX_get_asiox_dcm_type()		(T2E6XXX_get_dcm_cnf_rg() & T2E6XXX_ASIOX_DCM_TYPE_BITMASK)
#define T2E6XXX_get_hcx_dcm_type()			(T2E6XXX_get_dcm_cnf_rg() & T2E6XXX_HCX_DCM_TYPE_BITMASK)
	// condition check macros (for use in IF() and other conditional operators)
#define T2E6XXX_PIOX_DCM_IS_INSTALLED		((T2E6XXX_get_piox_dcm_type() == T2E6XXX_PIOX_DCM_TYPE_ASYNC) ||\
												(T2E6XXX_get_piox_dcm_type() == T2E6XXX_PIOX_DCM_TYPE_ASYNC_SYNC))
#define T2E6XXX_PIOX_DCM_TYPE_IS_ASYNC		(T2E6XXX_get_piox_dcm_type() == T2E6XXX_PIOX_DCM_TYPE_ASYNC)
#define T2E6XXX_PIOX_DCM_TYPE_IS_ASYNC_SYNC	(T2E6XXX_get_piox_dcm_type() == T2E6XXX_PIOX_DCM_TYPE_ASYNC_SYNC)
#define T2E6XXX_ASIOX_DCM_IS_INSTALLED		((T2E6XXX_get_asiox_dcm_type() == T2E6XXX_ASIOX_DCM_TYPE_SIO) ||\
												(T2E6XXX_get_asiox_dcm_type() == T2E6XXX_ASIOX_DCM_TYPE_SIO_PIO))
#define T2E6XXX_ASIOX_DCM_TYPE_IS_SIO		(T2E6XXX_get_asiox_dcm_type() == T2E6XXX_ASIOX_DCM_TYPE_SIO)
#define T2E6XXX_ASIOX_DCM_TYPE_IS_SIO_PIO	(T2E6XXX_get_asiox_dcm_type() == T2E6XXX_ASIOX_DCM_TYPE_SIO_PIO)
#define T2E6XXX_HCX_DCM_IS_INSTALLED		((T2E6XXX_get_hcx_dcm_type() == T2E6XXX_HCX_DCM_TYPE_ASYNC) ||\
												(T2E6XXX_get_hcx_dcm_type() == T2E6XXX_HCX_DCM_TYPE_ASYNC_SYNC))
#define T2E6XXX_HCX_DCM_TYPE_IS_ASYNC		(T2E6XXX_get_hcx_dcm_type() == T2E6XXX_HCX_DCM_TYPE_ASYNC)
#define T2E6XXX_HCX_DCM_TYPE_IS_ASYNC_SYNC	(T2E6XXX_get_hcx_dcm_type() == T2E6XXX_HCX_DCM_TYPE_ASYNC_SYNC)



//----------------------------------------------------------------------------
//------------ Macros to control T2E6XXX controller DSP environment
// (external interrupts, DSP serial ports, FLASH, WDT circuit, UART, USB, RTC1, GPIO)
//----------------------------------------------------------------------------

//------------ C6xxx DSP EXT_INT4/EXT_INT7 and NMI interrupt selectors setting macros
// via T2E6XXX_EXT_INT4..7/NMI_SEL_RG registers
#define T2E6XXX_set_ext_int4_sel_rg(v)		(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_EXT_INT4_SEL_RG_ADDR)=((T2E6XXX_IO_DATA_TYPE)v)
#define T2E6XXX_get_ext_int4_sel_rg()		((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_EXT_INT4_SEL_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
#define T2E6XXX_set_ext_int5_sel_rg(v)		(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_EXT_INT5_SEL_RG_ADDR)=((T2E6XXX_IO_DATA_TYPE)v)
#define T2E6XXX_get_ext_int5_sel_rg()		((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_EXT_INT5_SEL_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
#define T2E6XXX_set_ext_int6_sel_rg(v)		(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_EXT_INT6_SEL_RG_ADDR)=((T2E6XXX_IO_DATA_TYPE)v)
#define T2E6XXX_get_ext_int6_sel_rg()		((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_EXT_INT6_SEL_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
#define T2E6XXX_set_ext_int7_sel_rg(v)		(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_EXT_INT7_SEL_RG_ADDR)=((T2E6XXX_IO_DATA_TYPE)v)
#define T2E6XXX_get_ext_int7_sel_rg()		((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_EXT_INT7_SEL_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
#define T2E6XXX_set_nmi_sel_rg(v)			(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_NMI_SEL_RG_ADDR)=((T2E6XXX_IO_DATA_TYPE)v)
#define T2E6XXX_get_nmi_sel_rg()			((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_NMI_SEL_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)

	// dedicated bit-specific macros 
#define T2E6XXX_set_ext_int4_sel(v)			T2E6XXX_set_ext_int4_sel_rg(v)
#define T2E6XXX_get_ext_int4_sel()			T2E6XXX_get_ext_int4_sel_rg()
#define T2E6XXX_set_ext_int5_sel(v)			T2E6XXX_set_ext_int5_sel_rg(v)
#define T2E6XXX_get_ext_int5_sel()			T2E6XXX_get_ext_int5_sel_rg()
#define T2E6XXX_set_ext_int6_sel(v)			T2E6XXX_set_ext_int6_sel_rg(v)
#define T2E6XXX_get_ext_int6_sel()			T2E6XXX_get_ext_int6_sel_rg()
#define T2E6XXX_set_ext_int7_sel(v)			T2E6XXX_set_ext_int7_sel_rg(v)
#define T2E6XXX_get_ext_int7_sel()			T2E6XXX_get_ext_int7_sel_rg()
#define T2E6XXX_set_nmi_sel(v)				T2E6XXX_set_nmi_sel_rg(v)
#define T2E6XXX_get_nmi_sel()				T2E6XXX_get_nmi_sel_rg()

	// universal macros to set/get EXT_INT/EXT_NMI selector regs using EXT_INT ID
	// IDs for EXT_INT/NMI selector registers
#define T2E6XXX_EXT_INT4_SEL				0
#define T2E6XXX_EXT_INT5_SEL				1
#define T2E6XXX_EXT_INT6_SEL				2
#define T2E6XXX_EXT_INT7_SEL				3
#define T2E6XXX_NMI_SEL						4

	//input params: IRQ={T2E6XXX_EXT_INTx_SEL/T2E6XXX_NMI_SEL}, V={T2E6XXX_EXT_INT_SEL_..}
#define T2E6XXX_set_ext_int_sel_rg(irq,v)	if(irq == 0) T2E6XXX_set_ext_int4_sel_rg(v); \
												else if(irq == 1) T2E6XXX_set_ext_int5_sel_rg(v);\
													else if(irq == 2) T2E6XXX_set_ext_int6_sel_rg(v);\
														else if(irq == 3) T2E6XXX_set_ext_int7_sel_rg(v);\
															else T2E6XXX_set_nmi_sel_rg(v)
#define T2E6XXX_get_ext_int_sel_rg(irq)		((irq == 0)? T2E6XXX_get_ext_int4_sel(): \
												((irq == 1)? T2E6XXX_get_ext_int5_sel():\
													((irq == 2)? T2E6XXX_get_ext_int6_sel():\
														((irq == 3)? T2E6XXX_get_ext_int7_sel():T2E6XXX_get_nmi_sel()))))
	// macros aliases
#define T2E6XXX_set_ext_int_sel(irq,v)		T2E6XXX_set_ext_int_sel_rg(irq,v)
#define T2E6XXX_get_ext_int_sel(irq)		T2E6XXX_get_ext_int_sel_rg(irq)

	// direct universal set/get macros
#define T2E6XXX_SET_EXT_INT_SEL_OFF(irq)				T2E6XXX_set_ext_int_sel(irq,T2E6XXX_EXT_INT_SEL_OFF)
#define T2E6XXX_SET_EXT_INT_SEL_WDT(irq)				T2E6XXX_set_ext_int_sel(irq,T2E6XXX_EXT_INT_SEL_WDT)
#define T2E6XXX_SET_EXT_INT_SEL_RTC(irq)				T2E6XXX_set_ext_int_sel(irq,T2E6XXX_EXT_INT_SEL_RTC)
#define T2E6XXX_SET_EXT_INT_SEL_GPIO0(irq)				T2E6XXX_set_ext_int_sel(irq,T2E6XXX_EXT_INT_SEL_GPIO0)
#define T2E6XXX_SET_EXT_INT_SEL_UARTA(irq)				T2E6XXX_set_ext_int_sel(irq,((irq < 4)? T2E6XXX_EXT_INT_SEL_UARTA:T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_UARTB(irq)				T2E6XXX_set_ext_int_sel(irq,((irq < 4)? T2E6XXX_EXT_INT_SEL_UARTB:T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_USB(irq)				T2E6XXX_set_ext_int_sel(irq,((irq < 4)? T2E6XXX_EXT_INT_SEL_USB:T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_USB_DC(irq)				T2E6XXX_set_ext_int_sel(irq,((irq < 4)? (irq == 0? T2E6XXX_EXT_INT_SEL_USB_DC:T2E6XXX_EXT_INT_SEL_OFF):T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_USB_HC(irq)				T2E6XXX_set_ext_int_sel(irq,((irq < 4)? (irq == 1? T2E6XXX_EXT_INT_SEL_USB_HC:T2E6XXX_EXT_INT_SEL_OFF):T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_USB_DC_DREQ(irq)		T2E6XXX_set_ext_int_sel(irq,((irq < 4)? (irq == 2? T2E6XXX_EXT_INT_SEL_USB_DC_DREQ:T2E6XXX_EXT_INT_SEL_OFF):T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_USB_HC_DREQ(irq)		T2E6XXX_set_ext_int_sel(irq,((irq < 4)? (irq == 3? T2E6XXX_EXT_INT_SEL_USB_HC_DREQ:T2E6XXX_EXT_INT_SEL_OFF):T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_PIOX_ASYNC_IRQ0(irq)	T2E6XXX_set_ext_int_sel(irq,((irq < 4)? T2E6XXX_EXT_INT_SEL_PIOX_ASYNC_IRQ0:T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_PIOX_ASYNC_IRQ1(irq)	T2E6XXX_set_ext_int_sel(irq,((irq < 4)? T2E6XXX_EXT_INT_SEL_PIOX_ASYNC_IRQ1:T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_PIOX_SYNC_IRQ0(irq)		T2E6XXX_set_ext_int_sel(irq,((irq < 4)? T2E6XXX_EXT_INT_SEL_PIOX_SYNC_IRQ0:T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_PIOX_SYNC_IRQ1(irq)		T2E6XXX_set_ext_int_sel(irq,((irq < 4)? T2E6XXX_EXT_INT_SEL_PIOX_SYNC_IRQ1:T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_SIOX_IRQ0(irq)			T2E6XXX_set_ext_int_sel(irq,((irq < 4)? T2E6XXX_EXT_INT_SEL_SIOX_IRQ0:T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_SIOX_IRQ1(irq)			T2E6XXX_set_ext_int_sel(irq,((irq < 4)? T2E6XXX_EXT_INT_SEL_SIOX_IRQ1:T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_HCX_SYNC_IRQ0(irq)		T2E6XXX_set_ext_int_sel(irq,((irq < 4)? T2E6XXX_EXT_INT_SEL_HCX_SYNC_IRQ0:T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_ASIOX_AMUTEIN0(irq)		T2E6XXX_set_ext_int_sel(irq,((irq < 4)? T2E6XXX_EXT_INT_SEL_ASIOX_AMUTEIN0:T2E6XXX_EXT_INT_SEL_OFF))
#define T2E6XXX_SET_EXT_INT_SEL_ASIOX_AMUTEIN1(irq)		T2E6XXX_set_ext_int_sel(irq,((irq < 4)? T2E6XXX_EXT_INT_SEL_ASIOX_AMUTEIN1:T2E6XXX_EXT_INT_SEL_OFF))

#define T2E6XXX_EXT_INT_SEL_IS_OFF(irq)					(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_OFF)
#define T2E6XXX_EXT_INT_SEL_IS_WDT(irq)					(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_WDT)
#define T2E6XXX_EXT_INT_SEL_IS_RTC(irq)					(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_RTC)
#define T2E6XXX_EXT_INT_SEL_IS_GPIO0(irq)				(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_GPIO0)
#define T2E6XXX_EXT_INT_SEL_IS_UARTA(irq)				(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_UARTA)
#define T2E6XXX_EXT_INT_SEL_IS_UARTB(irq)				(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_UARTB)
#define T2E6XXX_EXT_INT_SEL_IS_USB(irq)					(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_USB)
#define T2E6XXX_EXT_INT_SEL_IS_USB_DC(irq)				(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_USB_DC)
#define T2E6XXX_EXT_INT_SEL_IS_USB_HC(irq)				(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_USB_HC)
#define T2E6XXX_EXT_INT_SEL_IS_USB_DC_DREQ(irq)			(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_USB_DC_DREQ)
#define T2E6XXX_EXT_INT_SEL_IS_USB_HC_DREQ(irq)			(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_USB_HC_DREQ)
#define T2E6XXX_EXT_INT_SEL_IS_PIOX_ASYNC_IRQ0(irq)		(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_PIOX_ASYNC_IRQ0)
#define T2E6XXX_EXT_INT_SEL_IS_PIOX_ASYNC_IRQ1(irq)		(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_PIOX_ASYNC_IRQ1)
#define T2E6XXX_EXT_INT_SEL_IS_PIOX_SYNC_IRQ0(irq)		(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_PIOX_SYNC_IRQ0)
#define T2E6XXX_EXT_INT_SEL_IS_PIOX_SYNC_IRQ1(irq)		(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_PIOX_SYNC_IRQ1)
#define T2E6XXX_EXT_INT_SEL_IS_SIOX_IRQ0(irq)			(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_SIOX_IRQ0)
#define T2E6XXX_EXT_INT_SEL_IS_SIOX_IRQ1(irq)			(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_SIOX_IRQ1)
#define T2E6XXX_EXT_INT_SEL_IS_HCX_SYNC_IRQ0(irq)		(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_HCX_SYNC_IRQ0)
#define T2E6XXX_EXT_INT_SEL_IS_ASIOX_AMUTEIN0(irq)		(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_ASIOX_AMUTEIN0)
#define T2E6XXX_EXT_INT_SEL_IS_ASIOX_AMUTEIN1(irq)		(T2E6XXX_get_ext_int_sel(irq)==T2E6XXX_EXT_INT_SEL_ASIOX_AMUTEIN1)


//------------ Macro to configure polarity of DSP EXT_INT4..7 inputs upon the T2E6XXX board type
// E2/6713 board: require that EXT_INT4..7 inputs are configired as active high.
#define T2E6XXX_INIT_EXT_INT_POLARITY		(*(T2E6XXX_IO_DATA_TYPE *) 0x019C0008) = 0



//------------ DSP McBSP/McASP/I2C serial port configuration macros via T2E6XXX_DSP_PORTS_CNTR_RG

#define T2E6XXX_get_dsp_ports_cntr_rg()		((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_DSP_PORTS_CNTR_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
#define T2E6XXX_set_dsp_ports_cntr_rg(v)	(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_DSP_PORTS_CNTR_RG_ADDR) = ((T2E6XXX_IO_DATA_TYPE)v)

	// dedicated bit specific macros
#define T2E6XXX_get_mcasp0_buf_en1()		(T2E6XXX_get_dsp_ports_cntr_rg() & T2E6XXX_MCASP0_BUF_EN1_BITMASK)
#define T2E6XXX_set_mcasp0_buf_en1(v)		(T2E6XXX_set_dsp_ports_cntr_rg((T2E6XXX_get_dsp_ports_cntr_rg() & ~T2E6XXX_MCASP0_BUF_EN1_BITMASK) | (v & T2E6XXX_MCASP0_BUF_EN1_BITMASK)))
#define T2E6XXX_get_mcasp0_buf_en2()		(T2E6XXX_get_dsp_ports_cntr_rg() & T2E6XXX_MCASP0_BUF_EN2_BITMASK)
#define T2E6XXX_set_mcasp0_buf_en2(v)		(T2E6XXX_set_dsp_ports_cntr_rg((T2E6XXX_get_dsp_ports_cntr_rg() & ~T2E6XXX_MCASP0_BUF_EN2_BITMASK) | (v & T2E6XXX_MCASP0_BUF_EN2_BITMASK)))
#define T2E6XXX_get_mcasp0_buf_en3()		(T2E6XXX_get_dsp_ports_cntr_rg() & T2E6XXX_MCASP0_BUF_EN3_BITMASK)
#define T2E6XXX_set_mcasp0_buf_en3(v)		(T2E6XXX_set_dsp_ports_cntr_rg((T2E6XXX_get_dsp_ports_cntr_rg() & ~T2E6XXX_MCASP0_BUF_EN3_BITMASK) | (v & T2E6XXX_MCASP0_BUF_EN3_BITMASK)))
#define T2E6XXX_get_mcasp0_buf_en4()		(T2E6XXX_get_dsp_ports_cntr_rg() & T2E6XXX_MCASP0_BUF_EN4_BITMASK)
#define T2E6XXX_set_mcasp0_buf_en4(v)		(T2E6XXX_set_dsp_ports_cntr_rg((T2E6XXX_get_dsp_ports_cntr_rg() & ~T2E6XXX_MCASP0_BUF_EN4_BITMASK) | (v & T2E6XXX_MCASP0_BUF_EN4_BITMASK)))
#define T2E6XXX_get_mcasp1_buf_en()			(T2E6XXX_get_dsp_ports_cntr_rg() & T2E6XXX_MCASP1_BUF_EN_BITMASK)
#define T2E6XXX_set_mcasp1_buf_en(v)		(T2E6XXX_set_dsp_ports_cntr_rg((T2E6XXX_get_dsp_ports_cntr_rg() & ~T2E6XXX_MCASP1_BUF_EN_BITMASK) | (v & T2E6XXX_MCASP1_BUF_EN_BITMASK)))
#define T2E6XXX_get_mcbsp0_buf_en()			(T2E6XXX_get_dsp_ports_cntr_rg() & T2E6XXX_MCBSP0_BUF_EN_BITMASK)
#define T2E6XXX_set_mcbsp0_buf_en(v)		(T2E6XXX_set_dsp_ports_cntr_rg((T2E6XXX_get_dsp_ports_cntr_rg() & ~T2E6XXX_MCBSP0_BUF_EN_BITMASK) | (v & T2E6XXX_MCBSP0_BUF_EN_BITMASK)))
#define T2E6XXX_get_mcbsp1_buf_en()			(T2E6XXX_get_dsp_ports_cntr_rg() & T2E6XXX_MCBSP1_BUF_EN_BITMASK)
#define T2E6XXX_set_mcbsp1_buf_en(v)		(T2E6XXX_set_dsp_ports_cntr_rg((T2E6XXX_get_dsp_ports_cntr_rg() & ~T2E6XXX_MCBSP1_BUF_EN_BITMASK) | (v & T2E6XXX_MCBSP1_BUF_EN_BITMASK)))
#define T2E6XXX_get_i2c1_buf_en()			(T2E6XXX_get_dsp_ports_cntr_rg() & T2E6XXX_I2C1_BUF_EN_BITMASK)
#define T2E6XXX_set_i2c1_buf_en(v)			(T2E6XXX_set_dsp_ports_cntr_rg((T2E6XXX_get_dsp_ports_cntr_rg() & ~T2E6XXX_I2C1_BUF_EN_BITMASK) | (v & T2E6XXX_I2C1_BUF_EN_BITMASK)))
#define T2E6XXX_get_mcasp0_buf_en()			(T2E6XXX_get_dsp_ports_cntr_rg() & T2E6XXX_MCASP0_BUF_EN_BITMASK)
#define T2E6XXX_set_mcasp0_buf_en(v)		(T2E6XXX_set_dsp_ports_cntr_rg((T2E6XXX_get_dsp_ports_cntr_rg() & ~T2E6XXX_MCASP0_BUF_EN_BITMASK) | (v & T2E6XXX_MCASP0_BUF_EN_BITMASK)))

	// direct bit set macros
#define T2E6XXX_SET_MCASP0_BUF_EN1_OFF		(T2E6XXX_set_mcasp0_buf_en1(T2E6XXX_MCASP0_BUF_EN1_OFF))
#define T2E6XXX_SET_MCASP0_BUF_EN1_ON		(T2E6XXX_set_mcasp0_buf_en1(T2E6XXX_MCASP0_BUF_EN1_ON))
#define T2E6XXX_SET_MCASP0_BUF_EN2_OFF		(T2E6XXX_set_mcasp0_buf_en2(T2E6XXX_MCASP0_BUF_EN2_OFF))
#define T2E6XXX_SET_MCASP0_BUF_EN2_ON		(T2E6XXX_set_mcasp0_buf_en2(T2E6XXX_MCASP0_BUF_EN2_ON))
#define T2E6XXX_SET_MCASP0_BUF_EN3_OFF		(T2E6XXX_set_mcasp0_buf_en3(T2E6XXX_MCASP0_BUF_EN3_OFF))
#define T2E6XXX_SET_MCASP0_BUF_EN3_ON		(T2E6XXX_set_mcasp0_buf_en3(T2E6XXX_MCASP0_BUF_EN3_ON))
#define T2E6XXX_SET_MCASP0_BUF_EN4_OFF		(T2E6XXX_set_mcasp0_buf_en4(T2E6XXX_MCASP0_BUF_EN4_OFF))
#define T2E6XXX_SET_MCASP0_BUF_EN4_ON		(T2E6XXX_set_mcasp0_buf_en4(T2E6XXX_MCASP0_BUF_EN4_ON))
#define T2E6XXX_SET_MCASP1_BUF_EN_OFF		(T2E6XXX_set_mcasp1_buf_en(T2E6XXX_MCASP1_BUF_EN_OFF))
#define T2E6XXX_SET_MCASP1_BUF_EN_ON		(T2E6XXX_set_mcasp1_buf_en(T2E6XXX_MCASP1_BUF_EN_ON))
#define T2E6XXX_SET_MCBSP0_BUF_EN_OFF		(T2E6XXX_set_mcbsp0_buf_en(T2E6XXX_MCBSP0_BUF_EN_OFF))
#define T2E6XXX_SET_MCBSP0_BUF_EN_ON		(T2E6XXX_set_mcbsp0_buf_en(T2E6XXX_MCBSP0_BUF_EN_ON))
#define T2E6XXX_SET_MCBSP1_BUF_EN_OFF		(T2E6XXX_set_mcbsp1_buf_en(T2E6XXX_MCBSP1_BUF_EN_OFF))
#define T2E6XXX_SET_MCBSP1_BUF_EN_ON		(T2E6XXX_set_mcbsp1_buf_en(T2E6XXX_MCBSP1_BUF_EN_ON))
#define T2E6XXX_SET_I2C1_BUF_EN_OFF			(T2E6XXX_set_i2c1_buf_en(T2E6XXX_I2C1_BUF_EN_OFF))
#define T2E6XXX_SET_I2C1_BUF_EN_ON			(T2E6XXX_set_i2c1_buf_en(T2E6XXX_I2C1_BUF_EN_ON))
#define T2E6XXX_SET_MCASP0_BUF_EN_OFF		(T2E6XXX_set_mcasp0_buf_en(T2E6XXX_MCASP0_BUF_EN_OFF))
#define T2E6XXX_SET_MCASP0_BUF_EN_ON		(T2E6XXX_set_mcasp0_buf_en(T2E6XXX_MCASP0_BUF_EN_ON))

	// condition check macros (for use in IF() and other conditional operators)
#define T2E6XXX_MCASP0_BUF_EN1_IS_ON		(T2E6XXX_get_mcasp0_buf_en1() == T2E6XXX_MCASP0_BUF_EN1_ON)
#define T2E6XXX_MCASP0_BUF_EN2_IS_ON		(T2E6XXX_get_mcasp0_buf_en2() == T2E6XXX_MCASP0_BUF_EN2_ON)
#define T2E6XXX_MCASP0_BUF_EN3_IS_ON		(T2E6XXX_get_mcasp0_buf_en3() == T2E6XXX_MCASP0_BUF_EN3_ON)
#define T2E6XXX_MCASP0_BUF_EN4_IS_ON		(T2E6XXX_get_mcasp0_buf_en4() == T2E6XXX_MCASP0_BUF_EN4_ON)
#define T2E6XXX_MCASP1_BUF_EN_IS_ON			(T2E6XXX_get_mcasp1_buf_en() == T2E6XXX_MCASP1_BUF_EN_ON)
#define T2E6XXX_MCBSP0_BUF_EN_IS_ON			(T2E6XXX_get_mcbsp0_buf_en() == T2E6XXX_MCBSP0_BUF_EN_ON)
#define T2E6XXX_MCBSP1_BUF_EN_IS_ON			(T2E6XXX_get_mcbsp1_buf_en() == T2E6XXX_MCBSP1_BUF_EN_ON)
#define T2E6XXX_I2C1_BUF_EN_IS_ON			(T2E6XXX_get_i2c1_buf_en() == T2E6XXX_I2C1_BUF_EN_ON)
#define T2E6XXX_MCASP0_BUF_EN_IS_ON			(T2E6XXX_get_mcasp0_buf_en() == T2E6XXX_MCASP0_BUF_EN_ON)



//------------ T2E6XXX_FLASH_CNTR_RG FLASH control register macros
#define T2E6XXX_get_flash_cntr_rg()			((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_FLASH_CNTR_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
#define T2E6XXX_set_flash_cntr_rg(v)		(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_FLASH_CNTR_RG_ADDR) = ((T2E6XXX_IO_DATA_TYPE)v)

	// dedicated bit specific macros
#define T2E6XXX_get_flash64m_boot_sector_wr_en()		(T2E6XXX_get_flash_cntr_rg() & T2E6XXX_FLASH64M_BOOT_SECTOR_WR_EN_BITMASK)
#define T2E6XXX_set_flash64m_boot_sector_wr_en(v)		(T2E6XXX_set_flash_cntr_rg((T2E6XXX_get_flash_cntr_rg() & ~T2E6XXX_FLASH64M_BOOT_SECTOR_WR_EN_BITMASK) | (v & T2E6XXX_FLASH64M_BOOT_SECTOR_WR_EN_BITMASK)))
#define T2E6XXX_get_flash_wr_en()						(T2E6XXX_get_flash_cntr_rg() & T2E6XXX_FLASH_WR_EN_BITMASK)
#define T2E6XXX_set_flash_wr_en(v)						(T2E6XXX_set_flash_cntr_rg((T2E6XXX_get_flash_cntr_rg() & ~T2E6XXX_FLASH_WR_EN_BITMASK) | (v & T2E6XXX_FLASH_WR_EN_BITMASK)))
#define T2E6XXX_get_flash64m_boot_sector_xwrprot_stat()	(T2E6XXX_get_flash_cntr_rg() & T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_BITMASK)
#define T2E6XXX_get_flash_xwrprot_stat()				(T2E6XXX_get_flash_cntr_rg() & T2E6XXX_FLASH_XWRPROT_STAT_BITMASK)

	// direct bit set macros
#define T2E6XXX_SET_FLASH64M_BOOT_SECTOR_WR_EN_OFF		(T2E6XXX_set_flash64m_boot_sector_wr_en(T2E6XXX_FLASH64M_BOOT_SECTOR_WR_EN_OFF))
#define T2E6XXX_SET_FLASH64M_BOOT_SECTOR_WR_EN_ON		(T2E6XXX_set_flash64m_boot_sector_wr_en(T2E6XXX_FLASH64M_BOOT_SECTOR_WR_EN_ON))
#define T2E6XXX_SET_FLASH_WR_EN_OFF						(T2E6XXX_set_flash_wr_en(T2E6XXX_FLASH_WR_EN_OFF))
#define T2E6XXX_SET_FLASH_WR_EN_ON						(T2E6XXX_set_flash_wr_en(T2E6XXX_FLASH_WR_EN_ON))

	// condition check macros (for use in IF() and other conditional operators)
#define T2E6XXX_FLASH64M_BOOT_SECTOR_WR_EN_IS_ON		(T2E6XXX_get_flash64m_boot_sector_wr_en() == T2E6XXX_FLASH64M_BOOT_SECTOR_WR_EN_ON)
#define T2E6XXX_FLASH_WR_EN_IS_ON						(T2E6XXX_get_flash_wr_en() == T2E6XXX_FLASH_WR_EN_ON)
#define T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_IS_ON	(T2E6XXX_get_flash64m_boot_sector_xwrprot_stat() == T2E6XXX_FLASH64M_BOOT_SECTOR_XWRPROT_STAT_ON)
#define T2E6XXX_FLASH_XWRPROT_STAT_IS_ON				(T2E6XXX_get_flash_xwrprot_stat() == T2E6XXX_FLASH_XWRPROT_STAT_ON)



//------------ T2E6XXX_FLASH_PAGE_RG FLASH page register macros --
#define T2E6XXX_get_flash_page_rg()			((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_FLASH_PAGE_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
#define T2E6XXX_set_flash_page_rg(v)		(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_FLASH_PAGE_RG_ADDR) = ((T2E6XXX_IO_DATA_TYPE)v)

#define T2E6XXX_get_flash_page()			(T2E6XXX_get_flash_page_rg() & T2E6XXX_FLASH_PAGE_RG_BITMASK)
#define T2E6XXX_set_flash_page(v)			(T2E6XXX_set_flash_page_rg((T2E6XXX_get_flash_cntr_rg() & ~T2E6XXX_FLASH_PAGE_RG_BITMASK) | (v & T2E6XXX_FLASH_PAGE_RG_BITMASK)))



//------------ T2E6XXX_WDT_RTC_CNTR_RG uP Supervisory WDT/RTC control macros
	// reset uP Supervisory WDT
#define T2E6XXX_set_wdt_reset()				(*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_WDT_RESET_RG_ADDR) = 0

	// WDT/RTC control register (uP Supervisory WDT and RTC enable)
#define T2E6XXX_set_wdt_rtc_cntr_rg(v)		(*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_WDT_RTC_CNTR_RG_ADDR)=((T2E6XXX_IO_DATA_TYPE)v)
#define T2E6XXX_get_wdt_rtc_cntr_rg()		((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_WDT_RTC_CNTR_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)

	// dedicated bit-specific macros with V = {T2E6XXX_WDT_EN_ON,T2E6XXX_WDT_EN_OFF}
#define T2E6XXX_set_wdt_en(v)				T2E6XXX_set_wdt_rtc_cntr_rg((T2E6XXX_get_wdt_rtc_cntr_rg() & ~T2E6XXX_WDT_EN_BITMASK) | (v & T2E6XXX_WDT_EN_BITMASK))
#define T2E6XXX_get_wdt_en()				(T2E6XXX_get_wdt_rtc_cntr_rg() & T2E6XXX_WDT_EN_BITMASK)

	// dedicated bit-specific macros with V = {T2E6XXX_RTC_EN_ON,T2E6XXX_RTC_EN_OFF}
#define T2E6XXX_set_rtc_en(v)				T2E6XXX_set_wdt_rtc_cntr_rg((T2E6XXX_get_wdt_rtc_cntr_rg() & ~T2E6XXX_RTC_EN_BITMASK) | (v & T2E6XXX_RTC_EN_BITMASK))
#define T2E6XXX_get_rtc_en()				(T2E6XXX_get_wdt_rtc_cntr_rg() & T2E6XXX_RTC_EN_BITMASK)

	// dedicated bit-specific macros
#define T2E6XXX_get_rtc_xps_en()			(T2E6XXX_get_wdt_rtc_cntr_rg() & T2E6XXX_RTC_XPS_EN_BITMASK)

	// direct bit-specific set/get macros
#define T2E6XXX_SET_WDT_RESET				T2E6XXX_set_wdt_reset()
#define T2E6XXX_SET_WDT_EN_OFF				T2E6XXX_set_wdt_en(T2E6XXX_WDT_EN_OFF)
#define T2E6XXX_SET_WDT_EN_ON				T2E6XXX_set_wdt_en(T2E6XXX_WDT_EN_ON)
#define T2E6XXX_SET_RTC_EN_OFF				T2E6XXX_set_rtc_en(T2E6XXX_RTC_EN_OFF)
#define T2E6XXX_SET_RTC_EN_ON				T2E6XXX_set_rtc_en(T2E6XXX_RTC_EN_ON)

	// condition check macros (for use in IF() and other conditional operators)
#define T2E6XXX_WDT_EN_IS_ON				(T2E6XXX_get_wdt_en() == T2E6XXX_WDT_EN_ON)
#define T2E6XXX_RTC_EN_IS_ON				(T2E6XXX_get_rtc_en() == T2E6XXX_RTC_EN_ON)
#define T2E6XXX_RTC_XPS_EN_IS_ON			(T2E6XXX_get_rtc_xps_en() == T2E6XXX_RTC_XPS_EN_ON)



//------------ UART access macros --------------------------------
// ST16C2550 DUART controller access macros
// input parameters: a = address {UART registers offset from T2E6XXX_DSP_DEF.HXX}, v = {input 8-bit data}
#define T2E6XXX_set_uarta_rg(a,v)			(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_UARTA_AREA_SADDR + (((a) << T2E6XXX_UART_RG_OFFSET_BITSHIFT) & T2E6XXX_UART_RG_OFFSET_BITMASK)))=((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_UART_DATA_BITMASK)
#define T2E6XXX_get_uarta_rg(a)				((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_UARTA_AREA_SADDR + (((a) << T2E6XXX_UART_RG_OFFSET_BITSHIFT) & T2E6XXX_UART_RG_OFFSET_BITMASK))) & T2E6XXX_UART_DATA_BITMASK)

#define T2E6XXX_set_uartb_rg(a,v)			(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_UARTB_AREA_SADDR + (((a) << T2E6XXX_UART_RG_OFFSET_BITSHIFT) & T2E6XXX_UART_RG_OFFSET_BITMASK)))=((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_UART_DATA_BITMASK)
#define T2E6XXX_get_uartb_rg(a)				((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_UARTB_AREA_SADDR + (((a) << T2E6XXX_UART_RG_OFFSET_BITSHIFT) & T2E6XXX_UART_RG_OFFSET_BITMASK))) & T2E6XXX_UART_DATA_BITMASK)



//------------ USB access macros ---------------------------------
// For E2/6713 board there are 3 alternate versions of installed USB controllers:
// USB1 - USS-820 (8-bit data width), USB2 - NET2272 (16-bit data width) and USB3 - ISP1761 (32-bit data width).
// input parameters: a = address {USB registers offset from T2E6XXX_DSP_DEF.HXX}, v = {input data}
#define T2E6XXX_set_usb1_rg(a,v)			(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_USB_AREA_SADDR + (((a) << T2E6XXX_USB1_RG_OFFSET_BITSHIFT) & T2E6XXX_USB1_RG_OFFSET_BITMASK))) =((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_USB1_DATA_BITMASK)
#define T2E6XXX_set_usb2_rg(a,v)			(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_USB_AREA_SADDR + (((a) << T2E6XXX_USB2_RG_OFFSET_BITSHIFT) & T2E6XXX_USB2_RG_OFFSET_BITMASK))) =((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_USB2_DATA_BITMASK)
#define T2E6XXX_set_usb3_rg(a,v)			(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_USB_AREA_SADDR + (((a) << T2E6XXX_USB3_RG_OFFSET_BITSHIFT) & T2E6XXX_USB3_RG_OFFSET_BITMASK))) =((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_USB3_DATA_BITMASK)

#define T2E6XXX_get_usb1_rg(a)				((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_USB_AREA_SADDR + (((a) << T2E6XXX_USB1_RG_OFFSET_BITSHIFT) & T2E6XXX_USB1_RG_OFFSET_BITMASK))) & T2E6XXX_USB1_DATA_BITMASK)
#define T2E6XXX_get_usb2_rg(a)				((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_USB_AREA_SADDR + (((a) << T2E6XXX_USB2_RG_OFFSET_BITSHIFT) & T2E6XXX_USB2_RG_OFFSET_BITMASK))) & T2E6XXX_USB2_DATA_BITMASK)
#define T2E6XXX_get_usb3_rg(a)				((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_USB_AREA_SADDR + (((a) << T2E6XXX_USB3_RG_OFFSET_BITSHIFT) & T2E6XXX_USB3_RG_OFFSET_BITMASK))) & T2E6XXX_USB3_DATA_BITMASK)

// Universal macros for USB accesses
#define T2E6XXX_set_usb_rg(a,v)				(T2E6XXX_USB_ID_IS_USB1 ? ((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_USB_AREA_SADDR + (((a) << T2E6XXX_USB1_RG_OFFSET_BITSHIFT) & T2E6XXX_USB1_RG_OFFSET_BITMASK))) =((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_USB1_DATA_BITMASK)):\
												(T2E6XXX_USB_ID_IS_USB2 ? ((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_USB_AREA_SADDR + (((a) << T2E6XXX_USB2_RG_OFFSET_BITSHIFT) & T2E6XXX_USB2_RG_OFFSET_BITMASK))) =((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_USB2_DATA_BITMASK)):\
													((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_USB_AREA_SADDR + (((a) << T2E6XXX_USB3_RG_OFFSET_BITSHIFT) & T2E6XXX_USB3_RG_OFFSET_BITMASK))) =((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_USB3_DATA_BITMASK))))

#define T2E6XXX_get_usb_rg(a)				(T2E6XXX_USB_ID_IS_USB1 ? ((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_USB_AREA_SADDR + (((a) << T2E6XXX_USB1_RG_OFFSET_BITSHIFT) & T2E6XXX_USB1_RG_OFFSET_BITMASK))) & T2E6XXX_USB1_DATA_BITMASK):\
												(T2E6XXX_USB_ID_IS_USB2 ? ((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_USB_AREA_SADDR + (((a) << T2E6XXX_USB2_RG_OFFSET_BITSHIFT) & T2E6XXX_USB2_RG_OFFSET_BITMASK))) & T2E6XXX_USB2_DATA_BITMASK):\
													((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_USB_AREA_SADDR + (((a) << T2E6XXX_USB3_RG_OFFSET_BITSHIFT) & T2E6XXX_USB3_RG_OFFSET_BITMASK))) & T2E6XXX_USB3_DATA_BITMASK)))



//------------ RTC access macros ---------------------------------
// RTC1 (DS1501) real-time clock controller registers access macros
// input parameters: a = address {RTC1 registers offset from T2E6XXX_DSP_DEF.HXX}, v = {input 8-bit data}
#define T2E6XXX_set_rtc1_rg(a,v)			(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_RTC_AREA_SADDR + (((a) << T2E6XXX_RTC1_RG_OFFSET_BITSHIFT) & T2E6XXX_RTC1_RG_OFFSET_BITMASK))) =((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_RTC1_DATA_BITMASK)
#define T2E6XXX_get_rtc1_rg(a)				((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_RTC_AREA_SADDR + (((a) << T2E6XXX_RTC1_RG_OFFSET_BITSHIFT) & T2E6XXX_RTC1_RG_OFFSET_BITMASK))) & T2E6XXX_RTC1_DATA_BITMASK)

// RTC1 Control A and Control B registers access macros
#define T2E6XXX_set_rtc1_cntra_rg(v)		T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CNTRA_RG,v)
#define T2E6XXX_get_rtc1_cntra_rg()			T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CNTRA_RG)
#define T2E6XXX_set_rtc1_cntrb_rg(v)		T2E6XXX_set_rtc1_rg(T2E6XXX_RTC1_CNTRB_RG,v)
#define T2E6XXX_get_rtc1_cntrb_rg()			T2E6XXX_get_rtc1_rg(T2E6XXX_RTC1_CNTRB_RG)

	// dedicated bit specific macros for Control A and Control B registers
#define T2E6XXX_get_rtc1_cntra_blf1()		(T2E6XXX_get_rtc1_cntra_rg() & T2E6XXX_RTC1_CNTRA_BLF1_BITMASK)
#define T2E6XXX_get_rtc1_cntra_blf2()		(T2E6XXX_get_rtc1_cntra_rg() & T2E6XXX_RTC1_CNTRA_BLF2_BITMASK)
#define T2E6XXX_set_rtc1_cntra_prs(v)		(T2E6XXX_set_rtc1_cntra_rg((T2E6XXX_get_rtc1_cntra_rg() & ~T2E6XXX_RTC1_CNTRA_PRS_BITMASK) | (v & T2E6XXX_RTC1_CNTRA_PRS_BITMASK)))
#define T2E6XXX_get_rtc1_cntra_prs()		(T2E6XXX_get_rtc1_cntra_rg() & T2E6XXX_RTC1_CNTRA_PRS_BITMASK)
#define T2E6XXX_set_rtc1_cntra_pab(v)		(T2E6XXX_set_rtc1_cntra_rg((T2E6XXX_get_rtc1_cntra_rg() & ~T2E6XXX_RTC1_CNTRA_PAB_BITMASK) | (v & T2E6XXX_RTC1_CNTRA_PAB_BITMASK)))
#define T2E6XXX_get_rtc1_cntra_pab()		(T2E6XXX_get_rtc1_cntra_rg() & T2E6XXX_RTC1_CNTRA_PAB_BITMASK)
#define T2E6XXX_set_rtc1_cntra_tdf(v)		(T2E6XXX_set_rtc1_cntra_rg((T2E6XXX_get_rtc1_cntra_rg() & ~T2E6XXX_RTC1_CNTRA_TDF_BITMASK) | (v & T2E6XXX_RTC1_CNTRA_TDF_BITMASK)))
#define T2E6XXX_get_rtc1_cntra_tdf()		(T2E6XXX_get_rtc1_cntra_rg() & T2E6XXX_RTC1_CNTRA_TDF_BITMASK)
#define T2E6XXX_set_rtc1_cntra_ksf(v)		(T2E6XXX_set_rtc1_cntra_rg((T2E6XXX_get_rtc1_cntra_rg() & ~T2E6XXX_RTC1_CNTRA_KSF_BITMASK) | (v & T2E6XXX_RTC1_CNTRA_KSF_BITMASK)))
#define T2E6XXX_get_rtc1_cntra_ksf()		(T2E6XXX_get_rtc1_cntra_rg() & T2E6XXX_RTC1_CNTRA_KSF_BITMASK)
#define T2E6XXX_set_rtc1_cntra_wdf(v)		(T2E6XXX_set_rtc1_cntra_rg((T2E6XXX_get_rtc1_cntra_rg() & ~T2E6XXX_RTC1_CNTRA_WDF_BITMASK) | (v & T2E6XXX_RTC1_CNTRA_WDF_BITMASK)))
#define T2E6XXX_get_rtc1_cntra_wdf()		(T2E6XXX_get_rtc1_cntra_rg() & T2E6XXX_RTC1_CNTRA_WDF_BITMASK)
#define T2E6XXX_get_rtc1_cntra_irqf()		(T2E6XXX_get_rtc1_cntra_rg() & T2E6XXX_RTC1_CNTRA_IRQF_BITMASK)

#define T2E6XXX_set_rtc1_cntrb_te(v)		(T2E6XXX_set_rtc1_cntrb_rg((T2E6XXX_get_rtc1_cntrb_rg() & ~T2E6XXX_RTC1_CNTRB_TE_BITMASK) | (v & T2E6XXX_RTC1_CNTRB_TE_BITMASK)))
#define T2E6XXX_get_rtc1_cntrb_te()			(T2E6XXX_get_rtc1_cntrb_rg() & T2E6XXX_RTC1_CNTRB_TE_BITMASK)
#define T2E6XXX_set_rtc1_cntrb_cs(v)		(T2E6XXX_set_rtc1_cntrb_rg((T2E6XXX_get_rtc1_cntrb_rg() & ~T2E6XXX_RTC1_CNTRB_CS_BITMASK) | (v & T2E6XXX_RTC1_CNTRB_CS_BITMASK)))
#define T2E6XXX_get_rtc1_cntrb_cs()			(T2E6XXX_get_rtc1_cntrb_rg() & T2E6XXX_RTC1_CNTRB_CS_BITMASK)
#define T2E6XXX_set_rtc1_cntrb_bme(v)		(T2E6XXX_set_rtc1_cntrb_rg((T2E6XXX_get_rtc1_cntrb_rg() & ~T2E6XXX_RTC1_CNTRB_BME_BITMASK) | (v & T2E6XXX_RTC1_CNTRB_BME_BITMASK)))
#define T2E6XXX_get_rtc1_cntrb_bme()		(T2E6XXX_get_rtc1_cntrb_rg() & T2E6XXX_RTC1_CNTRB_BME_BITMASK)
#define T2E6XXX_set_rtc1_cntrb_tpe(v)		(T2E6XXX_set_rtc1_cntrb_rg((T2E6XXX_get_rtc1_cntrb_rg() & ~T2E6XXX_RTC1_CNTRB_TPE_BITMASK) | (v & T2E6XXX_RTC1_CNTRB_TPE_BITMASK)))
#define T2E6XXX_get_rtc1_cntrb_tpe()		(T2E6XXX_get_rtc1_cntrb_rg() & T2E6XXX_RTC1_CNTRB_TPE_BITMASK)
#define T2E6XXX_set_rtc1_cntrb_tie(v)		(T2E6XXX_set_rtc1_cntrb_rg((T2E6XXX_get_rtc1_cntrb_rg() & ~T2E6XXX_RTC1_CNTRB_TIE_BITMASK) | (v & T2E6XXX_RTC1_CNTRB_TIE_BITMASK)))
#define T2E6XXX_get_rtc1_cntrb_tie()		(T2E6XXX_get_rtc1_cntrb_rg() & T2E6XXX_RTC1_CNTRB_TIE_BITMASK)
#define T2E6XXX_set_rtc1_cntrb_kie(v)		(T2E6XXX_set_rtc1_cntrb_rg((T2E6XXX_get_rtc1_cntrb_rg() & ~T2E6XXX_RTC1_CNTRB_KIE_BITMASK) | (v & T2E6XXX_RTC1_CNTRB_KIE_BITMASK)))
#define T2E6XXX_get_rtc1_cntrb_kie()		(T2E6XXX_get_rtc1_cntrb_rg() & T2E6XXX_RTC1_CNTRB_KIE_BITMASK)
#define T2E6XXX_set_rtc1_cntrb_wde(v)		(T2E6XXX_set_rtc1_cntrb_rg((T2E6XXX_get_rtc1_cntrb_rg() & ~T2E6XXX_RTC1_CNTRB_WDE_BITMASK) | (v & T2E6XXX_RTC1_CNTRB_WDE_BITMASK)))
#define T2E6XXX_get_rtc1_cntrb_wde()		(T2E6XXX_get_rtc1_cntrb_rg() & T2E6XXX_RTC1_CNTRB_WDE_BITMASK)
#define T2E6XXX_set_rtc1_cntrb_wds(v)		(T2E6XXX_set_rtc1_cntrb_rg((T2E6XXX_get_rtc1_cntrb_rg() & ~T2E6XXX_RTC1_CNTRB_WDS_BITMASK) | (v & T2E6XXX_RTC1_CNTRB_WDS_BITMASK)))
#define T2E6XXX_get_rtc1_cntrb_wds()		(T2E6XXX_get_rtc1_cntrb_rg() & T2E6XXX_RTC1_CNTRB_WDS_BITMASK)

	// direct bit set macros
#define T2E6XXX_SET_RTC1_CNTRA_PRS_OFF		(T2E6XXX_set_rtc1_cntra_prs(T2E6XXX_RTC1_CNTRA_PRS_OFF))
#define T2E6XXX_SET_RTC1_CNTRA_PRS_ON		(T2E6XXX_set_rtc1_cntra_prs(T2E6XXX_RTC1_CNTRA_PRS_ON))
#define T2E6XXX_SET_RTC1_CNTRA_PAB_OFF		(T2E6XXX_set_rtc1_cntra_pab(T2E6XXX_RTC1_CNTRA_PAB_OFF))
#define T2E6XXX_SET_RTC1_CNTRA_PAB_ON		(T2E6XXX_set_rtc1_cntra_pab(T2E6XXX_RTC1_CNTRA_PAB_ON))
#define T2E6XXX_CLEAR_RTC1_CNTRA_TDF		(T2E6XXX_set_rtc1_cntra_tdf(T2E6XXX_RTC1_CNTRA_TDF_OFF))
#define T2E6XXX_CLEAR_RTC1_CNTRA_KSF		(T2E6XXX_set_rtc1_cntra_ksf(T2E6XXX_RTC1_CNTRA_KSF_OFF))
#define T2E6XXX_CLEAR_RTC1_CNTRA_WDF		(T2E6XXX_set_rtc1_cntra_wdf(T2E6XXX_RTC1_CNTRA_WDF_OFF))

#define T2E6XXX_SET_RTC1_CNTRB_TE_OFF		(T2E6XXX_set_rtc1_cntrb_te(T2E6XXX_RTC1_CNTRB_TE_OFF))
#define T2E6XXX_SET_RTC1_CNTRB_TE_ON		(T2E6XXX_set_rtc1_cntrb_te(T2E6XXX_RTC1_CNTRB_TE_ON))
#define T2E6XXX_SET_RTC1_CNTRB_CS_OFF		(T2E6XXX_set_rtc1_cntrb_cs(T2E6XXX_RTC1_CNTRB_CS_OFF))
#define T2E6XXX_SET_RTC1_CNTRB_CS_ON		(T2E6XXX_set_rtc1_cntrb_cs(T2E6XXX_RTC1_CNTRB_CS_ON))
#define T2E6XXX_SET_RTC1_CNTRB_BME_OFF		(T2E6XXX_set_rtc1_cntrb_bme(T2E6XXX_RTC1_CNTRB_BME_OFF))
#define T2E6XXX_SET_RTC1_CNTRB_BME_ON		(T2E6XXX_set_rtc1_cntrb_bme(T2E6XXX_RTC1_CNTRB_BME_ON))
#define T2E6XXX_SET_RTC1_CNTRB_TPE_OFF		(T2E6XXX_set_rtc1_cntrb_tpe(T2E6XXX_RTC1_CNTRB_TPE_OFF))
#define T2E6XXX_SET_RTC1_CNTRB_TPE_ON		(T2E6XXX_set_rtc1_cntrb_tpe(T2E6XXX_RTC1_CNTRB_TPE_ON))
#define T2E6XXX_SET_RTC1_CNTRB_TIE_OFF		(T2E6XXX_set_rtc1_cntrb_tie(T2E6XXX_RTC1_CNTRB_TIE_OFF))
#define T2E6XXX_SET_RTC1_CNTRB_TIE_ON		(T2E6XXX_set_rtc1_cntrb_tie(T2E6XXX_RTC1_CNTRB_TIE_ON))
#define T2E6XXX_SET_RTC1_CNTRB_KIE_OFF		(T2E6XXX_set_rtc1_cntrb_kie(T2E6XXX_RTC1_CNTRB_KIE_OFF))
#define T2E6XXX_SET_RTC1_CNTRB_KIE_ON		(T2E6XXX_set_rtc1_cntrb_kie(T2E6XXX_RTC1_CNTRB_KIE_ON))
#define T2E6XXX_SET_RTC1_CNTRB_WDE_OFF		(T2E6XXX_set_rtc1_cntrb_wde(T2E6XXX_RTC1_CNTRB_WDE_OFF))
#define T2E6XXX_SET_RTC1_CNTRB_WDE_ON		(T2E6XXX_set_rtc1_cntrb_wde(T2E6XXX_RTC1_CNTRB_WDE_ON))
#define T2E6XXX_SET_RTC1_CNTRB_WDS_OFF		(T2E6XXX_set_rtc1_cntrb_wds(T2E6XXX_RTC1_CNTRB_WDS_OFF))
#define T2E6XXX_SET_RTC1_CNTRB_WDS_ON		(T2E6XXX_set_rtc1_cntrb_wds(T2E6XXX_RTC1_CNTRB_WDS_ON))

	// condition check macros (for use in IF() and other conditional operators)
#define T2E6XXX_RTC1_CNTRA_BLF1_IS_ON		(T2E6XXX_get_rtc1_cntra_blf1() == T2E6XXX_RTC1_CNTRA_BLF1_ON)
#define T2E6XXX_RTC1_CNTRA_BLF2_IS_ON		(T2E6XXX_get_rtc1_cntra_blf2() == T2E6XXX_RTC1_CNTRA_BLF2_ON)
#define T2E6XXX_RTC1_CNTRA_PRS_IS_ON		(T2E6XXX_get_rtc1_cntra_prs() == T2E6XXX_RTC1_CNTRA_PRS_ON)
#define T2E6XXX_RTC1_CNTRA_PAB_IS_ON		(T2E6XXX_get_rtc1_cntra_pab() == T2E6XXX_RTC1_CNTRA_PAB_ON)
#define T2E6XXX_RTC1_CNTRA_TDF_IS_ON		(T2E6XXX_get_rtc1_cntra_tdf() == T2E6XXX_RTC1_CNTRA_TDF_ON)
#define T2E6XXX_RTC1_CNTRA_KSF_IS_ON		(T2E6XXX_get_rtc1_cntra_ksf() == T2E6XXX_RTC1_CNTRA_KSF_ON)
#define T2E6XXX_RTC1_CNTRA_WDF_IS_ON		(T2E6XXX_get_rtc1_cntra_wdf() == T2E6XXX_RTC1_CNTRA_WDF_ON)
#define T2E6XXX_RTC1_CNTRA_IRQF_IS_ON		(T2E6XXX_get_rtc1_cntra_irqf() == T2E6XXX_RTC1_CNTRA_IRQF_ON)

#define T2E6XXX_RTC1_CNTRB_TE_IS_ON			(T2E6XXX_get_rtc1_cntrb_te() == T2E6XXX_RTC1_CNTRB_TE_ON)
#define T2E6XXX_RTC1_CNTRB_CS_IS_ON			(T2E6XXX_get_rtc1_cntrb_cs() == T2E6XXX_RTC1_CNTRB_CS_ON)
#define T2E6XXX_RTC1_CNTRB_BME_IS_ON		(T2E6XXX_get_rtc1_cntrb_bme() == T2E6XXX_RTC1_CNTRB_BME_ON)
#define T2E6XXX_RTC1_CNTRB_TPE_IS_ON		(T2E6XXX_get_rtc1_cntrb_tpe() == T2E6XXX_RTC1_CNTRB_TPE_ON)
#define T2E6XXX_RTC1_CNTRB_TIE_IS_ON		(T2E6XXX_get_rtc1_cntrb_tie() == T2E6XXX_RTC1_CNTRB_TIE_ON)
#define T2E6XXX_RTC1_CNTRB_KIE_IS_ON		(T2E6XXX_get_rtc1_cntrb_kie() == T2E6XXX_RTC1_CNTRB_KIE_ON)
#define T2E6XXX_RTC1_CNTRB_WDE_IS_ON		(T2E6XXX_get_rtc1_cntrb_wde() == T2E6XXX_RTC1_CNTRB_WDE_ON)
#define T2E6XXX_RTC1_CNTRB_WDS_IS_ON		(T2E6XXX_get_rtc1_cntrb_wds() == T2E6XXX_RTC1_CNTRB_WDS_ON)



//------------ T2E6XXX_GPIO_DATA_RG GPIO data macros -------------
#define T2E6XXX_get_gpio_data_rg()			((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_GPIO_DATA_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
#define T2E6XXX_set_gpio_data_rg(v)			(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_GPIO_DATA_RG_ADDR) = ((T2E6XXX_IO_DATA_TYPE)v)

	// dedicated bit specific macros
#define T2E6XXX_get_gpio0_data()			(T2E6XXX_get_gpio_data_rg() & T2E6XXX_GPIO0_DATA_BITMASK)
#define T2E6XXX_set_gpio0_data(v)			(T2E6XXX_set_gpio_data_rg((T2E6XXX_get_gpio_data_rg() & ~T2E6XXX_GPIO0_DATA_BITMASK) | (v & T2E6XXX_GPIO0_DATA_BITMASK)))
#define T2E6XXX_get_gpio1_data()			(T2E6XXX_get_gpio_data_rg() & T2E6XXX_GPIO1_DATA_BITMASK)
#define T2E6XXX_set_gpio1_data(v)			(T2E6XXX_set_gpio_data_rg((T2E6XXX_get_gpio_data_rg() & ~T2E6XXX_GPIO1_DATA_BITMASK) | (v & T2E6XXX_GPIO1_DATA_BITMASK)))
#define T2E6XXX_get_gpio2_data()			(T2E6XXX_get_gpio_data_rg() & T2E6XXX_GPIO2_DATA_BITMASK)
#define T2E6XXX_set_gpio2_data(v)			(T2E6XXX_set_gpio_data_rg((T2E6XXX_get_gpio_data_rg() & ~T2E6XXX_GPIO2_DATA_BITMASK) | (v & T2E6XXX_GPIO2_DATA_BITMASK)))
#define T2E6XXX_get_gpio3_data()			(T2E6XXX_get_gpio_data_rg() & T2E6XXX_GPIO3_DATA_BITMASK)
#define T2E6XXX_set_gpio3_data(v)			(T2E6XXX_set_gpio_data_rg((T2E6XXX_get_gpio_data_rg() & ~T2E6XXX_GPIO3_DATA_BITMASK) | (v & T2E6XXX_GPIO3_DATA_BITMASK)))
#define T2E6XXX_get_gpio4_data()			(T2E6XXX_get_gpio_data_rg() & T2E6XXX_GPIO4_DATA_BITMASK)
#define T2E6XXX_set_gpio4_data(v)			(T2E6XXX_set_gpio_data_rg((T2E6XXX_get_gpio_data_rg() & ~T2E6XXX_GPIO4_DATA_BITMASK) | (v & T2E6XXX_GPIO4_DATA_BITMASK)))
#define T2E6XXX_get_gpio5_data()			(T2E6XXX_get_gpio_data_rg() & T2E6XXX_GPIO5_DATA_BITMASK)
#define T2E6XXX_set_gpio5_data(v)			(T2E6XXX_set_gpio_data_rg((T2E6XXX_get_gpio_data_rg() & ~T2E6XXX_GPIO5_DATA_BITMASK) | (v & T2E6XXX_GPIO5_DATA_BITMASK)))
#define T2E6XXX_get_gpio6_data()			(T2E6XXX_get_gpio_data_rg() & T2E6XXX_GPIO6_DATA_BITMASK)
#define T2E6XXX_set_gpio6_data(v)			(T2E6XXX_set_gpio_data_rg((T2E6XXX_get_gpio_data_rg() & ~T2E6XXX_GPIO6_DATA_BITMASK) | (v & T2E6XXX_GPIO6_DATA_BITMASK)))
#define T2E6XXX_get_gpio7_data()			(T2E6XXX_get_gpio_data_rg() & T2E6XXX_GPIO7_DATA_BITMASK)
#define T2E6XXX_set_gpio7_data(v)			(T2E6XXX_set_gpio_data_rg((T2E6XXX_get_gpio_data_rg() & ~T2E6XXX_GPIO7_DATA_BITMASK) | (v & T2E6XXX_GPIO7_DATA_BITMASK)))

	// direct bit set macros
#define T2E6XXX_SET_GPIO0_DATA_OFF			(T2E6XXX_set_gpio0_data(T2E6XXX_GPIO0_DATA_OFF))
#define T2E6XXX_SET_GPIO0_DATA_ON			(T2E6XXX_set_gpio0_data(T2E6XXX_GPIO0_DATA_ON))
#define T2E6XXX_SET_GPIO1_DATA_OFF			(T2E6XXX_set_gpio1_data(T2E6XXX_GPIO1_DATA_OFF))
#define T2E6XXX_SET_GPIO1_DATA_ON			(T2E6XXX_set_gpio1_data(T2E6XXX_GPIO1_DATA_ON))
#define T2E6XXX_SET_GPIO2_DATA_OFF			(T2E6XXX_set_gpio2_data(T2E6XXX_GPIO2_DATA_OFF))
#define T2E6XXX_SET_GPIO2_DATA_ON			(T2E6XXX_set_gpio2_data(T2E6XXX_GPIO2_DATA_ON))
#define T2E6XXX_SET_GPIO3_DATA_OFF			(T2E6XXX_set_gpio3_data(T2E6XXX_GPIO3_DATA_OFF))
#define T2E6XXX_SET_GPIO3_DATA_ON			(T2E6XXX_set_gpio3_data(T2E6XXX_GPIO3_DATA_ON))
#define T2E6XXX_SET_GPIO4_DATA_OFF			(T2E6XXX_set_gpio4_data(T2E6XXX_GPIO4_DATA_OFF))
#define T2E6XXX_SET_GPIO4_DATA_ON			(T2E6XXX_set_gpio4_data(T2E6XXX_GPIO4_DATA_ON))
#define T2E6XXX_SET_GPIO5_DATA_OFF			(T2E6XXX_set_gpio5_data(T2E6XXX_GPIO5_DATA_OFF))
#define T2E6XXX_SET_GPIO5_DATA_ON			(T2E6XXX_set_gpio5_data(T2E6XXX_GPIO5_DATA_ON))
#define T2E6XXX_SET_GPIO6_DATA_OFF			(T2E6XXX_set_gpio6_data(T2E6XXX_GPIO6_DATA_OFF))
#define T2E6XXX_SET_GPIO6_DATA_ON			(T2E6XXX_set_gpio6_data(T2E6XXX_GPIO6_DATA_ON))
#define T2E6XXX_SET_GPIO7_DATA_OFF			(T2E6XXX_set_gpio7_data(T2E6XXX_GPIO7_DATA_OFF))
#define T2E6XXX_SET_GPIO7_DATA_ON			(T2E6XXX_set_gpio7_data(T2E6XXX_GPIO7_DATA_ON))

	// condition check macros (for use in IF() and other conditional operators)
#define T2E6XXX_GPIO0_DATA_IS_ON			(T2E6XXX_get_gpio0_data() == T2E6XXX_GPIO0_DATA_ON)
#define T2E6XXX_GPIO1_DATA_IS_ON			(T2E6XXX_get_gpio1_data() == T2E6XXX_GPIO1_DATA_ON)
#define T2E6XXX_GPIO2_DATA_IS_ON			(T2E6XXX_get_gpio2_data() == T2E6XXX_GPIO2_DATA_ON)
#define T2E6XXX_GPIO3_DATA_IS_ON			(T2E6XXX_get_gpio3_data() == T2E6XXX_GPIO3_DATA_ON)
#define T2E6XXX_GPIO4_DATA_IS_ON			(T2E6XXX_get_gpio4_data() == T2E6XXX_GPIO4_DATA_ON)
#define T2E6XXX_GPIO5_DATA_IS_ON			(T2E6XXX_get_gpio5_data() == T2E6XXX_GPIO5_DATA_ON)
#define T2E6XXX_GPIO6_DATA_IS_ON			(T2E6XXX_get_gpio6_data() == T2E6XXX_GPIO6_DATA_ON)
#define T2E6XXX_GPIO7_DATA_IS_ON			(T2E6XXX_get_gpio7_data() == T2E6XXX_GPIO7_DATA_ON)



//------------ T2E6XXX_GPIO_DIR_RG GPIO direction macros ---------
#define T2E6XXX_get_gpio_dir_rg()			((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_GPIO_DIR_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
#define T2E6XXX_set_gpio_dir_rg(v)			(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_GPIO_DIR_RG_ADDR) = ((T2E6XXX_IO_DATA_TYPE)v)

	// dedicated bit specific macros
#define T2E6XXX_get_gpio0_dir()				(T2E6XXX_get_gpio_dir_rg() & T2E6XXX_GPIO0_DIR_BITMASK)
#define T2E6XXX_set_gpio0_dir(v)			(T2E6XXX_set_gpio_dir_rg((T2E6XXX_get_gpio_dir_rg() & ~T2E6XXX_GPIO0_DIR_BITMASK) | (v & T2E6XXX_GPIO0_DIR_BITMASK)))
#define T2E6XXX_get_gpio1_dir()				(T2E6XXX_get_gpio_dir_rg() & T2E6XXX_GPIO1_DIR_BITMASK)
#define T2E6XXX_set_gpio1_dir(v)			(T2E6XXX_set_gpio_dir_rg((T2E6XXX_get_gpio_dir_rg() & ~T2E6XXX_GPIO1_DIR_BITMASK) | (v & T2E6XXX_GPIO1_DIR_BITMASK)))
#define T2E6XXX_get_gpio2_dir()				(T2E6XXX_get_gpio_dir_rg() & T2E6XXX_GPIO2_DIR_BITMASK)
#define T2E6XXX_set_gpio2_dir(v)			(T2E6XXX_set_gpio_dir_rg((T2E6XXX_get_gpio_dir_rg() & ~T2E6XXX_GPIO2_DIR_BITMASK) | (v & T2E6XXX_GPIO2_DIR_BITMASK)))
#define T2E6XXX_get_gpio3_dir()				(T2E6XXX_get_gpio_dir_rg() & T2E6XXX_GPIO3_DIR_BITMASK)
#define T2E6XXX_set_gpio3_dir(v)			(T2E6XXX_set_gpio_dir_rg((T2E6XXX_get_gpio_dir_rg() & ~T2E6XXX_GPIO3_DIR_BITMASK) | (v & T2E6XXX_GPIO3_DIR_BITMASK)))
#define T2E6XXX_get_gpio4_dir()				(T2E6XXX_get_gpio_dir_rg() & T2E6XXX_GPIO4_DIR_BITMASK)
#define T2E6XXX_set_gpio4_dir(v)			(T2E6XXX_set_gpio_dir_rg((T2E6XXX_get_gpio_dir_rg() & ~T2E6XXX_GPIO4_DIR_BITMASK) | (v & T2E6XXX_GPIO4_DIR_BITMASK)))
#define T2E6XXX_get_gpio5_dir()				(T2E6XXX_get_gpio_dir_rg() & T2E6XXX_GPIO5_DIR_BITMASK)
#define T2E6XXX_set_gpio5_dir(v)			(T2E6XXX_set_gpio_dir_rg((T2E6XXX_get_gpio_dir_rg() & ~T2E6XXX_GPIO5_DIR_BITMASK) | (v & T2E6XXX_GPIO5_DIR_BITMASK)))
#define T2E6XXX_get_gpio6_dir()				(T2E6XXX_get_gpio_dir_rg() & T2E6XXX_GPIO6_DIR_BITMASK)
#define T2E6XXX_set_gpio6_dir(v)			(T2E6XXX_set_gpio_dir_rg((T2E6XXX_get_gpio_dir_rg() & ~T2E6XXX_GPIO6_DIR_BITMASK) | (v & T2E6XXX_GPIO6_DIR_BITMASK)))
#define T2E6XXX_get_gpio7_dir()				(T2E6XXX_get_gpio_dir_rg() & T2E6XXX_GPIO7_DIR_BITMASK)
#define T2E6XXX_set_gpio7_dir(v)			(T2E6XXX_set_gpio_dir_rg((T2E6XXX_get_gpio_dir_rg() & ~T2E6XXX_GPIO7_DIR_BITMASK) | (v & T2E6XXX_GPIO7_DIR_BITMASK)))

	// direct bit set macros
#define T2E6XXX_SET_GPIO0_DIR_INPUT			(T2E6XXX_set_gpio0_dir(T2E6XXX_GPIO0_DIR_INPUT))
#define T2E6XXX_SET_GPIO0_DIR_OUTPUT		(T2E6XXX_set_gpio0_dir(T2E6XXX_GPIO0_DIR_OUTPUT))
#define T2E6XXX_SET_GPIO1_DIR_INPUT			(T2E6XXX_set_gpio1_dir(T2E6XXX_GPIO1_DIR_INPUT))
#define T2E6XXX_SET_GPIO1_DIR_OUTPUT		(T2E6XXX_set_gpio1_dir(T2E6XXX_GPIO1_DIR_OUTPUT))
#define T2E6XXX_SET_GPIO2_DIR_INPUT			(T2E6XXX_set_gpio2_dir(T2E6XXX_GPIO2_DIR_INPUT))
#define T2E6XXX_SET_GPIO2_DIR_OUTPUT		(T2E6XXX_set_gpio2_dir(T2E6XXX_GPIO2_DIR_OUTPUT))
#define T2E6XXX_SET_GPIO3_DIR_INPUT			(T2E6XXX_set_gpio3_dir(T2E6XXX_GPIO3_DIR_INPUT))
#define T2E6XXX_SET_GPIO3_DIR_OUTPUT		(T2E6XXX_set_gpio3_dir(T2E6XXX_GPIO3_DIR_OUTPUT))
#define T2E6XXX_SET_GPIO4_DIR_INPUT			(T2E6XXX_set_gpio4_dir(T2E6XXX_GPIO4_DIR_INPUT))
#define T2E6XXX_SET_GPIO4_DIR_OUTPUT		(T2E6XXX_set_gpio4_dir(T2E6XXX_GPIO4_DIR_OUTPUT))
#define T2E6XXX_SET_GPIO5_DIR_INPUT			(T2E6XXX_set_gpio5_dir(T2E6XXX_GPIO5_DIR_INPUT))
#define T2E6XXX_SET_GPIO5_DIR_OUTPUT		(T2E6XXX_set_gpio5_dir(T2E6XXX_GPIO5_DIR_OUTPUT))
#define T2E6XXX_SET_GPIO6_DIR_INPUT			(T2E6XXX_set_gpio6_dir(T2E6XXX_GPIO6_DIR_INPUT))
#define T2E6XXX_SET_GPIO6_DIR_OUTPUT		(T2E6XXX_set_gpio6_dir(T2E6XXX_GPIO6_DIR_OUTPUT))
#define T2E6XXX_SET_GPIO7_DIR_INPUT			(T2E6XXX_set_gpio7_dir(T2E6XXX_GPIO7_DIR_INPUT))
#define T2E6XXX_SET_GPIO7_DIR_OUTPUT		(T2E6XXX_set_gpio7_dir(T2E6XXX_GPIO7_DIR_OUTPUT))

	// condition check macros (for use in IF() and other conditional operators)
#define T2E6XXX_GPIO0_DIR_IS_OUTPUT			(T2E6XXX_get_gpio0_dir() == T2E6XXX_GPIO0_DIR_OUTPUT)
#define T2E6XXX_GPIO1_DIR_IS_OUTPUT			(T2E6XXX_get_gpio1_dir() == T2E6XXX_GPIO1_DIR_OUTPUT)
#define T2E6XXX_GPIO2_DIR_IS_OUTPUT			(T2E6XXX_get_gpio2_dir() == T2E6XXX_GPIO2_DIR_OUTPUT)
#define T2E6XXX_GPIO3_DIR_IS_OUTPUT			(T2E6XXX_get_gpio3_dir() == T2E6XXX_GPIO3_DIR_OUTPUT)
#define T2E6XXX_GPIO4_DIR_IS_OUTPUT			(T2E6XXX_get_gpio4_dir() == T2E6XXX_GPIO4_DIR_OUTPUT)
#define T2E6XXX_GPIO5_DIR_IS_OUTPUT			(T2E6XXX_get_gpio5_dir() == T2E6XXX_GPIO5_DIR_OUTPUT)
#define T2E6XXX_GPIO6_DIR_IS_OUTPUT			(T2E6XXX_get_gpio6_dir() == T2E6XXX_GPIO6_DIR_OUTPUT)
#define T2E6XXX_GPIO7_DIR_IS_OUTPUT			(T2E6XXX_get_gpio7_dir() == T2E6XXX_GPIO7_DIR_OUTPUT)



//----------------------------------------------------------------------------
//------------ Macros to control T2E6XXX controller DSP environment
//----------------------------------------------------------------------------

//------------ SBSRAM access macros ------------------------------
// input parameters: a = address {byte addressing}, v = {input data}
#define T2E6XXX_write_sbsram(a,v)			(T2E6XXX_SBSRAM_LEN_IS_128KX32 ? ((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_SBSRAM_AREA_SADDR + ((a) & (T2E6XXX_SBSRAM_LEN_128KX32 - 1)))) =((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_SBSRAM_DATA_BITMASK)):\
												((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_SBSRAM_AREA_SADDR + ((a) & (T2E6XXX_SBSRAM_LEN_512KX32 - 1)))) =((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_SBSRAM_DATA_BITMASK)))

#define T2E6XXX_read_sbsram(a)				(T2E6XXX_SBSRAM_LEN_IS_128KX32 ? ((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_SBSRAM_AREA_SADDR + ((a) & (T2E6XXX_SBSRAM_LEN_128KX32 - 1)))) & T2E6XXX_SBSRAM_DATA_BITMASK):\
												((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_SBSRAM_AREA_SADDR + ((a) & (T2E6XXX_SBSRAM_LEN_512KX32 - 1)))) & T2E6XXX_SBSRAM_DATA_BITMASK))



//------------ T2E6XXX_DCM_RESET_RG DCM (PIOX2/SIOX/ASIOX) reset control
#define T2E6XXX_set_dcm_reset_rg(v)			(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_DCM_RESET_RG_ADDR)=((T2E6XXX_IO_DATA_TYPE)v)
#define T2E6XXX_get_dcm_reset_rg()			((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_DCM_RESET_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)

	// dedicated bit-specific macros with V = {T2E6XXX_{PIOX/SIOX}_RESET_ON,T2E6XXX_{PIOX/SIOX}_RESET_OFF}
#define T2E6XXX_set_piox_dcm_reset(v)		T2E6XXX_set_dcm_reset_rg((T2E6XXX_get_dcm_reset_rg() & ~T2E6XXX_PIOX_DCM_RESET_BITMASK) | (v & T2E6XXX_PIOX_DCM_RESET_BITMASK))
#define T2E6XXX_get_piox_dcm_reset()		(T2E6XXX_get_dcm_reset_rg() & T2E6XXX_PIOX_DCM_RESET_BITMASK)
#define T2E6XXX_set_siox_dcm_reset(v)		T2E6XXX_set_dcm_reset_rg((T2E6XXX_get_dcm_reset_rg() & ~T2E6XXX_SIOX_DCM_RESET_BITMASK) | (v & T2E6XXX_SIOX_DCM_RESET_BITMASK))
#define T2E6XXX_get_siox_dcm_reset()		(T2E6XXX_get_dcm_reset_rg() & T2E6XXX_SIOX_DCM_RESET_BITMASK)

	// direct bit-specific set/get macros
#define T2E6XXX_SET_PIOX_DCM_RESET_OFF		T2E6XXX_set_piox_dcm_reset(T2E6XXX_PIOX_DCM_RESET_OFF)
#define T2E6XXX_SET_PIOX_DCM_RESET_ON		T2E6XXX_set_piox_dcm_reset(T2E6XXX_PIOX_DCM_RESET_ON)
#define T2E6XXX_PIOX_DCM_RESET_IS_ON		(T2E6XXX_get_piox_dcm_reset() == T2E6XXX_PIOX_DCM_RESET_ON)

#define T2E6XXX_SET_SIOX_DCM_RESET_OFF		T2E6XXX_set_siox_dcm_reset(T2E6XXX_SIOX_DCM_RESET_OFF)
#define T2E6XXX_SET_SIOX_DCM_RESET_ON		T2E6XXX_set_siox_dcm_reset(T2E6XXX_SIOX_DCM_RESET_ON)
#define T2E6XXX_SIOX_DCM_RESET_IS_ON		(T2E6XXX_get_siox_dcm_reset() == T2E6XXX_SIOX_DCM_RESET_ON)

#define T2E6XXX_SET_ASIOX_DCM_RESET_OFF		T2E6XXX_SET_SIOX_DCM_RESET_OFF
#define T2E6XXX_SET_ASIOX_DCM_RESET_ON		T2E6XXX_SET_SIOX_DCM_RESET_ON
#define T2E6XXX_ASIOX_DCM_RESET_IS_ON		T2E6XXX_SIOX_DCM_RESET_IS_ON


//------------ PIOX2 access macros -------------------------------
// 32-bit PIOX-ASYNC section
// a - address (PIOX-ASYNC DCM 32-bit dataword index in linear addressing), v - value
#define T2E6XXX_write_piox_async_w32(a,v)	(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_ASYNC_AREA_SADDR + (((a) & T2E6713_PIOX_ASYNC_WINDEX_MAX_W32) << 2))) = ((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_PIOX_ASYNC_AREA_DATA_BITMASK)
#define T2E6XXX_read_piox_async_w32(a)		((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_ASYNC_AREA_SADDR + (((a) & T2E6713_PIOX_ASYNC_WINDEX_MAX_W32) << 2))) & T2E6XXX_PIOX_ASYNC_AREA_DATA_BITMASK)


// 32-bit PIOX-SYNC area #0 section
// a - address (PIOX-SYNC0 DCM 32-bit dataword index in linear addressing), v - value
#define T2E6XXX_write_piox_sync0_w32(a,v)	(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_SYNC0_AREA_SADDR + (((a) & T2E6XXX_PIOX_SYNC0_WINDEX_MAX_W32) << 2))) = ((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_PIOX_SYNC0_AREA_DATA_BITMASK)
#define T2E6XXX_read_piox_sync0_w32(a)		((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_SYNC0_AREA_SADDR + (((a) & T2E6XXX_PIOX_SYNC0_WINDEX_MAX_W32) << 2))) & T2E6XXX_PIOX_SYNC0_AREA_DATA_BITMASK)

// a - address (PIOX-SYNC0 DCM 16-bit dataword index in linear addressing), v - value
#define T2E6XXX_write_piox_sync0_w16(a,v)	(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_SYNC0_AREA_SADDR + (((a) & T2E6XXX_PIOX_SYNC0_WINDEX_MAX_W16) << 1))) = ((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_PIOX_SYNC0_AREA_DATA_BITMASK)
#define T2E6XXX_read_piox_sync0_w16(a)		((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_SYNC0_AREA_SADDR + (((a) & T2E6XXX_PIOX_SYNC0_WINDEX_MAX_W16) << 1))) & T2E6XXX_PIOX_SYNC0_AREA_DATA_BITMASK)

// a - address (PIOX-SYNC0 DCM 8-bit dataword index in linear addressing), v - value
#define T2E6XXX_write_piox_sync0_byte(a,v)	(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_SYNC0_AREA_SADDR + ((a) & T2E6XXX_PIOX_SYNC0_WINDEX_MAX_BYTE))) = ((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_PIOX_SYNC0_AREA_DATA_BITMASK)
#define T2E6XXX_read_piox_sync0_byte(a)		((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_SYNC0_AREA_SADDR + ((a) & T2E6XXX_PIOX_SYNC0_WINDEX_MAX_BYTE))) & T2E6XXX_PIOX_SYNC0_AREA_DATA_BITMASK)


// 32-bit PIOX-SYNC area #1 section
// a - address (PIOX-SYNC1 DCM 32-bit dataword index in linear addressing), v - value
#define T2E6XXX_write_piox_sync1_w32(a,v)	(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_SYNC1_AREA_SADDR + (((a) & T2E6XXX_PIOX_SYNC1_WINDEX_MAX_W32) << 2))) = ((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_PIOX_SYNC1_AREA_DATA_BITMASK)
#define T2E6XXX_read_piox_sync1_w32(a)		((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_SYNC1_AREA_SADDR + (((a) & T2E6XXX_PIOX_SYNC1_WINDEX_MAX_W32) << 2))) & T2E6XXX_PIOX_SYNC1_AREA_DATA_BITMASK)

// a - address (PIOX-SYNC1 DCM 16-bit dataword index in linear addressing), v - value
#define T2E6XXX_write_piox_sync1_w16(a,v)	(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_SYNC1_AREA_SADDR + (((a) & T2E6XXX_PIOX_SYNC1_WINDEX_MAX_W16) << 1))) = ((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_PIOX_SYNC1_AREA_DATA_BITMASK)
#define T2E6XXX_read_piox_sync1_w16(a)		((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_SYNC1_AREA_SADDR + (((a) & T2E6XXX_PIOX_SYNC1_WINDEX_MAX_W16) << 1))) & T2E6XXX_PIOX_SYNC1_AREA_DATA_BITMASK)

// a - address (PIOX-SYNC1 DCM 8-bit dataword index in linear addressing), v - value
#define T2E6XXX_write_piox_sync1_byte(a,v)	(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_SYNC1_AREA_SADDR + ((a) & T2E6XXX_PIOX_SYNC1_WINDEX_MAX_BYTE))) = ((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_PIOX_SYNC1_AREA_DATA_BITMASK)
#define T2E6XXX_read_piox_sync1_byte(a)		((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_PIOX_SYNC1_AREA_SADDR + ((a) & T2E6XXX_PIOX_SYNC1_WINDEX_MAX_BYTE))) & T2E6XXX_PIOX_SYNC1_AREA_DATA_BITMASK)



//------------ 16-bit ASIOX rev.D access macros ------------------
// a - address (ASIOX DCM 16-bit dataword index in linear addressing), v - value
// Note that ASIOX 16-bit datawords are aligned at 32-bit boundaries,
// so only 16-bit LSW of 32-bit dataword are valid!!!
#define T2E6XXX_write_asiox_w16(a,v)		(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_ASIOX_AREA_SADDR + (((a) & T2E6XXX_ASIOX_WINDEX_MAX_W16) << 2))) = ((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_ASIOX_AREA_DATA_BITMASK)
#define T2E6XXX_read_asiox_w16(a)			((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_ASIOX_AREA_SADDR + (((a) & T2E6XXX_ASIOX_WINDEX_MAX_W16) << 2))) & T2E6XXX_ASIOX_AREA_DATA_BITMASK)



//------------ HCX-SYNC access macros ----------------------------
//------------ T2E6XXX_HCX_SYNC_PAGE_RG HCX-SYNC Address Extension register macros
#define T2E6XXX_get_hcx_sync_page_rg()		((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_HCX_SYNC_PAGE_RG_ADDR) & T2E6XXX_HCX_SYNC_PAGE_RG_BITMASK)
#define T2E6XXX_set_hcx_sync_page_rg(v)		(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_HCX_SYNC_PAGE_RG_ADDR) = ((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_HCX_SYNC_PAGE_RG_BITMASK)

// 32-bit Sync section HCX
// These macros are used to access data within HCX-SYNC area only
// For accessing HCX-SYNC DCM over HCX_SYNC_AREA_LEN use universal HCX-SYNC macros
// a - address (HCX-SYNC DCM 32-bit dataword index in linear addressing within HCX-SYNC area length), v - value
#define T2E6XXX_write_hcx_sync_area_w32(a,v)	(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_HCX_SYNC_AREA_SADDR + (((a) & T2E6XXX_HCX_SYNC_AREA_WINDEX_MAX_W32) << 2))) = ((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_HCX_SYNC_AREA_DATA_BITMASK)
#define T2E6XXX_read_hcx_sync_area_w32(a)		((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_HCX_SYNC_AREA_SADDR + (((a) & T2E6XXX_HCX_SYNC_AREA_WINDEX_MAX_W32) << 2))) & T2E6XXX_HCX_SYNC_AREA_DATA_BITMASK)

// a - address (HCX-SYNC DCM 16-bit dataword index in linear addressing within HCX-SYNC area length), v - value
#define T2E6XXX_write_hcx_sync_area_w16(a,v)	(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_HCX_SYNC_AREA_SADDR + (((a) & T2E6XXX_HCX_SYNC_AREA_WINDEX_MAX_W16) << 1))) = ((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_HCX_SYNC_AREA_DATA_BITMASK)
#define T2E6XXX_read_hcx_sync_area_w16(a)		((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_HCX_SYNC_AREA_SADDR + (((a) & T2E6XXX_HCX_SYNC_AREA_WINDEX_MAX_W16) << 1))) & T2E6XXX_HCX_SYNC_AREA_DATA_BITMASK)

// a - address (HCX-SYNC DCM 8-bit dataword index in linear addressing within HCX-SYNC area length), v - value
#define T2E6XXX_write_hcx_sync_area_byte(a,v)	(*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_HCX_SYNC_AREA_SADDR + ((a) & T2E6XXX_HCX_SYNC_AREA_WINDEX_MAX_BYTE))) = ((T2E6XXX_IO_DATA_TYPE)v & T2E6XXX_HCX_SYNC_AREA_DATA_BITMASK)
#define T2E6XXX_read_hcx_sync_area_byte(a)		((*(T2E6XXX_IO_DATA_TYPE *) (T2E6XXX_HCX_SYNC_AREA_SADDR + ((a) & T2E6XXX_HCX_SYNC_AREA_WINDEX_MAX_BYTE))) & T2E6XXX_HCX_SYNC_AREA_DATA_BITMASK)



//------------ T2E6XXX_SIOX_XIO_CNF_RG SIOX rev.B SX_TM/XIO-0/1 pins control macros
#define T2E6XXX_get_siox_xio_cnf_rg()		((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_SIOX_XIO_CNF_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
#define T2E6XXX_set_siox_xio_cnf_rg(v)		(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_SIOX_XIO_CNF_RG_ADDR) = ((T2E6XXX_IO_DATA_TYPE)v)

	// dedicated bit specific macros
#define T2E6XXX_get_siox_xio0_cnf()			(T2E6XXX_get_siox_xio_cnf_rg() & T2E6XXX_SIOX_XIO0_CNF_BITMASK)
#define T2E6XXX_set_siox_xio0_cnf(v)		(T2E6XXX_set_siox_xio_cnf_rg((T2E6XXX_get_siox_xio_cnf_rg() & ~T2E6XXX_SIOX_XIO0_CNF_BITMASK) | (v & T2E6XXX_SIOX_XIO0_CNF_BITMASK)))
#define T2E6XXX_get_siox_xio1_cnf()			(T2E6XXX_get_siox_xio_cnf_rg() & T2E6XXX_SIOX_XIO1_CNF_BITMASK)
#define T2E6XXX_set_siox_xio1_cnf(v)		(T2E6XXX_set_siox_xio_cnf_rg((T2E6XXX_get_siox_xio_cnf_rg() & ~T2E6XXX_SIOX_XIO1_CNF_BITMASK) | (v & T2E6XXX_SIOX_XIO1_CNF_BITMASK)))

	// direct bit set macros
#define T2E6XXX_SET_SIOX_XIO0_CNF_INPUT		(T2E6XXX_set_siox_xio0_cnf(T2E6XXX_SIOX_XIO0_CNF_INPUT))
#define T2E6XXX_SET_SIOX_XIO0_CNF_OUTPUT	(T2E6XXX_set_siox_xio0_cnf(T2E6XXX_SIOX_XIO0_CNF_OUTPUT))
#define T2E6XXX_SET_SIOX_XIO0_CNF_TOUT0		(T2E6XXX_set_siox_xio0_cnf(T2E6XXX_SIOX_XIO0_CNF_TOUT0))
#define T2E6XXX_SET_SIOX_XIO1_CNF_INPUT		(T2E6XXX_set_siox_xio1_cnf(T2E6XXX_SIOX_XIO1_CNF_INPUT))
#define T2E6XXX_SET_SIOX_XIO1_CNF_OUTPUT	(T2E6XXX_set_siox_xio1_cnf(T2E6XXX_SIOX_XIO1_CNF_OUTPUT))
#define T2E6XXX_SET_SIOX_XIO1_CNF_TOUT1		(T2E6XXX_set_siox_xio1_cnf(T2E6XXX_SIOX_XIO1_CNF_TOUT1))

	// condition check macros (for use in IF() and other conditional operators)
#define T2E6XXX_SIOX_XIO0_CNF_IS_INPUT		(T2E6XXX_get_siox_xio0_cnf() == T2E6XXX_SIOX_XIO0_CNF_INPUT)
#define T2E6XXX_SIOX_XIO0_CNF_IS_OUTPUT		(T2E6XXX_get_siox_xio0_cnf() == T2E6XXX_SIOX_XIO0_CNF_OUTPUT)
#define T2E6XXX_SIOX_XIO0_CNF_IS_TOUT0		(T2E6XXX_get_siox_xio0_cnf() == T2E6XXX_SIOX_XIO0_CNF_TOUT0)
#define T2E6XXX_SIOX_XIO1_CNF_IS_INPUT		(T2E6XXX_get_siox_xio1_cnf() == T2E6XXX_SIOX_XIO1_CNF_INPUT)
#define T2E6XXX_SIOX_XIO1_CNF_IS_OUTPUT		(T2E6XXX_get_siox_xio1_cnf() == T2E6XXX_SIOX_XIO1_CNF_OUTPUT)
#define T2E6XXX_SIOX_XIO1_CNF_IS_TOUT1		(T2E6XXX_get_siox_xio1_cnf() == T2E6XXX_SIOX_XIO1_CNF_TOUT1)



//------------ T2E6XXX_SIOX_XIO_DATA_RG SIOX rev.B SX_TM/XIO-0/1 pins output data macros
#define T2E6XXX_get_siox_xio_data_rg()		((*(T2E6XXX_IO_DATA_TYPE *) T2E6XXX_SIOX_XIO_DATA_RG_ADDR) & T2E6XXX_CNTR_DATA_BITMASK)
#define T2E6XXX_set_siox_xio_data_rg(v)		(*(T2E6XXX_IO_DATA_TYPE *)  T2E6XXX_SIOX_XIO_DATA_RG_ADDR) = ((T2E6XXX_IO_DATA_TYPE)v)

	// dedicated bit specific macros
#define T2E6XXX_get_siox_xio0_data()		(T2E6XXX_get_siox_xio_data_rg() & T2E6XXX_SIOX_XIO0_DATA_BITMASK)
#define T2E6XXX_set_siox_xio0_data(v)		(T2E6XXX_set_siox_xio_data_rg((T2E6XXX_get_siox_xio_data_rg() & ~T2E6XXX_SIOX_XIO0_DATA_BITMASK) | (v & T2E6XXX_SIOX_XIO0_DATA_BITMASK)))
#define T2E6XXX_get_siox_xio1_data()		(T2E6XXX_get_siox_xio_data_rg() & T2E6XXX_SIOX_XIO1_DATA_BITMASK)
#define T2E6XXX_set_siox_xio1_data(v)		(T2E6XXX_set_siox_xio_data_rg((T2E6XXX_get_siox_xio_data_rg() & ~T2E6XXX_SIOX_XIO1_DATA_BITMASK) | (v & T2E6XXX_SIOX_XIO1_DATA_BITMASK)))

	// direct bit set macros
#define T2E6XXX_SET_SIOX_XIO0_DATA_OFF		(T2E6XXX_set_siox_xio0_data(T2E6XXX_SIOX_XIO0_DATA_OFF))
#define T2E6XXX_SET_SIOX_XIO0_DATA_ON		(T2E6XXX_set_siox_xio0_data(T2E6XXX_SIOX_XIO0_DATA_ON))
#define T2E6XXX_SET_SIOX_XIO1_DATA_OFF		(T2E6XXX_set_siox_xio1_data(T2E6XXX_SIOX_XIO1_DATA_OFF))
#define T2E6XXX_SET_SIOX_XIO1_DATA_ON		(T2E6XXX_set_siox_xio1_data(T2E6XXX_SIOX_XIO1_DATA_ON))

	// condition check macros (for use in IF() and other conditional operators)
#define T2E6XXX_SIOX_XIO0_DATA_IS_ON		(T2E6XXX_get_siox_xio0_data() == T2E6XXX_SIOX_XIO0_DATA_ON)
#define T2E6XXX_SIOX_XIO1_DATA_IS_ON		(T2E6XXX_get_siox_xio1_data() == T2E6XXX_SIOX_XIO1_DATA_ON)

//============================================================================
#endif
